@@ -29,10 +29,14 @@
 #include <ccode/valaccodenode.h>
 #include <ccode/valaccodelinedirective.h>
 
+
+
+
 struct _ValaCCodeCaseStatementPrivate {
 	ValaCCodeExpression* _expression;
 	GeeList* statements;
 };
+
 #define VALA_CCODE_CASE_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_CASE_STATEMENT, ValaCCodeCaseStatementPrivate))
 enum  {
 	VALA_CCODE_CASE_STATEMENT_DUMMY_PROPERTY,
@@ -43,9 +47,10 @@ static gpointer vala_ccode_case_statement_parent_class = NULL;
 static void vala_ccode_case_statement_dispose (GObject * obj);
 
 
+
 ValaCCodeCaseStatement* vala_ccode_case_statement_new (ValaCCodeExpression* expression) {
 	ValaCCodeCaseStatement * self;
-	g_return_val_if_fail (expression == NULL || VALA_IS_CCODE_EXPRESSION (expression), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expression), NULL);
 	self = g_object_newv (VALA_TYPE_CCODE_CASE_STATEMENT, 0, NULL);
 	vala_ccode_case_statement_set_expression (self, expression);
 	return self;
@@ -59,7 +64,7 @@ ValaCCodeCaseStatement* vala_ccode_case_statement_new (ValaCCodeExpression* expr
  */
 void vala_ccode_case_statement_add_statement (ValaCCodeCaseStatement* self, ValaCCodeStatement* stmt) {
 	g_return_if_fail (VALA_IS_CCODE_CASE_STATEMENT (self));
-	g_return_if_fail (stmt == NULL || VALA_IS_CCODE_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_CCODE_STATEMENT (stmt));
 	gee_collection_add (GEE_COLLECTION (self->priv->statements), stmt);
 }
 
@@ -67,26 +72,24 @@ void vala_ccode_case_statement_add_statement (ValaCCodeCaseStatement* self, Vala
 static void vala_ccode_case_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeCaseStatement * self;
 	self = VALA_CCODE_CASE_STATEMENT (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
 	vala_ccode_writer_write_string (writer, "case ");
-	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_case_statement_get_expression (self)), writer);
+	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_expression), writer);
 	vala_ccode_writer_write_string (writer, ":");
 	vala_ccode_writer_write_newline (writer);
 	{
 		GeeList* stmt_collection;
-		GeeIterator* stmt_it;
+		int stmt_it;
 		stmt_collection = self->priv->statements;
-		stmt_it = gee_iterable_iterator (GEE_ITERABLE (stmt_collection));
-		while (gee_iterator_next (stmt_it)) {
+		for (stmt_it = 0; stmt_it < gee_collection_get_size (GEE_COLLECTION (stmt_collection)); stmt_it = stmt_it + 1) {
 			ValaCCodeStatement* stmt;
-			stmt = ((ValaCCodeStatement*) gee_iterator_get (stmt_it));
+			stmt = ((ValaCCodeStatement*) (gee_list_get (GEE_LIST (stmt_collection), stmt_it)));
 			{
 				vala_ccode_node_write (VALA_CCODE_NODE (stmt), writer);
 				(stmt == NULL ? NULL : (stmt = (g_object_unref (stmt), NULL)));
 			}
 		}
-		(stmt_it == NULL ? NULL : (stmt_it = (g_object_unref (stmt_it), NULL)));
 	}
 }
 
@@ -146,9 +149,9 @@ static void vala_ccode_case_statement_class_init (ValaCCodeCaseStatementClass *
 }
 
 
-static void vala_ccode_case_statement_init (ValaCCodeCaseStatement * self) {
+static void vala_ccode_case_statement_instance_init (ValaCCodeCaseStatement * self) {
 	self->priv = VALA_CCODE_CASE_STATEMENT_GET_PRIVATE (self);
-	self->priv->statements = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_STATEMENT, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->statements = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_STATEMENT, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 }
 
 
@@ -164,7 +167,7 @@ static void vala_ccode_case_statement_dispose (GObject * obj) {
 GType vala_ccode_case_statement_get_type (void) {
 	static GType vala_ccode_case_statement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_case_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeCaseStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_case_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeCaseStatement), 0, (GInstanceInitFunc) vala_ccode_case_statement_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeCaseStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_case_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeCaseStatement), 0, (GInstanceInitFunc) vala_ccode_case_statement_instance_init };
 		vala_ccode_case_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeCaseStatement", &g_define_type_info, 0);
 	}
 	return vala_ccode_case_statement_type_id;
