@@ -1,6 +1,6 @@
 /* valaccodecastexpression.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -76,8 +76,9 @@ static void vala_ccode_cast_expression_real_write (ValaCCodeNode* base, ValaCCod
 	vala_ccode_writer_write_string (writer, "((");
 	vala_ccode_writer_write_string (writer, self->priv->_type_name);
 	vala_ccode_writer_write_string (writer, ") ");
+	vala_ccode_writer_write_string (writer, "(");
 	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_inner), writer);
-	vala_ccode_writer_write_string (writer, ")");
+	vala_ccode_writer_write_string (writer, "))");
 }
 
 
@@ -97,7 +98,7 @@ void vala_ccode_cast_expression_set_inner (ValaCCodeCastExpression* self, ValaCC
 }
 
 
-char* vala_ccode_cast_expression_get_type_name (ValaCCodeCastExpression* self) {
+const char* vala_ccode_cast_expression_get_type_name (ValaCCodeCastExpression* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_CAST_EXPRESSION (self), NULL);
 	return self->priv->_type_name;
 }
@@ -159,7 +160,7 @@ static void vala_ccode_cast_expression_class_init (ValaCCodeCastExpressionClass
 }
 
 
-static void vala_ccode_cast_expression_init (ValaCCodeCastExpression * self) {
+static void vala_ccode_cast_expression_instance_init (ValaCCodeCastExpression * self) {
 	self->priv = VALA_CCODE_CAST_EXPRESSION_GET_PRIVATE (self);
 }
 
@@ -176,7 +177,7 @@ static void vala_ccode_cast_expression_dispose (GObject * obj) {
 GType vala_ccode_cast_expression_get_type (void) {
 	static GType vala_ccode_cast_expression_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_cast_expression_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeCastExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_cast_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeCastExpression), 0, (GInstanceInitFunc) vala_ccode_cast_expression_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeCastExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_cast_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeCastExpression), 0, (GInstanceInitFunc) vala_ccode_cast_expression_instance_init };
 		vala_ccode_cast_expression_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION, "ValaCCodeCastExpression", &g_define_type_info, 0);
 	}
 	return vala_ccode_cast_expression_type_id;
