@@ -22,8 +22,8 @@
 
 #include <ccode/valaccodecommaexpression.h>
 #include <gee/arraylist.h>
-#include <gee/list.h>
-#include <gee/readonlycollection.h>
+#include <gee/collection.h>
+#include <gee/readonlylist.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ccode/valaccodenode.h>
@@ -34,6 +34,7 @@
 struct _ValaCCodeCommaExpressionPrivate {
 	GeeList* inner;
 };
+
 #define VALA_CCODE_COMMA_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_COMMA_EXPRESSION, ValaCCodeCommaExpressionPrivate))
 enum  {
 	VALA_CCODE_COMMA_EXPRESSION_DUMMY_PROPERTY
@@ -51,14 +52,14 @@ static void vala_ccode_comma_expression_dispose (GObject * obj);
  */
 void vala_ccode_comma_expression_append_expression (ValaCCodeCommaExpression* self, ValaCCodeExpression* expr) {
 	g_return_if_fail (VALA_IS_CCODE_COMMA_EXPRESSION (self));
-	g_return_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_CCODE_EXPRESSION (expr));
 	gee_collection_add (GEE_COLLECTION (self->priv->inner), expr);
 }
 
 
-GeeCollection* vala_ccode_comma_expression_get_inner (ValaCCodeCommaExpression* self) {
+GeeList* vala_ccode_comma_expression_get_inner (ValaCCodeCommaExpression* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_COMMA_EXPRESSION (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->inner)));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->inner));
 }
 
 
@@ -66,17 +67,16 @@ static void vala_ccode_comma_expression_real_write (ValaCCodeNode* base, ValaCCo
 	ValaCCodeCommaExpression * self;
 	gboolean first;
 	self = VALA_CCODE_COMMA_EXPRESSION (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	first = TRUE;
 	vala_ccode_writer_write_string (writer, "(");
 	{
 		GeeList* expr_collection;
-		GeeIterator* expr_it;
+		int expr_it;
 		expr_collection = self->priv->inner;
-		expr_it = gee_iterable_iterator (GEE_ITERABLE (expr_collection));
-		while (gee_iterator_next (expr_it)) {
+		for (expr_it = 0; expr_it < gee_collection_get_size (GEE_COLLECTION (expr_collection)); expr_it = expr_it + 1) {
 			ValaCCodeExpression* expr;
-			expr = ((ValaCCodeExpression*) gee_iterator_get (expr_it));
+			expr = ((ValaCCodeExpression*) (gee_list_get (GEE_LIST (expr_collection), expr_it)));
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ", ");
@@ -87,7 +87,6 @@ static void vala_ccode_comma_expression_real_write (ValaCCodeNode* base, ValaCCo
 				(expr == NULL ? NULL : (expr = (g_object_unref (expr), NULL)));
 			}
 		}
-		(expr_it == NULL ? NULL : (expr_it = (g_object_unref (expr_it), NULL)));
 	}
 	vala_ccode_writer_write_string (writer, ")");
 }
@@ -111,9 +110,9 @@ static void vala_ccode_comma_expression_class_init (ValaCCodeCommaExpressionClas
 }
 
 
-static void vala_ccode_comma_expression_init (ValaCCodeCommaExpression * self) {
+static void vala_ccode_comma_expression_instance_init (ValaCCodeCommaExpression * self) {
 	self->priv = VALA_CCODE_COMMA_EXPRESSION_GET_PRIVATE (self);
-	self->priv->inner = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->inner = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 }
 
 
@@ -128,7 +127,7 @@ static void vala_ccode_comma_expression_dispose (GObject * obj) {
 GType vala_ccode_comma_expression_get_type (void) {
 	static GType vala_ccode_comma_expression_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_comma_expression_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeCommaExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_comma_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeCommaExpression), 0, (GInstanceInitFunc) vala_ccode_comma_expression_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeCommaExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_comma_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeCommaExpression), 0, (GInstanceInitFunc) vala_ccode_comma_expression_instance_init };
 		vala_ccode_comma_expression_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION, "ValaCCodeCommaExpression", &g_define_type_info, 0);
 	}
 	return vala_ccode_comma_expression_type_id;
