@@ -33,6 +33,7 @@ struct _ValaCCodeConditionalExpressionPrivate {
 	ValaCCodeExpression* _true_expression;
 	ValaCCodeExpression* _false_expression;
 };
+
 #define VALA_CCODE_CONDITIONAL_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_CONDITIONAL_EXPRESSION, ValaCCodeConditionalExpressionPrivate))
 enum  {
 	VALA_CCODE_CONDITIONAL_EXPRESSION_DUMMY_PROPERTY,
@@ -50,9 +51,9 @@ ValaCCodeConditionalExpression* vala_ccode_conditional_expression_new (ValaCCode
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeConditionalExpression * self;
-	g_return_val_if_fail (cond == NULL || VALA_IS_CCODE_EXPRESSION (cond), NULL);
-	g_return_val_if_fail (true_expr == NULL || VALA_IS_CCODE_EXPRESSION (true_expr), NULL);
-	g_return_val_if_fail (false_expr == NULL || VALA_IS_CCODE_EXPRESSION (false_expr), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (cond), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (true_expr), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (false_expr), NULL);
 	__params = g_new0 (GParameter, 3);
 	__params_it = __params;
 	__params_it->name = "condition";
@@ -80,7 +81,7 @@ ValaCCodeConditionalExpression* vala_ccode_conditional_expression_new (ValaCCode
 static void vala_ccode_conditional_expression_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeConditionalExpression * self;
 	self = VALA_CCODE_CONDITIONAL_EXPRESSION (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, "(");
 	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_condition), writer);
 	vala_ccode_writer_write_string (writer, " ? ");
@@ -192,7 +193,7 @@ static void vala_ccode_conditional_expression_class_init (ValaCCodeConditionalEx
 }
 
 
-static void vala_ccode_conditional_expression_init (ValaCCodeConditionalExpression * self) {
+static void vala_ccode_conditional_expression_instance_init (ValaCCodeConditionalExpression * self) {
 	self->priv = VALA_CCODE_CONDITIONAL_EXPRESSION_GET_PRIVATE (self);
 }
 
@@ -210,7 +211,7 @@ static void vala_ccode_conditional_expression_dispose (GObject * obj) {
 GType vala_ccode_conditional_expression_get_type (void) {
 	static GType vala_ccode_conditional_expression_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_conditional_expression_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeConditionalExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_conditional_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeConditionalExpression), 0, (GInstanceInitFunc) vala_ccode_conditional_expression_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeConditionalExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_conditional_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeConditionalExpression), 0, (GInstanceInitFunc) vala_ccode_conditional_expression_instance_init };
 		vala_ccode_conditional_expression_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION, "ValaCCodeConditionalExpression", &g_define_type_info, 0);
 	}
 	return vala_ccode_conditional_expression_type_id;
