@@ -69,7 +69,7 @@ static void vala_ccode_constant_real_write (ValaCCodeNode* base, ValaCCodeWriter
 }
 
 
-char* vala_ccode_constant_get_name (ValaCCodeConstant* self) {
+const char* vala_ccode_constant_get_name (ValaCCodeConstant* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_CONSTANT (self), NULL);
 	return self->priv->_name;
 }
@@ -124,7 +124,7 @@ static void vala_ccode_constant_class_init (ValaCCodeConstantClass * klass) {
 }
 
 
-static void vala_ccode_constant_init (ValaCCodeConstant * self) {
+static void vala_ccode_constant_instance_init (ValaCCodeConstant * self) {
 	self->priv = VALA_CCODE_CONSTANT_GET_PRIVATE (self);
 }
 
@@ -140,7 +140,7 @@ static void vala_ccode_constant_dispose (GObject * obj) {
 GType vala_ccode_constant_get_type (void) {
 	static GType vala_ccode_constant_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_constant_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeConstantClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_constant_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeConstant), 0, (GInstanceInitFunc) vala_ccode_constant_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeConstantClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_constant_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeConstant), 0, (GInstanceInitFunc) vala_ccode_constant_instance_init };
 		vala_ccode_constant_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION, "ValaCCodeConstant", &g_define_type_info, 0);
 	}
 	return vala_ccode_constant_type_id;
