@@ -40,7 +40,7 @@ static gpointer vala_ccode_continue_statement_parent_class = NULL;
 static void vala_ccode_continue_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeContinueStatement * self;
 	self = VALA_CCODE_CONTINUE_STATEMENT (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
 	vala_ccode_writer_write_string (writer, "continue;");
 	vala_ccode_writer_write_newline (writer);
@@ -63,14 +63,14 @@ static void vala_ccode_continue_statement_class_init (ValaCCodeContinueStatement
 }
 
 
-static void vala_ccode_continue_statement_init (ValaCCodeContinueStatement * self) {
+static void vala_ccode_continue_statement_instance_init (ValaCCodeContinueStatement * self) {
 }
 
 
 GType vala_ccode_continue_statement_get_type (void) {
 	static GType vala_ccode_continue_statement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_continue_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeContinueStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_continue_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeContinueStatement), 0, (GInstanceInitFunc) vala_ccode_continue_statement_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeContinueStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_continue_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeContinueStatement), 0, (GInstanceInitFunc) vala_ccode_continue_statement_instance_init };
 		vala_ccode_continue_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeContinueStatement", &g_define_type_info, 0);
 	}
 	return vala_ccode_continue_statement_type_id;
