@@ -53,13 +53,15 @@ struct _ValaCCodeDeclaration {
 	ValaCCodeStatement parent_instance;
 	ValaCCodeDeclarationPrivate * priv;
 };
+
 struct _ValaCCodeDeclarationClass {
 	ValaCCodeStatementClass parent_class;
 };
 
+
 ValaCCodeDeclaration* vala_ccode_declaration_new (const char* type_name);
 void vala_ccode_declaration_add_declarator (ValaCCodeDeclaration* self, ValaCCodeDeclarator* decl);
-char* vala_ccode_declaration_get_type_name (ValaCCodeDeclaration* self);
+const char* vala_ccode_declaration_get_type_name (ValaCCodeDeclaration* self);
 void vala_ccode_declaration_set_type_name (ValaCCodeDeclaration* self, const char* value);
 ValaCCodeModifiers vala_ccode_declaration_get_modifiers (ValaCCodeDeclaration* self);
 void vala_ccode_declaration_set_modifiers (ValaCCodeDeclaration* self, ValaCCodeModifiers value);
