@@ -41,7 +41,7 @@ static gpointer vala_ccode_declarator_parent_class = NULL;
  */
 static void vala_ccode_declarator_real_write_initialization (ValaCCodeDeclarator* self, ValaCCodeWriter* writer) {
 	g_return_if_fail (VALA_IS_CCODE_DECLARATOR (self));
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 }
 
 
@@ -56,14 +56,14 @@ static void vala_ccode_declarator_class_init (ValaCCodeDeclaratorClass * klass)
 }
 
 
-static void vala_ccode_declarator_init (ValaCCodeDeclarator * self) {
+static void vala_ccode_declarator_instance_init (ValaCCodeDeclarator * self) {
 }
 
 
 GType vala_ccode_declarator_get_type (void) {
 	static GType vala_ccode_declarator_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_declarator_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeDeclaratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_declarator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeDeclarator), 0, (GInstanceInitFunc) vala_ccode_declarator_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeDeclaratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_declarator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeDeclarator), 0, (GInstanceInitFunc) vala_ccode_declarator_instance_init };
 		vala_ccode_declarator_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeDeclarator", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
 	return vala_ccode_declarator_type_id;
