@@ -1,6 +1,6 @@
 /* valaccodeenum.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -33,6 +33,7 @@ struct _ValaCCodeEnumPrivate {
 	char* _name;
 	GeeList* values;
 };
+
 #define VALA_CCODE_ENUM_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_ENUM, ValaCCodeEnumPrivate))
 enum  {
 	VALA_CCODE_ENUM_DUMMY_PROPERTY,
@@ -60,7 +61,7 @@ ValaCCodeEnum* vala_ccode_enum_new (const char* name) {
  */
 void vala_ccode_enum_add_value (ValaCCodeEnum* self, ValaCCodeEnumValue* value) {
 	g_return_if_fail (VALA_IS_CCODE_ENUM (self));
-	g_return_if_fail (value == NULL || VALA_IS_CCODE_ENUM_VALUE (value));
+	g_return_if_fail (VALA_IS_CCODE_ENUM_VALUE (value));
 	gee_collection_add (GEE_COLLECTION (self->priv->values), value);
 }
 
@@ -69,7 +70,7 @@ static void vala_ccode_enum_real_write (ValaCCodeNode* base, ValaCCodeWriter* wr
 	ValaCCodeEnum * self;
 	gboolean first;
 	self = VALA_CCODE_ENUM (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	if (self->priv->_name != NULL) {
 		vala_ccode_writer_write_string (writer, "typedef ");
 	}
@@ -78,12 +79,11 @@ static void vala_ccode_enum_real_write (ValaCCodeNode* base, ValaCCodeWriter* wr
 	first = TRUE;
 	{
 		GeeList* value_collection;
-		GeeIterator* value_it;
+		int value_it;
 		value_collection = self->priv->values;
-		value_it = gee_iterable_iterator (GEE_ITERABLE (value_collection));
-		while (gee_iterator_next (value_it)) {
+		for (value_it = 0; value_it < gee_collection_get_size (GEE_COLLECTION (value_collection)); value_it = value_it + 1) {
 			ValaCCodeEnumValue* value;
-			value = ((ValaCCodeEnumValue*) gee_iterator_get (value_it));
+			value = ((ValaCCodeEnumValue*) (gee_list_get (GEE_LIST (value_collection), value_it)));
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ",");
@@ -95,7 +95,6 @@ static void vala_ccode_enum_real_write (ValaCCodeNode* base, ValaCCodeWriter* wr
 				(value == NULL ? NULL : (value = (g_object_unref (value), NULL)));
 			}
 		}
-		(value_it == NULL ? NULL : (value_it = (g_object_unref (value_it), NULL)));
 	}
 	if (!first) {
 		vala_ccode_writer_write_newline (writer);
@@ -110,7 +109,7 @@ static void vala_ccode_enum_real_write (ValaCCodeNode* base, ValaCCodeWriter* wr
 }
 
 
-char* vala_ccode_enum_get_name (ValaCCodeEnum* self) {
+const char* vala_ccode_enum_get_name (ValaCCodeEnum* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_ENUM (self), NULL);
 	return self->priv->_name;
 }
@@ -165,9 +164,9 @@ static void vala_ccode_enum_class_init (ValaCCodeEnumClass * klass) {
 }
 
 
-static void vala_ccode_enum_init (ValaCCodeEnum * self) {
+static void vala_ccode_enum_instance_init (ValaCCodeEnum * self) {
 	self->priv = VALA_CCODE_ENUM_GET_PRIVATE (self);
-	self->priv->values = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_ENUM_VALUE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->values = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_ENUM_VALUE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 }
 
 
@@ -183,7 +182,7 @@ static void vala_ccode_enum_dispose (GObject * obj) {
 GType vala_ccode_enum_get_type (void) {
 	static GType vala_ccode_enum_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_enum_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeEnumClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_enum_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeEnum), 0, (GInstanceInitFunc) vala_ccode_enum_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeEnumClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_enum_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeEnum), 0, (GInstanceInitFunc) vala_ccode_enum_instance_init };
 		vala_ccode_enum_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeEnum", &g_define_type_info, 0);
 	}
 	return vala_ccode_enum_type_id;
