@@ -65,7 +65,7 @@ static void vala_ccode_enum_value_real_write (ValaCCodeNode* base, ValaCCodeWrit
 }
 
 
-char* vala_ccode_enum_value_get_name (ValaCCodeEnumValue* self) {
+const char* vala_ccode_enum_value_get_name (ValaCCodeEnumValue* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_ENUM_VALUE (self), NULL);
 	return self->priv->_name;
 }
@@ -143,7 +143,7 @@ static void vala_ccode_enum_value_class_init (ValaCCodeEnumValueClass * klass) {
 }
 
 
-static void vala_ccode_enum_value_init (ValaCCodeEnumValue * self) {
+static void vala_ccode_enum_value_instance_init (ValaCCodeEnumValue * self) {
 	self->priv = VALA_CCODE_ENUM_VALUE_GET_PRIVATE (self);
 }
 
@@ -160,7 +160,7 @@ static void vala_ccode_enum_value_dispose (GObject * obj) {
 GType vala_ccode_enum_value_get_type (void) {
 	static GType vala_ccode_enum_value_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_enum_value_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeEnumValueClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_enum_value_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeEnumValue), 0, (GInstanceInitFunc) vala_ccode_enum_value_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeEnumValueClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_enum_value_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeEnumValue), 0, (GInstanceInitFunc) vala_ccode_enum_value_instance_init };
 		vala_ccode_enum_value_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeEnumValue", &g_define_type_info, 0);
 	}
 	return vala_ccode_enum_value_type_id;
