@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +20,10 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaccodeexpression.h"
+#include <ccode/valaccodeexpression.h>
+
+
+
 
 enum  {
 	VALA_CCODE_EXPRESSION_DUMMY_PROPERTY
@@ -28,22 +31,20 @@ enum  {
 static gpointer vala_ccode_expression_parent_class = NULL;
 
 
-static void vala_ccode_expression_class_init (ValaCCodeExpressionClass * klass)
-{
+
+static void vala_ccode_expression_class_init (ValaCCodeExpressionClass * klass) {
 	vala_ccode_expression_parent_class = g_type_class_peek_parent (klass);
 }
 
 
-static void vala_ccode_expression_init (ValaCCodeExpression * self)
-{
+static void vala_ccode_expression_instance_init (ValaCCodeExpression * self) {
 }
 
 
-GType vala_ccode_expression_get_type (void)
-{
+GType vala_ccode_expression_get_type (void) {
 	static GType vala_ccode_expression_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_expression_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeExpression), 0, (GInstanceInitFunc) vala_ccode_expression_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeExpression), 0, (GInstanceInitFunc) vala_ccode_expression_instance_init };
 		vala_ccode_expression_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeExpression", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
 	return vala_ccode_expression_type_id;
