@@ -80,22 +80,20 @@ static void vala_ccode_expression_statement_real_write (ValaCCodeNode* base, Val
 		 to improve code readability*/
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		ccomma = (_tmp1 = (_tmp0 = self->priv->_expression, (VALA_IS_CCODE_COMMA_EXPRESSION (_tmp0) ? ((ValaCCodeCommaExpression*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+		ccomma = (_tmp1 = (_tmp0 = self->priv->_expression, (VALA_IS_CCODE_COMMA_EXPRESSION (_tmp0) ? ((ValaCCodeCommaExpression*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
 		{
-			GeeCollection* expr_collection;
-			GeeIterator* expr_it;
+			GeeList* expr_collection;
+			int expr_it;
 			expr_collection = vala_ccode_comma_expression_get_inner (ccomma);
-			expr_it = gee_iterable_iterator (GEE_ITERABLE (expr_collection));
-			while (gee_iterator_next (expr_it)) {
+			for (expr_it = 0; expr_it < gee_collection_get_size (GEE_COLLECTION (expr_collection)); expr_it = expr_it + 1) {
 				ValaCCodeExpression* expr;
-				expr = ((ValaCCodeExpression*) gee_iterator_get (expr_it));
+				expr = ((ValaCCodeExpression*) (gee_list_get (GEE_LIST (expr_collection), expr_it)));
 				{
 					vala_ccode_expression_statement_write_expression (self, writer, expr);
 					(expr == NULL ? NULL : (expr = (g_object_unref (expr), NULL)));
 				}
 			}
 			(expr_collection == NULL ? NULL : (expr_collection = (g_object_unref (expr_collection), NULL)));
-			(expr_it == NULL ? NULL : (expr_it = (g_object_unref (expr_it), NULL)));
 		}
 		(ccomma == NULL ? NULL : (ccomma = (g_object_unref (ccomma), NULL)));
 	} else {
@@ -105,7 +103,7 @@ static void vala_ccode_expression_statement_real_write (ValaCCodeNode* base, Val
 			ValaCCodeParenthesizedExpression* cpar;
 			_tmp3 = NULL;
 			_tmp2 = NULL;
-			cpar = (_tmp3 = (_tmp2 = self->priv->_expression, (VALA_IS_CCODE_PARENTHESIZED_EXPRESSION (_tmp2) ? ((ValaCCodeParenthesizedExpression*) _tmp2) : NULL)), (_tmp3 == NULL ? NULL : g_object_ref (_tmp3)));
+			cpar = (_tmp3 = (_tmp2 = self->priv->_expression, (VALA_IS_CCODE_PARENTHESIZED_EXPRESSION (_tmp2) ? ((ValaCCodeParenthesizedExpression*) (_tmp2)) : NULL)), (_tmp3 == NULL ? NULL : g_object_ref (_tmp3)));
 			vala_ccode_expression_statement_write_expression (self, writer, vala_ccode_parenthesized_expression_get_inner (cpar));
 			(cpar == NULL ? NULL : (cpar = (g_object_unref (cpar), NULL)));
 		} else {
@@ -183,7 +181,7 @@ static void vala_ccode_expression_statement_class_init (ValaCCodeExpressionState
 }
 
 
-static void vala_ccode_expression_statement_init (ValaCCodeExpressionStatement * self) {
+static void vala_ccode_expression_statement_instance_init (ValaCCodeExpressionStatement * self) {
 	self->priv = VALA_CCODE_EXPRESSION_STATEMENT_GET_PRIVATE (self);
 }
 
@@ -199,7 +197,7 @@ static void vala_ccode_expression_statement_dispose (GObject * obj) {
 GType vala_ccode_expression_statement_get_type (void) {
 	static GType vala_ccode_expression_statement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_expression_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeExpressionStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_expression_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeExpressionStatement), 0, (GInstanceInitFunc) vala_ccode_expression_statement_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeExpressionStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_expression_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeExpressionStatement), 0, (GInstanceInitFunc) vala_ccode_expression_statement_instance_init };
 		vala_ccode_expression_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeExpressionStatement", &g_define_type_info, 0);
 	}
 	return vala_ccode_expression_statement_type_id;
