@@ -77,7 +77,7 @@ static void vala_ccode_formal_parameter_real_write (ValaCCodeNode* base, ValaCCo
 }
 
 
-char* vala_ccode_formal_parameter_get_name (ValaCCodeFormalParameter* self) {
+const char* vala_ccode_formal_parameter_get_name (ValaCCodeFormalParameter* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_FORMAL_PARAMETER (self), NULL);
 	return self->priv->_name;
 }
@@ -93,7 +93,7 @@ void vala_ccode_formal_parameter_set_name (ValaCCodeFormalParameter* self, const
 }
 
 
-char* vala_ccode_formal_parameter_get_type_name (ValaCCodeFormalParameter* self) {
+const char* vala_ccode_formal_parameter_get_type_name (ValaCCodeFormalParameter* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_FORMAL_PARAMETER (self), NULL);
 	return self->priv->_type_name;
 }
@@ -174,7 +174,7 @@ static void vala_ccode_formal_parameter_class_init (ValaCCodeFormalParameterClas
 }
 
 
-static void vala_ccode_formal_parameter_init (ValaCCodeFormalParameter * self) {
+static void vala_ccode_formal_parameter_instance_init (ValaCCodeFormalParameter * self) {
 	self->priv = VALA_CCODE_FORMAL_PARAMETER_GET_PRIVATE (self);
 }
 
@@ -191,7 +191,7 @@ static void vala_ccode_formal_parameter_dispose (GObject * obj) {
 GType vala_ccode_formal_parameter_get_type (void) {
 	static GType vala_ccode_formal_parameter_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_formal_parameter_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFormalParameterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_formal_parameter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFormalParameter), 0, (GInstanceInitFunc) vala_ccode_formal_parameter_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFormalParameterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_formal_parameter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFormalParameter), 0, (GInstanceInitFunc) vala_ccode_formal_parameter_instance_init };
 		vala_ccode_formal_parameter_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeFormalParameter", &g_define_type_info, 0);
 	}
 	return vala_ccode_formal_parameter_type_id;
