@@ -1,6 +1,6 @@
 /* valaccodeforstatement.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -38,6 +38,7 @@ struct _ValaCCodeForStatementPrivate {
 	GeeList* initializer;
 	GeeList* iterator;
 };
+
 #define VALA_CCODE_FOR_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_FOR_STATEMENT, ValaCCodeForStatementPrivate))
 enum  {
 	VALA_CCODE_FOR_STATEMENT_DUMMY_PROPERTY,
@@ -68,7 +69,7 @@ ValaCCodeForStatement* vala_ccode_for_statement_new (ValaCCodeExpression* condit
  */
 void vala_ccode_for_statement_add_initializer (ValaCCodeForStatement* self, ValaCCodeExpression* expr) {
 	g_return_if_fail (VALA_IS_CCODE_FOR_STATEMENT (self));
-	g_return_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_CCODE_EXPRESSION (expr));
 	gee_collection_add (GEE_COLLECTION (self->priv->initializer), expr);
 }
 
@@ -80,7 +81,7 @@ void vala_ccode_for_statement_add_initializer (ValaCCodeForStatement* self, Vala
  */
 void vala_ccode_for_statement_add_iterator (ValaCCodeForStatement* self, ValaCCodeExpression* expr) {
 	g_return_if_fail (VALA_IS_CCODE_FOR_STATEMENT (self));
-	g_return_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_CCODE_EXPRESSION (expr));
 	gee_collection_add (GEE_COLLECTION (self->priv->iterator), expr);
 }
 
@@ -89,19 +90,18 @@ static void vala_ccode_for_statement_real_write (ValaCCodeNode* base, ValaCCodeW
 	ValaCCodeForStatement * self;
 	gboolean first;
 	self = VALA_CCODE_FOR_STATEMENT (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	first = FALSE;
 	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
 	vala_ccode_writer_write_string (writer, "for (");
 	first = TRUE;
 	{
 		GeeList* init_expr_collection;
-		GeeIterator* init_expr_it;
+		int init_expr_it;
 		init_expr_collection = self->priv->initializer;
-		init_expr_it = gee_iterable_iterator (GEE_ITERABLE (init_expr_collection));
-		while (gee_iterator_next (init_expr_it)) {
+		for (init_expr_it = 0; init_expr_it < gee_collection_get_size (GEE_COLLECTION (init_expr_collection)); init_expr_it = init_expr_it + 1) {
 			ValaCCodeExpression* init_expr;
-			init_expr = ((ValaCCodeExpression*) gee_iterator_get (init_expr_it));
+			init_expr = ((ValaCCodeExpression*) (gee_list_get (GEE_LIST (init_expr_collection), init_expr_it)));
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ", ");
@@ -114,7 +114,6 @@ static void vala_ccode_for_statement_real_write (ValaCCodeNode* base, ValaCCodeW
 				(init_expr == NULL ? NULL : (init_expr = (g_object_unref (init_expr), NULL)));
 			}
 		}
-		(init_expr_it == NULL ? NULL : (init_expr_it = (g_object_unref (init_expr_it), NULL)));
 	}
 	vala_ccode_writer_write_string (writer, "; ");
 	if (self->priv->_condition != NULL) {
@@ -124,12 +123,11 @@ static void vala_ccode_for_statement_real_write (ValaCCodeNode* base, ValaCCodeW
 	first = TRUE;
 	{
 		GeeList* it_expr_collection;
-		GeeIterator* it_expr_it;
+		int it_expr_it;
 		it_expr_collection = self->priv->iterator;
-		it_expr_it = gee_iterable_iterator (GEE_ITERABLE (it_expr_collection));
-		while (gee_iterator_next (it_expr_it)) {
+		for (it_expr_it = 0; it_expr_it < gee_collection_get_size (GEE_COLLECTION (it_expr_collection)); it_expr_it = it_expr_it + 1) {
 			ValaCCodeExpression* it_expr;
-			it_expr = ((ValaCCodeExpression*) gee_iterator_get (it_expr_it));
+			it_expr = ((ValaCCodeExpression*) (gee_list_get (GEE_LIST (it_expr_collection), it_expr_it)));
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ", ");
@@ -142,7 +140,6 @@ static void vala_ccode_for_statement_real_write (ValaCCodeNode* base, ValaCCodeW
 				(it_expr == NULL ? NULL : (it_expr = (g_object_unref (it_expr), NULL)));
 			}
 		}
-		(it_expr_it == NULL ? NULL : (it_expr_it = (g_object_unref (it_expr_it), NULL)));
 	}
 	vala_ccode_writer_write_string (writer, ")");
 	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_body), writer);
@@ -227,10 +224,10 @@ static void vala_ccode_for_statement_class_init (ValaCCodeForStatementClass * kl
 }
 
 
-static void vala_ccode_for_statement_init (ValaCCodeForStatement * self) {
+static void vala_ccode_for_statement_instance_init (ValaCCodeForStatement * self) {
 	self->priv = VALA_CCODE_FOR_STATEMENT_GET_PRIVATE (self);
-	self->priv->initializer = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
-	self->priv->iterator = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->initializer = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->iterator = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 }
 
 
@@ -248,7 +245,7 @@ static void vala_ccode_for_statement_dispose (GObject * obj) {
 GType vala_ccode_for_statement_get_type (void) {
 	static GType vala_ccode_for_statement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_for_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeForStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_for_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeForStatement), 0, (GInstanceInitFunc) vala_ccode_for_statement_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeForStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_for_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeForStatement), 0, (GInstanceInitFunc) vala_ccode_for_statement_instance_init };
 		vala_ccode_for_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeForStatement", &g_define_type_info, 0);
 	}
 	return vala_ccode_for_statement_type_id;
