@@ -22,8 +22,8 @@
 
 #include <ccode/valaccodefragment.h>
 #include <gee/arraylist.h>
-#include <gee/list.h>
-#include <gee/readonlycollection.h>
+#include <gee/collection.h>
+#include <gee/readonlylist.h>
 
 
 
@@ -31,6 +31,7 @@
 struct _ValaCCodeFragmentPrivate {
 	GeeList* children;
 };
+
 #define VALA_CCODE_FRAGMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_FRAGMENT, ValaCCodeFragmentPrivate))
 enum  {
 	VALA_CCODE_FRAGMENT_DUMMY_PROPERTY
@@ -50,7 +51,7 @@ static void vala_ccode_fragment_dispose (GObject * obj);
  */
 void vala_ccode_fragment_append (ValaCCodeFragment* self, ValaCCodeNode* node) {
 	g_return_if_fail (VALA_IS_CCODE_FRAGMENT (self));
-	g_return_if_fail (node == NULL || VALA_IS_CCODE_NODE (node));
+	g_return_if_fail (VALA_IS_CCODE_NODE (node));
 	gee_collection_add (GEE_COLLECTION (self->priv->children), node);
 }
 
@@ -60,30 +61,28 @@ void vala_ccode_fragment_append (ValaCCodeFragment* self, ValaCCodeNode* node) {
  *
  * @return children list
  */
-GeeCollection* vala_ccode_fragment_get_children (ValaCCodeFragment* self) {
+GeeList* vala_ccode_fragment_get_children (ValaCCodeFragment* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_FRAGMENT (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_CCODE_NODE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->children)));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_CCODE_NODE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->children));
 }
 
 
 static void vala_ccode_fragment_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeFragment * self;
 	self = VALA_CCODE_FRAGMENT (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	{
 		GeeList* node_collection;
-		GeeIterator* node_it;
+		int node_it;
 		node_collection = self->priv->children;
-		node_it = gee_iterable_iterator (GEE_ITERABLE (node_collection));
-		while (gee_iterator_next (node_it)) {
+		for (node_it = 0; node_it < gee_collection_get_size (GEE_COLLECTION (node_collection)); node_it = node_it + 1) {
 			ValaCCodeNode* node;
-			node = ((ValaCCodeNode*) gee_iterator_get (node_it));
+			node = ((ValaCCodeNode*) (gee_list_get (GEE_LIST (node_collection), node_it)));
 			{
 				vala_ccode_node_write (node, writer);
 				(node == NULL ? NULL : (node = (g_object_unref (node), NULL)));
 			}
 		}
-		(node_it == NULL ? NULL : (node_it = (g_object_unref (node_it), NULL)));
 	}
 }
 
@@ -91,21 +90,19 @@ static void vala_ccode_fragment_real_write (ValaCCodeNode* base, ValaCCodeWriter
 static void vala_ccode_fragment_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeFragment * self;
 	self = VALA_CCODE_FRAGMENT (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	{
 		GeeList* node_collection;
-		GeeIterator* node_it;
+		int node_it;
 		node_collection = self->priv->children;
-		node_it = gee_iterable_iterator (GEE_ITERABLE (node_collection));
-		while (gee_iterator_next (node_it)) {
+		for (node_it = 0; node_it < gee_collection_get_size (GEE_COLLECTION (node_collection)); node_it = node_it + 1) {
 			ValaCCodeNode* node;
-			node = ((ValaCCodeNode*) gee_iterator_get (node_it));
+			node = ((ValaCCodeNode*) (gee_list_get (GEE_LIST (node_collection), node_it)));
 			{
 				vala_ccode_node_write_declaration (node, writer);
 				(node == NULL ? NULL : (node = (g_object_unref (node), NULL)));
 			}
 		}
-		(node_it == NULL ? NULL : (node_it = (g_object_unref (node_it), NULL)));
 	}
 }
 
@@ -113,21 +110,19 @@ static void vala_ccode_fragment_real_write_declaration (ValaCCodeNode* base, Val
 static void vala_ccode_fragment_real_write_combined (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeFragment * self;
 	self = VALA_CCODE_FRAGMENT (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	{
 		GeeList* node_collection;
-		GeeIterator* node_it;
+		int node_it;
 		node_collection = self->priv->children;
-		node_it = gee_iterable_iterator (GEE_ITERABLE (node_collection));
-		while (gee_iterator_next (node_it)) {
+		for (node_it = 0; node_it < gee_collection_get_size (GEE_COLLECTION (node_collection)); node_it = node_it + 1) {
 			ValaCCodeNode* node;
-			node = ((ValaCCodeNode*) gee_iterator_get (node_it));
+			node = ((ValaCCodeNode*) (gee_list_get (GEE_LIST (node_collection), node_it)));
 			{
 				vala_ccode_node_write_combined (node, writer);
 				(node == NULL ? NULL : (node = (g_object_unref (node), NULL)));
 			}
 		}
-		(node_it == NULL ? NULL : (node_it = (g_object_unref (node_it), NULL)));
 	}
 }
 
@@ -152,9 +147,9 @@ static void vala_ccode_fragment_class_init (ValaCCodeFragmentClass * klass) {
 }
 
 
-static void vala_ccode_fragment_init (ValaCCodeFragment * self) {
+static void vala_ccode_fragment_instance_init (ValaCCodeFragment * self) {
 	self->priv = VALA_CCODE_FRAGMENT_GET_PRIVATE (self);
-	self->priv->children = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_NODE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->children = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_NODE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 }
 
 
@@ -169,7 +164,7 @@ static void vala_ccode_fragment_dispose (GObject * obj) {
 GType vala_ccode_fragment_get_type (void) {
 	static GType vala_ccode_fragment_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_fragment_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFragmentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_fragment_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFragment), 0, (GInstanceInitFunc) vala_ccode_fragment_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFragmentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_fragment_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFragment), 0, (GInstanceInitFunc) vala_ccode_fragment_instance_init };
 		vala_ccode_fragment_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeFragment", &g_define_type_info, 0);
 	}
 	return vala_ccode_fragment_type_id;
