@@ -25,7 +25,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <gee/collection.h>
+#include <gee/list.h>
 #include <ccode/valaccodenode.h>
 #include <ccode/valaccodewriter.h>
 
@@ -57,7 +57,7 @@ struct _ValaCCodeFragmentClass {
 
 
 void vala_ccode_fragment_append (ValaCCodeFragment* self, ValaCCodeNode* node);
-GeeCollection* vala_ccode_fragment_get_children (ValaCCodeFragment* self);
+GeeList* vala_ccode_fragment_get_children (ValaCCodeFragment* self);
 ValaCCodeFragment* vala_ccode_fragment_new (void);
 GType vala_ccode_fragment_get_type (void);
 
