@@ -36,6 +36,7 @@ struct _ValaCCodeFunctionPrivate {
 	ValaCCodeBlock* _block;
 	GeeList* parameters;
 };
+
 #define VALA_CCODE_FUNCTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_FUNCTION, ValaCCodeFunctionPrivate))
 enum  {
 	VALA_CCODE_FUNCTION_DUMMY_PROPERTY,
@@ -88,18 +89,16 @@ ValaCCodeFunction* vala_ccode_function_copy (ValaCCodeFunction* self) {
 	 */
 	{
 		GeeList* param_collection;
-		GeeIterator* param_it;
+		int param_it;
 		param_collection = self->priv->parameters;
-		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
-		while (gee_iterator_next (param_it)) {
+		for (param_it = 0; param_it < gee_collection_get_size (GEE_COLLECTION (param_collection)); param_it = param_it + 1) {
 			ValaCCodeFormalParameter* param;
-			param = ((ValaCCodeFormalParameter*) gee_iterator_get (param_it));
+			param = ((ValaCCodeFormalParameter*) (gee_list_get (GEE_LIST (param_collection), param_it)));
 			{
 				gee_collection_add (GEE_COLLECTION (func->priv->parameters), param);
 				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 			}
 		}
-		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
 	}
 	vala_ccode_function_set_block (func, self->priv->_block);
 	return func;
@@ -125,12 +124,11 @@ static void vala_ccode_function_real_write (ValaCCodeNode* base, ValaCCodeWriter
 	first = TRUE;
 	{
 		GeeList* param_collection;
-		GeeIterator* param_it;
+		int param_it;
 		param_collection = self->priv->parameters;
-		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
-		while (gee_iterator_next (param_it)) {
+		for (param_it = 0; param_it < gee_collection_get_size (GEE_COLLECTION (param_collection)); param_it = param_it + 1) {
 			ValaCCodeFormalParameter* param;
-			param = ((ValaCCodeFormalParameter*) gee_iterator_get (param_it));
+			param = ((ValaCCodeFormalParameter*) (gee_list_get (GEE_LIST (param_collection), param_it)));
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ", ");
@@ -141,7 +139,6 @@ static void vala_ccode_function_real_write (ValaCCodeNode* base, ValaCCodeWriter
 				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 			}
 		}
-		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
 	}
 	if (first) {
 		vala_ccode_writer_write_string (writer, "void");
@@ -157,7 +154,7 @@ static void vala_ccode_function_real_write (ValaCCodeNode* base, ValaCCodeWriter
 }
 
 
-char* vala_ccode_function_get_name (ValaCCodeFunction* self) {
+const char* vala_ccode_function_get_name (ValaCCodeFunction* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_FUNCTION (self), NULL);
 	return self->priv->_name;
 }
@@ -185,7 +182,7 @@ void vala_ccode_function_set_modifiers (ValaCCodeFunction* self, ValaCCodeModifi
 }
 
 
-char* vala_ccode_function_get_return_type (ValaCCodeFunction* self) {
+const char* vala_ccode_function_get_return_type (ValaCCodeFunction* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_FUNCTION (self), NULL);
 	return self->priv->_return_type;
 }
@@ -277,9 +274,9 @@ static void vala_ccode_function_class_init (ValaCCodeFunctionClass * klass) {
 }
 
 
-static void vala_ccode_function_init (ValaCCodeFunction * self) {
+static void vala_ccode_function_instance_init (ValaCCodeFunction * self) {
 	self->priv = VALA_CCODE_FUNCTION_GET_PRIVATE (self);
-	self->priv->parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_FORMAL_PARAMETER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_FORMAL_PARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 }
 
 
@@ -297,7 +294,7 @@ static void vala_ccode_function_dispose (GObject * obj) {
 GType vala_ccode_function_get_type (void) {
 	static GType vala_ccode_function_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_function_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFunctionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_function_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFunction), 0, (GInstanceInitFunc) vala_ccode_function_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFunctionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_function_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFunction), 0, (GInstanceInitFunc) vala_ccode_function_instance_init };
 		vala_ccode_function_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeFunction", &g_define_type_info, 0);
 	}
 	return vala_ccode_function_type_id;
