@@ -28,10 +28,14 @@
 #include <string.h>
 #include <ccode/valaccodenode.h>
 
+
+
+
 struct _ValaCCodeFunctionCallPrivate {
 	ValaCCodeExpression* _call;
 	GeeList* arguments;
 };
+
 #define VALA_CCODE_FUNCTION_CALL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_FUNCTION_CALL, ValaCCodeFunctionCallPrivate))
 enum  {
 	VALA_CCODE_FUNCTION_CALL_DUMMY_PROPERTY,
@@ -42,6 +46,7 @@ static gpointer vala_ccode_function_call_parent_class = NULL;
 static void vala_ccode_function_call_dispose (GObject * obj);
 
 
+
 ValaCCodeFunctionCall* vala_ccode_function_call_new (ValaCCodeExpression* call) {
 	ValaCCodeFunctionCall * self;
 	g_return_val_if_fail (call == NULL || VALA_IS_CCODE_EXPRESSION (call), NULL);
@@ -58,7 +63,7 @@ ValaCCodeFunctionCall* vala_ccode_function_call_new (ValaCCodeExpression* call)
  */
 void vala_ccode_function_call_add_argument (ValaCCodeFunctionCall* self, ValaCCodeExpression* expr) {
 	g_return_if_fail (VALA_IS_CCODE_FUNCTION_CALL (self));
-	g_return_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_CCODE_EXPRESSION (expr));
 	gee_collection_add (GEE_COLLECTION (self->priv->arguments), expr);
 }
 
@@ -70,7 +75,7 @@ void vala_ccode_function_call_add_argument (ValaCCodeFunctionCall* self, ValaCCo
  */
 GeeList* vala_ccode_function_call_get_arguments (ValaCCodeFunctionCall* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_FUNCTION_CALL (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, self->priv->arguments));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->arguments));
 }
 
 
@@ -78,18 +83,17 @@ static void vala_ccode_function_call_real_write (ValaCCodeNode* base, ValaCCodeW
 	ValaCCodeFunctionCall * self;
 	gboolean first;
 	self = VALA_CCODE_FUNCTION_CALL (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
-	vala_ccode_node_write (VALA_CCODE_NODE (vala_ccode_function_call_get_call (self)), writer);
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_call), writer);
 	vala_ccode_writer_write_string (writer, " (");
 	first = TRUE;
 	{
 		GeeList* expr_collection;
-		GeeIterator* expr_it;
+		int expr_it;
 		expr_collection = self->priv->arguments;
-		expr_it = gee_iterable_iterator (GEE_ITERABLE (expr_collection));
-		while (gee_iterator_next (expr_it)) {
+		for (expr_it = 0; expr_it < gee_collection_get_size (GEE_COLLECTION (expr_collection)); expr_it = expr_it + 1) {
 			ValaCCodeExpression* expr;
-			expr = gee_iterator_get (expr_it);
+			expr = ((ValaCCodeExpression*) (gee_list_get (GEE_LIST (expr_collection), expr_it)));
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ", ");
@@ -102,7 +106,6 @@ static void vala_ccode_function_call_real_write (ValaCCodeNode* base, ValaCCodeW
 				(expr == NULL ? NULL : (expr = (g_object_unref (expr), NULL)));
 			}
 		}
-		(expr_it == NULL ? NULL : (expr_it = (g_object_unref (expr_it), NULL)));
 	}
 	vala_ccode_writer_write_string (writer, ")");
 }
@@ -163,9 +166,9 @@ static void vala_ccode_function_call_class_init (ValaCCodeFunctionCallClass * kl
 }
 
 
-static void vala_ccode_function_call_init (ValaCCodeFunctionCall * self) {
+static void vala_ccode_function_call_instance_init (ValaCCodeFunctionCall * self) {
 	self->priv = VALA_CCODE_FUNCTION_CALL_GET_PRIVATE (self);
-	self->priv->arguments = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->arguments = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 }
 
 
@@ -181,7 +184,7 @@ static void vala_ccode_function_call_dispose (GObject * obj) {
 GType vala_ccode_function_call_get_type (void) {
 	static GType vala_ccode_function_call_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_function_call_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFunctionCallClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_function_call_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFunctionCall), 0, (GInstanceInitFunc) vala_ccode_function_call_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeFunctionCallClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_function_call_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeFunctionCall), 0, (GInstanceInitFunc) vala_ccode_function_call_instance_init };
 		vala_ccode_function_call_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION, "ValaCCodeFunctionCall", &g_define_type_info, 0);
 	}
 	return vala_ccode_function_call_type_id;
