@@ -74,7 +74,7 @@ static void vala_ccode_goto_statement_real_write (ValaCCodeNode* base, ValaCCode
 }
 
 
-char* vala_ccode_goto_statement_get_name (ValaCCodeGotoStatement* self) {
+const char* vala_ccode_goto_statement_get_name (ValaCCodeGotoStatement* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_GOTO_STATEMENT (self), NULL);
 	return self->priv->_name;
 }
@@ -129,7 +129,7 @@ static void vala_ccode_goto_statement_class_init (ValaCCodeGotoStatementClass *
 }
 
 
-static void vala_ccode_goto_statement_init (ValaCCodeGotoStatement * self) {
+static void vala_ccode_goto_statement_instance_init (ValaCCodeGotoStatement * self) {
 	self->priv = VALA_CCODE_GOTO_STATEMENT_GET_PRIVATE (self);
 }
 
@@ -145,7 +145,7 @@ static void vala_ccode_goto_statement_dispose (GObject * obj) {
 GType vala_ccode_goto_statement_get_type (void) {
 	static GType vala_ccode_goto_statement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_goto_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeGotoStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_goto_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeGotoStatement), 0, (GInstanceInitFunc) vala_ccode_goto_statement_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeGotoStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_goto_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeGotoStatement), 0, (GInstanceInitFunc) vala_ccode_goto_statement_instance_init };
 		vala_ccode_goto_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeGotoStatement", &g_define_type_info, 0);
 	}
 	return vala_ccode_goto_statement_type_id;
