@@ -51,12 +51,14 @@ struct _ValaCCodeGotoStatement {
 	ValaCCodeStatement parent_instance;
 	ValaCCodeGotoStatementPrivate * priv;
 };
+
 struct _ValaCCodeGotoStatementClass {
 	ValaCCodeStatementClass parent_class;
 };
 
+
 ValaCCodeGotoStatement* vala_ccode_goto_statement_new (const char* name);
-char* vala_ccode_goto_statement_get_name (ValaCCodeGotoStatement* self);
+const char* vala_ccode_goto_statement_get_name (ValaCCodeGotoStatement* self);
 void vala_ccode_goto_statement_set_name (ValaCCodeGotoStatement* self, const char* value);
 GType vala_ccode_goto_statement_get_type (void);
 
