@@ -69,7 +69,7 @@ static void vala_ccode_identifier_real_write (ValaCCodeNode* base, ValaCCodeWrit
 }
 
 
-char* vala_ccode_identifier_get_name (ValaCCodeIdentifier* self) {
+const char* vala_ccode_identifier_get_name (ValaCCodeIdentifier* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_IDENTIFIER (self), NULL);
 	return self->priv->_name;
 }
@@ -124,7 +124,7 @@ static void vala_ccode_identifier_class_init (ValaCCodeIdentifierClass * klass)
 }
 
 
-static void vala_ccode_identifier_init (ValaCCodeIdentifier * self) {
+static void vala_ccode_identifier_instance_init (ValaCCodeIdentifier * self) {
 	self->priv = VALA_CCODE_IDENTIFIER_GET_PRIVATE (self);
 }
 
@@ -140,7 +140,7 @@ static void vala_ccode_identifier_dispose (GObject * obj) {
 GType vala_ccode_identifier_get_type (void) {
 	static GType vala_ccode_identifier_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_identifier_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeIdentifierClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_identifier_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeIdentifier), 0, (GInstanceInitFunc) vala_ccode_identifier_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeIdentifierClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_identifier_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeIdentifier), 0, (GInstanceInitFunc) vala_ccode_identifier_instance_init };
 		vala_ccode_identifier_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION, "ValaCCodeIdentifier", &g_define_type_info, 0);
 	}
 	return vala_ccode_identifier_type_id;
