@@ -1,6 +1,6 @@
 /* valaccodeifstatement.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -36,6 +36,7 @@ struct _ValaCCodeIfStatementPrivate {
 	ValaCCodeStatement* _false_statement;
 	gboolean _else_if;
 };
+
 #define VALA_CCODE_IF_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_IF_STATEMENT, ValaCCodeIfStatementPrivate))
 enum  {
 	VALA_CCODE_IF_STATEMENT_DUMMY_PROPERTY,
@@ -54,8 +55,8 @@ ValaCCodeIfStatement* vala_ccode_if_statement_new (ValaCCodeExpression* cond, Va
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeIfStatement * self;
-	g_return_val_if_fail (cond == NULL || VALA_IS_CCODE_EXPRESSION (cond), NULL);
-	g_return_val_if_fail (true_stmt == NULL || VALA_IS_CCODE_STATEMENT (true_stmt), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (cond), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_STATEMENT (true_stmt), NULL);
 	g_return_val_if_fail (false_stmt == NULL || VALA_IS_CCODE_STATEMENT (false_stmt), NULL);
 	__params = g_new0 (GParameter, 3);
 	__params_it = __params;
@@ -84,7 +85,7 @@ ValaCCodeIfStatement* vala_ccode_if_statement_new (ValaCCodeExpression* cond, Va
 static void vala_ccode_if_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeIfStatement * self;
 	self = VALA_CCODE_IF_STATEMENT (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	if (!self->priv->_else_if) {
 		vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
 	} else {
@@ -246,7 +247,7 @@ static void vala_ccode_if_statement_class_init (ValaCCodeIfStatementClass * klas
 }
 
 
-static void vala_ccode_if_statement_init (ValaCCodeIfStatement * self) {
+static void vala_ccode_if_statement_instance_init (ValaCCodeIfStatement * self) {
 	self->priv = VALA_CCODE_IF_STATEMENT_GET_PRIVATE (self);
 }
 
@@ -264,7 +265,7 @@ static void vala_ccode_if_statement_dispose (GObject * obj) {
 GType vala_ccode_if_statement_get_type (void) {
 	static GType vala_ccode_if_statement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_if_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeIfStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_if_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeIfStatement), 0, (GInstanceInitFunc) vala_ccode_if_statement_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeIfStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_if_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeIfStatement), 0, (GInstanceInitFunc) vala_ccode_if_statement_instance_init };
 		vala_ccode_if_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeIfStatement", &g_define_type_info, 0);
 	}
 	return vala_ccode_if_statement_type_id;
