@@ -34,6 +34,7 @@
 struct _ValaCCodeInitializerListPrivate {
 	GeeList* initializers;
 };
+
 #define VALA_CCODE_INITIALIZER_LIST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_INITIALIZER_LIST, ValaCCodeInitializerListPrivate))
 enum  {
 	VALA_CCODE_INITIALIZER_LIST_DUMMY_PROPERTY
@@ -51,7 +52,7 @@ static void vala_ccode_initializer_list_dispose (GObject * obj);
  */
 void vala_ccode_initializer_list_append (ValaCCodeInitializerList* self, ValaCCodeExpression* expr) {
 	g_return_if_fail (VALA_IS_CCODE_INITIALIZER_LIST (self));
-	g_return_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr));
+	g_return_if_fail (VALA_IS_CCODE_EXPRESSION (expr));
 	gee_collection_add (GEE_COLLECTION (self->priv->initializers), expr);
 }
 
@@ -60,17 +61,16 @@ static void vala_ccode_initializer_list_real_write (ValaCCodeNode* base, ValaCCo
 	ValaCCodeInitializerList * self;
 	gboolean first;
 	self = VALA_CCODE_INITIALIZER_LIST (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, "{");
 	first = TRUE;
 	{
 		GeeList* expr_collection;
-		GeeIterator* expr_it;
+		int expr_it;
 		expr_collection = self->priv->initializers;
-		expr_it = gee_iterable_iterator (GEE_ITERABLE (expr_collection));
-		while (gee_iterator_next (expr_it)) {
+		for (expr_it = 0; expr_it < gee_collection_get_size (GEE_COLLECTION (expr_collection)); expr_it = expr_it + 1) {
 			ValaCCodeExpression* expr;
-			expr = ((ValaCCodeExpression*) gee_iterator_get (expr_it));
+			expr = ((ValaCCodeExpression*) (gee_list_get (GEE_LIST (expr_collection), expr_it)));
 			{
 				if (!first) {
 					vala_ccode_writer_write_string (writer, ", ");
@@ -83,7 +83,6 @@ static void vala_ccode_initializer_list_real_write (ValaCCodeNode* base, ValaCCo
 				(expr == NULL ? NULL : (expr = (g_object_unref (expr), NULL)));
 			}
 		}
-		(expr_it == NULL ? NULL : (expr_it = (g_object_unref (expr_it), NULL)));
 	}
 	vala_ccode_writer_write_string (writer, "}");
 }
@@ -107,9 +106,9 @@ static void vala_ccode_initializer_list_class_init (ValaCCodeInitializerListClas
 }
 
 
-static void vala_ccode_initializer_list_init (ValaCCodeInitializerList * self) {
+static void vala_ccode_initializer_list_instance_init (ValaCCodeInitializerList * self) {
 	self->priv = VALA_CCODE_INITIALIZER_LIST_GET_PRIVATE (self);
-	self->priv->initializers = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->initializers = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 }
 
 
@@ -124,7 +123,7 @@ static void vala_ccode_initializer_list_dispose (GObject * obj) {
 GType vala_ccode_initializer_list_get_type (void) {
 	static GType vala_ccode_initializer_list_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_initializer_list_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeInitializerListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_initializer_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeInitializerList), 0, (GInstanceInitFunc) vala_ccode_initializer_list_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeInitializerListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_initializer_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeInitializerList), 0, (GInstanceInitFunc) vala_ccode_initializer_list_instance_init };
 		vala_ccode_initializer_list_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION, "ValaCCodeInitializerList", &g_define_type_info, 0);
 	}
 	return vala_ccode_initializer_list_type_id;
