@@ -29,6 +29,7 @@
 struct _ValaCCodeLabelPrivate {
 	char* _name;
 };
+
 #define VALA_CCODE_LABEL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_LABEL, ValaCCodeLabelPrivate))
 enum  {
 	VALA_CCODE_LABEL_DUMMY_PROPERTY,
@@ -44,6 +45,7 @@ ValaCCodeLabel* vala_ccode_label_new (const char* name) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeLabel * self;
+	g_return_val_if_fail (name != NULL, NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	__params_it->name = "name";
@@ -63,7 +65,7 @@ ValaCCodeLabel* vala_ccode_label_new (const char* name) {
 static void vala_ccode_label_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeLabel * self;
 	self = VALA_CCODE_LABEL (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, NULL);
 	vala_ccode_writer_write_string (writer, self->priv->_name);
 	vala_ccode_writer_write_string (writer, ":");
@@ -71,7 +73,7 @@ static void vala_ccode_label_real_write (ValaCCodeNode* base, ValaCCodeWriter* w
 }
 
 
-char* vala_ccode_label_get_name (ValaCCodeLabel* self) {
+const char* vala_ccode_label_get_name (ValaCCodeLabel* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_LABEL (self), NULL);
 	return self->priv->_name;
 }
@@ -126,7 +128,7 @@ static void vala_ccode_label_class_init (ValaCCodeLabelClass * klass) {
 }
 
 
-static void vala_ccode_label_init (ValaCCodeLabel * self) {
+static void vala_ccode_label_instance_init (ValaCCodeLabel * self) {
 	self->priv = VALA_CCODE_LABEL_GET_PRIVATE (self);
 }
 
@@ -142,7 +144,7 @@ static void vala_ccode_label_dispose (GObject * obj) {
 GType vala_ccode_label_get_type (void) {
 	static GType vala_ccode_label_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_label_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeLabelClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_label_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeLabel), 0, (GInstanceInitFunc) vala_ccode_label_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeLabelClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_label_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeLabel), 0, (GInstanceInitFunc) vala_ccode_label_instance_init };
 		vala_ccode_label_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeLabel", &g_define_type_info, 0);
 	}
 	return vala_ccode_label_type_id;
