@@ -30,6 +30,7 @@ struct _ValaCCodeLineDirectivePrivate {
 	char* _filename;
 	gint _line;
 };
+
 #define VALA_CCODE_LINE_DIRECTIVE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirectivePrivate))
 enum  {
 	VALA_CCODE_LINE_DIRECTIVE_DUMMY_PROPERTY,
@@ -46,6 +47,7 @@ ValaCCodeLineDirective* vala_ccode_line_directive_new (const char* _filename, gi
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeLineDirective * self;
+	g_return_val_if_fail (_filename != NULL, NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	__params_it->name = "filename";
@@ -67,7 +69,7 @@ static void vala_ccode_line_directive_real_write (ValaCCodeNode* base, ValaCCode
 	ValaCCodeLineDirective * self;
 	char* _tmp0;
 	self = VALA_CCODE_LINE_DIRECTIVE (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	if (!vala_ccode_writer_get_bol (writer)) {
 		vala_ccode_writer_write_newline (writer);
 	}
@@ -78,7 +80,7 @@ static void vala_ccode_line_directive_real_write (ValaCCodeNode* base, ValaCCode
 }
 
 
-char* vala_ccode_line_directive_get_filename (ValaCCodeLineDirective* self) {
+const char* vala_ccode_line_directive_get_filename (ValaCCodeLineDirective* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_LINE_DIRECTIVE (self), NULL);
 	return self->priv->_filename;
 }
@@ -152,7 +154,7 @@ static void vala_ccode_line_directive_class_init (ValaCCodeLineDirectiveClass *
 }
 
 
-static void vala_ccode_line_directive_init (ValaCCodeLineDirective * self) {
+static void vala_ccode_line_directive_instance_init (ValaCCodeLineDirective * self) {
 	self->priv = VALA_CCODE_LINE_DIRECTIVE_GET_PRIVATE (self);
 }
 
@@ -168,7 +170,7 @@ static void vala_ccode_line_directive_dispose (GObject * obj) {
 GType vala_ccode_line_directive_get_type (void) {
 	static GType vala_ccode_line_directive_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_line_directive_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeLineDirectiveClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_line_directive_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeLineDirective), 0, (GInstanceInitFunc) vala_ccode_line_directive_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeLineDirectiveClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_line_directive_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeLineDirective), 0, (GInstanceInitFunc) vala_ccode_line_directive_instance_init };
 		vala_ccode_line_directive_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeLineDirective", &g_define_type_info, 0);
 	}
 	return vala_ccode_line_directive_type_id;
