@@ -55,7 +55,7 @@ struct _ValaCCodeLineDirectiveClass {
 
 
 ValaCCodeLineDirective* vala_ccode_line_directive_new (const char* _filename, gint _line);
-char* vala_ccode_line_directive_get_filename (ValaCCodeLineDirective* self);
+const char* vala_ccode_line_directive_get_filename (ValaCCodeLineDirective* self);
 void vala_ccode_line_directive_set_filename (ValaCCodeLineDirective* self, const char* value);
 gint vala_ccode_line_directive_get_line (ValaCCodeLineDirective* self);
 void vala_ccode_line_directive_set_line (ValaCCodeLineDirective* self, gint value);
