@@ -31,6 +31,7 @@ struct _ValaCCodeMacroReplacementPrivate {
 	char* _replacement;
 	ValaCCodeExpression* _replacement_expression;
 };
+
 #define VALA_CCODE_MACRO_REPLACEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_MACRO_REPLACEMENT, ValaCCodeMacroReplacementPrivate))
 enum  {
 	VALA_CCODE_MACRO_REPLACEMENT_DUMMY_PROPERTY,
@@ -48,6 +49,8 @@ ValaCCodeMacroReplacement* vala_ccode_macro_replacement_new (const char* name, c
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeMacroReplacement * self;
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (replacement != NULL, NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	__params_it->name = "name";
@@ -69,7 +72,8 @@ ValaCCodeMacroReplacement* vala_ccode_macro_replacement_new_with_expression (con
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeMacroReplacement * self;
-	g_return_val_if_fail (replacement_expression == NULL || VALA_IS_CCODE_EXPRESSION (replacement_expression), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (replacement_expression), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	__params_it->name = "name";
@@ -90,7 +94,7 @@ ValaCCodeMacroReplacement* vala_ccode_macro_replacement_new_with_expression (con
 static void vala_ccode_macro_replacement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeMacroReplacement * self;
 	self = VALA_CCODE_MACRO_REPLACEMENT (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, NULL);
 	vala_ccode_writer_write_string (writer, "#define ");
 	vala_ccode_writer_write_string (writer, self->priv->_name);
@@ -104,7 +108,7 @@ static void vala_ccode_macro_replacement_real_write (ValaCCodeNode* base, ValaCC
 }
 
 
-char* vala_ccode_macro_replacement_get_name (ValaCCodeMacroReplacement* self) {
+const char* vala_ccode_macro_replacement_get_name (ValaCCodeMacroReplacement* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_MACRO_REPLACEMENT (self), NULL);
 	return self->priv->_name;
 }
@@ -120,7 +124,7 @@ void vala_ccode_macro_replacement_set_name (ValaCCodeMacroReplacement* self, con
 }
 
 
-char* vala_ccode_macro_replacement_get_replacement (ValaCCodeMacroReplacement* self) {
+const char* vala_ccode_macro_replacement_get_replacement (ValaCCodeMacroReplacement* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_MACRO_REPLACEMENT (self), NULL);
 	return self->priv->_replacement;
 }
@@ -205,7 +209,7 @@ static void vala_ccode_macro_replacement_class_init (ValaCCodeMacroReplacementCl
 }
 
 
-static void vala_ccode_macro_replacement_init (ValaCCodeMacroReplacement * self) {
+static void vala_ccode_macro_replacement_instance_init (ValaCCodeMacroReplacement * self) {
 	self->priv = VALA_CCODE_MACRO_REPLACEMENT_GET_PRIVATE (self);
 }
 
@@ -223,7 +227,7 @@ static void vala_ccode_macro_replacement_dispose (GObject * obj) {
 GType vala_ccode_macro_replacement_get_type (void) {
 	static GType vala_ccode_macro_replacement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_macro_replacement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeMacroReplacementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_macro_replacement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeMacroReplacement), 0, (GInstanceInitFunc) vala_ccode_macro_replacement_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeMacroReplacementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_macro_replacement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeMacroReplacement), 0, (GInstanceInitFunc) vala_ccode_macro_replacement_instance_init };
 		vala_ccode_macro_replacement_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeMacroReplacement", &g_define_type_info, 0);
 	}
 	return vala_ccode_macro_replacement_type_id;
