@@ -22,6 +22,9 @@
 
 #include <ccode/valaccodenewline.h>
 
+
+
+
 enum  {
 	VALA_CCODE_NEWLINE_DUMMY_PROPERTY
 };
@@ -29,10 +32,11 @@ static void vala_ccode_newline_real_write (ValaCCodeNode* base, ValaCCodeWriter*
 static gpointer vala_ccode_newline_parent_class = NULL;
 
 
+
 static void vala_ccode_newline_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeNewline * self;
 	self = VALA_CCODE_NEWLINE (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_newline (writer);
 }
 
@@ -53,14 +57,14 @@ static void vala_ccode_newline_class_init (ValaCCodeNewlineClass * klass) {
 }
 
 
-static void vala_ccode_newline_init (ValaCCodeNewline * self) {
+static void vala_ccode_newline_instance_init (ValaCCodeNewline * self) {
 }
 
 
 GType vala_ccode_newline_get_type (void) {
 	static GType vala_ccode_newline_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_newline_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeNewlineClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_newline_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeNewline), 0, (GInstanceInitFunc) vala_ccode_newline_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeNewlineClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_newline_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeNewline), 0, (GInstanceInitFunc) vala_ccode_newline_instance_init };
 		vala_ccode_newline_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeNewline", &g_define_type_info, 0);
 	}
 	return vala_ccode_newline_type_id;
