@@ -32,29 +32,19 @@ static gpointer vala_ccode_statement_parent_class = NULL;
 
 
 
-/**
- * Represents a statement in the C code.
- */
-ValaCCodeStatement* vala_ccode_statement_new (void) {
-	ValaCCodeStatement * self;
-	self = g_object_newv (VALA_TYPE_CCODE_STATEMENT, 0, NULL);
-	return self;
-}
-
-
 static void vala_ccode_statement_class_init (ValaCCodeStatementClass * klass) {
 	vala_ccode_statement_parent_class = g_type_class_peek_parent (klass);
 }
 
 
-static void vala_ccode_statement_init (ValaCCodeStatement * self) {
+static void vala_ccode_statement_instance_init (ValaCCodeStatement * self) {
 }
 
 
 GType vala_ccode_statement_get_type (void) {
 	static GType vala_ccode_statement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeStatement), 0, (GInstanceInitFunc) vala_ccode_statement_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeStatement), 0, (GInstanceInitFunc) vala_ccode_statement_instance_init };
 		vala_ccode_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeStatement", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
 	return vala_ccode_statement_type_id;
