@@ -93,18 +93,16 @@ static void vala_ccode_switch_statement_real_write (ValaCCodeNode* base, ValaCCo
 	vala_ccode_writer_write_begin_block (writer);
 	{
 		GeeList* case_stmt_collection;
-		GeeIterator* case_stmt_it;
+		int case_stmt_it;
 		case_stmt_collection = self->priv->case_statements;
-		case_stmt_it = gee_iterable_iterator (GEE_ITERABLE (case_stmt_collection));
-		while (gee_iterator_next (case_stmt_it)) {
+		for (case_stmt_it = 0; case_stmt_it < gee_collection_get_size (GEE_COLLECTION (case_stmt_collection)); case_stmt_it = case_stmt_it + 1) {
 			ValaCCodeCaseStatement* case_stmt;
-			case_stmt = ((ValaCCodeCaseStatement*) gee_iterator_get (case_stmt_it));
+			case_stmt = ((ValaCCodeCaseStatement*) (gee_list_get (GEE_LIST (case_stmt_collection), case_stmt_it)));
 			{
 				vala_ccode_node_write (VALA_CCODE_NODE (case_stmt), writer);
 				(case_stmt == NULL ? NULL : (case_stmt = (g_object_unref (case_stmt), NULL)));
 			}
 		}
-		(case_stmt_it == NULL ? NULL : (case_stmt_it = (g_object_unref (case_stmt_it), NULL)));
 	}
 	if (gee_collection_get_size (GEE_COLLECTION (self->priv->default_statements)) > 0) {
 		vala_ccode_writer_write_indent (writer, NULL);
@@ -112,18 +110,16 @@ static void vala_ccode_switch_statement_real_write (ValaCCodeNode* base, ValaCCo
 		vala_ccode_writer_write_newline (writer);
 		{
 			GeeList* stmt_collection;
-			GeeIterator* stmt_it;
+			int stmt_it;
 			stmt_collection = self->priv->default_statements;
-			stmt_it = gee_iterable_iterator (GEE_ITERABLE (stmt_collection));
-			while (gee_iterator_next (stmt_it)) {
+			for (stmt_it = 0; stmt_it < gee_collection_get_size (GEE_COLLECTION (stmt_collection)); stmt_it = stmt_it + 1) {
 				ValaCCodeStatement* stmt;
-				stmt = ((ValaCCodeStatement*) gee_iterator_get (stmt_it));
+				stmt = ((ValaCCodeStatement*) (gee_list_get (GEE_LIST (stmt_collection), stmt_it)));
 				{
 					vala_ccode_node_write (VALA_CCODE_NODE (stmt), writer);
 					(stmt == NULL ? NULL : (stmt = (g_object_unref (stmt), NULL)));
 				}
 			}
-			(stmt_it == NULL ? NULL : (stmt_it = (g_object_unref (stmt_it), NULL)));
 		}
 	}
 	vala_ccode_writer_write_end_block (writer);
@@ -185,10 +181,10 @@ static void vala_ccode_switch_statement_class_init (ValaCCodeSwitchStatementClas
 }
 
 
-static void vala_ccode_switch_statement_init (ValaCCodeSwitchStatement * self) {
+static void vala_ccode_switch_statement_instance_init (ValaCCodeSwitchStatement * self) {
 	self->priv = VALA_CCODE_SWITCH_STATEMENT_GET_PRIVATE (self);
-	self->priv->case_statements = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_CASE_STATEMENT, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
-	self->priv->default_statements = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_STATEMENT, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->case_statements = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_CASE_STATEMENT, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->default_statements = GEE_LIST (gee_array_list_new (VALA_TYPE_CCODE_STATEMENT, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 }
 
 
@@ -205,7 +201,7 @@ static void vala_ccode_switch_statement_dispose (GObject * obj) {
 GType vala_ccode_switch_statement_get_type (void) {
 	static GType vala_ccode_switch_statement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_switch_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeSwitchStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_switch_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeSwitchStatement), 0, (GInstanceInitFunc) vala_ccode_switch_statement_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeSwitchStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_switch_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeSwitchStatement), 0, (GInstanceInitFunc) vala_ccode_switch_statement_instance_init };
 		vala_ccode_switch_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeSwitchStatement", &g_define_type_info, 0);
 	}
 	return vala_ccode_switch_statement_type_id;
