@@ -30,6 +30,7 @@ struct _ValaCCodeTypeDefinitionPrivate {
 	char* _type_name;
 	ValaCCodeDeclarator* _declarator;
 };
+
 #define VALA_CCODE_TYPE_DEFINITION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_TYPE_DEFINITION, ValaCCodeTypeDefinitionPrivate))
 enum  {
 	VALA_CCODE_TYPE_DEFINITION_DUMMY_PROPERTY,
@@ -45,7 +46,8 @@ static void vala_ccode_type_definition_dispose (GObject * obj);
 
 ValaCCodeTypeDefinition* vala_ccode_type_definition_new (const char* type, ValaCCodeDeclarator* decl) {
 	ValaCCodeTypeDefinition * self;
-	g_return_val_if_fail (decl == NULL || VALA_IS_CCODE_DECLARATOR (decl), NULL);
+	g_return_val_if_fail (type != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_DECLARATOR (decl), NULL);
 	self = g_object_newv (VALA_TYPE_CCODE_TYPE_DEFINITION, 0, NULL);
 	vala_ccode_type_definition_set_type_name (self, type);
 	vala_ccode_type_definition_set_declarator (self, decl);
@@ -56,14 +58,14 @@ ValaCCodeTypeDefinition* vala_ccode_type_definition_new (const char* type, ValaC
 static void vala_ccode_type_definition_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeTypeDefinition * self;
 	self = VALA_CCODE_TYPE_DEFINITION (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 }
 
 
 static void vala_ccode_type_definition_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeTypeDefinition * self;
 	self = VALA_CCODE_TYPE_DEFINITION (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, NULL);
 	vala_ccode_writer_write_string (writer, "typedef ");
 	vala_ccode_writer_write_string (writer, self->priv->_type_name);
@@ -74,7 +76,7 @@ static void vala_ccode_type_definition_real_write_declaration (ValaCCodeNode* ba
 }
 
 
-char* vala_ccode_type_definition_get_type_name (ValaCCodeTypeDefinition* self) {
+const char* vala_ccode_type_definition_get_type_name (ValaCCodeTypeDefinition* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_TYPE_DEFINITION (self), NULL);
 	return self->priv->_type_name;
 }
@@ -153,7 +155,7 @@ static void vala_ccode_type_definition_class_init (ValaCCodeTypeDefinitionClass
 }
 
 
-static void vala_ccode_type_definition_init (ValaCCodeTypeDefinition * self) {
+static void vala_ccode_type_definition_instance_init (ValaCCodeTypeDefinition * self) {
 	self->priv = VALA_CCODE_TYPE_DEFINITION_GET_PRIVATE (self);
 }
 
@@ -170,7 +172,7 @@ static void vala_ccode_type_definition_dispose (GObject * obj) {
 GType vala_ccode_type_definition_get_type (void) {
 	static GType vala_ccode_type_definition_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_type_definition_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeTypeDefinitionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_type_definition_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeTypeDefinition), 0, (GInstanceInitFunc) vala_ccode_type_definition_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeTypeDefinitionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_type_definition_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeTypeDefinition), 0, (GInstanceInitFunc) vala_ccode_type_definition_instance_init };
 		vala_ccode_type_definition_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeTypeDefinition", &g_define_type_info, 0);
 	}
 	return vala_ccode_type_definition_type_id;
