@@ -32,6 +32,7 @@ struct _ValaCCodeVariableDeclaratorPrivate {
 	char* _name;
 	ValaCCodeExpression* _initializer;
 };
+
 #define VALA_CCODE_VARIABLE_DECLARATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_VARIABLE_DECLARATOR, ValaCCodeVariableDeclaratorPrivate))
 enum  {
 	VALA_CCODE_VARIABLE_DECLARATOR_DUMMY_PROPERTY,
@@ -130,7 +131,7 @@ static void vala_ccode_variable_declarator_real_write_initialization (ValaCCodeD
 }
 
 
-char* vala_ccode_variable_declarator_get_name (ValaCCodeVariableDeclarator* self) {
+const char* vala_ccode_variable_declarator_get_name (ValaCCodeVariableDeclarator* self) {
 	g_return_val_if_fail (VALA_IS_CCODE_VARIABLE_DECLARATOR (self), NULL);
 	return self->priv->_name;
 }
@@ -210,7 +211,7 @@ static void vala_ccode_variable_declarator_class_init (ValaCCodeVariableDeclarat
 }
 
 
-static void vala_ccode_variable_declarator_init (ValaCCodeVariableDeclarator * self) {
+static void vala_ccode_variable_declarator_instance_init (ValaCCodeVariableDeclarator * self) {
 	self->priv = VALA_CCODE_VARIABLE_DECLARATOR_GET_PRIVATE (self);
 }
 
@@ -227,7 +228,7 @@ static void vala_ccode_variable_declarator_dispose (GObject * obj) {
 GType vala_ccode_variable_declarator_get_type (void) {
 	static GType vala_ccode_variable_declarator_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_variable_declarator_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeVariableDeclaratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_variable_declarator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeVariableDeclarator), 0, (GInstanceInitFunc) vala_ccode_variable_declarator_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeVariableDeclaratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_variable_declarator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeVariableDeclarator), 0, (GInstanceInitFunc) vala_ccode_variable_declarator_instance_init };
 		vala_ccode_variable_declarator_type_id = g_type_register_static (VALA_TYPE_CCODE_DECLARATOR, "ValaCCodeVariableDeclarator", &g_define_type_info, 0);
 	}
 	return vala_ccode_variable_declarator_type_id;
