@@ -1,6 +1,6 @@
 /* valaccodewhilestatement.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -33,6 +33,7 @@ struct _ValaCCodeWhileStatementPrivate {
 	ValaCCodeExpression* _condition;
 	ValaCCodeStatement* _body;
 };
+
 #define VALA_CCODE_WHILE_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_WHILE_STATEMENT, ValaCCodeWhileStatementPrivate))
 enum  {
 	VALA_CCODE_WHILE_STATEMENT_DUMMY_PROPERTY,
@@ -49,7 +50,7 @@ ValaCCodeWhileStatement* vala_ccode_while_statement_new (ValaCCodeExpression* co
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeWhileStatement * self;
-	g_return_val_if_fail (cond == NULL || VALA_IS_CCODE_EXPRESSION (cond), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (cond), NULL);
 	g_return_val_if_fail (stmt == NULL || VALA_IS_CCODE_STATEMENT (stmt), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
@@ -71,7 +72,7 @@ ValaCCodeWhileStatement* vala_ccode_while_statement_new (ValaCCodeExpression* co
 static void vala_ccode_while_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeWhileStatement * self;
 	self = VALA_CCODE_WHILE_STATEMENT (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
 	vala_ccode_writer_write_string (writer, "while (");
 	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_condition), writer);
@@ -158,7 +159,7 @@ static void vala_ccode_while_statement_class_init (ValaCCodeWhileStatementClass
 }
 
 
-static void vala_ccode_while_statement_init (ValaCCodeWhileStatement * self) {
+static void vala_ccode_while_statement_instance_init (ValaCCodeWhileStatement * self) {
 	self->priv = VALA_CCODE_WHILE_STATEMENT_GET_PRIVATE (self);
 }
 
@@ -175,7 +176,7 @@ static void vala_ccode_while_statement_dispose (GObject * obj) {
 GType vala_ccode_while_statement_get_type (void) {
 	static GType vala_ccode_while_statement_type_id = 0;
 	if (G_UNLIKELY (vala_ccode_while_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeWhileStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_while_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeWhileStatement), 0, (GInstanceInitFunc) vala_ccode_while_statement_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeWhileStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_while_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeWhileStatement), 0, (GInstanceInitFunc) vala_ccode_while_statement_instance_init };
 		vala_ccode_while_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeWhileStatement", &g_define_type_info, 0);
 	}
 	return vala_ccode_while_statement_type_id;
