@@ -348,14 +348,14 @@ GeeHashMap* gee_hash_map_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyN
 static GeeSet* gee_hash_map_real_get_keys (GeeMap* base) {
 	GeeHashMap * self;
 	self = GEE_HASH_MAP (base);
-	return GEE_SET (gee_hash_map_key_set_new (self->priv->k_type, ((GBoxedCopyFunc) self->priv->k_dup_func), self->priv->k_destroy_func, self->priv->v_type, ((GBoxedCopyFunc) self->priv->v_dup_func), self->priv->v_destroy_func, self));
+	return GEE_SET (gee_hash_map_key_set_new (self->priv->k_type, ((GBoxedCopyFunc) (self->priv->k_dup_func)), self->priv->k_destroy_func, self->priv->v_type, ((GBoxedCopyFunc) (self->priv->v_dup_func)), self->priv->v_destroy_func, self));
 }
 
 
 static GeeCollection* gee_hash_map_real_get_values (GeeMap* base) {
 	GeeHashMap * self;
 	self = GEE_HASH_MAP (base);
-	return GEE_COLLECTION (gee_hash_map_value_collection_new (self->priv->k_type, ((GBoxedCopyFunc) self->priv->k_dup_func), self->priv->k_destroy_func, self->priv->v_type, ((GBoxedCopyFunc) self->priv->v_dup_func), self->priv->v_destroy_func, self));
+	return GEE_COLLECTION (gee_hash_map_value_collection_new (self->priv->k_type, ((GBoxedCopyFunc) (self->priv->k_dup_func)), self->priv->k_destroy_func, self->priv->v_type, ((GBoxedCopyFunc) (self->priv->v_dup_func)), self->priv->v_destroy_func, self));
 }
 
 
@@ -365,8 +365,8 @@ static GeeHashMapNode** gee_hash_map_lookup_node (GeeHashMap* self, gconstpointe
 	g_return_val_if_fail (GEE_IS_HASH_MAP (self), NULL);
 	hash_value = self->priv->_key_hash_func (key);
 	node = &self->priv->_nodes[hash_value % self->priv->_array_size];
-	while ((*node) != NULL && (hash_value != (*node)->key_hash || !self->priv->_key_equal_func ((*node)->key, key))) {
-		node = &((*node)->next);
+	while (((*node)) != NULL && (hash_value != ((*node))->key_hash || !self->priv->_key_equal_func (((*node))->key, key))) {
+		node = &(((*node))->next);
 	}
 	return node;
 }
@@ -377,7 +377,7 @@ static gboolean gee_hash_map_real_contains (GeeMap* base, gconstpointer key) {
 	GeeHashMapNode** node;
 	self = GEE_HASH_MAP (base);
 	node = gee_hash_map_lookup_node (self, key);
-	return (*node != NULL);
+	return ((*node) != NULL);
 }
 
 
@@ -385,11 +385,11 @@ static gpointer gee_hash_map_real_get (GeeMap* base, gconstpointer key) {
 	GeeHashMap * self;
 	GeeHashMapNode* node;
 	self = GEE_HASH_MAP (base);
-	node = (*gee_hash_map_lookup_node (self, key));
+	node = ((*gee_hash_map_lookup_node (self, key)));
 	if (node != NULL) {
 		gconstpointer _tmp0;
 		_tmp0 = NULL;
-		return (_tmp0 = node->value, (_tmp0 == NULL || self->priv->v_dup_func == NULL ? ((gpointer) _tmp0) : self->priv->v_dup_func (((gpointer) _tmp0))));
+		return (_tmp0 = node->value, (_tmp0 == NULL || self->priv->v_dup_func == NULL ? ((gpointer) (_tmp0)) : self->priv->v_dup_func (((gpointer) (_tmp0)))));
 	} else {
 		return NULL;
 	}
@@ -401,12 +401,12 @@ static void gee_hash_map_real_set (GeeMap* base, gconstpointer key, gconstpointe
 	GeeHashMapNode** node;
 	self = GEE_HASH_MAP (base);
 	node = gee_hash_map_lookup_node (self, key);
-	if (*node != NULL) {
+	if ((*node) != NULL) {
 		gpointer _tmp1;
 		gconstpointer _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		(*node)->value = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL || self->priv->v_dup_func == NULL ? ((gpointer) _tmp0) : self->priv->v_dup_func (((gpointer) _tmp0)))), ((*node)->value == NULL || self->priv->v_destroy_func == NULL ? NULL : ((*node)->value = (self->priv->v_destroy_func ((*node)->value), NULL))), _tmp1);
+		((*node))->value = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL || self->priv->v_dup_func == NULL ? ((gpointer) (_tmp0)) : self->priv->v_dup_func (((gpointer) (_tmp0))))), (((*node))->value == NULL || self->priv->v_destroy_func == NULL ? NULL : (((*node))->value = (self->priv->v_destroy_func (((*node))->value), NULL))), _tmp1);
 	} else {
 		guint hash_value;
 		gconstpointer _tmp3;
@@ -414,7 +414,7 @@ static void gee_hash_map_real_set (GeeMap* base, gconstpointer key, gconstpointe
 		hash_value = self->priv->_key_hash_func (key);
 		_tmp3 = NULL;
 		_tmp2 = NULL;
-		*node = gee_hash_map_node_new ((_tmp2 = key, (_tmp2 == NULL || self->priv->k_dup_func == NULL ? ((gpointer) _tmp2) : self->priv->k_dup_func (((gpointer) _tmp2)))), (_tmp3 = value, (_tmp3 == NULL || self->priv->v_dup_func == NULL ? ((gpointer) _tmp3) : self->priv->v_dup_func (((gpointer) _tmp3)))), hash_value);
+		(*node) = gee_hash_map_node_new ((_tmp2 = key, (_tmp2 == NULL || self->priv->k_dup_func == NULL ? ((gpointer) (_tmp2)) : self->priv->k_dup_func (((gpointer) (_tmp2))))), (_tmp3 = value, (_tmp3 == NULL || self->priv->v_dup_func == NULL ? ((gpointer) (_tmp3)) : self->priv->v_dup_func (((gpointer) (_tmp3))))), hash_value);
 		self->priv->_nnodes++;
 		gee_hash_map_resize (self);
 	}
@@ -427,14 +427,14 @@ static gboolean gee_hash_map_real_remove (GeeMap* base, gconstpointer key) {
 	GeeHashMapNode** node;
 	self = GEE_HASH_MAP (base);
 	node = gee_hash_map_lookup_node (self, key);
-	if (*node != NULL) {
+	if ((*node) != NULL) {
 		gpointer _tmp0;
 		gpointer _tmp1;
 		_tmp0 = NULL;
-		(*node)->key = (_tmp0 = NULL, ((*node)->key == NULL || self->priv->k_destroy_func == NULL ? NULL : ((*node)->key = (self->priv->k_destroy_func ((*node)->key), NULL))), _tmp0);
+		((*node))->key = (_tmp0 = NULL, (((*node))->key == NULL || self->priv->k_destroy_func == NULL ? NULL : (((*node))->key = (self->priv->k_destroy_func (((*node))->key), NULL))), _tmp0);
 		_tmp1 = NULL;
-		(*node)->value = (_tmp1 = NULL, ((*node)->value == NULL || self->priv->v_destroy_func == NULL ? NULL : ((*node)->value = (self->priv->v_destroy_func ((*node)->value), NULL))), _tmp1);
-		*node = (*node)->next;
+		((*node))->value = (_tmp1 = NULL, (((*node))->value == NULL || self->priv->v_destroy_func == NULL ? NULL : (((*node))->value = (self->priv->v_destroy_func (((*node))->value), NULL))), _tmp1);
+		(*node) = ((*node))->next;
 		self->priv->_nnodes--;
 		gee_hash_map_resize (self);
 		self->priv->_stamp++;
@@ -490,7 +490,7 @@ static void gee_hash_map_resize (GeeHashMap* self) {
 		GeeHashMapNode** new_nodes;
 		GeeHashMapNode** _tmp12;
 		GeeHashMapNode** _tmp11;
-		new_array_size = ((gint) g_spaced_primes_closest (((guint) self->priv->_nnodes)));
+		new_array_size = ((gint) (g_spaced_primes_closest (((guint) (self->priv->_nnodes)))));
 		new_array_size = CLAMP (new_array_size, GEE_HASH_MAP_MIN_SIZE, GEE_HASH_MAP_MAX_SIZE);
 		_tmp0 = NULL;
 		new_nodes = (_tmp0 = g_new0 (GeeHashMapNode*, new_array_size + 1), new_nodes_length1 = new_array_size, _tmp0);
@@ -535,9 +535,9 @@ static void gee_hash_map_resize (GeeHashMap* self) {
 		}
 		_tmp12 = NULL;
 		_tmp11 = NULL;
-		self->priv->_nodes = (_tmp12 = (_tmp11 = new_nodes, new_nodes = NULL, _tmp11), (self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) gee_hash_map_node_free)), NULL)), self->priv->_nodes_length1 = new_nodes_length1, _tmp12);
+		self->priv->_nodes = (_tmp12 = (_tmp11 = new_nodes, new_nodes = NULL, _tmp11), (self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) (gee_hash_map_node_free))), NULL)), self->priv->_nodes_length1 = new_nodes_length1, _tmp12);
 		self->priv->_array_size = new_array_size;
-		new_nodes = (_vala_array_free (new_nodes, new_nodes_length1, ((GDestroyNotify) gee_hash_map_node_free)), NULL);
+		new_nodes = (_vala_array_free (new_nodes, new_nodes_length1, ((GDestroyNotify) (gee_hash_map_node_free))), NULL);
 	}
 }
 
@@ -579,7 +579,7 @@ static GObject * gee_hash_map_constructor (GType type, guint n_construct_propert
 		GeeHashMapNode** _tmp0;
 		self->priv->_array_size = GEE_HASH_MAP_MIN_SIZE;
 		_tmp0 = NULL;
-		self->priv->_nodes = (_tmp0 = g_new0 (GeeHashMapNode*, self->priv->_array_size + 1), (self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) gee_hash_map_node_free)), NULL)), self->priv->_nodes_length1 = self->priv->_array_size, _tmp0);
+		self->priv->_nodes = (_tmp0 = g_new0 (GeeHashMapNode*, self->priv->_array_size + 1), (self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) (gee_hash_map_node_free))), NULL)), self->priv->_nodes_length1 = self->priv->_array_size, _tmp0);
 	}
 	return obj;
 }
@@ -587,25 +587,19 @@ static GObject * gee_hash_map_constructor (GType type, guint n_construct_propert
 
 static GeeHashMapNode* gee_hash_map_node_new (gpointer k, gpointer v, guint hash) {
 	GeeHashMapNode* self;
-	gpointer _tmp1;
 	gpointer _tmp0;
-	gpointer _tmp3;
-	gpointer _tmp2;
+	gpointer _tmp1;
 	self = g_slice_new0 (GeeHashMapNode);
-	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->key = (_tmp1 = (_tmp0 = k, k = NULL, _tmp0), NULL, _tmp1);
-	_tmp3 = NULL;
-	_tmp2 = NULL;
-	self->value = (_tmp3 = (_tmp2 = v, v = NULL, _tmp2), NULL, _tmp3);
+	self->key = (_tmp0 = k, k = NULL, _tmp0);
+	_tmp1 = NULL;
+	self->value = (_tmp1 = v, v = NULL, _tmp1);
 	self->key_hash = hash;
 	return self;
 }
 
 
 static void gee_hash_map_node_free (GeeHashMapNode* self) {
-	NULL;
-	NULL;
 	(self->next == NULL ? NULL : (self->next = (gee_hash_map_node_free (self->next), NULL)));
 	g_slice_free (GeeHashMapNode, self);
 }
@@ -663,7 +657,7 @@ static GType gee_hash_map_key_set_real_get_element_type (GeeIterable* base) {
 static GeeIterator* gee_hash_map_key_set_real_iterator (GeeIterable* base) {
 	GeeHashMapKeySet * self;
 	self = GEE_HASH_MAP_KEY_SET (base);
-	return GEE_ITERATOR (gee_hash_map_key_iterator_new (self->priv->k_type, ((GBoxedCopyFunc) self->priv->k_dup_func), self->priv->k_destroy_func, self->priv->v_type, ((GBoxedCopyFunc) self->priv->v_dup_func), self->priv->v_destroy_func, self->priv->_map));
+	return GEE_ITERATOR (gee_hash_map_key_iterator_new (self->priv->k_type, ((GBoxedCopyFunc) (self->priv->k_dup_func)), self->priv->k_destroy_func, self->priv->v_type, ((GBoxedCopyFunc) (self->priv->v_dup_func)), self->priv->v_destroy_func, self->priv->_map));
 }
 
 
@@ -795,7 +789,7 @@ static void gee_hash_map_key_set_gee_set_interface_init (GeeSetIface * iface) {
 }
 
 
-static void gee_hash_map_key_set_init (GeeHashMapKeySet * self) {
+static void gee_hash_map_key_set_instance_init (GeeHashMapKeySet * self) {
 	self->priv = GEE_HASH_MAP_KEY_SET_GET_PRIVATE (self);
 }
 
@@ -811,7 +805,7 @@ static void gee_hash_map_key_set_dispose (GObject * obj) {
 static GType gee_hash_map_key_set_get_type (void) {
 	static GType gee_hash_map_key_set_type_id = 0;
 	if (G_UNLIKELY (gee_hash_map_key_set_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeHashMapKeySetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_hash_map_key_set_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeHashMapKeySet), 0, (GInstanceInitFunc) gee_hash_map_key_set_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GeeHashMapKeySetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_hash_map_key_set_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeHashMapKeySet), 0, (GInstanceInitFunc) gee_hash_map_key_set_instance_init };
 		static const GInterfaceInfo gee_iterable_info = { (GInterfaceInitFunc) gee_hash_map_key_set_gee_iterable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_collection_info = { (GInterfaceInitFunc) gee_hash_map_key_set_gee_collection_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_set_info = { (GInterfaceInitFunc) gee_hash_map_key_set_gee_set_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
@@ -887,7 +881,7 @@ static gpointer gee_hash_map_key_iterator_real_get (GeeIterator* base) {
 	g_assert (self->priv->_stamp == self->priv->_map->priv->_stamp);
 	g_assert (self->priv->_node != NULL);
 	_tmp0 = NULL;
-	return (_tmp0 = self->priv->_node->key, (_tmp0 == NULL || self->priv->k_dup_func == NULL ? ((gpointer) _tmp0) : self->priv->k_dup_func (((gpointer) _tmp0))));
+	return (_tmp0 = self->priv->_node->key, (_tmp0 == NULL || self->priv->k_dup_func == NULL ? ((gpointer) (_tmp0)) : self->priv->k_dup_func (((gpointer) (_tmp0)))));
 }
 
 
@@ -968,7 +962,7 @@ static void gee_hash_map_key_iterator_gee_iterator_interface_init (GeeIteratorIf
 }
 
 
-static void gee_hash_map_key_iterator_init (GeeHashMapKeyIterator * self) {
+static void gee_hash_map_key_iterator_instance_init (GeeHashMapKeyIterator * self) {
 	self->priv = GEE_HASH_MAP_KEY_ITERATOR_GET_PRIVATE (self);
 	self->priv->_index = -1;
 }
@@ -985,7 +979,7 @@ static void gee_hash_map_key_iterator_dispose (GObject * obj) {
 static GType gee_hash_map_key_iterator_get_type (void) {
 	static GType gee_hash_map_key_iterator_type_id = 0;
 	if (G_UNLIKELY (gee_hash_map_key_iterator_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeHashMapKeyIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_hash_map_key_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeHashMapKeyIterator), 0, (GInstanceInitFunc) gee_hash_map_key_iterator_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GeeHashMapKeyIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_hash_map_key_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeHashMapKeyIterator), 0, (GInstanceInitFunc) gee_hash_map_key_iterator_instance_init };
 		static const GInterfaceInfo gee_iterator_info = { (GInterfaceInitFunc) gee_hash_map_key_iterator_gee_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		gee_hash_map_key_iterator_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeHashMapKeyIterator", &g_define_type_info, 0);
 		g_type_add_interface_static (gee_hash_map_key_iterator_type_id, GEE_TYPE_ITERATOR, &gee_iterator_info);
@@ -1046,7 +1040,7 @@ static GType gee_hash_map_value_collection_real_get_element_type (GeeIterable* b
 static GeeIterator* gee_hash_map_value_collection_real_iterator (GeeIterable* base) {
 	GeeHashMapValueCollection * self;
 	self = GEE_HASH_MAP_VALUE_COLLECTION (base);
-	return GEE_ITERATOR (gee_hash_map_value_iterator_new (self->priv->k_type, ((GBoxedCopyFunc) self->priv->k_dup_func), self->priv->k_destroy_func, self->priv->v_type, ((GBoxedCopyFunc) self->priv->v_dup_func), self->priv->v_destroy_func, self->priv->_map));
+	return GEE_ITERATOR (gee_hash_map_value_iterator_new (self->priv->k_type, ((GBoxedCopyFunc) (self->priv->k_dup_func)), self->priv->k_destroy_func, self->priv->v_type, ((GBoxedCopyFunc) (self->priv->v_dup_func)), self->priv->v_destroy_func, self->priv->_map));
 }
 
 
@@ -1185,7 +1179,7 @@ static void gee_hash_map_value_collection_gee_collection_interface_init (GeeColl
 }
 
 
-static void gee_hash_map_value_collection_init (GeeHashMapValueCollection * self) {
+static void gee_hash_map_value_collection_instance_init (GeeHashMapValueCollection * self) {
 	self->priv = GEE_HASH_MAP_VALUE_COLLECTION_GET_PRIVATE (self);
 }
 
@@ -1201,7 +1195,7 @@ static void gee_hash_map_value_collection_dispose (GObject * obj) {
 static GType gee_hash_map_value_collection_get_type (void) {
 	static GType gee_hash_map_value_collection_type_id = 0;
 	if (G_UNLIKELY (gee_hash_map_value_collection_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeHashMapValueCollectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_hash_map_value_collection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeHashMapValueCollection), 0, (GInstanceInitFunc) gee_hash_map_value_collection_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GeeHashMapValueCollectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_hash_map_value_collection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeHashMapValueCollection), 0, (GInstanceInitFunc) gee_hash_map_value_collection_instance_init };
 		static const GInterfaceInfo gee_iterable_info = { (GInterfaceInitFunc) gee_hash_map_value_collection_gee_iterable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_collection_info = { (GInterfaceInitFunc) gee_hash_map_value_collection_gee_collection_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		gee_hash_map_value_collection_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeHashMapValueCollection", &g_define_type_info, 0);
@@ -1275,7 +1269,7 @@ static gpointer gee_hash_map_value_iterator_real_get (GeeIterator* base) {
 	g_assert (self->priv->_stamp == self->priv->_map->priv->_stamp);
 	g_assert (self->priv->_node != NULL);
 	_tmp0 = NULL;
-	return (_tmp0 = self->priv->_node->value, (_tmp0 == NULL || self->priv->v_dup_func == NULL ? ((gpointer) _tmp0) : self->priv->v_dup_func (((gpointer) _tmp0))));
+	return (_tmp0 = self->priv->_node->value, (_tmp0 == NULL || self->priv->v_dup_func == NULL ? ((gpointer) (_tmp0)) : self->priv->v_dup_func (((gpointer) (_tmp0)))));
 }
 
 
@@ -1356,7 +1350,7 @@ static void gee_hash_map_value_iterator_gee_iterator_interface_init (GeeIterator
 }
 
 
-static void gee_hash_map_value_iterator_init (GeeHashMapValueIterator * self) {
+static void gee_hash_map_value_iterator_instance_init (GeeHashMapValueIterator * self) {
 	self->priv = GEE_HASH_MAP_VALUE_ITERATOR_GET_PRIVATE (self);
 	self->priv->_index = -1;
 }
@@ -1373,7 +1367,7 @@ static void gee_hash_map_value_iterator_dispose (GObject * obj) {
 static GType gee_hash_map_value_iterator_get_type (void) {
 	static GType gee_hash_map_value_iterator_type_id = 0;
 	if (G_UNLIKELY (gee_hash_map_value_iterator_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeHashMapValueIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_hash_map_value_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeHashMapValueIterator), 0, (GInstanceInitFunc) gee_hash_map_value_iterator_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GeeHashMapValueIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_hash_map_value_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeHashMapValueIterator), 0, (GInstanceInitFunc) gee_hash_map_value_iterator_instance_init };
 		static const GInterfaceInfo gee_iterator_info = { (GInterfaceInitFunc) gee_hash_map_value_iterator_gee_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		gee_hash_map_value_iterator_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeHashMapValueIterator", &g_define_type_info, 0);
 		g_type_add_interface_static (gee_hash_map_value_iterator_type_id, GEE_TYPE_ITERATOR, &gee_iterator_info);
@@ -1466,7 +1460,7 @@ static void gee_hash_map_gee_map_interface_init (GeeMapIface * iface) {
 }
 
 
-static void gee_hash_map_init (GeeHashMap * self) {
+static void gee_hash_map_instance_init (GeeHashMap * self) {
 	self->priv = GEE_HASH_MAP_GET_PRIVATE (self);
 	self->priv->_stamp = 0;
 }
@@ -1478,7 +1472,7 @@ static void gee_hash_map_dispose (GObject * obj) {
 	{
 		gee_map_clear (GEE_MAP (self));
 	}
-	self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) gee_hash_map_node_free)), NULL);
+	self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) (gee_hash_map_node_free))), NULL);
 	G_OBJECT_CLASS (gee_hash_map_parent_class)->dispose (obj);
 }
 
@@ -1486,7 +1480,7 @@ static void gee_hash_map_dispose (GObject * obj) {
 GType gee_hash_map_get_type (void) {
 	static GType gee_hash_map_type_id = 0;
 	if (G_UNLIKELY (gee_hash_map_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeHashMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_hash_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeHashMap), 0, (GInstanceInitFunc) gee_hash_map_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GeeHashMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_hash_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeHashMap), 0, (GInstanceInitFunc) gee_hash_map_instance_init };
 		static const GInterfaceInfo gee_map_info = { (GInterfaceInitFunc) gee_hash_map_gee_map_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		gee_hash_map_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeHashMap", &g_define_type_info, 0);
 		g_type_add_interface_static (gee_hash_map_type_id, GEE_TYPE_MAP, &gee_map_info);
@@ -1500,12 +1494,12 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 		int i;
 		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) array)[i] != NULL)
-			destroy_func (((gpointer*) array)[i]);
+			if (((gpointer*) (array))[i] != NULL)
+			destroy_func (((gpointer*) (array))[i]);
 		}
 		else
-		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) array)[i]);
+		for (i = 0; ((gpointer*) (array))[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) (array))[i]);
 		}
 	}
 	g_free (array);
