@@ -42,15 +42,18 @@ struct _GeeHashSetNode {
 	GeeHashSetNode* next;
 	guint key_hash;
 };
+
 struct _GeeHashSetIterator {
 	GObject parent_instance;
 	GeeHashSetIteratorPrivate * priv;
 };
+
 struct _GeeHashSetIteratorClass {
 	GObjectClass parent_class;
 };
 
 
+
 struct _GeeHashSetPrivate {
 	gint _array_size;
 	gint _nnodes;
@@ -63,6 +66,7 @@ struct _GeeHashSetPrivate {
 	GBoxedCopyFunc g_dup_func;
 	GDestroyNotify g_destroy_func;
 };
+
 #define GEE_HASH_SET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_TYPE_HASH_SET, GeeHashSetPrivate))
 enum  {
 	GEE_HASH_SET_DUMMY_PROPERTY,
@@ -93,6 +97,7 @@ struct _GeeHashSetIteratorPrivate {
 	GBoxedCopyFunc g_dup_func;
 	GDestroyNotify g_destroy_func;
 };
+
 #define GEE_HASH_SET_ITERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_HASH_SET_TYPE_ITERATOR, GeeHashSetIteratorPrivate))
 enum  {
 	GEE_HASH_SET_ITERATOR_DUMMY_PROPERTY,
@@ -121,13 +126,31 @@ static const gint GEE_HASH_SET_MAX_SIZE = 13845163;
 
 
 GeeHashSet* gee_hash_set_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GHashFunc hash_func, GEqualFunc equal_func) {
+	GParameter * __params;
+	GParameter * __params_it;
 	GeeHashSet * self;
-	self = g_object_newv (GEE_TYPE_HASH_SET, 0, NULL);
+	__params = g_new0 (GParameter, 3);
+	__params_it = __params;
+	__params_it->name = "g-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, g_type);
+	__params_it++;
+	__params_it->name = "g-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_dup_func);
+	__params_it++;
+	__params_it->name = "g-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_destroy_func);
+	__params_it++;
+	self = g_object_newv (GEE_TYPE_HASH_SET, __params_it - __params, __params);
 	gee_hash_set_set_hash_func (self, hash_func);
 	gee_hash_set_set_equal_func (self, equal_func);
-	self->priv->g_type = g_type;
-	self->priv->g_dup_func = g_dup_func;
-	self->priv->g_destroy_func = g_destroy_func;
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -138,8 +161,8 @@ static GeeHashSetNode** gee_hash_set_lookup_node (GeeHashSet* self, gconstpointe
 	g_return_val_if_fail (GEE_IS_HASH_SET (self), NULL);
 	hash_value = self->priv->_hash_func (key);
 	node = &self->priv->_nodes[hash_value % self->priv->_array_size];
-	while ((*node) != NULL && (hash_value != (*node)->key_hash || !self->priv->_equal_func ((*node)->key, key))) {
-		node = &((*node)->next);
+	while (((*node)) != NULL && (hash_value != ((*node))->key_hash || !self->priv->_equal_func (((*node))->key, key))) {
+		node = &(((*node))->next);
 	}
 	return node;
 }
@@ -150,7 +173,7 @@ static gboolean gee_hash_set_real_contains (GeeCollection* base, gconstpointer k
 	GeeHashSetNode** node;
 	self = GEE_HASH_SET (base);
 	node = gee_hash_set_lookup_node (self, key);
-	return (*node != NULL);
+	return ((*node) != NULL);
 }
 
 
@@ -164,7 +187,7 @@ static GType gee_hash_set_real_get_element_type (GeeIterable* base) {
 static GeeIterator* gee_hash_set_real_iterator (GeeIterable* base) {
 	GeeHashSet * self;
 	self = GEE_HASH_SET (base);
-	return GEE_ITERATOR (gee_hash_set_iterator_new (self->priv->g_type, ((GBoxedCopyFunc) self->priv->g_dup_func), self->priv->g_destroy_func, self));
+	return GEE_ITERATOR (gee_hash_set_iterator_new (self->priv->g_type, ((GBoxedCopyFunc) (self->priv->g_dup_func)), self->priv->g_destroy_func, self));
 }
 
 
@@ -173,14 +196,14 @@ static gboolean gee_hash_set_real_add (GeeCollection* base, gconstpointer key) {
 	GeeHashSetNode** node;
 	self = GEE_HASH_SET (base);
 	node = gee_hash_set_lookup_node (self, key);
-	if (*node != NULL) {
+	if ((*node) != NULL) {
 		return FALSE;
 	} else {
 		guint hash_value;
 		gconstpointer _tmp1;
 		hash_value = self->priv->_hash_func (key);
 		_tmp1 = NULL;
-		*node = gee_hash_set_node_new ((_tmp1 = key, (_tmp1 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) _tmp1) : self->priv->g_dup_func (((gpointer) _tmp1)))), hash_value);
+		(*node) = gee_hash_set_node_new ((_tmp1 = key, (_tmp1 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) (_tmp1)) : self->priv->g_dup_func (((gpointer) (_tmp1))))), hash_value);
 		self->priv->_nnodes++;
 		gee_hash_set_resize (self);
 		self->priv->_stamp++;
@@ -194,11 +217,11 @@ static gboolean gee_hash_set_real_remove (GeeCollection* base, gconstpointer key
 	GeeHashSetNode** node;
 	self = GEE_HASH_SET (base);
 	node = gee_hash_set_lookup_node (self, key);
-	if (*node != NULL) {
+	if ((*node) != NULL) {
 		gpointer _tmp0;
 		_tmp0 = NULL;
-		(*node)->key = (_tmp0 = NULL, ((*node)->key == NULL || self->priv->g_destroy_func == NULL ? NULL : ((*node)->key = (self->priv->g_destroy_func ((*node)->key), NULL))), _tmp0);
-		*node = (*node)->next;
+		((*node))->key = (_tmp0 = NULL, (((*node))->key == NULL || self->priv->g_destroy_func == NULL ? NULL : (((*node))->key = (self->priv->g_destroy_func (((*node))->key), NULL))), _tmp0);
+		(*node) = ((*node))->next;
 		self->priv->_nnodes--;
 		gee_hash_set_resize (self);
 		self->priv->_stamp++;
@@ -214,7 +237,7 @@ static void gee_hash_set_real_clear (GeeCollection* base) {
 	{
 		gint i;
 		i = 0;
-		for (i = 0; i < self->priv->_array_size; i++) {
+		for (; i < self->priv->_array_size; i++) {
 			GeeHashSetNode* _tmp0;
 			GeeHashSetNode* node;
 			_tmp0 = NULL;
@@ -251,14 +274,14 @@ static void gee_hash_set_resize (GeeHashSet* self) {
 		GeeHashSetNode** new_nodes;
 		GeeHashSetNode** _tmp12;
 		GeeHashSetNode** _tmp11;
-		new_array_size = ((gint) g_spaced_primes_closest (((guint) self->priv->_nnodes)));
+		new_array_size = ((gint) (g_spaced_primes_closest (((guint) (self->priv->_nnodes)))));
 		new_array_size = CLAMP (new_array_size, GEE_HASH_SET_MIN_SIZE, GEE_HASH_SET_MAX_SIZE);
 		_tmp0 = NULL;
 		new_nodes = (_tmp0 = g_new0 (GeeHashSetNode*, new_array_size + 1), new_nodes_length1 = new_array_size, _tmp0);
 		{
 			gint i;
 			i = 0;
-			for (i = 0; i < self->priv->_array_size; i++) {
+			for (; i < self->priv->_array_size; i++) {
 				GeeHashSetNode* node;
 				GeeHashSetNode* next;
 				GeeHashSetNode* _tmp4;
@@ -296,9 +319,9 @@ static void gee_hash_set_resize (GeeHashSet* self) {
 		}
 		_tmp12 = NULL;
 		_tmp11 = NULL;
-		self->priv->_nodes = (_tmp12 = (_tmp11 = new_nodes, new_nodes = NULL, _tmp11), (self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) gee_hash_set_node_free)), NULL)), self->priv->_nodes_length1 = new_nodes_length1, _tmp12);
+		self->priv->_nodes = (_tmp12 = (_tmp11 = new_nodes, new_nodes = NULL, _tmp11), (self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) (gee_hash_set_node_free))), NULL)), self->priv->_nodes_length1 = new_nodes_length1, _tmp12);
 		self->priv->_array_size = new_array_size;
-		new_nodes = (_vala_array_free (new_nodes, new_nodes_length1, ((GDestroyNotify) gee_hash_set_node_free)), NULL);
+		new_nodes = (_vala_array_free (new_nodes, new_nodes_length1, ((GDestroyNotify) (gee_hash_set_node_free))), NULL);
 	}
 }
 
@@ -334,7 +357,7 @@ static GObject * gee_hash_set_constructor (GType type, guint n_construct_propert
 		GeeHashSetNode** _tmp0;
 		self->priv->_array_size = GEE_HASH_SET_MIN_SIZE;
 		_tmp0 = NULL;
-		self->priv->_nodes = (_tmp0 = g_new0 (GeeHashSetNode*, self->priv->_array_size + 1), (self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) gee_hash_set_node_free)), NULL)), self->priv->_nodes_length1 = self->priv->_array_size, _tmp0);
+		self->priv->_nodes = (_tmp0 = g_new0 (GeeHashSetNode*, self->priv->_array_size + 1), (self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) (gee_hash_set_node_free))), NULL)), self->priv->_nodes_length1 = self->priv->_array_size, _tmp0);
 	}
 	return obj;
 }
@@ -342,32 +365,47 @@ static GObject * gee_hash_set_constructor (GType type, guint n_construct_propert
 
 static GeeHashSetNode* gee_hash_set_node_new (gpointer k, guint hash) {
 	GeeHashSetNode* self;
-	gpointer _tmp1;
 	gpointer _tmp0;
 	self = g_slice_new0 (GeeHashSetNode);
-	_tmp1 = NULL;
 	_tmp0 = NULL;
-	self->key = (_tmp1 = (_tmp0 = k, k = NULL, _tmp0), NULL, _tmp1);
+	self->key = (_tmp0 = k, k = NULL, _tmp0);
 	self->key_hash = hash;
 	return self;
 }
 
 
 static void gee_hash_set_node_free (GeeHashSetNode* self) {
-	NULL;
 	(self->next == NULL ? NULL : (self->next = (gee_hash_set_node_free (self->next), NULL)));
 	g_slice_free (GeeHashSetNode, self);
 }
 
 
 static GeeHashSetIterator* gee_hash_set_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeHashSet* set) {
+	GParameter * __params;
+	GParameter * __params_it;
 	GeeHashSetIterator * self;
-	g_return_val_if_fail (set == NULL || GEE_IS_HASH_SET (set), NULL);
-	self = g_object_newv (GEE_HASH_SET_TYPE_ITERATOR, 0, NULL);
+	g_return_val_if_fail (GEE_IS_HASH_SET (set), NULL);
+	__params = g_new0 (GParameter, 3);
+	__params_it = __params;
+	__params_it->name = "g-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, g_type);
+	__params_it++;
+	__params_it->name = "g-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_dup_func);
+	__params_it++;
+	__params_it->name = "g-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_destroy_func);
+	__params_it++;
+	self = g_object_newv (GEE_HASH_SET_TYPE_ITERATOR, __params_it - __params, __params);
 	gee_hash_set_iterator_set_set (self, set);
-	self->priv->g_type = g_type;
-	self->priv->g_dup_func = g_dup_func;
-	self->priv->g_destroy_func = g_destroy_func;
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -393,7 +431,7 @@ static gpointer gee_hash_set_iterator_real_get (GeeIterator* base) {
 	g_assert (self->priv->_stamp == self->priv->_set->priv->_stamp);
 	g_assert (self->priv->_node != NULL);
 	_tmp0 = NULL;
-	return (_tmp0 = self->priv->_node->key, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) _tmp0) : self->priv->g_dup_func (((gpointer) _tmp0))));
+	return (_tmp0 = self->priv->_node->key, (_tmp0 == NULL || self->priv->g_dup_func == NULL ? ((gpointer) (_tmp0)) : self->priv->g_dup_func (((gpointer) (_tmp0)))));
 }
 
 
@@ -448,9 +486,9 @@ static void gee_hash_set_iterator_class_init (GeeHashSetIteratorClass * klass) {
 	G_OBJECT_CLASS (klass)->get_property = gee_hash_set_iterator_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_hash_set_iterator_set_property;
 	G_OBJECT_CLASS (klass)->dispose = gee_hash_set_iterator_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_ITERATOR_SET, g_param_spec_object ("set", "set", "set", GEE_TYPE_HASH_SET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
 
@@ -462,7 +500,7 @@ static void gee_hash_set_iterator_gee_iterator_interface_init (GeeIteratorIface
 }
 
 
-static void gee_hash_set_iterator_init (GeeHashSetIterator * self) {
+static void gee_hash_set_iterator_instance_init (GeeHashSetIterator * self) {
 	self->priv = GEE_HASH_SET_ITERATOR_GET_PRIVATE (self);
 	self->priv->_index = -1;
 	self->priv->_stamp = 0;
@@ -480,7 +518,7 @@ static void gee_hash_set_iterator_dispose (GObject * obj) {
 static GType gee_hash_set_iterator_get_type (void) {
 	static GType gee_hash_set_iterator_type_id = 0;
 	if (G_UNLIKELY (gee_hash_set_iterator_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeHashSetIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_hash_set_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeHashSetIterator), 0, (GInstanceInitFunc) gee_hash_set_iterator_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GeeHashSetIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_hash_set_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeHashSetIterator), 0, (GInstanceInitFunc) gee_hash_set_iterator_instance_init };
 		static const GInterfaceInfo gee_iterator_info = { (GInterfaceInitFunc) gee_hash_set_iterator_gee_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		gee_hash_set_iterator_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeHashSetIterator", &g_define_type_info, 0);
 		g_type_add_interface_static (gee_hash_set_iterator_type_id, GEE_TYPE_ITERATOR, &gee_iterator_info);
@@ -536,9 +574,9 @@ static void gee_hash_set_class_init (GeeHashSetClass * klass) {
 	G_OBJECT_CLASS (klass)->set_property = gee_hash_set_set_property;
 	G_OBJECT_CLASS (klass)->constructor = gee_hash_set_constructor;
 	G_OBJECT_CLASS (klass)->dispose = gee_hash_set_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_override_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_SIZE, "size");
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_HASH_FUNC, g_param_spec_pointer ("hash-func", "hash-func", "hash-func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_SET_EQUAL_FUNC, g_param_spec_pointer ("equal-func", "equal-func", "equal-func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
@@ -566,7 +604,7 @@ static void gee_hash_set_gee_set_interface_init (GeeSetIface * iface) {
 }
 
 
-static void gee_hash_set_init (GeeHashSet * self) {
+static void gee_hash_set_instance_init (GeeHashSet * self) {
 	self->priv = GEE_HASH_SET_GET_PRIVATE (self);
 	self->priv->_stamp = 0;
 }
@@ -578,7 +616,7 @@ static void gee_hash_set_dispose (GObject * obj) {
 	{
 		gee_collection_clear (GEE_COLLECTION (self));
 	}
-	self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) gee_hash_set_node_free)), NULL);
+	self->priv->_nodes = (_vala_array_free (self->priv->_nodes, self->priv->_nodes_length1, ((GDestroyNotify) (gee_hash_set_node_free))), NULL);
 	G_OBJECT_CLASS (gee_hash_set_parent_class)->dispose (obj);
 }
 
@@ -586,7 +624,7 @@ static void gee_hash_set_dispose (GObject * obj) {
 GType gee_hash_set_get_type (void) {
 	static GType gee_hash_set_type_id = 0;
 	if (G_UNLIKELY (gee_hash_set_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeHashSetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_hash_set_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeHashSet), 0, (GInstanceInitFunc) gee_hash_set_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GeeHashSetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_hash_set_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeHashSet), 0, (GInstanceInitFunc) gee_hash_set_instance_init };
 		static const GInterfaceInfo gee_iterable_info = { (GInterfaceInitFunc) gee_hash_set_gee_iterable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_collection_info = { (GInterfaceInitFunc) gee_hash_set_gee_collection_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_set_info = { (GInterfaceInitFunc) gee_hash_set_gee_set_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
@@ -604,12 +642,12 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 		int i;
 		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) array)[i] != NULL)
-			destroy_func (((gpointer*) array)[i]);
+			if (((gpointer*) (array))[i] != NULL)
+			destroy_func (((gpointer*) (array))[i]);
 		}
 		else
-		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) array)[i]);
+		for (i = 0; ((gpointer*) (array))[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) (array))[i]);
 		}
 	}
 	g_free (array);
