@@ -24,15 +24,17 @@
 
 
 
+
+
+
+
 /**
  * Returns the keys of this map as a read-only set.
  *
  * @return the keys of the map
  */
 GeeSet* gee_map_get_keys (GeeMap* self) {
-	GeeSet* result;
-	result = GEE_MAP_GET_INTERFACE (self)->get_keys (self);
-	return result;
+	return GEE_MAP_GET_INTERFACE (self)->get_keys (self);
 }
 
 
@@ -42,9 +44,7 @@ GeeSet* gee_map_get_keys (GeeMap* self) {
  * @return the values of the map
  */
 GeeCollection* gee_map_get_values (GeeMap* self) {
-	GeeCollection* result;
-	result = GEE_MAP_GET_INTERFACE (self)->get_values (self);
-	return result;
+	return GEE_MAP_GET_INTERFACE (self)->get_values (self);
 }
 
 
@@ -56,9 +56,7 @@ GeeCollection* gee_map_get_values (GeeMap* self) {
  * @return    true if key is found, false otherwise
  */
 gboolean gee_map_contains (GeeMap* self, gconstpointer key) {
-	gboolean result;
-	result = GEE_MAP_GET_INTERFACE (self)->contains (self, key);
-	return result;
+	return GEE_MAP_GET_INTERFACE (self)->contains (self, key);
 }
 
 
@@ -71,9 +69,7 @@ gboolean gee_map_contains (GeeMap* self, gconstpointer key) {
  *            couldn't be found
  */
 gpointer gee_map_get (GeeMap* self, gconstpointer key) {
-	gpointer result;
-	result = GEE_MAP_GET_INTERFACE (self)->get (self, key);
-	return result;
+	return GEE_MAP_GET_INTERFACE (self)->get (self, key);
 }
 
 
@@ -96,9 +92,7 @@ void gee_map_set (GeeMap* self, gconstpointer key, gconstpointer value) {
  * @return    true if the map has been changed, false otherwise
  */
 gboolean gee_map_remove (GeeMap* self, gconstpointer key) {
-	gboolean result;
-	result = GEE_MAP_GET_INTERFACE (self)->remove (self, key);
-	return result;
+	return GEE_MAP_GET_INTERFACE (self)->remove (self, key);
 }
 
 
