@@ -38,17 +38,20 @@ struct _GeeReadOnlyCollectionIterator {
 	GObject parent_instance;
 	GeeReadOnlyCollectionIteratorPrivate * priv;
 };
+
 struct _GeeReadOnlyCollectionIteratorClass {
 	GObjectClass parent_class;
 };
 
 
+
 struct _GeeReadOnlyCollectionPrivate {
 	GeeCollection* _collection;
 	GType g_type;
 	GBoxedCopyFunc g_dup_func;
 	GDestroyNotify g_destroy_func;
 };
+
 #define GEE_READ_ONLY_COLLECTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_TYPE_READ_ONLY_COLLECTION, GeeReadOnlyCollectionPrivate))
 enum  {
 	GEE_READ_ONLY_COLLECTION_DUMMY_PROPERTY,
@@ -69,6 +72,7 @@ struct _GeeReadOnlyCollectionIteratorPrivate {
 	GBoxedCopyFunc g_dup_func;
 	GDestroyNotify g_destroy_func;
 };
+
 #define GEE_READ_ONLY_COLLECTION_ITERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_READ_ONLY_COLLECTION_TYPE_ITERATOR, GeeReadOnlyCollectionIteratorPrivate))
 enum  {
 	GEE_READ_ONLY_COLLECTION_ITERATOR_DUMMY_PROPERTY,
@@ -90,13 +94,31 @@ static void gee_read_only_collection_dispose (GObject * obj);
 
 
 GeeReadOnlyCollection* gee_read_only_collection_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeCollection* collection) {
+	GParameter * __params;
+	GParameter * __params_it;
 	GeeReadOnlyCollection * self;
 	g_return_val_if_fail (collection == NULL || GEE_IS_COLLECTION (collection), NULL);
-	self = g_object_newv (GEE_TYPE_READ_ONLY_COLLECTION, 0, NULL);
+	__params = g_new0 (GParameter, 3);
+	__params_it = __params;
+	__params_it->name = "g-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, g_type);
+	__params_it++;
+	__params_it->name = "g-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_dup_func);
+	__params_it++;
+	__params_it->name = "g-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_destroy_func);
+	__params_it++;
+	self = g_object_newv (GEE_TYPE_READ_ONLY_COLLECTION, __params_it - __params, __params);
 	gee_read_only_collection_set_collection (self, collection);
-	self->priv->g_type = g_type;
-	self->priv->g_dup_func = g_dup_func;
-	self->priv->g_destroy_func = g_destroy_func;
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -112,7 +134,7 @@ static GeeIterator* gee_read_only_collection_real_iterator (GeeIterable* base) {
 	GeeReadOnlyCollection * self;
 	self = GEE_READ_ONLY_COLLECTION (base);
 	if (self->priv->_collection == NULL) {
-		return GEE_ITERATOR (gee_read_only_collection_iterator_new (self->priv->g_type, ((GBoxedCopyFunc) self->priv->g_dup_func), self->priv->g_destroy_func));
+		return GEE_ITERATOR (gee_read_only_collection_iterator_new (self->priv->g_type, ((GBoxedCopyFunc) (self->priv->g_dup_func)), self->priv->g_destroy_func));
 	}
 	return gee_iterable_iterator (GEE_ITERABLE (self->priv->_collection));
 }
@@ -180,11 +202,29 @@ static gpointer gee_read_only_collection_iterator_real_get (GeeIterator* base) {
 
 
 static GeeReadOnlyCollectionIterator* gee_read_only_collection_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func) {
+	GParameter * __params;
+	GParameter * __params_it;
 	GeeReadOnlyCollectionIterator * self;
-	self = g_object_newv (GEE_READ_ONLY_COLLECTION_TYPE_ITERATOR, 0, NULL);
-	self->priv->g_type = g_type;
-	self->priv->g_dup_func = g_dup_func;
-	self->priv->g_destroy_func = g_destroy_func;
+	__params = g_new0 (GParameter, 3);
+	__params_it = __params;
+	__params_it->name = "g-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, g_type);
+	__params_it++;
+	__params_it->name = "g-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_dup_func);
+	__params_it++;
+	__params_it->name = "g-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_destroy_func);
+	__params_it++;
+	self = g_object_newv (GEE_READ_ONLY_COLLECTION_TYPE_ITERATOR, __params_it - __params, __params);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -225,9 +265,9 @@ static void gee_read_only_collection_iterator_class_init (GeeReadOnlyCollectionI
 	g_type_class_add_private (klass, sizeof (GeeReadOnlyCollectionIteratorPrivate));
 	G_OBJECT_CLASS (klass)->get_property = gee_read_only_collection_iterator_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_read_only_collection_iterator_set_property;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 }
 
 
@@ -238,7 +278,7 @@ static void gee_read_only_collection_iterator_gee_iterator_interface_init (GeeIt
 }
 
 
-static void gee_read_only_collection_iterator_init (GeeReadOnlyCollectionIterator * self) {
+static void gee_read_only_collection_iterator_instance_init (GeeReadOnlyCollectionIterator * self) {
 	self->priv = GEE_READ_ONLY_COLLECTION_ITERATOR_GET_PRIVATE (self);
 }
 
@@ -246,7 +286,7 @@ static void gee_read_only_collection_iterator_init (GeeReadOnlyCollectionIterato
 static GType gee_read_only_collection_iterator_get_type (void) {
 	static GType gee_read_only_collection_iterator_type_id = 0;
 	if (G_UNLIKELY (gee_read_only_collection_iterator_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyCollectionIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_collection_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyCollectionIterator), 0, (GInstanceInitFunc) gee_read_only_collection_iterator_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyCollectionIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_collection_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyCollectionIterator), 0, (GInstanceInitFunc) gee_read_only_collection_iterator_instance_init };
 		static const GInterfaceInfo gee_iterator_info = { (GInterfaceInitFunc) gee_read_only_collection_iterator_gee_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		gee_read_only_collection_iterator_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeReadOnlyCollectionIterator", &g_define_type_info, 0);
 		g_type_add_interface_static (gee_read_only_collection_iterator_type_id, GEE_TYPE_ITERATOR, &gee_iterator_info);
@@ -298,9 +338,9 @@ static void gee_read_only_collection_class_init (GeeReadOnlyCollectionClass * kl
 	G_OBJECT_CLASS (klass)->get_property = gee_read_only_collection_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_read_only_collection_set_property;
 	G_OBJECT_CLASS (klass)->dispose = gee_read_only_collection_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_override_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_SIZE, "size");
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_COLLECTION_COLLECTION, g_param_spec_object ("collection", "collection", "collection", GEE_TYPE_COLLECTION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
@@ -322,7 +362,7 @@ static void gee_read_only_collection_gee_collection_interface_init (GeeCollectio
 }
 
 
-static void gee_read_only_collection_init (GeeReadOnlyCollection * self) {
+static void gee_read_only_collection_instance_init (GeeReadOnlyCollection * self) {
 	self->priv = GEE_READ_ONLY_COLLECTION_GET_PRIVATE (self);
 }
 
@@ -338,7 +378,7 @@ static void gee_read_only_collection_dispose (GObject * obj) {
 GType gee_read_only_collection_get_type (void) {
 	static GType gee_read_only_collection_type_id = 0;
 	if (G_UNLIKELY (gee_read_only_collection_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyCollectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_collection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyCollection), 0, (GInstanceInitFunc) gee_read_only_collection_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlyCollectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_collection_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlyCollection), 0, (GInstanceInitFunc) gee_read_only_collection_instance_init };
 		static const GInterfaceInfo gee_iterable_info = { (GInterfaceInitFunc) gee_read_only_collection_gee_iterable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_collection_info = { (GInterfaceInitFunc) gee_read_only_collection_gee_collection_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		gee_read_only_collection_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeReadOnlyCollection", &g_define_type_info, 0);
