@@ -38,17 +38,20 @@ struct _GeeReadOnlySetIterator {
 	GObject parent_instance;
 	GeeReadOnlySetIteratorPrivate * priv;
 };
+
 struct _GeeReadOnlySetIteratorClass {
 	GObjectClass parent_class;
 };
 
 
+
 struct _GeeReadOnlySetPrivate {
 	GeeSet* _set;
 	GType g_type;
 	GBoxedCopyFunc g_dup_func;
 	GDestroyNotify g_destroy_func;
 };
+
 #define GEE_READ_ONLY_SET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_TYPE_READ_ONLY_SET, GeeReadOnlySetPrivate))
 enum  {
 	GEE_READ_ONLY_SET_DUMMY_PROPERTY,
@@ -69,6 +72,7 @@ struct _GeeReadOnlySetIteratorPrivate {
 	GBoxedCopyFunc g_dup_func;
 	GDestroyNotify g_destroy_func;
 };
+
 #define GEE_READ_ONLY_SET_ITERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_READ_ONLY_SET_TYPE_ITERATOR, GeeReadOnlySetIteratorPrivate))
 enum  {
 	GEE_READ_ONLY_SET_ITERATOR_DUMMY_PROPERTY,
@@ -91,13 +95,31 @@ static void gee_read_only_set_dispose (GObject * obj);
 
 
 GeeReadOnlySet* gee_read_only_set_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeSet* set) {
+	GParameter * __params;
+	GParameter * __params_it;
 	GeeReadOnlySet * self;
 	g_return_val_if_fail (set == NULL || GEE_IS_SET (set), NULL);
-	self = g_object_newv (GEE_TYPE_READ_ONLY_SET, 0, NULL);
+	__params = g_new0 (GParameter, 3);
+	__params_it = __params;
+	__params_it->name = "g-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, g_type);
+	__params_it++;
+	__params_it->name = "g-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_dup_func);
+	__params_it++;
+	__params_it->name = "g-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_destroy_func);
+	__params_it++;
+	self = g_object_newv (GEE_TYPE_READ_ONLY_SET, __params_it - __params, __params);
 	gee_read_only_set_set_set (self, set);
-	self->priv->g_type = g_type;
-	self->priv->g_dup_func = g_dup_func;
-	self->priv->g_destroy_func = g_destroy_func;
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -113,7 +135,7 @@ static GeeIterator* gee_read_only_set_real_iterator (GeeIterable* base) {
 	GeeReadOnlySet * self;
 	self = GEE_READ_ONLY_SET (base);
 	if (self->priv->_set == NULL) {
-		return GEE_ITERATOR (gee_read_only_set_iterator_new (self->priv->g_type, ((GBoxedCopyFunc) self->priv->g_dup_func), self->priv->g_destroy_func));
+		return GEE_ITERATOR (gee_read_only_set_iterator_new (self->priv->g_type, ((GBoxedCopyFunc) (self->priv->g_dup_func)), self->priv->g_destroy_func));
 	}
 	return gee_iterable_iterator (GEE_ITERABLE (self->priv->_set));
 }
@@ -181,11 +203,29 @@ static gpointer gee_read_only_set_iterator_real_get (GeeIterator* base) {
 
 
 static GeeReadOnlySetIterator* gee_read_only_set_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func) {
+	GParameter * __params;
+	GParameter * __params_it;
 	GeeReadOnlySetIterator * self;
-	self = g_object_newv (GEE_READ_ONLY_SET_TYPE_ITERATOR, 0, NULL);
-	self->priv->g_type = g_type;
-	self->priv->g_dup_func = g_dup_func;
-	self->priv->g_destroy_func = g_destroy_func;
+	__params = g_new0 (GParameter, 3);
+	__params_it = __params;
+	__params_it->name = "g-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, g_type);
+	__params_it++;
+	__params_it->name = "g-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_dup_func);
+	__params_it++;
+	__params_it->name = "g-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, g_destroy_func);
+	__params_it++;
+	self = g_object_newv (GEE_READ_ONLY_SET_TYPE_ITERATOR, __params_it - __params, __params);
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -226,9 +266,9 @@ static void gee_read_only_set_iterator_class_init (GeeReadOnlySetIteratorClass *
 	g_type_class_add_private (klass, sizeof (GeeReadOnlySetIteratorPrivate));
 	G_OBJECT_CLASS (klass)->get_property = gee_read_only_set_iterator_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_read_only_set_iterator_set_property;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_ITERATOR_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_ITERATOR_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_ITERATOR_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 }
 
 
@@ -239,7 +279,7 @@ static void gee_read_only_set_iterator_gee_iterator_interface_init (GeeIteratorI
 }
 
 
-static void gee_read_only_set_iterator_init (GeeReadOnlySetIterator * self) {
+static void gee_read_only_set_iterator_instance_init (GeeReadOnlySetIterator * self) {
 	self->priv = GEE_READ_ONLY_SET_ITERATOR_GET_PRIVATE (self);
 }
 
@@ -247,7 +287,7 @@ static void gee_read_only_set_iterator_init (GeeReadOnlySetIterator * self) {
 static GType gee_read_only_set_iterator_get_type (void) {
 	static GType gee_read_only_set_iterator_type_id = 0;
 	if (G_UNLIKELY (gee_read_only_set_iterator_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlySetIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_set_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlySetIterator), 0, (GInstanceInitFunc) gee_read_only_set_iterator_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlySetIteratorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_set_iterator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlySetIterator), 0, (GInstanceInitFunc) gee_read_only_set_iterator_instance_init };
 		static const GInterfaceInfo gee_iterator_info = { (GInterfaceInitFunc) gee_read_only_set_iterator_gee_iterator_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		gee_read_only_set_iterator_type_id = g_type_register_static (G_TYPE_OBJECT, "GeeReadOnlySetIterator", &g_define_type_info, 0);
 		g_type_add_interface_static (gee_read_only_set_iterator_type_id, GEE_TYPE_ITERATOR, &gee_iterator_info);
@@ -299,9 +339,9 @@ static void gee_read_only_set_class_init (GeeReadOnlySetClass * klass) {
 	G_OBJECT_CLASS (klass)->get_property = gee_read_only_set_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_read_only_set_set_property;
 	G_OBJECT_CLASS (klass)->dispose = gee_read_only_set_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_G_TYPE, g_param_spec_gtype ("g-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_G_DUP_FUNC, g_param_spec_pointer ("g-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_G_DESTROY_FUNC, g_param_spec_pointer ("g-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_override_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_SIZE, "size");
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_READ_ONLY_SET_SET, g_param_spec_object ("set", "set", "set", GEE_TYPE_SET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
@@ -328,7 +368,7 @@ static void gee_read_only_set_gee_set_interface_init (GeeSetIface * iface) {
 }
 
 
-static void gee_read_only_set_init (GeeReadOnlySet * self) {
+static void gee_read_only_set_instance_init (GeeReadOnlySet * self) {
 	self->priv = GEE_READ_ONLY_SET_GET_PRIVATE (self);
 }
 
@@ -344,7 +384,7 @@ static void gee_read_only_set_dispose (GObject * obj) {
 GType gee_read_only_set_get_type (void) {
 	static GType gee_read_only_set_type_id = 0;
 	if (G_UNLIKELY (gee_read_only_set_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlySetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_set_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlySet), 0, (GInstanceInitFunc) gee_read_only_set_init };
+		static const GTypeInfo g_define_type_info = { sizeof (GeeReadOnlySetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gee_read_only_set_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GeeReadOnlySet), 0, (GInstanceInitFunc) gee_read_only_set_instance_init };
 		static const GInterfaceInfo gee_iterable_info = { (GInterfaceInitFunc) gee_read_only_set_gee_iterable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_collection_info = { (GInterfaceInitFunc) gee_read_only_set_gee_collection_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		static const GInterfaceInfo gee_set_info = { (GInterfaceInitFunc) gee_read_only_set_gee_set_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
