@@ -1,6 +1,6 @@
 /* readonlyset.vala
  *
- * Copyright (C) 2007  Jürg Billeter
+ * Copyright (C) 2007-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -48,17 +48,20 @@ typedef struct _GeeReadOnlySetPrivate GeeReadOnlySetPrivate;
  * Represents a read-only collection of items without duplicates.
  */
 struct _GeeReadOnlySet {
-	GObject parent;
+	GObject parent_instance;
 	GeeReadOnlySetPrivate * priv;
 };
+
 struct _GeeReadOnlySetClass {
-	GObjectClass parent;
+	GObjectClass parent_class;
 };
 
-GeeReadOnlySet* gee_read_only_set_new (GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeSet* set);
+
+GeeReadOnlySet* gee_read_only_set_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeSet* set);
 void gee_read_only_set_set_set (GeeReadOnlySet* self, GeeSet* value);
 GType gee_read_only_set_get_type (void);
 
+
 G_END_DECLS
 
 #endif
