@@ -498,6 +498,7 @@ static void vala_project_generator_create_project (ValaProjectGenerator* self) {
 		inner_error = NULL;
 		{
 			g_critical ("valaprojectgenerator.vala:236: Error while creating project: %s", e->message);
+			(e == NULL ? NULL : (e = (g_error_free (e), NULL)));
 		}
 	}
 	__finally0:
@@ -526,6 +527,7 @@ static void vala_project_generator_write_autogen_sh (ValaProjectGenerator* self,
 	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/autogen.sh", NULL)), s->str, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
+		(s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL)));
 		return;
 	}
 	_tmp0 = (g_free (_tmp0), NULL);
@@ -584,6 +586,7 @@ static void vala_project_generator_write_configure_ac (ValaProjectGenerator* sel
 	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/configure.ac", NULL)), s->str, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
+		(s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL)));
 		return;
 	}
 	_tmp0 = (g_free (_tmp0), NULL);
@@ -649,6 +652,7 @@ static void vala_project_generator_write_makefile_am (ValaProjectGenerator* self
 	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/Makefile.am", NULL)), s->str, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
+		(s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL)));
 		return;
 	}
 	_tmp0 = (g_free (_tmp0), NULL);
@@ -675,7 +679,7 @@ static char* vala_project_generator_generate_source_file_header (ValaProjectGene
 	g_date_set_time_val (&d, &tv);
 	g_string_append_printf (s, "/* %s\n", filename);
 	g_string_append (s, " *\n");
-	g_string_append_printf (s, " * Copyright (C) %d  %s\n", g_date_get_year (&d), self->priv->real_name);
+	g_string_append_printf (s, " * Copyright (C) %d  %s\n", ((gint) (g_date_get_year (&d))), self->priv->real_name);
 	g_string_append (s, " *\n");
 	license_name = g_strdup ("");
 	license_version = NULL;
@@ -784,6 +788,7 @@ static void vala_project_generator_write_main_vala (ValaProjectGenerator* self,
 	g_file_set_contents ((_tmp1 = g_strconcat (self->priv->project_path, "/src/main.vala", NULL)), s->str, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
+		(s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL)));
 		return;
 	}
 	_tmp1 = (g_free (_tmp1), NULL);
@@ -895,6 +900,7 @@ static void vala_project_generator_write_mainwindow_vala (ValaProjectGenerator*
 	g_file_set_contents ((_tmp2 = g_strconcat (self->priv->project_path, "/src/mainwindow.vala", NULL)), s->str, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
+		(s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL)));
 		return;
 	}
 	_tmp2 = (g_free (_tmp2), NULL);
@@ -922,6 +928,7 @@ static void vala_project_generator_write_potfiles (ValaProjectGenerator* self, G
 	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/po/POTFILES.in", NULL)), s->str, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
+		(s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL)));
 		return;
 	}
 	_tmp0 = (g_free (_tmp0), NULL);
@@ -931,6 +938,7 @@ static void vala_project_generator_write_potfiles (ValaProjectGenerator* self, G
 		g_file_set_contents ((_tmp1 = g_strconcat (self->priv->project_path, "/po/POTFILES.skip", NULL)), "src/mainwindow.c\n", ((glong) (-1)), &inner_error);
 		if (inner_error != NULL) {
 			g_propagate_error (error, inner_error);
+			(s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL)));
 			return;
 		}
 		_tmp1 = (g_free (_tmp1), NULL);
@@ -940,6 +948,7 @@ static void vala_project_generator_write_potfiles (ValaProjectGenerator* self, G
 		g_file_set_contents ((_tmp2 = g_strconcat (self->priv->project_path, "/po/POTFILES.skip", NULL)), "src/main.c\n", ((glong) (-1)), &inner_error);
 		if (inner_error != NULL) {
 			g_propagate_error (error, inner_error);
+			(s == NULL ? NULL : (s = (g_string_free (s, TRUE), NULL)));
 			return;
 		}
 		_tmp2 = (g_free (_tmp2), NULL);
@@ -959,6 +968,7 @@ static void vala_project_generator_write_linguas (ValaProjectGenerator* self, GE
 	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/po/LINGUAS", NULL)), s, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
+		s = (g_free (s), NULL);
 		return;
 	}
 	_tmp0 = (g_free (_tmp0), NULL);
@@ -977,6 +987,7 @@ static void vala_project_generator_write_authors (ValaProjectGenerator* self, GE
 	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/AUTHORS", NULL)), s, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
+		s = (g_free (s), NULL);
 		return;
 	}
 	_tmp0 = (g_free (_tmp0), NULL);
@@ -995,6 +1006,7 @@ static void vala_project_generator_write_maintainers (ValaProjectGenerator* self
 	g_file_set_contents ((_tmp0 = g_strconcat (self->priv->project_path, "/MAINTAINERS", NULL)), s, ((glong) (-1)), &inner_error);
 	if (inner_error != NULL) {
 		g_propagate_error (error, inner_error);
+		s = (g_free (s), NULL);
 		return;
 	}
 	_tmp0 = (g_free (_tmp0), NULL);
