@@ -46,13 +46,14 @@
 #include <vala/valareport.h>
 #include <vala/valasourcereference.h>
 #include <ccode/valaccodeidentifier.h>
+#include <vala/valaelementaccess.h>
+#include <gee/list.h>
+#include <vala/valastringliteral.h>
 #include <vala/valasymbol.h>
 #include <vala/valalocalvariable.h>
-#include <gee/list.h>
 #include <ccode/valaccodeunaryexpression.h>
 #include <ccode/valaccodecastexpression.h>
 #include <vala/valalambdaexpression.h>
-#include <vala/valaelementaccess.h>
 #include <gee/iterable.h>
 #include <gee/iterator.h>
 #include <vala/valascope.h>
@@ -206,168 +207,229 @@ static void vala_ccode_assignment_binding_emit_property_assignment (ValaCCodeAss
 
 
 static void vala_ccode_assignment_binding_emit_signal_assignment (ValaCCodeAssignmentBinding* self) {
-	ValaMemberAccess* _tmp1;
-	ValaExpression* _tmp0;
-	ValaMemberAccess* ma;
-	ValaSignal* _tmp2;
+	ValaSignal* _tmp0;
 	ValaSignal* sig;
-	ValaMethod* _tmp3;
+	ValaMethod* _tmp1;
 	ValaMethod* m;
 	char* connect_func;
 	gboolean disconnect;
-	ValaCCodeIdentifier* _tmp11;
-	ValaCCodeFunctionCall* _tmp12;
+	ValaCCodeIdentifier* _tmp9;
+	ValaCCodeFunctionCall* _tmp10;
 	ValaCCodeFunctionCall* ccall;
-	ValaCCodeCastExpression* _tmp31;
+	char* signal_detail;
+	ValaMemberAccess* ma;
+	ValaCCodeCastExpression* _tmp41;
 	g_return_if_fail (VALA_IS_CCODE_ASSIGNMENT_BINDING (self));
-	_tmp1 = NULL;
 	_tmp0 = NULL;
-	ma = (_tmp1 = (_tmp0 = vala_assignment_get_left (self->priv->_assignment), (VALA_IS_MEMBER_ACCESS (_tmp0) ? ((ValaMemberAccess*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
-	_tmp2 = NULL;
-	sig = (_tmp2 = VALA_SIGNAL (vala_expression_get_symbol_reference (vala_assignment_get_left (self->priv->_assignment))), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)));
-	_tmp3 = NULL;
-	m = (_tmp3 = VALA_METHOD (vala_expression_get_symbol_reference (vala_assignment_get_right (self->priv->_assignment))), (_tmp3 == NULL ? NULL : g_object_ref (_tmp3)));
+	sig = (_tmp0 = VALA_SIGNAL (vala_expression_get_symbol_reference (vala_assignment_get_left (self->priv->_assignment))), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+	_tmp1 = NULL;
+	m = (_tmp1 = VALA_METHOD (vala_expression_get_symbol_reference (vala_assignment_get_right (self->priv->_assignment))), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
 	connect_func = NULL;
 	disconnect = FALSE;
 	if (vala_assignment_get_operator (self->priv->_assignment) == VALA_ASSIGNMENT_OPERATOR_ADD) {
 		if (VALA_IS_DYNAMIC_SIGNAL (sig)) {
-			char* _tmp5;
-			ValaCCodeDynamicSignalBinding* _tmp4;
-			_tmp5 = NULL;
-			_tmp4 = NULL;
-			connect_func = (_tmp5 = vala_ccode_dynamic_signal_binding_get_connect_wrapper_name ((_tmp4 = vala_ccode_generator_dynamic_signal_binding (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), VALA_DYNAMIC_SIGNAL (sig)))), (connect_func = (g_free (connect_func), NULL)), _tmp5);
-			(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
+			char* _tmp3;
+			ValaCCodeDynamicSignalBinding* _tmp2;
+			_tmp3 = NULL;
+			_tmp2 = NULL;
+			connect_func = (_tmp3 = vala_ccode_dynamic_signal_binding_get_connect_wrapper_name ((_tmp2 = vala_ccode_generator_dynamic_signal_binding (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), VALA_DYNAMIC_SIGNAL (sig)))), (connect_func = (g_free (connect_func), NULL)), _tmp3);
+			(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
 		} else {
-			char* _tmp6;
-			_tmp6 = NULL;
-			connect_func = (_tmp6 = g_strdup ("g_signal_connect_object"), (connect_func = (g_free (connect_func), NULL)), _tmp6);
+			char* _tmp4;
+			_tmp4 = NULL;
+			connect_func = (_tmp4 = g_strdup ("g_signal_connect_object"), (connect_func = (g_free (connect_func), NULL)), _tmp4);
 			if (vala_method_get_binding (m) != MEMBER_BINDING_INSTANCE) {
-				char* _tmp7;
-				_tmp7 = NULL;
-				connect_func = (_tmp7 = g_strdup ("g_signal_connect"), (connect_func = (g_free (connect_func), NULL)), _tmp7);
+				char* _tmp5;
+				_tmp5 = NULL;
+				connect_func = (_tmp5 = g_strdup ("g_signal_connect"), (connect_func = (g_free (connect_func), NULL)), _tmp5);
 			}
 		}
 	} else {
 		if (vala_assignment_get_operator (self->priv->_assignment) == VALA_ASSIGNMENT_OPERATOR_SUB) {
 			if (VALA_IS_DYNAMIC_SIGNAL (sig)) {
-				char* _tmp9;
-				ValaCCodeDynamicSignalBinding* _tmp8;
-				_tmp9 = NULL;
-				_tmp8 = NULL;
-				connect_func = (_tmp9 = vala_ccode_dynamic_signal_binding_get_disconnect_wrapper_name ((_tmp8 = vala_ccode_generator_dynamic_signal_binding (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), VALA_DYNAMIC_SIGNAL (sig)))), (connect_func = (g_free (connect_func), NULL)), _tmp9);
-				(_tmp8 == NULL ? NULL : (_tmp8 = (g_object_unref (_tmp8), NULL)));
+				char* _tmp7;
+				ValaCCodeDynamicSignalBinding* _tmp6;
+				_tmp7 = NULL;
+				_tmp6 = NULL;
+				connect_func = (_tmp7 = vala_ccode_dynamic_signal_binding_get_disconnect_wrapper_name ((_tmp6 = vala_ccode_generator_dynamic_signal_binding (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), VALA_DYNAMIC_SIGNAL (sig)))), (connect_func = (g_free (connect_func), NULL)), _tmp7);
+				(_tmp6 == NULL ? NULL : (_tmp6 = (g_object_unref (_tmp6), NULL)));
 			} else {
-				char* _tmp10;
-				_tmp10 = NULL;
-				connect_func = (_tmp10 = g_strdup ("g_signal_handlers_disconnect_matched"), (connect_func = (g_free (connect_func), NULL)), _tmp10);
+				char* _tmp8;
+				_tmp8 = NULL;
+				connect_func = (_tmp8 = g_strdup ("g_signal_handlers_disconnect_matched"), (connect_func = (g_free (connect_func), NULL)), _tmp8);
 			}
 			disconnect = TRUE;
 		} else {
 			vala_code_node_set_error (VALA_CODE_NODE (self->priv->_assignment), TRUE);
 			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self->priv->_assignment)), "Specified compound assignment type for signals not supported.");
-			(ma == NULL ? NULL : (ma = (g_object_unref (ma), NULL)));
 			(sig == NULL ? NULL : (sig = (g_object_unref (sig), NULL)));
 			(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
 			connect_func = (g_free (connect_func), NULL);
 			return;
 		}
 	}
-	_tmp11 = NULL;
-	_tmp12 = NULL;
-	ccall = (_tmp12 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp11 = vala_ccode_identifier_new (connect_func)))), (_tmp11 == NULL ? NULL : (_tmp11 = (g_object_unref (_tmp11), NULL))), _tmp12);
+	_tmp9 = NULL;
+	_tmp10 = NULL;
+	ccall = (_tmp10 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp9 = vala_ccode_identifier_new (connect_func)))), (_tmp9 == NULL ? NULL : (_tmp9 = (g_object_unref (_tmp9), NULL))), _tmp10);
+	signal_detail = NULL;
 	/* first argument: instance of sender*/
+	ma = NULL;
+	if (VALA_IS_ELEMENT_ACCESS (vala_assignment_get_left (self->priv->_assignment))) {
+		ValaElementAccess* _tmp11;
+		ValaElementAccess* ea;
+		ValaMemberAccess* _tmp13;
+		ValaMemberAccess* _tmp12;
+		GeeList* _tmp14;
+		ValaExpression* _tmp15;
+		ValaStringLiteral* _tmp16;
+		ValaStringLiteral* detail_expr;
+		char* _tmp17;
+		_tmp11 = NULL;
+		ea = (_tmp11 = VALA_ELEMENT_ACCESS (vala_assignment_get_left (self->priv->_assignment)), (_tmp11 == NULL ? NULL : g_object_ref (_tmp11)));
+		_tmp13 = NULL;
+		_tmp12 = NULL;
+		ma = (_tmp13 = (_tmp12 = VALA_MEMBER_ACCESS (vala_element_access_get_container (ea)), (_tmp12 == NULL ? NULL : g_object_ref (_tmp12))), (ma == NULL ? NULL : (ma = (g_object_unref (ma), NULL))), _tmp13);
+		_tmp14 = NULL;
+		_tmp15 = NULL;
+		_tmp16 = NULL;
+		detail_expr = (_tmp16 = (_tmp15 = ((ValaExpression*) (gee_list_get ((_tmp14 = vala_element_access_get_indices (ea)), 0))), (VALA_IS_STRING_LITERAL (_tmp15) ? ((ValaStringLiteral*) (_tmp15)) : NULL)), (_tmp14 == NULL ? NULL : (_tmp14 = (g_object_unref (_tmp14), NULL))), _tmp16);
+		if (detail_expr == NULL) {
+			vala_code_node_set_error (VALA_CODE_NODE (self->priv->_assignment), TRUE);
+			vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (detail_expr)), "internal error: only literal string details supported");
+			(ea == NULL ? NULL : (ea = (g_object_unref (ea), NULL)));
+			(detail_expr == NULL ? NULL : (detail_expr = (g_object_unref (detail_expr), NULL)));
+			(sig == NULL ? NULL : (sig = (g_object_unref (sig), NULL)));
+			(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
+			connect_func = (g_free (connect_func), NULL);
+			(ccall == NULL ? NULL : (ccall = (g_object_unref (ccall), NULL)));
+			signal_detail = (g_free (signal_detail), NULL);
+			(ma == NULL ? NULL : (ma = (g_object_unref (ma), NULL)));
+			return;
+		}
+		_tmp17 = NULL;
+		signal_detail = (_tmp17 = vala_string_literal_eval (detail_expr), (signal_detail = (g_free (signal_detail), NULL)), _tmp17);
+		(ea == NULL ? NULL : (ea = (g_object_unref (ea), NULL)));
+		(detail_expr == NULL ? NULL : (detail_expr = (g_object_unref (detail_expr), NULL)));
+	} else {
+		ValaMemberAccess* _tmp19;
+		ValaMemberAccess* _tmp18;
+		_tmp19 = NULL;
+		_tmp18 = NULL;
+		ma = (_tmp19 = (_tmp18 = VALA_MEMBER_ACCESS (vala_assignment_get_left (self->priv->_assignment)), (_tmp18 == NULL ? NULL : g_object_ref (_tmp18))), (ma == NULL ? NULL : (ma = (g_object_unref (ma), NULL))), _tmp19);
+	}
 	if (vala_member_access_get_inner (ma) != NULL) {
 		vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (vala_member_access_get_inner (ma)))));
 	} else {
-		ValaCCodeIdentifier* _tmp13;
-		_tmp13 = NULL;
-		vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp13 = vala_ccode_identifier_new ("self"))));
-		(_tmp13 == NULL ? NULL : (_tmp13 = (g_object_unref (_tmp13), NULL)));
+		ValaCCodeIdentifier* _tmp20;
+		_tmp20 = NULL;
+		vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp20 = vala_ccode_identifier_new ("self"))));
+		(_tmp20 == NULL ? NULL : (_tmp20 = (g_object_unref (_tmp20), NULL)));
 	}
 	if (VALA_IS_DYNAMIC_SIGNAL (sig)) {
-		ValaCCodeConstant* _tmp15;
-		char* _tmp14;
+		ValaCCodeConstant* _tmp22;
+		char* _tmp21;
 		/* dynamic_signal_connect or dynamic_signal_disconnect
 		 second argument: signal name*/
-		_tmp15 = NULL;
-		_tmp14 = NULL;
-		vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp15 = vala_ccode_constant_new ((_tmp14 = g_strdup_printf ("\"%s\"", vala_symbol_get_name (VALA_SYMBOL (sig))))))));
-		(_tmp15 == NULL ? NULL : (_tmp15 = (g_object_unref (_tmp15), NULL)));
-		_tmp14 = (g_free (_tmp14), NULL);
+		_tmp22 = NULL;
+		_tmp21 = NULL;
+		vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp22 = vala_ccode_constant_new ((_tmp21 = g_strdup_printf ("\"%s\"", vala_symbol_get_name (VALA_SYMBOL (sig))))))));
+		(_tmp22 == NULL ? NULL : (_tmp22 = (g_object_unref (_tmp22), NULL)));
+		_tmp21 = (g_free (_tmp21), NULL);
 	} else {
 		if (!disconnect) {
-			ValaCCodeConstant* _tmp16;
+			ValaCCodeConstant* _tmp23;
 			/* g_signal_connect_object or g_signal_connect
 			 second argument: signal name*/
-			_tmp16 = NULL;
-			vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp16 = vala_signal_get_canonical_cconstant (sig))));
-			(_tmp16 == NULL ? NULL : (_tmp16 = (g_object_unref (_tmp16), NULL)));
+			_tmp23 = NULL;
+			vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp23 = vala_signal_get_canonical_cconstant (sig, signal_detail))));
+			(_tmp23 == NULL ? NULL : (_tmp23 = (g_object_unref (_tmp23), NULL)));
 		} else {
-			ValaCCodeConstant* _tmp17;
 			ValaCCodeCommaExpression* ccomma;
 			ValaLocalVariable* temp_decl;
-			ValaCCodeIdentifier* _tmp18;
-			ValaCCodeFunctionCall* _tmp19;
+			ValaCCodeIdentifier* _tmp26;
+			ValaCCodeFunctionCall* _tmp27;
 			ValaCCodeFunctionCall* parse_call;
-			ValaCCodeConstant* _tmp20;
-			ValaTypeSymbol* _tmp21;
+			ValaCCodeConstant* _tmp28;
+			ValaTypeSymbol* _tmp29;
 			ValaTypeSymbol* decl_type;
-			ValaCCodeIdentifier* _tmp23;
-			char* _tmp22;
-			ValaCCodeUnaryExpression* _tmp25;
-			ValaCCodeIdentifier* _tmp24;
-			ValaCCodeConstant* _tmp26;
-			ValaCCodeConstant* _tmp27;
-			ValaCCodeIdentifier* _tmp28;
-			ValaCCodeConstant* _tmp29;
-			ValaCCodeConstant* _tmp30;
+			ValaCCodeIdentifier* _tmp31;
+			char* _tmp30;
+			ValaCCodeUnaryExpression* _tmp33;
+			ValaCCodeIdentifier* _tmp32;
+			ValaCCodeConstant* _tmp37;
+			ValaCCodeIdentifier* _tmp38;
+			ValaCCodeConstant* _tmp39;
+			ValaCCodeConstant* _tmp40;
 			/* g_signal_handlers_disconnect_matched
 			 second argument: mask*/
-			_tmp17 = NULL;
-			vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp17 = vala_ccode_constant_new ("G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA"))));
-			(_tmp17 == NULL ? NULL : (_tmp17 = (g_object_unref (_tmp17), NULL)));
+			if (signal_detail == NULL) {
+				ValaCCodeConstant* _tmp24;
+				_tmp24 = NULL;
+				vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp24 = vala_ccode_constant_new ("G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA"))));
+				(_tmp24 == NULL ? NULL : (_tmp24 = (g_object_unref (_tmp24), NULL)));
+			} else {
+				ValaCCodeConstant* _tmp25;
+				_tmp25 = NULL;
+				vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp25 = vala_ccode_constant_new ("G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_DETAIL | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA"))));
+				(_tmp25 == NULL ? NULL : (_tmp25 = (g_object_unref (_tmp25), NULL)));
+			}
 			/* get signal id*/
 			ccomma = vala_ccode_comma_expression_new ();
 			temp_decl = vala_ccode_generator_get_temp_variable (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->uint_type, TRUE, NULL);
 			gee_list_insert (GEE_LIST (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->temp_vars), 0, temp_decl);
-			_tmp18 = NULL;
-			_tmp19 = NULL;
-			parse_call = (_tmp19 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp18 = vala_ccode_identifier_new ("g_signal_parse_name")))), (_tmp18 == NULL ? NULL : (_tmp18 = (g_object_unref (_tmp18), NULL))), _tmp19);
-			_tmp20 = NULL;
-			vala_ccode_function_call_add_argument (parse_call, VALA_CCODE_EXPRESSION ((_tmp20 = vala_signal_get_canonical_cconstant (sig))));
-			(_tmp20 == NULL ? NULL : (_tmp20 = (g_object_unref (_tmp20), NULL)));
-			_tmp21 = NULL;
-			decl_type = (_tmp21 = VALA_TYPESYMBOL (vala_symbol_get_parent_symbol (VALA_SYMBOL (sig))), (_tmp21 == NULL ? NULL : g_object_ref (_tmp21)));
-			_tmp23 = NULL;
-			_tmp22 = NULL;
-			vala_ccode_function_call_add_argument (parse_call, VALA_CCODE_EXPRESSION ((_tmp23 = vala_ccode_identifier_new ((_tmp22 = vala_typesymbol_get_type_id (decl_type))))));
-			(_tmp23 == NULL ? NULL : (_tmp23 = (g_object_unref (_tmp23), NULL)));
-			_tmp22 = (g_free (_tmp22), NULL);
-			_tmp25 = NULL;
-			_tmp24 = NULL;
-			vala_ccode_function_call_add_argument (parse_call, VALA_CCODE_EXPRESSION ((_tmp25 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, VALA_CCODE_EXPRESSION ((_tmp24 = vala_ccode_identifier_new (vala_symbol_get_name (VALA_SYMBOL (temp_decl)))))))));
-			(_tmp25 == NULL ? NULL : (_tmp25 = (g_object_unref (_tmp25), NULL)));
-			(_tmp24 == NULL ? NULL : (_tmp24 = (g_object_unref (_tmp24), NULL)));
 			_tmp26 = NULL;
-			vala_ccode_function_call_add_argument (parse_call, VALA_CCODE_EXPRESSION ((_tmp26 = vala_ccode_constant_new ("NULL"))));
-			(_tmp26 == NULL ? NULL : (_tmp26 = (g_object_unref (_tmp26), NULL)));
 			_tmp27 = NULL;
-			vala_ccode_function_call_add_argument (parse_call, VALA_CCODE_EXPRESSION ((_tmp27 = vala_ccode_constant_new ("FALSE"))));
-			(_tmp27 == NULL ? NULL : (_tmp27 = (g_object_unref (_tmp27), NULL)));
-			vala_ccode_comma_expression_append_expression (ccomma, VALA_CCODE_EXPRESSION (parse_call));
+			parse_call = (_tmp27 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp26 = vala_ccode_identifier_new ("g_signal_parse_name")))), (_tmp26 == NULL ? NULL : (_tmp26 = (g_object_unref (_tmp26), NULL))), _tmp27);
 			_tmp28 = NULL;
-			vala_ccode_comma_expression_append_expression (ccomma, VALA_CCODE_EXPRESSION ((_tmp28 = vala_ccode_identifier_new (vala_symbol_get_name (VALA_SYMBOL (temp_decl))))));
+			vala_ccode_function_call_add_argument (parse_call, VALA_CCODE_EXPRESSION ((_tmp28 = vala_signal_get_canonical_cconstant (sig, signal_detail))));
 			(_tmp28 == NULL ? NULL : (_tmp28 = (g_object_unref (_tmp28), NULL)));
+			_tmp29 = NULL;
+			decl_type = (_tmp29 = VALA_TYPESYMBOL (vala_symbol_get_parent_symbol (VALA_SYMBOL (sig))), (_tmp29 == NULL ? NULL : g_object_ref (_tmp29)));
+			_tmp31 = NULL;
+			_tmp30 = NULL;
+			vala_ccode_function_call_add_argument (parse_call, VALA_CCODE_EXPRESSION ((_tmp31 = vala_ccode_identifier_new ((_tmp30 = vala_typesymbol_get_type_id (decl_type))))));
+			(_tmp31 == NULL ? NULL : (_tmp31 = (g_object_unref (_tmp31), NULL)));
+			_tmp30 = (g_free (_tmp30), NULL);
+			_tmp33 = NULL;
+			_tmp32 = NULL;
+			vala_ccode_function_call_add_argument (parse_call, VALA_CCODE_EXPRESSION ((_tmp33 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, VALA_CCODE_EXPRESSION ((_tmp32 = vala_ccode_identifier_new (vala_symbol_get_name (VALA_SYMBOL (temp_decl)))))))));
+			(_tmp33 == NULL ? NULL : (_tmp33 = (g_object_unref (_tmp33), NULL)));
+			(_tmp32 == NULL ? NULL : (_tmp32 = (g_object_unref (_tmp32), NULL)));
+			if (signal_detail == NULL) {
+				ValaCCodeConstant* _tmp34;
+				_tmp34 = NULL;
+				vala_ccode_function_call_add_argument (parse_call, VALA_CCODE_EXPRESSION ((_tmp34 = vala_ccode_constant_new ("NULL"))));
+				(_tmp34 == NULL ? NULL : (_tmp34 = (g_object_unref (_tmp34), NULL)));
+			} else {
+				ValaLocalVariable* detail_temp_decl;
+				ValaCCodeUnaryExpression* _tmp36;
+				ValaCCodeIdentifier* _tmp35;
+				detail_temp_decl = vala_ccode_generator_get_temp_variable (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->gquark_type, TRUE, NULL);
+				gee_list_insert (GEE_LIST (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->temp_vars), 0, detail_temp_decl);
+				_tmp36 = NULL;
+				_tmp35 = NULL;
+				vala_ccode_function_call_add_argument (parse_call, VALA_CCODE_EXPRESSION ((_tmp36 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, VALA_CCODE_EXPRESSION ((_tmp35 = vala_ccode_identifier_new (vala_symbol_get_name (VALA_SYMBOL (detail_temp_decl)))))))));
+				(_tmp36 == NULL ? NULL : (_tmp36 = (g_object_unref (_tmp36), NULL)));
+				(_tmp35 == NULL ? NULL : (_tmp35 = (g_object_unref (_tmp35), NULL)));
+				(detail_temp_decl == NULL ? NULL : (detail_temp_decl = (g_object_unref (detail_temp_decl), NULL)));
+			}
+			_tmp37 = NULL;
+			vala_ccode_function_call_add_argument (parse_call, VALA_CCODE_EXPRESSION ((_tmp37 = vala_ccode_constant_new ("FALSE"))));
+			(_tmp37 == NULL ? NULL : (_tmp37 = (g_object_unref (_tmp37), NULL)));
+			vala_ccode_comma_expression_append_expression (ccomma, VALA_CCODE_EXPRESSION (parse_call));
+			_tmp38 = NULL;
+			vala_ccode_comma_expression_append_expression (ccomma, VALA_CCODE_EXPRESSION ((_tmp38 = vala_ccode_identifier_new (vala_symbol_get_name (VALA_SYMBOL (temp_decl))))));
+			(_tmp38 == NULL ? NULL : (_tmp38 = (g_object_unref (_tmp38), NULL)));
 			/* third argument: signal_id*/
 			vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION (ccomma));
 			/* fourth argument: detail*/
-			_tmp29 = NULL;
-			vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp29 = vala_ccode_constant_new ("0"))));
-			(_tmp29 == NULL ? NULL : (_tmp29 = (g_object_unref (_tmp29), NULL)));
+			_tmp39 = NULL;
+			vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp39 = vala_ccode_constant_new ("0"))));
+			(_tmp39 == NULL ? NULL : (_tmp39 = (g_object_unref (_tmp39), NULL)));
 			/* fifth argument: closure*/
-			_tmp30 = NULL;
-			vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp30 = vala_ccode_constant_new ("NULL"))));
-			(_tmp30 == NULL ? NULL : (_tmp30 = (g_object_unref (_tmp30), NULL)));
+			_tmp40 = NULL;
+			vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp40 = vala_ccode_constant_new ("NULL"))));
+			(_tmp40 == NULL ? NULL : (_tmp40 = (g_object_unref (_tmp40), NULL)));
 			(ccomma == NULL ? NULL : (ccomma = (g_object_unref (ccomma), NULL)));
 			(temp_decl == NULL ? NULL : (temp_decl = (g_object_unref (temp_decl), NULL)));
 			(parse_call == NULL ? NULL : (parse_call = (g_object_unref (parse_call), NULL)));
@@ -375,58 +437,59 @@ static void vala_ccode_assignment_binding_emit_signal_assignment (ValaCCodeAssig
 		}
 	}
 	/* third resp. sixth argument: handler*/
-	_tmp31 = NULL;
-	vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp31 = vala_ccode_cast_expression_new (VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (vala_assignment_get_right (self->priv->_assignment)))), "GCallback"))));
-	(_tmp31 == NULL ? NULL : (_tmp31 = (g_object_unref (_tmp31), NULL)));
+	_tmp41 = NULL;
+	vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp41 = vala_ccode_cast_expression_new (VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (vala_assignment_get_right (self->priv->_assignment)))), "GCallback"))));
+	(_tmp41 == NULL ? NULL : (_tmp41 = (g_object_unref (_tmp41), NULL)));
 	if (vala_method_get_binding (m) == MEMBER_BINDING_INSTANCE) {
 		/* g_signal_connect_object or g_signal_handlers_disconnect_matched
 		 or dynamic_signal_connect or dynamic_signal_disconnect
 		 fourth resp. seventh argument: object/user_data*/
 		if (VALA_IS_MEMBER_ACCESS (vala_assignment_get_right (self->priv->_assignment))) {
-			ValaMemberAccess* _tmp32;
+			ValaMemberAccess* _tmp42;
 			ValaMemberAccess* right_ma;
-			_tmp32 = NULL;
-			right_ma = (_tmp32 = VALA_MEMBER_ACCESS (vala_assignment_get_right (self->priv->_assignment)), (_tmp32 == NULL ? NULL : g_object_ref (_tmp32)));
+			_tmp42 = NULL;
+			right_ma = (_tmp42 = VALA_MEMBER_ACCESS (vala_assignment_get_right (self->priv->_assignment)), (_tmp42 == NULL ? NULL : g_object_ref (_tmp42)));
 			if (vala_member_access_get_inner (right_ma) != NULL) {
 				vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (vala_member_access_get_inner (right_ma)))));
 			} else {
-				ValaCCodeIdentifier* _tmp33;
-				_tmp33 = NULL;
-				vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp33 = vala_ccode_identifier_new ("self"))));
-				(_tmp33 == NULL ? NULL : (_tmp33 = (g_object_unref (_tmp33), NULL)));
+				ValaCCodeIdentifier* _tmp43;
+				_tmp43 = NULL;
+				vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp43 = vala_ccode_identifier_new ("self"))));
+				(_tmp43 == NULL ? NULL : (_tmp43 = (g_object_unref (_tmp43), NULL)));
 			}
 			(right_ma == NULL ? NULL : (right_ma = (g_object_unref (right_ma), NULL)));
 		} else {
 			if (VALA_IS_LAMBDA_EXPRESSION (vala_assignment_get_right (self->priv->_assignment))) {
-				ValaCCodeIdentifier* _tmp34;
-				_tmp34 = NULL;
-				vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp34 = vala_ccode_identifier_new ("self"))));
-				(_tmp34 == NULL ? NULL : (_tmp34 = (g_object_unref (_tmp34), NULL)));
+				ValaCCodeIdentifier* _tmp44;
+				_tmp44 = NULL;
+				vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp44 = vala_ccode_identifier_new ("self"))));
+				(_tmp44 == NULL ? NULL : (_tmp44 = (g_object_unref (_tmp44), NULL)));
 			}
 		}
 		if (!disconnect && !(VALA_IS_DYNAMIC_SIGNAL (sig))) {
-			ValaCCodeConstant* _tmp35;
+			ValaCCodeConstant* _tmp45;
 			/* g_signal_connect_object
 			 fifth argument: connect_flags*/
-			_tmp35 = NULL;
-			vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp35 = vala_ccode_constant_new ("0"))));
-			(_tmp35 == NULL ? NULL : (_tmp35 = (g_object_unref (_tmp35), NULL)));
+			_tmp45 = NULL;
+			vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp45 = vala_ccode_constant_new ("0"))));
+			(_tmp45 == NULL ? NULL : (_tmp45 = (g_object_unref (_tmp45), NULL)));
 		}
 	} else {
-		ValaCCodeConstant* _tmp36;
+		ValaCCodeConstant* _tmp46;
 		/* g_signal_connect or g_signal_handlers_disconnect_matched
 		 or dynamic_signal_connect or dynamic_signal_disconnect
 		 fourth resp. seventh argument: user_data*/
-		_tmp36 = NULL;
-		vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp36 = vala_ccode_constant_new ("NULL"))));
-		(_tmp36 == NULL ? NULL : (_tmp36 = (g_object_unref (_tmp36), NULL)));
+		_tmp46 = NULL;
+		vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp46 = vala_ccode_constant_new ("NULL"))));
+		(_tmp46 == NULL ? NULL : (_tmp46 = (g_object_unref (_tmp46), NULL)));
 	}
 	vala_ccode_expression_binding_set_codenode (VALA_CCODE_EXPRESSION_BINDING (self), VALA_CCODE_EXPRESSION (ccall));
-	(ma == NULL ? NULL : (ma = (g_object_unref (ma), NULL)));
 	(sig == NULL ? NULL : (sig = (g_object_unref (sig), NULL)));
 	(m == NULL ? NULL : (m = (g_object_unref (m), NULL)));
 	connect_func = (g_free (connect_func), NULL);
 	(ccall == NULL ? NULL : (ccall = (g_object_unref (ccall), NULL)));
+	signal_detail = (g_free (signal_detail), NULL);
+	(ma == NULL ? NULL : (ma = (g_object_unref (ma), NULL)));
 }
 
 
@@ -726,6 +789,10 @@ static void vala_ccode_assignment_binding_real_emit (ValaCCodeBinding* base) {
 	ValaCCodeAssignmentBinding * self;
 	self = VALA_CCODE_ASSIGNMENT_BINDING (base);
 	vala_code_node_accept_children (VALA_CODE_NODE (self->priv->_assignment), VALA_CODE_VISITOR (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))));
+	if (vala_code_node_get_error (VALA_CODE_NODE (vala_assignment_get_left (self->priv->_assignment))) || vala_code_node_get_error (VALA_CODE_NODE (vala_assignment_get_right (self->priv->_assignment)))) {
+		vala_code_node_set_error (VALA_CODE_NODE (self->priv->_assignment), TRUE);
+		return;
+	}
 	if (VALA_IS_PROPERTY (vala_expression_get_symbol_reference (vala_assignment_get_left (self->priv->_assignment)))) {
 		vala_ccode_assignment_binding_emit_property_assignment (self);
 	} else {
