@@ -50,6 +50,8 @@ typedef struct _ValaCCodeGenerator ValaCCodeGenerator;
 typedef struct _ValaCCodeGeneratorClass ValaCCodeGeneratorClass;
 typedef struct _ValaCCodeDynamicMethodBinding ValaCCodeDynamicMethodBinding;
 typedef struct _ValaCCodeDynamicMethodBindingClass ValaCCodeDynamicMethodBindingClass;
+typedef struct _ValaCCodeDynamicPropertyBinding ValaCCodeDynamicPropertyBinding;
+typedef struct _ValaCCodeDynamicPropertyBindingClass ValaCCodeDynamicPropertyBindingClass;
 typedef struct _ValaCCodeDynamicSignalBinding ValaCCodeDynamicSignalBinding;
 typedef struct _ValaCCodeDynamicSignalBindingClass ValaCCodeDynamicSignalBindingClass;
 typedef struct _ValaCCodeElementAccessBinding ValaCCodeElementAccessBinding;
@@ -88,7 +90,6 @@ ValaCCodeMethodBinding* vala_ccode_binding_method_binding (ValaCCodeBinding* sel
 ValaCCodeArrayCreationExpressionBinding* vala_ccode_binding_array_creation_expression_binding (ValaCCodeBinding* self, ValaArrayCreationExpression* node);
 ValaCCodeElementAccessBinding* vala_ccode_binding_element_access_binding (ValaCCodeBinding* self, ValaElementAccess* node);
 ValaCCodeAssignmentBinding* vala_ccode_binding_assignment_binding (ValaCCodeBinding* self, ValaAssignment* node);
-ValaCCodeBinding* vala_ccode_binding_new (void);
 ValaCCodeGenerator* vala_ccode_binding_get_codegen (ValaCCodeBinding* self);
 void vala_ccode_binding_set_codegen (ValaCCodeBinding* self, ValaCCodeGenerator* value);
 GType vala_ccode_binding_get_type (void);
