@@ -38,8 +38,6 @@ G_BEGIN_DECLS
 #define VALA_IS_CCODE_EXPRESSION_BINDING_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CCODE_EXPRESSION_BINDING))
 #define VALA_CCODE_EXPRESSION_BINDING_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CCODE_EXPRESSION_BINDING, ValaCCodeExpressionBindingClass))
 
-typedef struct _ValaCCodeExpressionBinding ValaCCodeExpressionBinding;
-typedef struct _ValaCCodeExpressionBindingClass ValaCCodeExpressionBindingClass;
 typedef struct _ValaCCodeExpressionBindingPrivate ValaCCodeExpressionBindingPrivate;
 
 /**
@@ -49,14 +47,17 @@ struct _ValaCCodeExpressionBinding {
 	ValaCCodeBinding parent_instance;
 	ValaCCodeExpressionBindingPrivate * priv;
 };
+
 struct _ValaCCodeExpressionBindingClass {
 	ValaCCodeBindingClass parent_class;
 };
 
+
 ValaCCodeExpression* vala_ccode_expression_binding_get_codenode (ValaCCodeExpressionBinding* self);
 void vala_ccode_expression_binding_set_codenode (ValaCCodeExpressionBinding* self, ValaCCodeExpression* value);
 GType vala_ccode_expression_binding_get_type (void);
 
+
 G_END_DECLS
 
 #endif
