@@ -1,6 +1,6 @@
 /* valaccodegeneratorstruct.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter, Raffaele Sandrini
+ * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,7 +18,7 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
- *	Raffaele Sandrini <rasa@gmx.ch>
+ *	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #ifndef __GOBJECT_VALACCODEGENERATORSTRUCT_H__
@@ -32,6 +32,7 @@ G_BEGIN_DECLS
 
 
 
+
 G_END_DECLS
 
 #endif
