@@ -193,13 +193,13 @@ static void vala_ccode_interface_binding_real_emit (ValaCCodeBinding* base) {
 		macro = (_tmp21 = g_strdup_printf ("(%s_get_type ())", (_tmp20 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_iface), NULL))), (_tmp20 = (g_free (_tmp20), NULL)), _tmp21);
 		_tmp23 = NULL;
 		_tmp22 = NULL;
-		vala_ccode_fragment_append (decl_frag, VALA_CCODE_NODE ((_tmp23 = vala_ccode_macro_replacement_new ((_tmp22 = vala_typesymbol_get_upper_case_cname (VALA_TYPESYMBOL (self->priv->_iface), "TYPE_")), macro))));
+		vala_ccode_fragment_append (decl_frag, VALA_CCODE_NODE ((_tmp23 = vala_ccode_macro_replacement_new ((_tmp22 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (self->priv->_iface))), macro))));
 		(_tmp23 == NULL ? NULL : (_tmp23 = (g_object_unref (_tmp23), NULL)));
 		_tmp22 = (g_free (_tmp22), NULL);
 		_tmp26 = NULL;
 		_tmp25 = NULL;
 		_tmp24 = NULL;
-		macro = (_tmp26 = g_strdup_printf ("(G_TYPE_CHECK_INSTANCE_CAST ((obj), %s, %s))", (_tmp24 = vala_typesymbol_get_upper_case_cname (VALA_TYPESYMBOL (self->priv->_iface), "TYPE_")), (_tmp25 = vala_typesymbol_get_cname (VALA_TYPESYMBOL (self->priv->_iface), FALSE))), (macro = (g_free (macro), NULL)), _tmp26);
+		macro = (_tmp26 = g_strdup_printf ("(G_TYPE_CHECK_INSTANCE_CAST ((obj), %s, %s))", (_tmp24 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (self->priv->_iface))), (_tmp25 = vala_typesymbol_get_cname (VALA_TYPESYMBOL (self->priv->_iface), FALSE))), (macro = (g_free (macro), NULL)), _tmp26);
 		_tmp25 = (g_free (_tmp25), NULL);
 		_tmp24 = (g_free (_tmp24), NULL);
 		_tmp29 = NULL;
@@ -211,7 +211,7 @@ static void vala_ccode_interface_binding_real_emit (ValaCCodeBinding* base) {
 		_tmp27 = (g_free (_tmp27), NULL);
 		_tmp31 = NULL;
 		_tmp30 = NULL;
-		macro = (_tmp31 = g_strdup_printf ("(G_TYPE_CHECK_INSTANCE_TYPE ((obj), %s))", (_tmp30 = vala_typesymbol_get_upper_case_cname (VALA_TYPESYMBOL (self->priv->_iface), "TYPE_"))), (macro = (g_free (macro), NULL)), _tmp31);
+		macro = (_tmp31 = g_strdup_printf ("(G_TYPE_CHECK_INSTANCE_TYPE ((obj), %s))", (_tmp30 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (self->priv->_iface)))), (macro = (g_free (macro), NULL)), _tmp31);
 		_tmp30 = (g_free (_tmp30), NULL);
 		_tmp34 = NULL;
 		_tmp33 = NULL;
@@ -223,7 +223,7 @@ static void vala_ccode_interface_binding_real_emit (ValaCCodeBinding* base) {
 		_tmp37 = NULL;
 		_tmp36 = NULL;
 		_tmp35 = NULL;
-		macro = (_tmp37 = g_strdup_printf ("(G_TYPE_INSTANCE_GET_INTERFACE ((obj), %s, %s))", (_tmp35 = vala_typesymbol_get_upper_case_cname (VALA_TYPESYMBOL (self->priv->_iface), "TYPE_")), (_tmp36 = vala_interface_get_type_cname (self->priv->_iface))), (macro = (g_free (macro), NULL)), _tmp37);
+		macro = (_tmp37 = g_strdup_printf ("(G_TYPE_INSTANCE_GET_INTERFACE ((obj), %s, %s))", (_tmp35 = vala_typesymbol_get_type_id (VALA_TYPESYMBOL (self->priv->_iface))), (_tmp36 = vala_interface_get_type_cname (self->priv->_iface))), (macro = (g_free (macro), NULL)), _tmp37);
 		_tmp36 = (g_free (_tmp36), NULL);
 		_tmp35 = (g_free (_tmp35), NULL);
 		_tmp40 = NULL;
