@@ -308,9 +308,9 @@ static void vala_ccode_member_access_binding_process_cmember (ValaCCodeMemberAcc
 						char* _tmp43;
 						ValaCCodeFunctionCall* _tmp46;
 						ValaCCodeFunctionCall* cast;
-						ValaCCodeIdentifier* _tmp47;
-						ValaCCodeMemberAccess* _tmp49;
-						char* _tmp48;
+						ValaCCodeExpression* klass;
+						ValaCCodeMemberAccess* _tmp58;
+						char* _tmp57;
 						_tmp42 = NULL;
 						cl = (_tmp42 = VALA_CLASS (vala_symbol_get_parent_symbol (VALA_SYMBOL (f))), (_tmp42 == NULL ? NULL : g_object_ref (_tmp42)));
 						_tmp45 = NULL;
@@ -318,115 +318,156 @@ static void vala_ccode_member_access_binding_process_cmember (ValaCCodeMemberAcc
 						_tmp43 = NULL;
 						_tmp46 = NULL;
 						cast = (_tmp46 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp45 = vala_ccode_identifier_new ((_tmp44 = g_strconcat ((_tmp43 = vala_typesymbol_get_upper_case_cname (VALA_TYPESYMBOL (cl), NULL)), "_CLASS", NULL)))))), (_tmp45 == NULL ? NULL : (_tmp45 = (g_object_unref (_tmp45), NULL))), (_tmp44 = (g_free (_tmp44), NULL)), (_tmp43 = (g_free (_tmp43), NULL)), _tmp46);
-						_tmp47 = NULL;
-						vala_ccode_function_call_add_argument (cast, VALA_CCODE_EXPRESSION ((_tmp47 = vala_ccode_identifier_new ("klass"))));
-						(_tmp47 == NULL ? NULL : (_tmp47 = (g_object_unref (_tmp47), NULL)));
-						_tmp49 = NULL;
-						_tmp48 = NULL;
-						vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp49 = vala_ccode_member_access_new_pointer (VALA_CCODE_EXPRESSION (cast), (_tmp48 = vala_field_get_cname (f))))));
-						(_tmp49 == NULL ? NULL : (_tmp49 = (g_object_unref (_tmp49), NULL)));
-						_tmp48 = (g_free (_tmp48), NULL);
+						klass = NULL;
+						if (vala_member_access_get_inner (expr) == NULL) {
+							if (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->in_static_or_class_ctor) {
+								ValaCCodeExpression* _tmp47;
+								/* Accessing the field from a static or class constructor*/
+								_tmp47 = NULL;
+								klass = (_tmp47 = VALA_CCODE_EXPRESSION (vala_ccode_identifier_new ("klass")), (klass == NULL ? NULL : (klass = (g_object_unref (klass), NULL))), _tmp47);
+							} else {
+								ValaCCodeIdentifier* _tmp48;
+								ValaCCodeFunctionCall* _tmp49;
+								ValaCCodeFunctionCall* k;
+								ValaCCodeIdentifier* _tmp50;
+								ValaCCodeExpression* _tmp52;
+								ValaCCodeExpression* _tmp51;
+								/* Accessing the field from within an instance method*/
+								_tmp48 = NULL;
+								_tmp49 = NULL;
+								k = (_tmp49 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp48 = vala_ccode_identifier_new ("G_OBJECT_GET_CLASS")))), (_tmp48 == NULL ? NULL : (_tmp48 = (g_object_unref (_tmp48), NULL))), _tmp49);
+								_tmp50 = NULL;
+								vala_ccode_function_call_add_argument (k, VALA_CCODE_EXPRESSION ((_tmp50 = vala_ccode_identifier_new ("self"))));
+								(_tmp50 == NULL ? NULL : (_tmp50 = (g_object_unref (_tmp50), NULL)));
+								_tmp52 = NULL;
+								_tmp51 = NULL;
+								klass = (_tmp52 = (_tmp51 = VALA_CCODE_EXPRESSION (k), (_tmp51 == NULL ? NULL : g_object_ref (_tmp51))), (klass == NULL ? NULL : (klass = (g_object_unref (klass), NULL))), _tmp52);
+								(k == NULL ? NULL : (k = (g_object_unref (k), NULL)));
+							}
+						} else {
+							ValaCCodeIdentifier* _tmp53;
+							ValaCCodeFunctionCall* _tmp54;
+							ValaCCodeFunctionCall* k;
+							ValaCCodeExpression* _tmp56;
+							ValaCCodeExpression* _tmp55;
+							/* Accessing the field of an instance*/
+							_tmp53 = NULL;
+							_tmp54 = NULL;
+							k = (_tmp54 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp53 = vala_ccode_identifier_new ("G_OBJECT_GET_CLASS")))), (_tmp53 == NULL ? NULL : (_tmp53 = (g_object_unref (_tmp53), NULL))), _tmp54);
+							vala_ccode_function_call_add_argument (k, VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (vala_member_access_get_inner (expr)))));
+							_tmp56 = NULL;
+							_tmp55 = NULL;
+							klass = (_tmp56 = (_tmp55 = VALA_CCODE_EXPRESSION (k), (_tmp55 == NULL ? NULL : g_object_ref (_tmp55))), (klass == NULL ? NULL : (klass = (g_object_unref (klass), NULL))), _tmp56);
+							(k == NULL ? NULL : (k = (g_object_unref (k), NULL)));
+						}
+						vala_ccode_function_call_add_argument (cast, klass);
+						_tmp58 = NULL;
+						_tmp57 = NULL;
+						vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp58 = vala_ccode_member_access_new_pointer (VALA_CCODE_EXPRESSION (cast), (_tmp57 = vala_field_get_cname (f))))));
+						(_tmp58 == NULL ? NULL : (_tmp58 = (g_object_unref (_tmp58), NULL)));
+						_tmp57 = (g_free (_tmp57), NULL);
 						(cl == NULL ? NULL : (cl = (g_object_unref (cl), NULL)));
 						(cast == NULL ? NULL : (cast = (g_object_unref (cast), NULL)));
+						(klass == NULL ? NULL : (klass = (g_object_unref (klass), NULL)));
 					} else {
-						ValaCCodeIdentifier* _tmp51;
-						char* _tmp50;
-						_tmp51 = NULL;
-						_tmp50 = NULL;
-						vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp51 = vala_ccode_identifier_new ((_tmp50 = vala_field_get_cname (f))))));
-						(_tmp51 == NULL ? NULL : (_tmp51 = (g_object_unref (_tmp51), NULL)));
-						_tmp50 = (g_free (_tmp50), NULL);
+						ValaCCodeIdentifier* _tmp60;
+						char* _tmp59;
+						_tmp60 = NULL;
+						_tmp59 = NULL;
+						vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp60 = vala_ccode_identifier_new ((_tmp59 = vala_field_get_cname (f))))));
+						(_tmp60 == NULL ? NULL : (_tmp60 = (g_object_unref (_tmp60), NULL)));
+						_tmp59 = (g_free (_tmp59), NULL);
 					}
 				}
 				if (vala_data_type_get_type_parameter (vala_field_get_field_type (f)) != NULL && vala_data_type_get_type_parameter (vala_expression_get_value_type (VALA_EXPRESSION (expr))) == NULL) {
-					ValaCCodeExpression* _tmp52;
-					_tmp52 = NULL;
-					vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp52 = vala_ccode_generator_convert_from_generic_pointer (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (expr))), vala_expression_get_value_type (VALA_EXPRESSION (expr))))));
-					(_tmp52 == NULL ? NULL : (_tmp52 = (g_object_unref (_tmp52), NULL)));
+					ValaCCodeExpression* _tmp61;
+					_tmp61 = NULL;
+					vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp61 = vala_ccode_generator_convert_from_generic_pointer (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), VALA_CCODE_EXPRESSION (vala_code_node_get_ccodenode (VALA_CODE_NODE (expr))), vala_expression_get_value_type (VALA_EXPRESSION (expr))))));
+					(_tmp61 == NULL ? NULL : (_tmp61 = (g_object_unref (_tmp61), NULL)));
 				}
 				(f == NULL ? NULL : (f = (g_object_unref (f), NULL)));
 			} else {
 				if (VALA_IS_CONSTANT (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr)))) {
-					ValaConstant* _tmp53;
+					ValaConstant* _tmp62;
 					ValaConstant* c;
-					ValaCCodeIdentifier* _tmp55;
-					char* _tmp54;
-					_tmp53 = NULL;
-					c = (_tmp53 = VALA_CONSTANT (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp53 == NULL ? NULL : g_object_ref (_tmp53)));
-					_tmp55 = NULL;
-					_tmp54 = NULL;
-					vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp55 = vala_ccode_identifier_new ((_tmp54 = vala_constant_get_cname (c))))));
-					(_tmp55 == NULL ? NULL : (_tmp55 = (g_object_unref (_tmp55), NULL)));
-					_tmp54 = (g_free (_tmp54), NULL);
+					ValaCCodeIdentifier* _tmp64;
+					char* _tmp63;
+					_tmp62 = NULL;
+					c = (_tmp62 = VALA_CONSTANT (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp62 == NULL ? NULL : g_object_ref (_tmp62)));
+					_tmp64 = NULL;
+					_tmp63 = NULL;
+					vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp64 = vala_ccode_identifier_new ((_tmp63 = vala_constant_get_cname (c))))));
+					(_tmp64 == NULL ? NULL : (_tmp64 = (g_object_unref (_tmp64), NULL)));
+					_tmp63 = (g_free (_tmp63), NULL);
 					(c == NULL ? NULL : (c = (g_object_unref (c), NULL)));
 				} else {
 					if (VALA_IS_PROPERTY (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr)))) {
-						ValaProperty* _tmp56;
+						ValaProperty* _tmp65;
 						ValaProperty* prop;
-						_tmp56 = NULL;
-						prop = (_tmp56 = VALA_PROPERTY (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp56 == NULL ? NULL : g_object_ref (_tmp56)));
-						if (vala_property_get_get_accessor (prop) != NULL && vala_property_accessor_get_automatic_body (vala_property_get_get_accessor (prop)) && VALA_SYMBOL (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol) == vala_symbol_get_parent_symbol (VALA_SYMBOL (prop))) {
+						_tmp65 = NULL;
+						prop = (_tmp65 = VALA_PROPERTY (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp65 == NULL ? NULL : g_object_ref (_tmp65)));
+						if (vala_property_get_get_accessor (prop) != NULL && vala_property_accessor_get_automatic_body (vala_property_get_get_accessor (prop)) && VALA_SYMBOL (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol) == vala_symbol_get_parent_symbol (VALA_SYMBOL (prop)) && vala_property_get_base_property (prop) == NULL && vala_property_get_base_interface_property (prop) == NULL) {
 							ValaCCodeExpression* inst;
-							ValaCCodeExpression* _tmp57;
-							ValaCCodeMemberAccess* _tmp59;
-							char* _tmp58;
+							ValaCCodeExpression* _tmp66;
+							ValaCCodeMemberAccess* _tmp68;
+							char* _tmp67;
 							inst = NULL;
-							_tmp57 = NULL;
-							inst = (_tmp57 = VALA_CCODE_EXPRESSION (vala_ccode_member_access_new_pointer (pub_inst, "priv")), (inst == NULL ? NULL : (inst = (g_object_unref (inst), NULL))), _tmp57);
-							_tmp59 = NULL;
-							_tmp58 = NULL;
-							vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp59 = vala_ccode_member_access_new_pointer (inst, (_tmp58 = vala_field_get_cname (vala_property_get_field (prop)))))));
-							(_tmp59 == NULL ? NULL : (_tmp59 = (g_object_unref (_tmp59), NULL)));
-							_tmp58 = (g_free (_tmp58), NULL);
+							_tmp66 = NULL;
+							inst = (_tmp66 = VALA_CCODE_EXPRESSION (vala_ccode_member_access_new_pointer (pub_inst, "priv")), (inst == NULL ? NULL : (inst = (g_object_unref (inst), NULL))), _tmp66);
+							_tmp68 = NULL;
+							_tmp67 = NULL;
+							vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp68 = vala_ccode_member_access_new_pointer (inst, (_tmp67 = vala_field_get_cname (vala_property_get_field (prop)))))));
+							(_tmp68 == NULL ? NULL : (_tmp68 = (g_object_unref (_tmp68), NULL)));
+							_tmp67 = (g_free (_tmp67), NULL);
 							(inst == NULL ? NULL : (inst = (g_object_unref (inst), NULL)));
 						} else {
 							if (!vala_property_get_no_accessor_method (prop)) {
-								ValaProperty* _tmp60;
+								ValaProperty* _tmp69;
 								ValaProperty* base_property;
-								ValaTypeSymbol* _tmp65;
+								ValaTypeSymbol* _tmp74;
 								ValaTypeSymbol* base_property_type;
 								char* getter_cname;
-								ValaCCodeIdentifier* _tmp70;
-								ValaCCodeFunctionCall* _tmp71;
+								ValaCCodeIdentifier* _tmp79;
+								ValaCCodeFunctionCall* _tmp80;
 								ValaCCodeFunctionCall* ccall;
-								_tmp60 = NULL;
-								base_property = (_tmp60 = prop, (_tmp60 == NULL ? NULL : g_object_ref (_tmp60)));
+								_tmp69 = NULL;
+								base_property = (_tmp69 = prop, (_tmp69 == NULL ? NULL : g_object_ref (_tmp69)));
 								if (vala_property_get_base_property (prop) != NULL) {
-									ValaProperty* _tmp62;
-									ValaProperty* _tmp61;
-									_tmp62 = NULL;
-									_tmp61 = NULL;
-									base_property = (_tmp62 = (_tmp61 = vala_property_get_base_property (prop), (_tmp61 == NULL ? NULL : g_object_ref (_tmp61))), (base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL))), _tmp62);
+									ValaProperty* _tmp71;
+									ValaProperty* _tmp70;
+									_tmp71 = NULL;
+									_tmp70 = NULL;
+									base_property = (_tmp71 = (_tmp70 = vala_property_get_base_property (prop), (_tmp70 == NULL ? NULL : g_object_ref (_tmp70))), (base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL))), _tmp71);
 								} else {
 									if (vala_property_get_base_interface_property (prop) != NULL) {
-										ValaProperty* _tmp64;
-										ValaProperty* _tmp63;
-										_tmp64 = NULL;
-										_tmp63 = NULL;
-										base_property = (_tmp64 = (_tmp63 = vala_property_get_base_interface_property (prop), (_tmp63 == NULL ? NULL : g_object_ref (_tmp63))), (base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL))), _tmp64);
+										ValaProperty* _tmp73;
+										ValaProperty* _tmp72;
+										_tmp73 = NULL;
+										_tmp72 = NULL;
+										base_property = (_tmp73 = (_tmp72 = vala_property_get_base_interface_property (prop), (_tmp72 == NULL ? NULL : g_object_ref (_tmp72))), (base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL))), _tmp73);
 									}
 								}
-								_tmp65 = NULL;
-								base_property_type = (_tmp65 = VALA_TYPESYMBOL (vala_symbol_get_parent_symbol (VALA_SYMBOL (base_property))), (_tmp65 == NULL ? NULL : g_object_ref (_tmp65)));
+								_tmp74 = NULL;
+								base_property_type = (_tmp74 = VALA_TYPESYMBOL (vala_symbol_get_parent_symbol (VALA_SYMBOL (base_property))), (_tmp74 == NULL ? NULL : g_object_ref (_tmp74)));
 								getter_cname = NULL;
 								if (VALA_IS_DYNAMIC_PROPERTY (prop)) {
-									char* _tmp67;
-									ValaCCodeDynamicPropertyBinding* _tmp66;
-									_tmp67 = NULL;
-									_tmp66 = NULL;
-									getter_cname = (_tmp67 = vala_ccode_dynamic_property_binding_get_getter_cname ((_tmp66 = vala_ccode_generator_dynamic_property_binding (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), VALA_DYNAMIC_PROPERTY (prop)))), (getter_cname = (g_free (getter_cname), NULL)), _tmp67);
-									(_tmp66 == NULL ? NULL : (_tmp66 = (g_object_unref (_tmp66), NULL)));
+									char* _tmp76;
+									ValaCCodeDynamicPropertyBinding* _tmp75;
+									_tmp76 = NULL;
+									_tmp75 = NULL;
+									getter_cname = (_tmp76 = vala_ccode_dynamic_property_binding_get_getter_cname ((_tmp75 = vala_ccode_generator_dynamic_property_binding (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), VALA_DYNAMIC_PROPERTY (prop)))), (getter_cname = (g_free (getter_cname), NULL)), _tmp76);
+									(_tmp75 == NULL ? NULL : (_tmp75 = (g_object_unref (_tmp75), NULL)));
 								} else {
-									char* _tmp69;
-									char* _tmp68;
-									_tmp69 = NULL;
-									_tmp68 = NULL;
-									getter_cname = (_tmp69 = g_strdup_printf ("%s_get_%s", (_tmp68 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (base_property_type), NULL)), vala_symbol_get_name (VALA_SYMBOL (base_property))), (getter_cname = (g_free (getter_cname), NULL)), _tmp69);
-									_tmp68 = (g_free (_tmp68), NULL);
+									char* _tmp78;
+									char* _tmp77;
+									_tmp78 = NULL;
+									_tmp77 = NULL;
+									getter_cname = (_tmp78 = g_strdup_printf ("%s_get_%s", (_tmp77 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (base_property_type), NULL)), vala_symbol_get_name (VALA_SYMBOL (base_property))), (getter_cname = (g_free (getter_cname), NULL)), _tmp78);
+									_tmp77 = (g_free (_tmp77), NULL);
 								}
-								_tmp70 = NULL;
-								_tmp71 = NULL;
-								ccall = (_tmp71 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp70 = vala_ccode_identifier_new (getter_cname)))), (_tmp70 == NULL ? NULL : (_tmp70 = (g_object_unref (_tmp70), NULL))), _tmp71);
+								_tmp79 = NULL;
+								_tmp80 = NULL;
+								ccall = (_tmp80 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp79 = vala_ccode_identifier_new (getter_cname)))), (_tmp79 == NULL ? NULL : (_tmp79 = (g_object_unref (_tmp79), NULL))), _tmp80);
 								vala_ccode_function_call_add_argument (ccall, pub_inst);
 								/* Property acesses to real struct types are handeled different to other properties.
 								 They are returned as out parameter.*/
@@ -434,14 +475,14 @@ static void vala_ccode_member_access_binding_process_cmember (ValaCCodeMemberAcc
 									ValaCCodeCommaExpression* ccomma;
 									ValaLocalVariable* temp_var;
 									ValaCCodeIdentifier* ctemp;
-									ValaCCodeUnaryExpression* _tmp72;
+									ValaCCodeUnaryExpression* _tmp81;
 									ccomma = vala_ccode_comma_expression_new ();
 									temp_var = vala_ccode_generator_get_temp_variable (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), vala_property_get_property_type (base_property), TRUE, NULL);
 									ctemp = vala_ccode_identifier_new (vala_symbol_get_name (VALA_SYMBOL (temp_var)));
 									gee_collection_add (GEE_COLLECTION (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->temp_vars), temp_var);
-									_tmp72 = NULL;
-									vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp72 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, VALA_CCODE_EXPRESSION (ctemp)))));
-									(_tmp72 == NULL ? NULL : (_tmp72 = (g_object_unref (_tmp72), NULL)));
+									_tmp81 = NULL;
+									vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp81 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, VALA_CCODE_EXPRESSION (ctemp)))));
+									(_tmp81 == NULL ? NULL : (_tmp81 = (g_object_unref (_tmp81), NULL)));
 									vala_ccode_comma_expression_append_expression (ccomma, VALA_CCODE_EXPRESSION (ccall));
 									vala_ccode_comma_expression_append_expression (ccomma, VALA_CCODE_EXPRESSION (ctemp));
 									vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE (ccomma));
@@ -456,40 +497,40 @@ static void vala_ccode_member_access_binding_process_cmember (ValaCCodeMemberAcc
 								getter_cname = (g_free (getter_cname), NULL);
 								(ccall == NULL ? NULL : (ccall = (g_object_unref (ccall), NULL)));
 							} else {
-								ValaCCodeIdentifier* _tmp73;
-								ValaCCodeFunctionCall* _tmp74;
+								ValaCCodeIdentifier* _tmp82;
+								ValaCCodeFunctionCall* _tmp83;
 								ValaCCodeFunctionCall* ccall;
-								ValaCCodeIdentifier* _tmp75;
-								ValaCCodeFunctionCall* _tmp76;
+								ValaCCodeIdentifier* _tmp84;
+								ValaCCodeFunctionCall* _tmp85;
 								ValaCCodeFunctionCall* ccast;
-								ValaCCodeConstant* _tmp77;
+								ValaCCodeConstant* _tmp86;
 								ValaLocalVariable* temp_var;
 								ValaCCodeIdentifier* ctemp;
-								ValaCCodeUnaryExpression* _tmp78;
-								ValaCCodeConstant* _tmp79;
+								ValaCCodeUnaryExpression* _tmp87;
+								ValaCCodeConstant* _tmp88;
 								ValaCCodeCommaExpression* ccomma;
-								_tmp73 = NULL;
-								_tmp74 = NULL;
-								ccall = (_tmp74 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp73 = vala_ccode_identifier_new ("g_object_get")))), (_tmp73 == NULL ? NULL : (_tmp73 = (g_object_unref (_tmp73), NULL))), _tmp74);
-								_tmp75 = NULL;
-								_tmp76 = NULL;
-								ccast = (_tmp76 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp75 = vala_ccode_identifier_new ("G_OBJECT")))), (_tmp75 == NULL ? NULL : (_tmp75 = (g_object_unref (_tmp75), NULL))), _tmp76);
+								_tmp82 = NULL;
+								_tmp83 = NULL;
+								ccall = (_tmp83 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp82 = vala_ccode_identifier_new ("g_object_get")))), (_tmp82 == NULL ? NULL : (_tmp82 = (g_object_unref (_tmp82), NULL))), _tmp83);
+								_tmp84 = NULL;
+								_tmp85 = NULL;
+								ccast = (_tmp85 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp84 = vala_ccode_identifier_new ("G_OBJECT")))), (_tmp84 == NULL ? NULL : (_tmp84 = (g_object_unref (_tmp84), NULL))), _tmp85);
 								vala_ccode_function_call_add_argument (ccast, pub_inst);
 								vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION (ccast));
 								/* property name is second argument of g_object_get*/
-								_tmp77 = NULL;
-								vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp77 = vala_property_get_canonical_cconstant (prop))));
-								(_tmp77 == NULL ? NULL : (_tmp77 = (g_object_unref (_tmp77), NULL)));
+								_tmp86 = NULL;
+								vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp86 = vala_property_get_canonical_cconstant (prop))));
+								(_tmp86 == NULL ? NULL : (_tmp86 = (g_object_unref (_tmp86), NULL)));
 								/* we need a temporary variable to save the property value*/
 								temp_var = vala_ccode_generator_get_temp_variable (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), vala_expression_get_value_type (VALA_EXPRESSION (expr)), TRUE, NULL);
 								gee_list_insert (GEE_LIST (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->temp_vars), 0, temp_var);
 								ctemp = vala_ccode_identifier_new (vala_symbol_get_name (VALA_SYMBOL (temp_var)));
-								_tmp78 = NULL;
-								vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp78 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, VALA_CCODE_EXPRESSION (ctemp)))));
-								(_tmp78 == NULL ? NULL : (_tmp78 = (g_object_unref (_tmp78), NULL)));
-								_tmp79 = NULL;
-								vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp79 = vala_ccode_constant_new ("NULL"))));
-								(_tmp79 == NULL ? NULL : (_tmp79 = (g_object_unref (_tmp79), NULL)));
+								_tmp87 = NULL;
+								vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp87 = vala_ccode_unary_expression_new (VALA_CCODE_UNARY_OPERATOR_ADDRESS_OF, VALA_CCODE_EXPRESSION (ctemp)))));
+								(_tmp87 == NULL ? NULL : (_tmp87 = (g_object_unref (_tmp87), NULL)));
+								_tmp88 = NULL;
+								vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp88 = vala_ccode_constant_new ("NULL"))));
+								(_tmp88 == NULL ? NULL : (_tmp88 = (g_object_unref (_tmp88), NULL)));
 								ccomma = vala_ccode_comma_expression_new ();
 								vala_ccode_comma_expression_append_expression (ccomma, VALA_CCODE_EXPRESSION (ccall));
 								vala_ccode_comma_expression_append_expression (ccomma, VALA_CCODE_EXPRESSION (ctemp));
@@ -504,86 +545,86 @@ static void vala_ccode_member_access_binding_process_cmember (ValaCCodeMemberAcc
 						(prop == NULL ? NULL : (prop = (g_object_unref (prop), NULL)));
 					} else {
 						if (VALA_IS_ENUM_VALUE (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr)))) {
-							ValaEnumValue* _tmp80;
+							ValaEnumValue* _tmp89;
 							ValaEnumValue* ev;
-							ValaCCodeConstant* _tmp82;
-							char* _tmp81;
-							_tmp80 = NULL;
-							ev = (_tmp80 = VALA_ENUM_VALUE (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp80 == NULL ? NULL : g_object_ref (_tmp80)));
-							_tmp82 = NULL;
-							_tmp81 = NULL;
-							vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp82 = vala_ccode_constant_new ((_tmp81 = vala_enum_value_get_cname (ev))))));
-							(_tmp82 == NULL ? NULL : (_tmp82 = (g_object_unref (_tmp82), NULL)));
-							_tmp81 = (g_free (_tmp81), NULL);
+							ValaCCodeConstant* _tmp91;
+							char* _tmp90;
+							_tmp89 = NULL;
+							ev = (_tmp89 = VALA_ENUM_VALUE (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp89 == NULL ? NULL : g_object_ref (_tmp89)));
+							_tmp91 = NULL;
+							_tmp90 = NULL;
+							vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp91 = vala_ccode_constant_new ((_tmp90 = vala_enum_value_get_cname (ev))))));
+							(_tmp91 == NULL ? NULL : (_tmp91 = (g_object_unref (_tmp91), NULL)));
+							_tmp90 = (g_free (_tmp90), NULL);
 							(ev == NULL ? NULL : (ev = (g_object_unref (ev), NULL)));
 						} else {
 							if (VALA_IS_LOCAL_VARIABLE (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr)))) {
-								ValaLocalVariable* _tmp83;
+								ValaLocalVariable* _tmp92;
 								ValaLocalVariable* local;
-								ValaCCodeIdentifier* _tmp85;
-								char* _tmp84;
-								_tmp83 = NULL;
-								local = (_tmp83 = VALA_LOCAL_VARIABLE (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp83 == NULL ? NULL : g_object_ref (_tmp83)));
-								_tmp85 = NULL;
-								_tmp84 = NULL;
-								vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp85 = vala_ccode_identifier_new ((_tmp84 = vala_ccode_generator_get_variable_cname (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), vala_symbol_get_name (VALA_SYMBOL (local))))))));
-								(_tmp85 == NULL ? NULL : (_tmp85 = (g_object_unref (_tmp85), NULL)));
-								_tmp84 = (g_free (_tmp84), NULL);
+								ValaCCodeIdentifier* _tmp94;
+								char* _tmp93;
+								_tmp92 = NULL;
+								local = (_tmp92 = VALA_LOCAL_VARIABLE (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp92 == NULL ? NULL : g_object_ref (_tmp92)));
+								_tmp94 = NULL;
+								_tmp93 = NULL;
+								vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp94 = vala_ccode_identifier_new ((_tmp93 = vala_ccode_generator_get_variable_cname (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self)), vala_symbol_get_name (VALA_SYMBOL (local))))))));
+								(_tmp94 == NULL ? NULL : (_tmp94 = (g_object_unref (_tmp94), NULL)));
+								_tmp93 = (g_free (_tmp93), NULL);
 								(local == NULL ? NULL : (local = (g_object_unref (local), NULL)));
 							} else {
 								if (VALA_IS_FORMAL_PARAMETER (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr)))) {
-									ValaFormalParameter* _tmp86;
+									ValaFormalParameter* _tmp95;
 									ValaFormalParameter* p;
-									_tmp86 = NULL;
-									p = (_tmp86 = VALA_FORMAL_PARAMETER (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp86 == NULL ? NULL : g_object_ref (_tmp86)));
+									_tmp95 = NULL;
+									p = (_tmp95 = VALA_FORMAL_PARAMETER (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp95 == NULL ? NULL : g_object_ref (_tmp95)));
 									if (_vala_strcmp0 (vala_symbol_get_name (VALA_SYMBOL (p)), "this") == 0) {
-										ValaStruct* _tmp88;
-										ValaTypeSymbol* _tmp87;
+										ValaStruct* _tmp97;
+										ValaTypeSymbol* _tmp96;
 										ValaStruct* st;
-										_tmp88 = NULL;
-										_tmp87 = NULL;
-										st = (_tmp88 = (_tmp87 = vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol, (VALA_IS_STRUCT (_tmp87) ? ((ValaStruct*) (_tmp87)) : NULL)), (_tmp88 == NULL ? NULL : g_object_ref (_tmp88)));
+										_tmp97 = NULL;
+										_tmp96 = NULL;
+										st = (_tmp97 = (_tmp96 = vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_type_symbol, (VALA_IS_STRUCT (_tmp96) ? ((ValaStruct*) (_tmp96)) : NULL)), (_tmp97 == NULL ? NULL : g_object_ref (_tmp97)));
 										if (st != NULL && !vala_struct_is_simple_type (st)) {
-											ValaCCodeIdentifier* _tmp89;
-											_tmp89 = NULL;
-											vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp89 = vala_ccode_identifier_new ("(*self)"))));
-											(_tmp89 == NULL ? NULL : (_tmp89 = (g_object_unref (_tmp89), NULL)));
+											ValaCCodeIdentifier* _tmp98;
+											_tmp98 = NULL;
+											vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp98 = vala_ccode_identifier_new ("(*self)"))));
+											(_tmp98 == NULL ? NULL : (_tmp98 = (g_object_unref (_tmp98), NULL)));
 										} else {
-											ValaCCodeIdentifier* _tmp90;
-											_tmp90 = NULL;
-											vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp90 = vala_ccode_identifier_new ("self"))));
-											(_tmp90 == NULL ? NULL : (_tmp90 = (g_object_unref (_tmp90), NULL)));
+											ValaCCodeIdentifier* _tmp99;
+											_tmp99 = NULL;
+											vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp99 = vala_ccode_identifier_new ("self"))));
+											(_tmp99 == NULL ? NULL : (_tmp99 = (g_object_unref (_tmp99), NULL)));
 										}
 										(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
 									} else {
-										ValaStruct* _tmp92;
-										ValaTypeSymbol* _tmp91;
+										ValaStruct* _tmp101;
+										ValaTypeSymbol* _tmp100;
 										ValaStruct* type_as_struct;
-										_tmp92 = NULL;
-										_tmp91 = NULL;
-										type_as_struct = (_tmp92 = (_tmp91 = vala_data_type_get_data_type (vala_formal_parameter_get_parameter_type (p)), (VALA_IS_STRUCT (_tmp91) ? ((ValaStruct*) (_tmp91)) : NULL)), (_tmp92 == NULL ? NULL : g_object_ref (_tmp92)));
+										_tmp101 = NULL;
+										_tmp100 = NULL;
+										type_as_struct = (_tmp101 = (_tmp100 = vala_data_type_get_data_type (vala_formal_parameter_get_parameter_type (p)), (VALA_IS_STRUCT (_tmp100) ? ((ValaStruct*) (_tmp100)) : NULL)), (_tmp101 == NULL ? NULL : g_object_ref (_tmp101)));
 										if (vala_formal_parameter_get_direction (p) != VALA_PARAMETER_DIRECTION_IN || (type_as_struct != NULL && !vala_struct_is_simple_type (type_as_struct) && !vala_data_type_get_nullable (vala_formal_parameter_get_parameter_type (p)))) {
-											ValaCCodeIdentifier* _tmp94;
-											char* _tmp93;
-											_tmp94 = NULL;
-											_tmp93 = NULL;
-											vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp94 = vala_ccode_identifier_new ((_tmp93 = g_strdup_printf ("(*%s)", vala_symbol_get_name (VALA_SYMBOL (p))))))));
-											(_tmp94 == NULL ? NULL : (_tmp94 = (g_object_unref (_tmp94), NULL)));
-											_tmp93 = (g_free (_tmp93), NULL);
+											ValaCCodeIdentifier* _tmp103;
+											char* _tmp102;
+											_tmp103 = NULL;
+											_tmp102 = NULL;
+											vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp103 = vala_ccode_identifier_new ((_tmp102 = g_strdup_printf ("(*%s)", vala_symbol_get_name (VALA_SYMBOL (p))))))));
+											(_tmp103 == NULL ? NULL : (_tmp103 = (g_object_unref (_tmp103), NULL)));
+											_tmp102 = (g_free (_tmp102), NULL);
 										} else {
 											/* Property setters of non simple structs shall replace all occurences
 											 of the "value" formal parameter with a dereferencing version of that
 											 parameter.*/
 											if (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_property_accessor != NULL && vala_property_accessor_get_writable (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_property_accessor) && vala_property_accessor_get_value_parameter (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_property_accessor) == p && vala_data_type_is_real_struct_type (vala_property_get_property_type (vala_property_accessor_get_prop (vala_ccode_binding_get_codegen (VALA_CCODE_BINDING (self))->current_property_accessor)))) {
-												ValaCCodeIdentifier* _tmp95;
-												_tmp95 = NULL;
-												vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp95 = vala_ccode_identifier_new ("(*value)"))));
-												(_tmp95 == NULL ? NULL : (_tmp95 = (g_object_unref (_tmp95), NULL)));
+												ValaCCodeIdentifier* _tmp104;
+												_tmp104 = NULL;
+												vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp104 = vala_ccode_identifier_new ("(*value)"))));
+												(_tmp104 == NULL ? NULL : (_tmp104 = (g_object_unref (_tmp104), NULL)));
 											} else {
-												ValaCCodeIdentifier* _tmp96;
-												_tmp96 = NULL;
-												vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp96 = vala_ccode_identifier_new (vala_symbol_get_name (VALA_SYMBOL (p))))));
-												(_tmp96 == NULL ? NULL : (_tmp96 = (g_object_unref (_tmp96), NULL)));
+												ValaCCodeIdentifier* _tmp105;
+												_tmp105 = NULL;
+												vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE ((_tmp105 = vala_ccode_identifier_new (vala_symbol_get_name (VALA_SYMBOL (p))))));
+												(_tmp105 == NULL ? NULL : (_tmp105 = (g_object_unref (_tmp105), NULL)));
 											}
 										}
 										(type_as_struct == NULL ? NULL : (type_as_struct = (g_object_unref (type_as_struct), NULL)));
@@ -591,48 +632,48 @@ static void vala_ccode_member_access_binding_process_cmember (ValaCCodeMemberAcc
 									(p == NULL ? NULL : (p = (g_object_unref (p), NULL)));
 								} else {
 									if (VALA_IS_SIGNAL (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr)))) {
-										ValaSignal* _tmp97;
+										ValaSignal* _tmp106;
 										ValaSignal* sig;
-										ValaTypeSymbol* _tmp98;
+										ValaTypeSymbol* _tmp107;
 										ValaTypeSymbol* cl;
-										_tmp97 = NULL;
-										sig = (_tmp97 = VALA_SIGNAL (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp97 == NULL ? NULL : g_object_ref (_tmp97)));
-										_tmp98 = NULL;
-										cl = (_tmp98 = VALA_TYPESYMBOL (vala_symbol_get_parent_symbol (VALA_SYMBOL (sig))), (_tmp98 == NULL ? NULL : g_object_ref (_tmp98)));
+										_tmp106 = NULL;
+										sig = (_tmp106 = VALA_SIGNAL (vala_expression_get_symbol_reference (VALA_EXPRESSION (expr))), (_tmp106 == NULL ? NULL : g_object_ref (_tmp106)));
+										_tmp107 = NULL;
+										cl = (_tmp107 = VALA_TYPESYMBOL (vala_symbol_get_parent_symbol (VALA_SYMBOL (sig))), (_tmp107 == NULL ? NULL : g_object_ref (_tmp107)));
 										if (vala_signal_get_has_emitter (sig)) {
-											ValaCCodeIdentifier* _tmp101;
-											char* _tmp100;
-											char* _tmp99;
-											ValaCCodeFunctionCall* _tmp102;
+											ValaCCodeIdentifier* _tmp110;
+											char* _tmp109;
+											char* _tmp108;
+											ValaCCodeFunctionCall* _tmp111;
 											ValaCCodeFunctionCall* ccall;
-											_tmp101 = NULL;
-											_tmp100 = NULL;
-											_tmp99 = NULL;
-											_tmp102 = NULL;
-											ccall = (_tmp102 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp101 = vala_ccode_identifier_new ((_tmp100 = g_strdup_printf ("%s_%s", (_tmp99 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (cl), NULL)), vala_symbol_get_name (VALA_SYMBOL (sig)))))))), (_tmp101 == NULL ? NULL : (_tmp101 = (g_object_unref (_tmp101), NULL))), (_tmp100 = (g_free (_tmp100), NULL)), (_tmp99 = (g_free (_tmp99), NULL)), _tmp102);
+											_tmp110 = NULL;
+											_tmp109 = NULL;
+											_tmp108 = NULL;
+											_tmp111 = NULL;
+											ccall = (_tmp111 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp110 = vala_ccode_identifier_new ((_tmp109 = g_strdup_printf ("%s_%s", (_tmp108 = vala_symbol_get_lower_case_cname (VALA_SYMBOL (cl), NULL)), vala_symbol_get_name (VALA_SYMBOL (sig)))))))), (_tmp110 == NULL ? NULL : (_tmp110 = (g_object_unref (_tmp110), NULL))), (_tmp109 = (g_free (_tmp109), NULL)), (_tmp108 = (g_free (_tmp108), NULL)), _tmp111);
 											vala_ccode_function_call_add_argument (ccall, pub_inst);
 											vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE (ccall));
 											(ccall == NULL ? NULL : (ccall = (g_object_unref (ccall), NULL)));
 										} else {
-											ValaCCodeIdentifier* _tmp103;
-											ValaCCodeFunctionCall* _tmp104;
+											ValaCCodeIdentifier* _tmp112;
+											ValaCCodeFunctionCall* _tmp113;
 											ValaCCodeFunctionCall* ccall;
-											ValaCCodeIdentifier* _tmp105;
-											ValaCCodeFunctionCall* _tmp106;
+											ValaCCodeIdentifier* _tmp114;
+											ValaCCodeFunctionCall* _tmp115;
 											ValaCCodeFunctionCall* ccast;
-											ValaCCodeConstant* _tmp107;
-											_tmp103 = NULL;
-											_tmp104 = NULL;
-											ccall = (_tmp104 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp103 = vala_ccode_identifier_new ("g_signal_emit_by_name")))), (_tmp103 == NULL ? NULL : (_tmp103 = (g_object_unref (_tmp103), NULL))), _tmp104);
+											ValaCCodeConstant* _tmp116;
+											_tmp112 = NULL;
+											_tmp113 = NULL;
+											ccall = (_tmp113 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp112 = vala_ccode_identifier_new ("g_signal_emit_by_name")))), (_tmp112 == NULL ? NULL : (_tmp112 = (g_object_unref (_tmp112), NULL))), _tmp113);
 											/* FIXME: use C cast if debugging disabled*/
-											_tmp105 = NULL;
-											_tmp106 = NULL;
-											ccast = (_tmp106 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp105 = vala_ccode_identifier_new ("G_OBJECT")))), (_tmp105 == NULL ? NULL : (_tmp105 = (g_object_unref (_tmp105), NULL))), _tmp106);
+											_tmp114 = NULL;
+											_tmp115 = NULL;
+											ccast = (_tmp115 = vala_ccode_function_call_new (VALA_CCODE_EXPRESSION ((_tmp114 = vala_ccode_identifier_new ("G_OBJECT")))), (_tmp114 == NULL ? NULL : (_tmp114 = (g_object_unref (_tmp114), NULL))), _tmp115);
 											vala_ccode_function_call_add_argument (ccast, pub_inst);
 											vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION (ccast));
-											_tmp107 = NULL;
-											vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp107 = vala_signal_get_canonical_cconstant (sig))));
-											(_tmp107 == NULL ? NULL : (_tmp107 = (g_object_unref (_tmp107), NULL)));
+											_tmp116 = NULL;
+											vala_ccode_function_call_add_argument (ccall, VALA_CCODE_EXPRESSION ((_tmp116 = vala_signal_get_canonical_cconstant (sig, NULL))));
+											(_tmp116 == NULL ? NULL : (_tmp116 = (g_object_unref (_tmp116), NULL)));
 											vala_code_node_set_ccodenode (VALA_CODE_NODE (expr), VALA_CCODE_NODE (ccall));
 											(ccall == NULL ? NULL : (ccall = (g_object_unref (ccall), NULL)));
 											(ccast == NULL ? NULL : (ccast = (g_object_unref (ccast), NULL)));
