@@ -1,6 +1,6 @@
 /* valaccodemethodbinding.vala
  *
- * Copyright (C) 2007  Jürg Billeter
+ * Copyright (C) 2007-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,8 +25,11 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <vala/valacodegenerator.h>
 #include <vala/valamethod.h>
+#include <vala/valadatatype.h>
+#include <gee/map.h>
+#include <ccode/valaccodefunction.h>
+#include <ccode/valaccodefunctiondeclarator.h>
 #include <gobject/valaccodebinding.h>
 
 G_BEGIN_DECLS
@@ -39,8 +42,6 @@ G_BEGIN_DECLS
 #define VALA_IS_CCODE_METHOD_BINDING_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CCODE_METHOD_BINDING))
 #define VALA_CCODE_METHOD_BINDING_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CCODE_METHOD_BINDING, ValaCCodeMethodBindingClass))
 
-typedef struct _ValaCCodeMethodBinding ValaCCodeMethodBinding;
-typedef struct _ValaCCodeMethodBindingClass ValaCCodeMethodBindingClass;
 typedef struct _ValaCCodeMethodBindingPrivate ValaCCodeMethodBindingPrivate;
 
 /**
@@ -50,12 +51,14 @@ struct _ValaCCodeMethodBinding {
 	ValaCCodeBinding parent_instance;
 	ValaCCodeMethodBindingPrivate * priv;
 };
+
 struct _ValaCCodeMethodBindingClass {
 	ValaCCodeBindingClass parent_class;
 };
 
-ValaCCodeMethodBinding* vala_ccode_method_binding_new (ValaCodeGenerator* codegen, ValaMethod* method);
-ValaCCodeMethodBinding* vala_ccode_method_binding_get (ValaMethod* method);
+
+ValaCCodeMethodBinding* vala_ccode_method_binding_new (ValaCCodeGenerator* codegen, ValaMethod* method);
+void vala_ccode_method_binding_generate_cparameters (ValaCCodeMethodBinding* self, ValaMethod* m, ValaDataType* creturn_type, GeeMap* cparam_map, ValaCCodeFunction* func, ValaCCodeFunctionDeclarator* vdeclarator);
 ValaMethod* vala_ccode_method_binding_get_method (ValaCCodeMethodBinding* self);
 void vala_ccode_method_binding_set_method (ValaCCodeMethodBinding* self, ValaMethod* value);
 gboolean vala_ccode_method_binding_get_has_wrapper (ValaCCodeMethodBinding* self);
