@@ -26,14 +26,13 @@
 #include <vala/valasymbol.h>
 #include <vala/valascope.h>
 #include <vala/valacodenode.h>
-#include <vala/valasourcereference.h>
-#include <vala/valasourcefile.h>
 #include <vala/valadatatype.h>
-#include <vala/valainterfacetype.h>
+#include <vala/valaobjecttype.h>
 #include <gee/collection.h>
-#include <vala/valaclasstype.h>
 #include <vala/valadelegatetype.h>
+#include <gee/list.h>
 #include <vala/valaformalparameter.h>
+#include <vala/valamember.h>
 #include <gobject/valaccodegenerator.h>
 
 
@@ -43,8 +42,9 @@ struct _ValaGIdlWriterPrivate {
 	ValaCodeContext* context;
 	FILE* stream;
 	gint indent;
-	ValaTypesymbol* gobject_type;
+	ValaTypeSymbol* gobject_type;
 };
+
 #define VALA_GIDL_WRITER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_GIDL_WRITER, ValaGIdlWriterPrivate))
 enum  {
 	VALA_GIDL_WRITER_DUMMY_PROPERTY
@@ -60,7 +60,7 @@ static void vala_gidl_writer_real_visit_error_code (ValaCodeVisitor* base, ValaE
 static void vala_gidl_writer_real_visit_constant (ValaCodeVisitor* base, ValaConstant* c);
 static void vala_gidl_writer_real_visit_field (ValaCodeVisitor* base, ValaField* f);
 static char* vala_gidl_writer_get_gidl_type_name (ValaGIdlWriter* self, ValaDataType* type);
-static void vala_gidl_writer_write_params (ValaGIdlWriter* self, GeeCollection* params, ValaDataType* instance_type);
+static void vala_gidl_writer_write_params (ValaGIdlWriter* self, GeeList* params, ValaDataType* instance_type);
 static void vala_gidl_writer_real_visit_delegate (ValaCodeVisitor* base, ValaDelegate* cb);
 static void vala_gidl_writer_real_visit_method (ValaCodeVisitor* base, ValaMethod* m);
 static void vala_gidl_writer_real_visit_creation_method (ValaCodeVisitor* base, ValaCreationMethod* m);
@@ -87,11 +87,12 @@ void vala_gidl_writer_write_file (ValaGIdlWriter* self, ValaCodeContext* context
 	ValaNamespace* _tmp2;
 	ValaNamespace* root_symbol;
 	ValaSymbol* glib_ns;
-	ValaTypesymbol* _tmp3;
+	ValaTypeSymbol* _tmp3;
 	FILE* _tmp4;
 	FILE* _tmp5;
 	g_return_if_fail (VALA_IS_GIDL_WRITER (self));
-	g_return_if_fail (context == NULL || VALA_IS_CODE_CONTEXT (context));
+	g_return_if_fail (VALA_IS_CODE_CONTEXT (context));
+	g_return_if_fail (filename != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->context = (_tmp1 = (_tmp0 = context, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->context == NULL ? NULL : (self->priv->context = (g_object_unref (self->priv->context), NULL))), _tmp1);
@@ -116,8 +117,8 @@ void vala_gidl_writer_write_file (ValaGIdlWriter* self, ValaCodeContext* context
 static void vala_gidl_writer_real_visit_namespace (ValaCodeVisitor* base, ValaNamespace* ns) {
 	ValaGIdlWriter * self;
 	self = VALA_GIDL_WRITER (base);
-	g_return_if_fail (ns == NULL || VALA_IS_NAMESPACE (ns));
-	if (vala_namespace_get_pkg (ns)) {
+	g_return_if_fail (VALA_IS_NAMESPACE (ns));
+	if (vala_symbol_get_external_package (VALA_SYMBOL (ns))) {
 		return;
 	}
 	if (vala_symbol_get_name (VALA_SYMBOL (ns)) == NULL) {
@@ -138,8 +139,8 @@ static void vala_gidl_writer_real_visit_namespace (ValaCodeVisitor* base, ValaNa
 static void vala_gidl_writer_real_visit_class (ValaCodeVisitor* base, ValaClass* cl) {
 	ValaGIdlWriter * self;
 	self = VALA_GIDL_WRITER (base);
-	g_return_if_fail (cl == NULL || VALA_IS_CLASS (cl));
-	if (vala_code_node_get_source_reference (VALA_CODE_NODE (cl)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (cl))))) {
+	g_return_if_fail (VALA_IS_CLASS (cl));
+	if (vala_symbol_get_external_package (VALA_SYMBOL (cl))) {
 		return;
 	}
 	if (!vala_gidl_writer_check_accessibility (self, VALA_SYMBOL (cl))) {
@@ -166,22 +167,19 @@ static void vala_gidl_writer_real_visit_class (ValaCodeVisitor* base, ValaClass*
 		/* write implemented interfaces*/
 		first = TRUE;
 		{
-			GeeCollection* base_type_collection;
-			GeeIterator* base_type_it;
+			GeeList* base_type_collection;
+			int base_type_it;
 			base_type_collection = vala_class_get_base_types (cl);
-			base_type_it = gee_iterable_iterator (GEE_ITERABLE (base_type_collection));
-			while (gee_iterator_next (base_type_it)) {
+			for (base_type_it = 0; base_type_it < gee_collection_get_size (GEE_COLLECTION (base_type_collection)); base_type_it = base_type_it + 1) {
 				ValaDataType* base_type;
-				base_type = ((ValaDataType*) gee_iterator_get (base_type_it));
+				base_type = ((ValaDataType*) (gee_list_get (GEE_LIST (base_type_collection), base_type_it)));
 				{
-					ValaInterfaceType* _tmp4;
-					ValaDataType* _tmp3;
-					ValaInterfaceType* iface_type;
-					_tmp4 = NULL;
+					ValaObjectType* _tmp3;
+					ValaObjectType* object_type;
 					_tmp3 = NULL;
-					iface_type = (_tmp4 = (_tmp3 = base_type, (VALA_IS_INTERFACE_TYPE (_tmp3) ? ((ValaInterfaceType*) _tmp3) : NULL)), (_tmp4 == NULL ? NULL : g_object_ref (_tmp4)));
-					if (iface_type != NULL) {
-						char* _tmp5;
+					object_type = (_tmp3 = VALA_OBJECT_TYPE (base_type), (_tmp3 == NULL ? NULL : g_object_ref (_tmp3)));
+					if (VALA_IS_INTERFACE (vala_object_type_get_type_symbol (object_type))) {
+						char* _tmp4;
 						if (first) {
 							vala_gidl_writer_write_indent (self);
 							fprintf (self->priv->stream, "<implements>\n");
@@ -189,16 +187,15 @@ static void vala_gidl_writer_real_visit_class (ValaCodeVisitor* base, ValaClass*
 							first = FALSE;
 						}
 						vala_gidl_writer_write_indent (self);
-						_tmp5 = NULL;
-						fprintf (self->priv->stream, "<interface name=\"%s\"/>\n", (_tmp5 = vala_symbol_get_full_name (VALA_SYMBOL (vala_interface_type_get_interface_symbol (iface_type)))));
-						_tmp5 = (g_free (_tmp5), NULL);
+						_tmp4 = NULL;
+						fprintf (self->priv->stream, "<interface name=\"%s\"/>\n", (_tmp4 = vala_symbol_get_full_name (VALA_SYMBOL (vala_object_type_get_type_symbol (object_type)))));
+						_tmp4 = (g_free (_tmp4), NULL);
 					}
 					(base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL)));
-					(iface_type == NULL ? NULL : (iface_type = (g_object_unref (iface_type), NULL)));
+					(object_type == NULL ? NULL : (object_type = (g_object_unref (object_type), NULL)));
 				}
 			}
 			(base_type_collection == NULL ? NULL : (base_type_collection = (g_object_unref (base_type_collection), NULL)));
-			(base_type_it == NULL ? NULL : (base_type_it = (g_object_unref (base_type_it), NULL)));
 		}
 		if (!first) {
 			self->priv->indent--;
@@ -226,8 +223,8 @@ static void vala_gidl_writer_real_visit_struct (ValaCodeVisitor* base, ValaStruc
 	ValaGIdlWriter * self;
 	char* _tmp0;
 	self = VALA_GIDL_WRITER (base);
-	g_return_if_fail (st == NULL || VALA_IS_STRUCT (st));
-	if (vala_code_node_get_source_reference (VALA_CODE_NODE (st)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (st))))) {
+	g_return_if_fail (VALA_IS_STRUCT (st));
+	if (vala_symbol_get_external_package (VALA_SYMBOL (st))) {
 		return;
 	}
 	if (!vala_gidl_writer_check_accessibility (self, VALA_SYMBOL (st))) {
@@ -250,11 +247,11 @@ static void vala_gidl_writer_real_visit_interface (ValaCodeVisitor* base, ValaIn
 	ValaGIdlWriter * self;
 	char* _tmp0;
 	char* _tmp1;
-	GeeCollection* _tmp2;
+	GeeList* _tmp2;
 	gboolean _tmp3;
 	self = VALA_GIDL_WRITER (base);
-	g_return_if_fail (iface == NULL || VALA_IS_INTERFACE (iface));
-	if (vala_code_node_get_source_reference (VALA_CODE_NODE (iface)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (iface))))) {
+	g_return_if_fail (VALA_IS_INTERFACE (iface));
+	if (vala_symbol_get_external_package (VALA_SYMBOL (iface))) {
 		return;
 	}
 	if (!vala_gidl_writer_check_accessibility (self, VALA_SYMBOL (iface))) {
@@ -271,55 +268,44 @@ static void vala_gidl_writer_real_visit_interface (ValaCodeVisitor* base, ValaIn
 	self->priv->indent++;
 	/* write prerequisites*/
 	_tmp2 = NULL;
-	if ((_tmp3 = gee_collection_get_size ((_tmp2 = vala_interface_get_prerequisites (iface))) > 0, (_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL))), _tmp3)) {
+	if ((_tmp3 = gee_collection_get_size (GEE_COLLECTION ((_tmp2 = vala_interface_get_prerequisites (iface)))) > 0, (_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL))), _tmp3)) {
 		vala_gidl_writer_write_indent (self);
 		fprintf (self->priv->stream, "<requires>\n");
 		self->priv->indent++;
 		{
-			GeeCollection* base_type_collection;
-			GeeIterator* base_type_it;
+			GeeList* base_type_collection;
+			int base_type_it;
 			base_type_collection = vala_interface_get_prerequisites (iface);
-			base_type_it = gee_iterable_iterator (GEE_ITERABLE (base_type_collection));
-			while (gee_iterator_next (base_type_it)) {
+			for (base_type_it = 0; base_type_it < gee_collection_get_size (GEE_COLLECTION (base_type_collection)); base_type_it = base_type_it + 1) {
 				ValaDataType* base_type;
-				base_type = ((ValaDataType*) gee_iterator_get (base_type_it));
+				base_type = ((ValaDataType*) (gee_list_get (GEE_LIST (base_type_collection), base_type_it)));
 				{
-					ValaClassType* _tmp5;
-					ValaDataType* _tmp4;
-					ValaClassType* class_type;
-					ValaInterfaceType* _tmp7;
-					ValaDataType* _tmp6;
-					ValaInterfaceType* iface_type;
-					_tmp5 = NULL;
+					ValaObjectType* _tmp4;
+					ValaObjectType* object_type;
 					_tmp4 = NULL;
-					class_type = (_tmp5 = (_tmp4 = base_type, (VALA_IS_CLASS_TYPE (_tmp4) ? ((ValaClassType*) _tmp4) : NULL)), (_tmp5 == NULL ? NULL : g_object_ref (_tmp5)));
-					_tmp7 = NULL;
-					_tmp6 = NULL;
-					iface_type = (_tmp7 = (_tmp6 = base_type, (VALA_IS_INTERFACE_TYPE (_tmp6) ? ((ValaInterfaceType*) _tmp6) : NULL)), (_tmp7 == NULL ? NULL : g_object_ref (_tmp7)));
-					if (class_type != NULL) {
-						char* _tmp8;
+					object_type = (_tmp4 = VALA_OBJECT_TYPE (base_type), (_tmp4 == NULL ? NULL : g_object_ref (_tmp4)));
+					if (VALA_IS_CLASS (vala_object_type_get_type_symbol (object_type))) {
+						char* _tmp5;
 						vala_gidl_writer_write_indent (self);
-						_tmp8 = NULL;
-						fprintf (self->priv->stream, "<object name=\"%s\"/>\n", (_tmp8 = vala_symbol_get_full_name (VALA_SYMBOL (vala_class_type_get_class_symbol (class_type)))));
-						_tmp8 = (g_free (_tmp8), NULL);
+						_tmp5 = NULL;
+						fprintf (self->priv->stream, "<object name=\"%s\"/>\n", (_tmp5 = vala_symbol_get_full_name (VALA_SYMBOL (vala_object_type_get_type_symbol (object_type)))));
+						_tmp5 = (g_free (_tmp5), NULL);
 					} else {
-						if (iface_type != NULL) {
-							char* _tmp9;
+						if (VALA_IS_INTERFACE (vala_object_type_get_type_symbol (object_type))) {
+							char* _tmp6;
 							vala_gidl_writer_write_indent (self);
-							_tmp9 = NULL;
-							fprintf (self->priv->stream, "<interface name=\"%s\"/>\n", (_tmp9 = vala_symbol_get_full_name (VALA_SYMBOL (vala_interface_type_get_interface_symbol (iface_type)))));
-							_tmp9 = (g_free (_tmp9), NULL);
+							_tmp6 = NULL;
+							fprintf (self->priv->stream, "<interface name=\"%s\"/>\n", (_tmp6 = vala_symbol_get_full_name (VALA_SYMBOL (vala_object_type_get_type_symbol (object_type)))));
+							_tmp6 = (g_free (_tmp6), NULL);
 						} else {
 							g_assert_not_reached ();
 						}
 					}
 					(base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL)));
-					(class_type == NULL ? NULL : (class_type = (g_object_unref (class_type), NULL)));
-					(iface_type == NULL ? NULL : (iface_type = (g_object_unref (iface_type), NULL)));
+					(object_type == NULL ? NULL : (object_type = (g_object_unref (object_type), NULL)));
 				}
 			}
 			(base_type_collection == NULL ? NULL : (base_type_collection = (g_object_unref (base_type_collection), NULL)));
-			(base_type_it == NULL ? NULL : (base_type_it = (g_object_unref (base_type_it), NULL)));
 		}
 		self->priv->indent--;
 		vala_gidl_writer_write_indent (self);
@@ -337,8 +323,8 @@ static void vala_gidl_writer_real_visit_enum (ValaCodeVisitor* base, ValaEnum* e
 	char* _tmp0;
 	char* _tmp1;
 	self = VALA_GIDL_WRITER (base);
-	g_return_if_fail (en == NULL || VALA_IS_ENUM (en));
-	if (vala_code_node_get_source_reference (VALA_CODE_NODE (en)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (en))))) {
+	g_return_if_fail (VALA_IS_ENUM (en));
+	if (vala_symbol_get_external_package (VALA_SYMBOL (en))) {
 		return;
 	}
 	if (!vala_gidl_writer_check_accessibility (self, VALA_SYMBOL (en))) {
@@ -364,7 +350,7 @@ static void vala_gidl_writer_real_visit_enum_value (ValaCodeVisitor* base, ValaE
 	ValaGIdlWriter * self;
 	char* _tmp0;
 	self = VALA_GIDL_WRITER (base);
-	g_return_if_fail (ev == NULL || VALA_IS_ENUM_VALUE (ev));
+	g_return_if_fail (VALA_IS_ENUM_VALUE (ev));
 	vala_gidl_writer_write_indent (self);
 	_tmp0 = NULL;
 	fprintf (self->priv->stream, "<member name=\"%s\"/>\n", (_tmp0 = vala_enum_value_get_cname (ev)));
@@ -376,8 +362,8 @@ static void vala_gidl_writer_real_visit_error_domain (ValaCodeVisitor* base, Val
 	ValaGIdlWriter * self;
 	char* _tmp0;
 	self = VALA_GIDL_WRITER (base);
-	g_return_if_fail (edomain == NULL || VALA_IS_ERROR_DOMAIN (edomain));
-	if (vala_code_node_get_source_reference (VALA_CODE_NODE (edomain)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (edomain))))) {
+	g_return_if_fail (VALA_IS_ERROR_DOMAIN (edomain));
+	if (vala_symbol_get_external_package (VALA_SYMBOL (edomain))) {
 		return;
 	}
 	if (!vala_gidl_writer_check_accessibility (self, VALA_SYMBOL (edomain))) {
@@ -400,7 +386,7 @@ static void vala_gidl_writer_real_visit_error_code (ValaCodeVisitor* base, ValaE
 	ValaGIdlWriter * self;
 	char* _tmp0;
 	self = VALA_GIDL_WRITER (base);
-	g_return_if_fail (ecode == NULL || VALA_IS_ERROR_CODE (ecode));
+	g_return_if_fail (VALA_IS_ERROR_CODE (ecode));
 	vala_gidl_writer_write_indent (self);
 	_tmp0 = NULL;
 	fprintf (self->priv->stream, "<member name=\"%s\"/>\n", (_tmp0 = vala_error_code_get_cname (ecode)));
@@ -412,8 +398,8 @@ static void vala_gidl_writer_real_visit_constant (ValaCodeVisitor* base, ValaCon
 	ValaGIdlWriter * self;
 	char* _tmp0;
 	self = VALA_GIDL_WRITER (base);
-	g_return_if_fail (c == NULL || VALA_IS_CONSTANT (c));
-	if (vala_code_node_get_source_reference (VALA_CODE_NODE (c)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (c))))) {
+	g_return_if_fail (VALA_IS_CONSTANT (c));
+	if (vala_symbol_get_external_package (VALA_SYMBOL (c))) {
 		return;
 	}
 	if (!vala_gidl_writer_check_accessibility (self, VALA_SYMBOL (c))) {
@@ -430,8 +416,8 @@ static void vala_gidl_writer_real_visit_field (ValaCodeVisitor* base, ValaField*
 	ValaGIdlWriter * self;
 	char* _tmp0;
 	self = VALA_GIDL_WRITER (base);
-	g_return_if_fail (f == NULL || VALA_IS_FIELD (f));
-	if (vala_code_node_get_source_reference (VALA_CODE_NODE (f)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (f))))) {
+	g_return_if_fail (VALA_IS_FIELD (f));
+	if (vala_symbol_get_external_package (VALA_SYMBOL (f))) {
 		return;
 	}
 	if (!vala_gidl_writer_check_accessibility (self, VALA_SYMBOL (f))) {
@@ -447,9 +433,9 @@ static void vala_gidl_writer_real_visit_field (ValaCodeVisitor* base, ValaField*
 static char* vala_gidl_writer_get_gidl_type_name (ValaGIdlWriter* self, ValaDataType* type) {
 	char* gidl_type;
 	g_return_val_if_fail (VALA_IS_GIDL_WRITER (self), NULL);
-	g_return_val_if_fail (type == NULL || VALA_IS_DATA_TYPE (type), NULL);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (type), NULL);
 	/* workaround to get GIDL-specific type name*/
-	gidl_type = vala_data_type_get_cname (type, FALSE, FALSE);
+	gidl_type = vala_data_type_get_cname (type);
 	if (vala_data_type_get_data_type (type) != NULL) {
 		char* cname;
 		cname = vala_typesymbol_get_cname (vala_data_type_get_data_type (type), FALSE);
@@ -462,8 +448,8 @@ static char* vala_gidl_writer_get_gidl_type_name (ValaGIdlWriter* self, ValaData
 			_tmp2 = NULL;
 			_tmp1 = NULL;
 			_tmp0 = NULL;
-			gidl_type = (_tmp3 = g_strconcat ((_tmp0 = vala_symbol_get_full_name (VALA_SYMBOL (vala_data_type_get_data_type (type)))), (_tmp2 = g_utf8_offset_to_pointer (gidl_type, g_utf8_strlen (cname, -1)), g_strndup (_tmp2, g_utf8_offset_to_pointer (_tmp2, g_utf8_strlen (gidl_type, -1) - g_utf8_strlen (cname, -1)) - _tmp2)), NULL), (gidl_type = (g_free (gidl_type), NULL)), _tmp3);
-			_tmp1 = (g_free (_tmp1), NULL);
+			gidl_type = (_tmp3 = g_strconcat ((_tmp0 = vala_symbol_get_full_name (VALA_SYMBOL (vala_data_type_get_data_type (type)))), (_tmp2 = (_tmp1 = g_utf8_offset_to_pointer (gidl_type, g_utf8_strlen (cname, -1)), g_strndup (_tmp1, g_utf8_offset_to_pointer (_tmp1, g_utf8_strlen (gidl_type, -1) - g_utf8_strlen (cname, -1)) - _tmp1))), NULL), (gidl_type = (g_free (gidl_type), NULL)), _tmp3);
+			_tmp2 = (g_free (_tmp2), NULL);
 			_tmp0 = (g_free (_tmp0), NULL);
 		}
 		cname = (g_free (cname), NULL);
@@ -474,7 +460,7 @@ static char* vala_gidl_writer_get_gidl_type_name (ValaGIdlWriter* self, ValaData
 			char* cname;
 			_tmp4 = NULL;
 			dt = (_tmp4 = VALA_DELEGATE_TYPE (type), (_tmp4 == NULL ? NULL : g_object_ref (_tmp4)));
-			cname = vala_data_type_get_cname (VALA_DATA_TYPE (dt), FALSE, FALSE);
+			cname = vala_data_type_get_cname (VALA_DATA_TYPE (dt));
 			if (g_str_has_prefix (gidl_type, cname)) {
 				char* _tmp8;
 				char* _tmp7;
@@ -484,8 +470,8 @@ static char* vala_gidl_writer_get_gidl_type_name (ValaGIdlWriter* self, ValaData
 				_tmp7 = NULL;
 				_tmp6 = NULL;
 				_tmp5 = NULL;
-				gidl_type = (_tmp8 = g_strconcat ((_tmp5 = vala_symbol_get_full_name (VALA_SYMBOL (vala_delegate_type_get_delegate_symbol (dt)))), (_tmp7 = g_utf8_offset_to_pointer (gidl_type, g_utf8_strlen (cname, -1)), g_strndup (_tmp7, g_utf8_offset_to_pointer (_tmp7, g_utf8_strlen (gidl_type, -1) - g_utf8_strlen (cname, -1)) - _tmp7)), NULL), (gidl_type = (g_free (gidl_type), NULL)), _tmp8);
-				_tmp6 = (g_free (_tmp6), NULL);
+				gidl_type = (_tmp8 = g_strconcat ((_tmp5 = vala_symbol_get_full_name (VALA_SYMBOL (vala_delegate_type_get_delegate_symbol (dt)))), (_tmp7 = (_tmp6 = g_utf8_offset_to_pointer (gidl_type, g_utf8_strlen (cname, -1)), g_strndup (_tmp6, g_utf8_offset_to_pointer (_tmp6, g_utf8_strlen (gidl_type, -1) - g_utf8_strlen (cname, -1)) - _tmp6))), NULL), (gidl_type = (g_free (gidl_type), NULL)), _tmp8);
+				_tmp7 = (g_free (_tmp7), NULL);
 				_tmp5 = (g_free (_tmp5), NULL);
 			}
 			(dt == NULL ? NULL : (dt = (g_object_unref (dt), NULL)));
@@ -496,9 +482,9 @@ static char* vala_gidl_writer_get_gidl_type_name (ValaGIdlWriter* self, ValaData
 }
 
 
-static void vala_gidl_writer_write_params (ValaGIdlWriter* self, GeeCollection* params, ValaDataType* instance_type) {
+static void vala_gidl_writer_write_params (ValaGIdlWriter* self, GeeList* params, ValaDataType* instance_type) {
 	g_return_if_fail (VALA_IS_GIDL_WRITER (self));
-	g_return_if_fail (params == NULL || GEE_IS_COLLECTION (params));
+	g_return_if_fail (GEE_IS_LIST (params));
 	g_return_if_fail (instance_type == NULL || VALA_IS_DATA_TYPE (instance_type));
 	vala_gidl_writer_write_indent (self);
 	fprintf (self->priv->stream, "<parameters>\n");
@@ -511,35 +497,34 @@ static void vala_gidl_writer_write_params (ValaGIdlWriter* self, GeeCollection*
 		_tmp0 = (g_free (_tmp0), NULL);
 	}
 	{
-		GeeCollection* param_collection;
-		GeeIterator* param_it;
+		GeeList* param_collection;
+		int param_it;
 		param_collection = params;
-		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
-		while (gee_iterator_next (param_it)) {
+		for (param_it = 0; param_it < gee_collection_get_size (GEE_COLLECTION (param_collection)); param_it = param_it + 1) {
 			ValaFormalParameter* param;
-			param = ((ValaFormalParameter*) gee_iterator_get (param_it));
+			param = ((ValaFormalParameter*) (gee_list_get (GEE_LIST (param_collection), param_it)));
 			{
 				char* _tmp1;
 				vala_gidl_writer_write_indent (self);
 				_tmp1 = NULL;
-				fprintf (self->priv->stream, "<parameter name=\"%s\" type=\"%s\"", vala_symbol_get_name (VALA_SYMBOL (param)), (_tmp1 = vala_gidl_writer_get_gidl_type_name (self, vala_formal_parameter_get_type_reference (param))));
+				fprintf (self->priv->stream, "<parameter name=\"%s\" type=\"%s\"", vala_symbol_get_name (VALA_SYMBOL (param)), (_tmp1 = vala_gidl_writer_get_gidl_type_name (self, vala_formal_parameter_get_parameter_type (param))));
 				_tmp1 = (g_free (_tmp1), NULL);
-				if (vala_data_type_get_is_ref (vala_formal_parameter_get_type_reference (param))) {
+				if (vala_formal_parameter_get_direction (param) == VALA_PARAMETER_DIRECTION_REF) {
 					fprintf (self->priv->stream, " direction=\"inout\"");
 					/* in/out paramter*/
-					if (vala_data_type_get_takes_ownership (vala_formal_parameter_get_type_reference (param))) {
+					if (vala_data_type_get_value_owned (vala_formal_parameter_get_parameter_type (param))) {
 						fprintf (self->priv->stream, " transfer=\"full\"");
 					}
 				} else {
-					if (vala_data_type_get_is_out (vala_formal_parameter_get_type_reference (param))) {
+					if (vala_formal_parameter_get_direction (param) == VALA_PARAMETER_DIRECTION_OUT) {
 						/* out paramter*/
 						fprintf (self->priv->stream, " direction=\"out\"");
-						if (vala_data_type_get_takes_ownership (vala_formal_parameter_get_type_reference (param))) {
+						if (vala_data_type_get_value_owned (vala_formal_parameter_get_parameter_type (param))) {
 							fprintf (self->priv->stream, " transfer=\"full\"");
 						}
 					} else {
 						/* normal in paramter*/
-						if (vala_data_type_get_transfers_ownership (vala_formal_parameter_get_type_reference (param))) {
+						if (vala_data_type_get_value_owned (vala_formal_parameter_get_parameter_type (param))) {
 							fprintf (self->priv->stream, " transfer=\"full\"");
 						}
 					}
@@ -548,7 +533,6 @@ static void vala_gidl_writer_write_params (ValaGIdlWriter* self, GeeCollection*
 				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 			}
 		}
-		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
 	}
 	self->priv->indent--;
 	vala_gidl_writer_write_indent (self);
@@ -561,8 +545,8 @@ static void vala_gidl_writer_real_visit_delegate (ValaCodeVisitor* base, ValaDel
 	char* _tmp0;
 	GeeList* _tmp1;
 	self = VALA_GIDL_WRITER (base);
-	g_return_if_fail (cb == NULL || VALA_IS_DELEGATE (cb));
-	if (vala_code_node_get_source_reference (VALA_CODE_NODE (cb)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (cb))))) {
+	g_return_if_fail (VALA_IS_DELEGATE (cb));
+	if (vala_symbol_get_external_package (VALA_SYMBOL (cb))) {
 		return;
 	}
 	if (!vala_gidl_writer_check_accessibility (self, VALA_SYMBOL (cb))) {
@@ -575,7 +559,7 @@ static void vala_gidl_writer_real_visit_delegate (ValaCodeVisitor* base, ValaDel
 	fprintf (self->priv->stream, ">\n");
 	self->priv->indent++;
 	_tmp1 = NULL;
-	vala_gidl_writer_write_params (self, GEE_COLLECTION ((_tmp1 = vala_delegate_get_parameters (cb))), NULL);
+	vala_gidl_writer_write_params (self, (_tmp1 = vala_delegate_get_parameters (cb)), NULL);
 	(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
 	vala_gidl_writer_write_return_type (self, vala_delegate_get_return_type (cb));
 	self->priv->indent--;
@@ -588,10 +572,10 @@ static void vala_gidl_writer_real_visit_method (ValaCodeVisitor* base, ValaMetho
 	ValaGIdlWriter * self;
 	char* _tmp0;
 	ValaDataType* instance_type;
-	GeeCollection* _tmp2;
+	GeeList* _tmp2;
 	self = VALA_GIDL_WRITER (base);
-	g_return_if_fail (m == NULL || VALA_IS_METHOD (m));
-	if (vala_code_node_get_source_reference (VALA_CODE_NODE (m)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (m))))) {
+	g_return_if_fail (VALA_IS_METHOD (m));
+	if (vala_symbol_get_external_package (VALA_SYMBOL (m))) {
 		return;
 	}
 	/* don't write interface implementation unless it's an abstract or virtual method*/
@@ -605,7 +589,7 @@ static void vala_gidl_writer_real_visit_method (ValaCodeVisitor* base, ValaMetho
 	fprintf (self->priv->stream, ">\n");
 	self->priv->indent++;
 	instance_type = NULL;
-	if (vala_method_get_instance (m)) {
+	if (vala_method_get_binding (m) == MEMBER_BINDING_INSTANCE) {
 		ValaDataType* _tmp1;
 		_tmp1 = NULL;
 		instance_type = (_tmp1 = vala_ccode_generator_get_data_type_for_symbol (VALA_TYPESYMBOL (vala_symbol_get_parent_symbol (VALA_SYMBOL (m)))), (instance_type == NULL ? NULL : (instance_type = (g_object_unref (instance_type), NULL))), _tmp1);
@@ -625,11 +609,11 @@ static void vala_gidl_writer_real_visit_creation_method (ValaCodeVisitor* base,
 	ValaGIdlWriter * self;
 	char* name;
 	char* _tmp2;
-	GeeCollection* _tmp3;
+	GeeList* _tmp3;
 	ValaDataType* _tmp4;
 	self = VALA_GIDL_WRITER (base);
-	g_return_if_fail (m == NULL || VALA_IS_CREATION_METHOD (m));
-	if (vala_code_node_get_source_reference (VALA_CODE_NODE (m)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (m))))) {
+	g_return_if_fail (VALA_IS_CREATION_METHOD (m));
+	if (vala_symbol_get_external_package (VALA_SYMBOL (m))) {
 		return;
 	}
 	if (!vala_gidl_writer_check_accessibility (self, VALA_SYMBOL (m))) {
@@ -641,7 +625,7 @@ static void vala_gidl_writer_real_visit_creation_method (ValaCodeVisitor* base,
 		char* _tmp0;
 		_tmp1 = NULL;
 		_tmp0 = NULL;
-		name = (_tmp1 = (_tmp0 = g_utf8_offset_to_pointer (vala_symbol_get_name (VALA_SYMBOL (m)), ((glong) 5)), g_strndup (_tmp0, g_utf8_offset_to_pointer (_tmp0, g_utf8_strlen (vala_symbol_get_name (VALA_SYMBOL (m)), -1) - 5) - _tmp0)), (name = (g_free (name), NULL)), _tmp1);
+		name = (_tmp1 = (_tmp0 = g_utf8_offset_to_pointer (vala_symbol_get_name (VALA_SYMBOL (m)), ((glong) (5))), g_strndup (_tmp0, g_utf8_offset_to_pointer (_tmp0, g_utf8_strlen (vala_symbol_get_name (VALA_SYMBOL (m)), -1) - 5) - _tmp0)), (name = (g_free (name), NULL)), _tmp1);
 	}
 	vala_gidl_writer_write_indent (self);
 	_tmp2 = NULL;
@@ -666,13 +650,13 @@ static void vala_gidl_writer_real_visit_property (ValaCodeVisitor* base, ValaPro
 	ValaGIdlWriter * self;
 	char* _tmp0;
 	self = VALA_GIDL_WRITER (base);
-	g_return_if_fail (prop == NULL || VALA_IS_PROPERTY (prop));
-	if (!vala_gidl_writer_check_accessibility (self, VALA_SYMBOL (prop)) || vala_property_get_overrides (prop) || vala_property_get_base_interface_property (prop) != NULL) {
+	g_return_if_fail (VALA_IS_PROPERTY (prop));
+	if (!vala_gidl_writer_check_accessibility (self, VALA_SYMBOL (prop)) || vala_property_get_overrides (prop) || (vala_property_get_base_interface_property (prop) != NULL && !vala_property_get_is_abstract (prop) && !vala_property_get_is_virtual (prop))) {
 		return;
 	}
 	vala_gidl_writer_write_indent (self);
 	_tmp0 = NULL;
-	fprintf (self->priv->stream, "<property name=\"%s\" type=\"%s\"", vala_symbol_get_name (VALA_SYMBOL (prop)), (_tmp0 = vala_gidl_writer_get_gidl_type_name (self, vala_property_get_type_reference (prop))));
+	fprintf (self->priv->stream, "<property name=\"%s\" type=\"%s\"", vala_symbol_get_name (VALA_SYMBOL (prop)), (_tmp0 = vala_gidl_writer_get_gidl_type_name (self, vala_property_get_property_type (prop))));
 	_tmp0 = (g_free (_tmp0), NULL);
 	if (vala_property_get_get_accessor (prop) != NULL) {
 		fprintf (self->priv->stream, " readable=\"1\"");
@@ -689,7 +673,7 @@ static void vala_gidl_writer_real_visit_signal (ValaCodeVisitor* base, ValaSigna
 	char* _tmp0;
 	GeeList* _tmp1;
 	self = VALA_GIDL_WRITER (base);
-	g_return_if_fail (sig == NULL || VALA_IS_SIGNAL (sig));
+	g_return_if_fail (VALA_IS_SIGNAL (sig));
 	if (!vala_gidl_writer_check_accessibility (self, VALA_SYMBOL (sig))) {
 		return;
 	}
@@ -700,7 +684,7 @@ static void vala_gidl_writer_real_visit_signal (ValaCodeVisitor* base, ValaSigna
 	fprintf (self->priv->stream, ">\n");
 	self->priv->indent++;
 	_tmp1 = NULL;
-	vala_gidl_writer_write_params (self, GEE_COLLECTION ((_tmp1 = vala_signal_get_parameters (sig))), NULL);
+	vala_gidl_writer_write_params (self, (_tmp1 = vala_signal_get_parameters (sig)), NULL);
 	(_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL)));
 	vala_gidl_writer_write_return_type (self, vala_signal_get_return_type (sig));
 	self->priv->indent--;
@@ -722,12 +706,12 @@ static void vala_gidl_writer_write_indent (ValaGIdlWriter* self) {
 static void vala_gidl_writer_write_return_type (ValaGIdlWriter* self, ValaDataType* type) {
 	char* _tmp0;
 	g_return_if_fail (VALA_IS_GIDL_WRITER (self));
-	g_return_if_fail (type == NULL || VALA_IS_DATA_TYPE (type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (type));
 	vala_gidl_writer_write_indent (self);
 	_tmp0 = NULL;
 	fprintf (self->priv->stream, "<return-type type=\"%s\"", (_tmp0 = vala_gidl_writer_get_gidl_type_name (self, type)));
 	_tmp0 = (g_free (_tmp0), NULL);
-	if (vala_data_type_get_transfers_ownership (type)) {
+	if (vala_data_type_get_value_owned (type)) {
 		fprintf (self->priv->stream, " transfer=\"full\"");
 	}
 	fprintf (self->priv->stream, "/>\n");
@@ -736,7 +720,7 @@ static void vala_gidl_writer_write_return_type (ValaGIdlWriter* self, ValaDataTy
 
 static gboolean vala_gidl_writer_check_accessibility (ValaGIdlWriter* self, ValaSymbol* sym) {
 	g_return_val_if_fail (VALA_IS_GIDL_WRITER (self), FALSE);
-	g_return_val_if_fail (sym == NULL || VALA_IS_SYMBOL (sym), FALSE);
+	g_return_val_if_fail (VALA_IS_SYMBOL (sym), FALSE);
 	if (vala_symbol_get_access (sym) == VALA_SYMBOL_ACCESSIBILITY_PUBLIC || vala_symbol_get_access (sym) == VALA_SYMBOL_ACCESSIBILITY_PROTECTED) {
 		return TRUE;
 	}
@@ -776,7 +760,7 @@ static void vala_gidl_writer_class_init (ValaGIdlWriterClass * klass) {
 }
 
 
-static void vala_gidl_writer_init (ValaGIdlWriter * self) {
+static void vala_gidl_writer_instance_init (ValaGIdlWriter * self) {
 	self->priv = VALA_GIDL_WRITER_GET_PRIVATE (self);
 }
 
@@ -794,7 +778,7 @@ static void vala_gidl_writer_dispose (GObject * obj) {
 GType vala_gidl_writer_get_type (void) {
 	static GType vala_gidl_writer_type_id = 0;
 	if (G_UNLIKELY (vala_gidl_writer_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaGIdlWriterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_gidl_writer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaGIdlWriter), 0, (GInstanceInitFunc) vala_gidl_writer_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaGIdlWriterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_gidl_writer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaGIdlWriter), 0, (GInstanceInitFunc) vala_gidl_writer_instance_init };
 		vala_gidl_writer_type_id = g_type_register_static (VALA_TYPE_CODE_VISITOR, "ValaGIdlWriter", &g_define_type_info, 0);
 	}
 	return vala_gidl_writer_type_id;
