@@ -35,12 +35,13 @@
 struct _ValaInterfaceRegisterFunctionPrivate {
 	ValaInterface* _interface_reference;
 };
+
 #define VALA_INTERFACE_REGISTER_FUNCTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_INTERFACE_REGISTER_FUNCTION, ValaInterfaceRegisterFunctionPrivate))
 enum  {
 	VALA_INTERFACE_REGISTER_FUNCTION_DUMMY_PROPERTY,
 	VALA_INTERFACE_REGISTER_FUNCTION_INTERFACE_REFERENCE
 };
-static ValaTypesymbol* vala_interface_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base);
+static ValaTypeSymbol* vala_interface_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base);
 static char* vala_interface_register_function_real_get_type_struct_name (ValaTypeRegisterFunction* base);
 static char* vala_interface_register_function_real_get_base_init_func_name (ValaTypeRegisterFunction* base);
 static char* vala_interface_register_function_real_get_class_init_func_name (ValaTypeRegisterFunction* base);
@@ -63,12 +64,12 @@ ValaInterfaceRegisterFunction* vala_interface_register_function_new (ValaInterfa
 }
 
 
-static ValaTypesymbol* vala_interface_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base) {
+static ValaTypeSymbol* vala_interface_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base) {
 	ValaInterfaceRegisterFunction * self;
-	ValaInterface* _tmp0;
+	ValaTypeSymbol* _tmp0;
 	self = VALA_INTERFACE_REGISTER_FUNCTION (base);
 	_tmp0 = NULL;
-	return VALA_TYPESYMBOL ((_tmp0 = self->priv->_interface_reference, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))));
+	return (_tmp0 = VALA_TYPESYMBOL (self->priv->_interface_reference), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 }
 
 
@@ -132,16 +133,15 @@ static ValaCCodeFragment* vala_interface_register_function_real_get_type_interfa
 	frag = vala_ccode_fragment_new ();
 	/* register all prerequisites */
 	{
-		GeeCollection* prereq_ref_collection;
-		GeeIterator* prereq_ref_it;
+		GeeList* prereq_ref_collection;
+		int prereq_ref_it;
 		prereq_ref_collection = vala_interface_get_prerequisites (self->priv->_interface_reference);
-		prereq_ref_it = gee_iterable_iterator (GEE_ITERABLE (prereq_ref_collection));
-		while (gee_iterator_next (prereq_ref_it)) {
+		for (prereq_ref_it = 0; prereq_ref_it < gee_collection_get_size (GEE_COLLECTION (prereq_ref_collection)); prereq_ref_it = prereq_ref_it + 1) {
 			ValaDataType* prereq_ref;
-			prereq_ref = ((ValaDataType*) gee_iterator_get (prereq_ref_it));
+			prereq_ref = ((ValaDataType*) (gee_list_get (GEE_LIST (prereq_ref_collection), prereq_ref_it)));
 			{
-				ValaTypesymbol* _tmp0;
-				ValaTypesymbol* prereq;
+				ValaTypeSymbol* _tmp0;
+				ValaTypeSymbol* prereq;
 				ValaCCodeIdentifier* _tmp1;
 				ValaCCodeFunctionCall* _tmp2;
 				ValaCCodeFunctionCall* func;
@@ -177,7 +177,6 @@ static ValaCCodeFragment* vala_interface_register_function_real_get_type_interfa
 			}
 		}
 		(prereq_ref_collection == NULL ? NULL : (prereq_ref_collection = (g_object_unref (prereq_ref_collection), NULL)));
-		(prereq_ref_it == NULL ? NULL : (prereq_ref_it = (g_object_unref (prereq_ref_it), NULL)));
 	}
 	return frag;
 }
@@ -242,7 +241,7 @@ static void vala_interface_register_function_class_init (ValaInterfaceRegisterFu
 }
 
 
-static void vala_interface_register_function_init (ValaInterfaceRegisterFunction * self) {
+static void vala_interface_register_function_instance_init (ValaInterfaceRegisterFunction * self) {
 	self->priv = VALA_INTERFACE_REGISTER_FUNCTION_GET_PRIVATE (self);
 }
 
@@ -257,7 +256,7 @@ static void vala_interface_register_function_dispose (GObject * obj) {
 GType vala_interface_register_function_get_type (void) {
 	static GType vala_interface_register_function_type_id = 0;
 	if (G_UNLIKELY (vala_interface_register_function_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaInterfaceRegisterFunctionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_interface_register_function_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInterfaceRegisterFunction), 0, (GInstanceInitFunc) vala_interface_register_function_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaInterfaceRegisterFunctionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_interface_register_function_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInterfaceRegisterFunction), 0, (GInstanceInitFunc) vala_interface_register_function_instance_init };
 		vala_interface_register_function_type_id = g_type_register_static (VALA_TYPE_TYPEREGISTER_FUNCTION, "ValaInterfaceRegisterFunction", &g_define_type_info, 0);
 	}
 	return vala_interface_register_function_type_id;
