@@ -48,6 +48,7 @@ struct _ValaTypeRegisterFunctionPrivate {
 	ValaCCodeFragment* declaration_fragment;
 	ValaCCodeFragment* definition_fragment;
 };
+
 #define VALA_TYPEREGISTER_FUNCTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_TYPEREGISTER_FUNCTION, ValaTypeRegisterFunctionPrivate))
 enum  {
 	VALA_TYPEREGISTER_FUNCTION_DUMMY_PROPERTY
@@ -56,7 +57,6 @@ static char* vala_typeregister_function_real_get_type_flags (ValaTypeRegisterFun
 static ValaCCodeFragment* vala_typeregister_function_real_get_type_interface_init_declaration (ValaTypeRegisterFunction* self);
 static gpointer vala_typeregister_function_parent_class = NULL;
 static void vala_typeregister_function_dispose (GObject * obj);
-static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
@@ -65,10 +65,10 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  */
 void vala_typeregister_function_init_from_type (ValaTypeRegisterFunction* self, gboolean plugin) {
 	gboolean fundamental;
-	ValaTypesymbol* _tmp0;
+	ValaTypeSymbol* _tmp0;
 	ValaClass* cl;
 	char* _tmp2;
-	ValaTypesymbol* _tmp1;
+	ValaTypeSymbol* _tmp1;
 	char* _tmp3;
 	char* type_id_name;
 	ValaCCodeBlock* type_block;
@@ -91,7 +91,7 @@ void vala_typeregister_function_init_from_type (ValaTypeRegisterFunction* self,
 	ValaCCodeConstant* _tmp48;
 	char* _tmp47;
 	char* _tmp46;
-	ValaTypesymbol* _tmp45;
+	ValaTypeSymbol* _tmp45;
 	ValaCCodeIdentifier* _tmp49;
 	ValaCCodeConstant* _tmp52;
 	char* _tmp51;
@@ -105,8 +105,8 @@ void vala_typeregister_function_init_from_type (ValaTypeRegisterFunction* self,
 	g_return_if_fail (VALA_IS_TYPEREGISTER_FUNCTION (self));
 	fundamental = FALSE;
 	_tmp0 = NULL;
-	cl = (_tmp0 = vala_typeregister_function_get_type_declaration (self), (VALA_IS_CLASS (_tmp0) ? ((ValaClass*) _tmp0) : NULL));
-	if (cl != NULL && vala_class_get_base_class (cl) != NULL && _vala_strcmp0 (vala_symbol_get_name (VALA_SYMBOL (vala_class_get_base_class (cl))), "TypeInstance") == 0 && _vala_strcmp0 (vala_symbol_get_name (vala_symbol_get_parent_symbol (VALA_SYMBOL (vala_class_get_base_class (cl)))), "GLib") == 0) {
+	cl = (_tmp0 = vala_typeregister_function_get_type_declaration (self), (VALA_IS_CLASS (_tmp0) ? ((ValaClass*) (_tmp0)) : NULL));
+	if (cl != NULL && !vala_class_get_is_compact (cl) && vala_class_get_base_class (cl) == NULL) {
 		fundamental = TRUE;
 	}
 	_tmp2 = NULL;
@@ -131,7 +131,7 @@ void vala_typeregister_function_init_from_type (ValaTypeRegisterFunction* self,
 		ValaCCodeFunction* _tmp9;
 		char* _tmp8;
 		char* _tmp7;
-		ValaTypesymbol* _tmp6;
+		ValaTypeSymbol* _tmp6;
 		_tmp9 = NULL;
 		_tmp8 = NULL;
 		_tmp7 = NULL;
@@ -148,11 +148,11 @@ void vala_typeregister_function_init_from_type (ValaTypeRegisterFunction* self,
 		ValaCCodeFunction* _tmp13;
 		char* _tmp12;
 		char* _tmp11;
-		ValaTypesymbol* _tmp10;
+		ValaTypeSymbol* _tmp10;
 		ValaCCodeFormalParameter* _tmp14;
 		char* _tmp17;
 		char* _tmp16;
-		ValaTypesymbol* _tmp15;
+		ValaTypeSymbol* _tmp15;
 		ValaCCodeFunction* _tmp18;
 		ValaCCodeFunction* get_fun;
 		ValaCCodeFunction* _tmp19;
@@ -364,7 +364,7 @@ void vala_typeregister_function_init_from_type (ValaTypeRegisterFunction* self,
  *
  * @return type to be registered
  */
-ValaTypesymbol* vala_typeregister_function_get_type_declaration (ValaTypeRegisterFunction* self) {
+ValaTypeSymbol* vala_typeregister_function_get_type_declaration (ValaTypeRegisterFunction* self) {
 	return VALA_TYPEREGISTER_FUNCTION_GET_CLASS (self)->get_type_declaration (self);
 }
 
@@ -514,7 +514,7 @@ static void vala_typeregister_function_class_init (ValaTypeRegisterFunctionClass
 }
 
 
-static void vala_typeregister_function_init (ValaTypeRegisterFunction * self) {
+static void vala_typeregister_function_instance_init (ValaTypeRegisterFunction * self) {
 	self->priv = VALA_TYPEREGISTER_FUNCTION_GET_PRIVATE (self);
 	self->priv->declaration_fragment = vala_ccode_fragment_new ();
 	self->priv->definition_fragment = vala_ccode_fragment_new ();
@@ -533,23 +533,12 @@ static void vala_typeregister_function_dispose (GObject * obj) {
 GType vala_typeregister_function_get_type (void) {
 	static GType vala_typeregister_function_type_id = 0;
 	if (G_UNLIKELY (vala_typeregister_function_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaTypeRegisterFunctionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_typeregister_function_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaTypeRegisterFunction), 0, (GInstanceInitFunc) vala_typeregister_function_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaTypeRegisterFunctionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_typeregister_function_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaTypeRegisterFunction), 0, (GInstanceInitFunc) vala_typeregister_function_instance_init };
 		vala_typeregister_function_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaTypeRegisterFunction", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
 	return vala_typeregister_function_type_id;
 }
 
 
-static int _vala_strcmp0 (const char * str1, const char * str2) {
-	if (str1 == NULL) {
-		return -(str1 != str2);
-	}
-	if (str2 == NULL) {
-		return (str1 != str2);
-	}
-	return strcmp (str1, str2);
-}
-
-
 
 
