@@ -30,6 +30,7 @@
 struct _ValaAddressofExpressionPrivate {
 	ValaExpression* _inner;
 };
+
 #define VALA_ADDRESSOF_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_ADDRESSOF_EXPRESSION, ValaAddressofExpressionPrivate))
 enum  {
 	VALA_ADDRESSOF_EXPRESSION_DUMMY_PROPERTY,
@@ -53,7 +54,7 @@ ValaAddressofExpression* vala_addressof_expression_new (ValaExpression* inner, V
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaAddressofExpression * self;
-	g_return_val_if_fail (inner == NULL || VALA_IS_EXPRESSION (inner), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (inner), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
@@ -75,17 +76,18 @@ ValaAddressofExpression* vala_addressof_expression_new (ValaExpression* inner, V
 static void vala_addressof_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaAddressofExpression * self;
 	self = VALA_ADDRESSOF_EXPRESSION (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_addressof_expression_get_inner (self)), visitor);
 	vala_code_visitor_visit_addressof_expression (visitor, self);
+	vala_code_visitor_visit_expression (visitor, VALA_EXPRESSION (self));
 }
 
 
 static void vala_addressof_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaAddressofExpression * self;
 	self = VALA_ADDRESSOF_EXPRESSION (base);
-	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
 	if (vala_addressof_expression_get_inner (self) == old_node) {
 		vala_addressof_expression_set_inner (self, new_node);
 	}
@@ -157,7 +159,7 @@ static void vala_addressof_expression_class_init (ValaAddressofExpressionClass *
 }
 
 
-static void vala_addressof_expression_init (ValaAddressofExpression * self) {
+static void vala_addressof_expression_instance_init (ValaAddressofExpression * self) {
 	self->priv = VALA_ADDRESSOF_EXPRESSION_GET_PRIVATE (self);
 }
 
@@ -173,7 +175,7 @@ static void vala_addressof_expression_dispose (GObject * obj) {
 GType vala_addressof_expression_get_type (void) {
 	static GType vala_addressof_expression_type_id = 0;
 	if (G_UNLIKELY (vala_addressof_expression_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaAddressofExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_addressof_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaAddressofExpression), 0, (GInstanceInitFunc) vala_addressof_expression_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaAddressofExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_addressof_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaAddressofExpression), 0, (GInstanceInitFunc) vala_addressof_expression_instance_init };
 		vala_addressof_expression_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaAddressofExpression", &g_define_type_info, 0);
 	}
 	return vala_addressof_expression_type_id;
