@@ -1,6 +1,6 @@
 /* valaarraycreationexpression.vala
  *
- * Copyright (C) 2006-2007  Raffaele Sandrini, Jürg Billeter
+ * Copyright (C) 2006-2008  Raffaele Sandrini, Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -29,6 +29,7 @@
 #include <vala/valadatatype.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
+#include <vala/valacodegenerator.h>
 
 
 
@@ -39,6 +40,7 @@ struct _ValaArrayCreationExpressionPrivate {
 	ValaInitializerList* _initializer_list;
 	ValaDataType* _element_type;
 };
+
 #define VALA_ARRAY_CREATION_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_ARRAY_CREATION_EXPRESSION, ValaArrayCreationExpressionPrivate))
 enum  {
 	VALA_ARRAY_CREATION_EXPRESSION_DUMMY_PROPERTY,
@@ -50,6 +52,7 @@ static void vala_array_creation_expression_real_accept_children (ValaCodeNode* b
 static void vala_array_creation_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gboolean vala_array_creation_expression_real_is_pure (ValaExpression* base);
 static void vala_array_creation_expression_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
+static ValaCodeBinding* vala_array_creation_expression_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen);
 static gpointer vala_array_creation_expression_parent_class = NULL;
 static void vala_array_creation_expression_dispose (GObject * obj);
 
@@ -60,7 +63,7 @@ static void vala_array_creation_expression_dispose (GObject * obj);
  */
 void vala_array_creation_expression_append_size (ValaArrayCreationExpression* self, ValaExpression* size) {
 	g_return_if_fail (VALA_IS_ARRAY_CREATION_EXPRESSION (self));
-	g_return_if_fail (size == NULL || VALA_IS_EXPRESSION (size));
+	g_return_if_fail (VALA_IS_EXPRESSION (size));
 	gee_collection_add (GEE_COLLECTION (self->priv->sizes), size);
 }
 
@@ -70,7 +73,7 @@ void vala_array_creation_expression_append_size (ValaArrayCreationExpression* se
  */
 GeeList* vala_array_creation_expression_get_sizes (ValaArrayCreationExpression* self) {
 	g_return_val_if_fail (VALA_IS_ARRAY_CREATION_EXPRESSION (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, self->priv->sizes));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->sizes));
 }
 
 
@@ -78,9 +81,9 @@ ValaArrayCreationExpression* vala_array_creation_expression_new (ValaDataType* e
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaArrayCreationExpression * self;
-	g_return_val_if_fail (element_type == NULL || VALA_IS_DATA_TYPE (element_type), NULL);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (element_type), NULL);
 	g_return_val_if_fail (initializer_list == NULL || VALA_IS_INITIALIZER_LIST (initializer_list), NULL);
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
 	__params_it->name = "rank";
@@ -106,24 +109,22 @@ ValaArrayCreationExpression* vala_array_creation_expression_new (ValaDataType* e
 static void vala_array_creation_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaArrayCreationExpression * self;
 	self = VALA_ARRAY_CREATION_EXPRESSION (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (vala_array_creation_expression_get_element_type (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_array_creation_expression_get_element_type (self)), visitor);
 	}
 	{
 		GeeList* e_collection;
-		GeeIterator* e_it;
+		int e_it;
 		e_collection = self->priv->sizes;
-		e_it = gee_iterable_iterator (GEE_ITERABLE (e_collection));
-		while (gee_iterator_next (e_it)) {
+		for (e_it = 0; e_it < gee_collection_get_size (GEE_COLLECTION (e_collection)); e_it = e_it + 1) {
 			ValaExpression* e;
-			e = ((ValaExpression*) gee_iterator_get (e_it));
+			e = ((ValaExpression*) (gee_list_get (GEE_LIST (e_collection), e_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (e), visitor);
 				(e == NULL ? NULL : (e = (g_object_unref (e), NULL)));
 			}
 		}
-		(e_it == NULL ? NULL : (e_it = (g_object_unref (e_it), NULL)));
 	}
 	if (self->priv->_initializer_list != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (self->priv->_initializer_list), visitor);
@@ -134,8 +135,9 @@ static void vala_array_creation_expression_real_accept_children (ValaCodeNode* b
 static void vala_array_creation_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaArrayCreationExpression * self;
 	self = VALA_ARRAY_CREATION_EXPRESSION (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_array_creation_expression (visitor, self);
+	vala_code_visitor_visit_expression (visitor, VALA_EXPRESSION (self));
 }
 
 
@@ -149,14 +151,22 @@ static gboolean vala_array_creation_expression_real_is_pure (ValaExpression* bas
 static void vala_array_creation_expression_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaArrayCreationExpression * self;
 	self = VALA_ARRAY_CREATION_EXPRESSION (base);
-	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
 	if (vala_array_creation_expression_get_element_type (self) == old_type) {
 		vala_array_creation_expression_set_element_type (self, new_type);
 	}
 }
 
 
+static ValaCodeBinding* vala_array_creation_expression_real_create_code_binding (ValaCodeNode* base, ValaCodeGenerator* codegen) {
+	ValaArrayCreationExpression * self;
+	self = VALA_ARRAY_CREATION_EXPRESSION (base);
+	g_return_val_if_fail (VALA_IS_CODE_GENERATOR (codegen), NULL);
+	return vala_code_generator_create_array_creation_expression_binding (codegen, self);
+}
+
+
 ValaDataType* vala_array_creation_expression_get_element_type (ValaArrayCreationExpression* self) {
 	g_return_val_if_fail (VALA_IS_ARRAY_CREATION_EXPRESSION (self), NULL);
 	return self->priv->_element_type;
@@ -252,15 +262,16 @@ static void vala_array_creation_expression_class_init (ValaArrayCreationExpressi
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_array_creation_expression_real_accept;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_array_creation_expression_real_is_pure;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_array_creation_expression_real_replace_type;
+	VALA_CODE_NODE_CLASS (klass)->create_code_binding = vala_array_creation_expression_real_create_code_binding;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_CREATION_EXPRESSION_ELEMENT_TYPE, g_param_spec_object ("element-type", "element-type", "element-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_CREATION_EXPRESSION_RANK, g_param_spec_int ("rank", "rank", "rank", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ARRAY_CREATION_EXPRESSION_INITIALIZER_LIST, g_param_spec_object ("initializer-list", "initializer-list", "initializer-list", VALA_TYPE_INITIALIZER_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
 }
 
 
-static void vala_array_creation_expression_init (ValaArrayCreationExpression * self) {
+static void vala_array_creation_expression_instance_init (ValaArrayCreationExpression * self) {
 	self->priv = VALA_ARRAY_CREATION_EXPRESSION_GET_PRIVATE (self);
-	self->priv->sizes = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->sizes = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 }
 
 
@@ -277,7 +288,7 @@ static void vala_array_creation_expression_dispose (GObject * obj) {
 GType vala_array_creation_expression_get_type (void) {
 	static GType vala_array_creation_expression_type_id = 0;
 	if (G_UNLIKELY (vala_array_creation_expression_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaArrayCreationExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_array_creation_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaArrayCreationExpression), 0, (GInstanceInitFunc) vala_array_creation_expression_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaArrayCreationExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_array_creation_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaArrayCreationExpression), 0, (GInstanceInitFunc) vala_array_creation_expression_instance_init };
 		vala_array_creation_expression_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaArrayCreationExpression", &g_define_type_info, 0);
 	}
 	return vala_array_creation_expression_type_id;
