@@ -26,7 +26,7 @@
 #include <glib.h>
 #include <glib-object.h>
 #include <vala/valafield.h>
-#include <vala/valacodenode.h>
+#include <vala/valasourcereference.h>
 
 G_BEGIN_DECLS
 
@@ -38,6 +38,8 @@ G_BEGIN_DECLS
 #define VALA_IS_ARRAY_LENGTH_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ARRAY_LENGTH_FIELD))
 #define VALA_ARRAY_LENGTH_FIELD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ARRAY_LENGTH_FIELD, ValaArrayLengthFieldClass))
 
+typedef struct _ValaArrayLengthField ValaArrayLengthField;
+typedef struct _ValaArrayLengthFieldClass ValaArrayLengthFieldClass;
 typedef struct _ValaArrayLengthFieldPrivate ValaArrayLengthFieldPrivate;
 
 /**
@@ -47,13 +49,16 @@ struct _ValaArrayLengthField {
 	ValaField parent_instance;
 	ValaArrayLengthFieldPrivate * priv;
 };
+
 struct _ValaArrayLengthFieldClass {
 	ValaFieldClass parent_class;
 };
 
+
 ValaArrayLengthField* vala_array_length_field_new (ValaSourceReference* source_reference);
 GType vala_array_length_field_get_type (void);
 
+
 G_END_DECLS
 
 #endif
