@@ -21,8 +21,11 @@
  */
 
 #include <vala/valaarraymovemethod.h>
-#include <vala/valasymbol.h>
 #include <vala/valacodenode.h>
+#include <vala/valasymbol.h>
+
+
+
 
 enum  {
 	VALA_ARRAY_MOVE_METHOD_DUMMY_PROPERTY
@@ -30,6 +33,7 @@ enum  {
 static gpointer vala_array_move_method_parent_class = NULL;
 
 
+
 /**
  * Creates a new array move method.
  *
@@ -37,10 +41,10 @@ static gpointer vala_array_move_method_parent_class = NULL;
  */
 ValaArrayMoveMethod* vala_array_move_method_new (ValaSourceReference* source_reference) {
 	ValaArrayMoveMethod * self;
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_ARRAY_MOVE_METHOD, 0, NULL);
-	vala_symbol_set_name (VALA_SYMBOL (self), "move");
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_symbol_set_name (VALA_SYMBOL (self), "move");
 	return self;
 }
 
@@ -50,14 +54,14 @@ static void vala_array_move_method_class_init (ValaArrayMoveMethodClass * klass)
 }
 
 
-static void vala_array_move_method_init (ValaArrayMoveMethod * self) {
+static void vala_array_move_method_instance_init (ValaArrayMoveMethod * self) {
 }
 
 
 GType vala_array_move_method_get_type (void) {
 	static GType vala_array_move_method_type_id = 0;
 	if (G_UNLIKELY (vala_array_move_method_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaArrayMoveMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_array_move_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaArrayMoveMethod), 0, (GInstanceInitFunc) vala_array_move_method_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaArrayMoveMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_array_move_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaArrayMoveMethod), 0, (GInstanceInitFunc) vala_array_move_method_instance_init };
 		vala_array_move_method_type_id = g_type_register_static (VALA_TYPE_METHOD, "ValaArrayMoveMethod", &g_define_type_info, 0);
 	}
 	return vala_array_move_method_type_id;
