@@ -21,8 +21,8 @@
  */
 
 #include <vala/valaarrayresizemethod.h>
-#include <vala/valasymbol.h>
 #include <vala/valacodenode.h>
+#include <vala/valasymbol.h>
 
 
 
@@ -42,10 +42,10 @@ static gpointer vala_array_resize_method_parent_class = NULL;
  */
 ValaArrayResizeMethod* vala_array_resize_method_new (ValaSourceReference* source_reference) {
 	ValaArrayResizeMethod * self;
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_ARRAY_RESIZE_METHOD, 0, NULL);
-	vala_symbol_set_name (VALA_SYMBOL (self), "resize");
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_symbol_set_name (VALA_SYMBOL (self), "resize");
 	return self;
 }
 
@@ -72,14 +72,14 @@ static void vala_array_resize_method_class_init (ValaArrayResizeMethodClass * kl
 }
 
 
-static void vala_array_resize_method_init (ValaArrayResizeMethod * self) {
+static void vala_array_resize_method_instance_init (ValaArrayResizeMethod * self) {
 }
 
 
 GType vala_array_resize_method_get_type (void) {
 	static GType vala_array_resize_method_type_id = 0;
 	if (G_UNLIKELY (vala_array_resize_method_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaArrayResizeMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_array_resize_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaArrayResizeMethod), 0, (GInstanceInitFunc) vala_array_resize_method_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaArrayResizeMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_array_resize_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaArrayResizeMethod), 0, (GInstanceInitFunc) vala_array_resize_method_instance_init };
 		vala_array_resize_method_type_id = g_type_register_static (VALA_TYPE_METHOD, "ValaArrayResizeMethod", &g_define_type_info, 0);
 	}
 	return vala_array_resize_method_type_id;
