@@ -1,6 +1,6 @@
 /* valaarrayresizemethod.vala
  *
- * Copyright (C) 2007  Jürg Billeter
+ * Copyright (C) 2007-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,7 +26,7 @@
 #include <glib.h>
 #include <glib-object.h>
 #include <vala/valamethod.h>
-#include <vala/valacodenode.h>
+#include <vala/valasourcereference.h>
 
 G_BEGIN_DECLS
 
@@ -38,6 +38,8 @@ G_BEGIN_DECLS
 #define VALA_IS_ARRAY_RESIZE_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ARRAY_RESIZE_METHOD))
 #define VALA_ARRAY_RESIZE_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ARRAY_RESIZE_METHOD, ValaArrayResizeMethodClass))
 
+typedef struct _ValaArrayResizeMethod ValaArrayResizeMethod;
+typedef struct _ValaArrayResizeMethodClass ValaArrayResizeMethodClass;
 typedef struct _ValaArrayResizeMethodPrivate ValaArrayResizeMethodPrivate;
 
 /**
@@ -47,13 +49,16 @@ struct _ValaArrayResizeMethod {
 	ValaMethod parent_instance;
 	ValaArrayResizeMethodPrivate * priv;
 };
+
 struct _ValaArrayResizeMethodClass {
 	ValaMethodClass parent_class;
 };
 
+
 ValaArrayResizeMethod* vala_array_resize_method_new (ValaSourceReference* source_reference);
 GType vala_array_resize_method_get_type (void);
 
+
 G_END_DECLS
 
 #endif
