@@ -37,6 +37,7 @@
 struct _ValaAttributePrivate {
 	char* _name;
 };
+
 #define VALA_ATTRIBUTE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_ATTRIBUTE, ValaAttributePrivate))
 enum  {
 	VALA_ATTRIBUTE_DUMMY_PROPERTY,
@@ -57,6 +58,7 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  */
 ValaAttribute* vala_attribute_new (const char* name, ValaSourceReference* source_reference) {
 	ValaAttribute * self;
+	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_ATTRIBUTE, 0, NULL);
 	vala_attribute_set_name (self, name);
@@ -72,7 +74,7 @@ ValaAttribute* vala_attribute_new (const char* name, ValaSourceReference* source
  */
 void vala_attribute_add_argument (ValaAttribute* self, ValaNamedArgument* arg) {
 	g_return_if_fail (VALA_IS_ATTRIBUTE (self));
-	g_return_if_fail (arg == NULL || VALA_IS_NAMED_ARGUMENT (arg));
+	g_return_if_fail (VALA_IS_NAMED_ARGUMENT (arg));
 	gee_collection_add (GEE_COLLECTION (self->args), arg);
 }
 
@@ -85,24 +87,23 @@ void vala_attribute_add_argument (ValaAttribute* self, ValaNamedArgument* arg) {
  */
 gboolean vala_attribute_has_argument (ValaAttribute* self, const char* name) {
 	g_return_val_if_fail (VALA_IS_ATTRIBUTE (self), FALSE);
+	g_return_val_if_fail (name != NULL, FALSE);
+	/* FIXME: use hash table*/
 	{
 		GeeList* arg_collection;
-		GeeIterator* arg_it;
+		int arg_it;
 		arg_collection = self->args;
-		arg_it = gee_iterable_iterator (GEE_ITERABLE (arg_collection));
-		while (gee_iterator_next (arg_it)) {
+		for (arg_it = 0; arg_it < gee_collection_get_size (GEE_COLLECTION (arg_collection)); arg_it = arg_it + 1) {
 			ValaNamedArgument* arg;
-			arg = ((ValaNamedArgument*) gee_iterator_get (arg_it));
+			arg = ((ValaNamedArgument*) (gee_list_get (GEE_LIST (arg_collection), arg_it)));
 			{
-				/* FIXME: use hash table*/
 				if (_vala_strcmp0 (vala_named_argument_get_name (arg), name) == 0) {
 					gboolean _tmp0;
-					return (_tmp0 = TRUE, (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp0);
+					return (_tmp0 = TRUE, (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), _tmp0);
 				}
 				(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
 			}
 		}
-		(arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL)));
 	}
 	return FALSE;
 }
@@ -116,34 +117,33 @@ gboolean vala_attribute_has_argument (ValaAttribute* self, const char* name) {
  */
 char* vala_attribute_get_string (ValaAttribute* self, const char* name) {
 	g_return_val_if_fail (VALA_IS_ATTRIBUTE (self), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	/* FIXME: use hash table*/
 	{
 		GeeList* arg_collection;
-		GeeIterator* arg_it;
+		int arg_it;
 		arg_collection = self->args;
-		arg_it = gee_iterable_iterator (GEE_ITERABLE (arg_collection));
-		while (gee_iterator_next (arg_it)) {
+		for (arg_it = 0; arg_it < gee_collection_get_size (GEE_COLLECTION (arg_collection)); arg_it = arg_it + 1) {
 			ValaNamedArgument* arg;
-			arg = ((ValaNamedArgument*) gee_iterator_get (arg_it));
+			arg = ((ValaNamedArgument*) (gee_list_get (GEE_LIST (arg_collection), arg_it)));
 			{
-				/* FIXME: use hash table*/
 				if (_vala_strcmp0 (vala_named_argument_get_name (arg), name) == 0) {
 					ValaStringLiteral* _tmp1;
 					ValaExpression* _tmp0;
 					ValaStringLiteral* lit;
 					_tmp1 = NULL;
 					_tmp0 = NULL;
-					lit = (_tmp1 = (_tmp0 = vala_named_argument_get_argument (arg), (VALA_IS_STRING_LITERAL (_tmp0) ? ((ValaStringLiteral*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+					lit = (_tmp1 = (_tmp0 = vala_named_argument_get_argument (arg), (VALA_IS_STRING_LITERAL (_tmp0) ? ((ValaStringLiteral*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
 					if (lit != NULL) {
 						char* _tmp2;
 						_tmp2 = NULL;
-						return (_tmp2 = vala_string_literal_eval (lit), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp2);
+						return (_tmp2 = vala_string_literal_eval (lit), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), _tmp2);
 					}
 					(lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL)));
 				}
 				(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
 			}
 		}
-		(arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL)));
 	}
 	return NULL;
 }
@@ -157,33 +157,32 @@ char* vala_attribute_get_string (ValaAttribute* self, const char* name) {
  */
 gint vala_attribute_get_integer (ValaAttribute* self, const char* name) {
 	g_return_val_if_fail (VALA_IS_ATTRIBUTE (self), 0);
+	g_return_val_if_fail (name != NULL, 0);
+	/* FIXME: use hash table*/
 	{
 		GeeList* arg_collection;
-		GeeIterator* arg_it;
+		int arg_it;
 		arg_collection = self->args;
-		arg_it = gee_iterable_iterator (GEE_ITERABLE (arg_collection));
-		while (gee_iterator_next (arg_it)) {
+		for (arg_it = 0; arg_it < gee_collection_get_size (GEE_COLLECTION (arg_collection)); arg_it = arg_it + 1) {
 			ValaNamedArgument* arg;
-			arg = ((ValaNamedArgument*) gee_iterator_get (arg_it));
+			arg = ((ValaNamedArgument*) (gee_list_get (GEE_LIST (arg_collection), arg_it)));
 			{
-				/* FIXME: use hash table*/
 				if (_vala_strcmp0 (vala_named_argument_get_name (arg), name) == 0) {
 					ValaIntegerLiteral* _tmp1;
 					ValaExpression* _tmp0;
 					ValaIntegerLiteral* lit;
 					_tmp1 = NULL;
 					_tmp0 = NULL;
-					lit = (_tmp1 = (_tmp0 = vala_named_argument_get_argument (arg), (VALA_IS_INTEGER_LITERAL (_tmp0) ? ((ValaIntegerLiteral*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+					lit = (_tmp1 = (_tmp0 = vala_named_argument_get_argument (arg), (VALA_IS_INTEGER_LITERAL (_tmp0) ? ((ValaIntegerLiteral*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
 					if (lit != NULL) {
 						gint _tmp2;
-						return (_tmp2 = atoi (vala_integer_literal_get_value (lit)), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp2);
+						return (_tmp2 = atoi (vala_integer_literal_get_value (lit)), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), _tmp2);
 					}
 					(lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL)));
 				}
 				(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
 			}
 		}
-		(arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL)));
 	}
 	return 0;
 }
@@ -197,16 +196,16 @@ gint vala_attribute_get_integer (ValaAttribute* self, const char* name) {
  */
 double vala_attribute_get_double (ValaAttribute* self, const char* name) {
 	g_return_val_if_fail (VALA_IS_ATTRIBUTE (self), 0.0);
+	g_return_val_if_fail (name != NULL, 0.0);
+	/* FIXME: use hash table*/
 	{
 		GeeList* arg_collection;
-		GeeIterator* arg_it;
+		int arg_it;
 		arg_collection = self->args;
-		arg_it = gee_iterable_iterator (GEE_ITERABLE (arg_collection));
-		while (gee_iterator_next (arg_it)) {
+		for (arg_it = 0; arg_it < gee_collection_get_size (GEE_COLLECTION (arg_collection)); arg_it = arg_it + 1) {
 			ValaNamedArgument* arg;
-			arg = ((ValaNamedArgument*) gee_iterator_get (arg_it));
+			arg = ((ValaNamedArgument*) (gee_list_get (GEE_LIST (arg_collection), arg_it)));
 			{
-				/* FIXME: use hash table*/
 				if (_vala_strcmp0 (vala_named_argument_get_name (arg), name) == 0) {
 					if (VALA_IS_REAL_LITERAL (vala_named_argument_get_argument (arg))) {
 						ValaRealLiteral* _tmp0;
@@ -214,15 +213,15 @@ double vala_attribute_get_double (ValaAttribute* self, const char* name) {
 						double _tmp1;
 						_tmp0 = NULL;
 						lit = (_tmp0 = VALA_REAL_LITERAL (vala_named_argument_get_argument (arg)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
-						return (_tmp1 = strtod (vala_real_literal_get_value (lit), NULL), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp1);
+						return (_tmp1 = strtod (vala_real_literal_get_value (lit), NULL), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), _tmp1);
 					} else {
 						if (VALA_IS_INTEGER_LITERAL (vala_named_argument_get_argument (arg))) {
 							ValaIntegerLiteral* _tmp2;
 							ValaIntegerLiteral* lit;
-							gint _tmp3;
+							double _tmp3;
 							_tmp2 = NULL;
 							lit = (_tmp2 = VALA_INTEGER_LITERAL (vala_named_argument_get_argument (arg)), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)));
-							return ((double) (_tmp3 = atoi (vala_integer_literal_get_value (lit)), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp3));
+							return (_tmp3 = ((double) (atoi (vala_integer_literal_get_value (lit)))), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), _tmp3);
 						} else {
 							if (VALA_IS_UNARY_EXPRESSION (vala_named_argument_get_argument (arg))) {
 								ValaUnaryExpression* _tmp4;
@@ -236,15 +235,15 @@ double vala_attribute_get_double (ValaAttribute* self, const char* name) {
 										double _tmp6;
 										_tmp5 = NULL;
 										lit = (_tmp5 = VALA_REAL_LITERAL (vala_unary_expression_get_inner (unary)), (_tmp5 == NULL ? NULL : g_object_ref (_tmp5)));
-										return (_tmp6 = -strtod (vala_real_literal_get_value (lit), NULL), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (unary == NULL ? NULL : (unary = (g_object_unref (unary), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp6);
+										return (_tmp6 = -strtod (vala_real_literal_get_value (lit), NULL), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (unary == NULL ? NULL : (unary = (g_object_unref (unary), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), _tmp6);
 									} else {
 										if (VALA_IS_INTEGER_LITERAL (vala_unary_expression_get_inner (unary))) {
 											ValaIntegerLiteral* _tmp7;
 											ValaIntegerLiteral* lit;
-											gint _tmp8;
+											double _tmp8;
 											_tmp7 = NULL;
 											lit = (_tmp7 = VALA_INTEGER_LITERAL (vala_unary_expression_get_inner (unary)), (_tmp7 == NULL ? NULL : g_object_ref (_tmp7)));
-											return ((double) (_tmp8 = -atoi (vala_integer_literal_get_value (lit)), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (unary == NULL ? NULL : (unary = (g_object_unref (unary), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp8));
+											return (_tmp8 = ((double) (-atoi (vala_integer_literal_get_value (lit)))), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (unary == NULL ? NULL : (unary = (g_object_unref (unary), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), _tmp8);
 										}
 									}
 								}
@@ -256,9 +255,8 @@ double vala_attribute_get_double (ValaAttribute* self, const char* name) {
 				(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
 			}
 		}
-		(arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL)));
 	}
-	return ((double) 0);
+	return ((double) (0));
 }
 
 
@@ -270,39 +268,38 @@ double vala_attribute_get_double (ValaAttribute* self, const char* name) {
  */
 gboolean vala_attribute_get_bool (ValaAttribute* self, const char* name) {
 	g_return_val_if_fail (VALA_IS_ATTRIBUTE (self), FALSE);
+	g_return_val_if_fail (name != NULL, FALSE);
+	/* FIXME: use hash table*/
 	{
 		GeeList* arg_collection;
-		GeeIterator* arg_it;
+		int arg_it;
 		arg_collection = self->args;
-		arg_it = gee_iterable_iterator (GEE_ITERABLE (arg_collection));
-		while (gee_iterator_next (arg_it)) {
+		for (arg_it = 0; arg_it < gee_collection_get_size (GEE_COLLECTION (arg_collection)); arg_it = arg_it + 1) {
 			ValaNamedArgument* arg;
-			arg = ((ValaNamedArgument*) gee_iterator_get (arg_it));
+			arg = ((ValaNamedArgument*) (gee_list_get (GEE_LIST (arg_collection), arg_it)));
 			{
-				/* FIXME: use hash table*/
 				if (_vala_strcmp0 (vala_named_argument_get_name (arg), name) == 0) {
 					ValaBooleanLiteral* _tmp1;
 					ValaExpression* _tmp0;
 					ValaBooleanLiteral* lit;
 					_tmp1 = NULL;
 					_tmp0 = NULL;
-					lit = (_tmp1 = (_tmp0 = vala_named_argument_get_argument (arg), (VALA_IS_BOOLEAN_LITERAL (_tmp0) ? ((ValaBooleanLiteral*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+					lit = (_tmp1 = (_tmp0 = vala_named_argument_get_argument (arg), (VALA_IS_BOOLEAN_LITERAL (_tmp0) ? ((ValaBooleanLiteral*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
 					if (lit != NULL) {
 						gboolean _tmp2;
-						return (_tmp2 = vala_boolean_literal_get_value (lit), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), (arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL))), _tmp2);
+						return (_tmp2 = vala_boolean_literal_get_value (lit), (lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL))), (arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL))), _tmp2);
 					}
 					(lit == NULL ? NULL : (lit = (g_object_unref (lit), NULL)));
 				}
 				(arg == NULL ? NULL : (arg = (g_object_unref (arg), NULL)));
 			}
 		}
-		(arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL)));
 	}
 	return FALSE;
 }
 
 
-char* vala_attribute_get_name (ValaAttribute* self) {
+const char* vala_attribute_get_name (ValaAttribute* self) {
 	g_return_val_if_fail (VALA_IS_ATTRIBUTE (self), NULL);
 	return self->priv->_name;
 }
@@ -356,9 +353,9 @@ static void vala_attribute_class_init (ValaAttributeClass * klass) {
 }
 
 
-static void vala_attribute_init (ValaAttribute * self) {
+static void vala_attribute_instance_init (ValaAttribute * self) {
 	self->priv = VALA_ATTRIBUTE_GET_PRIVATE (self);
-	self->args = GEE_LIST (gee_array_list_new (VALA_TYPE_NAMED_ARGUMENT, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->args = GEE_LIST (gee_array_list_new (VALA_TYPE_NAMED_ARGUMENT, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 }
 
 
@@ -374,7 +371,7 @@ static void vala_attribute_dispose (GObject * obj) {
 GType vala_attribute_get_type (void) {
 	static GType vala_attribute_type_id = 0;
 	if (G_UNLIKELY (vala_attribute_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaAttributeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_attribute_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaAttribute), 0, (GInstanceInitFunc) vala_attribute_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaAttributeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_attribute_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaAttribute), 0, (GInstanceInitFunc) vala_attribute_instance_init };
 		vala_attribute_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaAttribute", &g_define_type_info, 0);
 	}
 	return vala_attribute_type_id;
