@@ -35,6 +35,8 @@ static void vala_attribute_processor_real_visit_class (ValaCodeVisitor* base, Va
 static void vala_attribute_processor_real_visit_struct (ValaCodeVisitor* base, ValaStruct* st);
 static void vala_attribute_processor_real_visit_interface (ValaCodeVisitor* base, ValaInterface* iface);
 static void vala_attribute_processor_real_visit_enum (ValaCodeVisitor* base, ValaEnum* en);
+static void vala_attribute_processor_real_visit_enum_value (ValaCodeVisitor* base, ValaEnumValue* ev);
+static void vala_attribute_processor_real_visit_error_domain (ValaCodeVisitor* base, ValaErrorDomain* edomain);
 static void vala_attribute_processor_real_visit_method (ValaCodeVisitor* base, ValaMethod* m);
 static void vala_attribute_processor_real_visit_creation_method (ValaCodeVisitor* base, ValaCreationMethod* m);
 static void vala_attribute_processor_real_visit_formal_parameter (ValaCodeVisitor* base, ValaFormalParameter* p);
@@ -54,7 +56,7 @@ static gpointer vala_attribute_processor_parent_class = NULL;
  */
 void vala_attribute_processor_process (ValaAttributeProcessor* self, ValaCodeContext* context) {
 	g_return_if_fail (VALA_IS_ATTRIBUTE_PROCESSOR (self));
-	g_return_if_fail (context == NULL || VALA_IS_CODE_CONTEXT (context));
+	g_return_if_fail (VALA_IS_CODE_CONTEXT (context));
 	vala_code_context_accept (context, VALA_CODE_VISITOR (self));
 }
 
@@ -62,7 +64,7 @@ void vala_attribute_processor_process (ValaAttributeProcessor* self, ValaCodeCon
 static void vala_attribute_processor_real_visit_source_file (ValaCodeVisitor* base, ValaSourceFile* source_file) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (source_file == NULL || VALA_IS_SOURCE_FILE (source_file));
+	g_return_if_fail (VALA_IS_SOURCE_FILE (source_file));
 	vala_source_file_accept_children (source_file, VALA_CODE_VISITOR (self));
 }
 
@@ -70,23 +72,21 @@ static void vala_attribute_processor_real_visit_source_file (ValaCodeVisitor* ba
 static void vala_attribute_processor_real_visit_namespace (ValaCodeVisitor* base, ValaNamespace* ns) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (ns == NULL || VALA_IS_NAMESPACE (ns));
+	g_return_if_fail (VALA_IS_NAMESPACE (ns));
 	vala_namespace_process_attributes (ns);
 	{
-		GeeCollection* ns_collection;
-		GeeIterator* ns_it;
+		GeeList* ns_collection;
+		int ns_it;
 		ns_collection = vala_namespace_get_namespaces (ns);
-		ns_it = gee_iterable_iterator (GEE_ITERABLE (ns_collection));
-		while (gee_iterator_next (ns_it)) {
+		for (ns_it = 0; ns_it < gee_collection_get_size (GEE_COLLECTION (ns_collection)); ns_it = ns_it + 1) {
 			ValaNamespace* ns;
-			ns = ((ValaNamespace*) gee_iterator_get (ns_it));
+			ns = ((ValaNamespace*) (gee_list_get (GEE_LIST (ns_collection), ns_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (ns), VALA_CODE_VISITOR (self));
 				(ns == NULL ? NULL : (ns = (g_object_unref (ns), NULL)));
 			}
 		}
 		(ns_collection == NULL ? NULL : (ns_collection = (g_object_unref (ns_collection), NULL)));
-		(ns_it == NULL ? NULL : (ns_it = (g_object_unref (ns_it), NULL)));
 	}
 }
 
@@ -94,7 +94,7 @@ static void vala_attribute_processor_real_visit_namespace (ValaCodeVisitor* base
 static void vala_attribute_processor_real_visit_class (ValaCodeVisitor* base, ValaClass* cl) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (cl == NULL || VALA_IS_CLASS (cl));
+	g_return_if_fail (VALA_IS_CLASS (cl));
 	vala_class_process_attributes (cl);
 	vala_code_node_accept_children (VALA_CODE_NODE (cl), VALA_CODE_VISITOR (self));
 }
@@ -103,7 +103,7 @@ static void vala_attribute_processor_real_visit_class (ValaCodeVisitor* base, Va
 static void vala_attribute_processor_real_visit_struct (ValaCodeVisitor* base, ValaStruct* st) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (st == NULL || VALA_IS_STRUCT (st));
+	g_return_if_fail (VALA_IS_STRUCT (st));
 	vala_struct_process_attributes (st);
 	vala_code_node_accept_children (VALA_CODE_NODE (st), VALA_CODE_VISITOR (self));
 }
@@ -112,7 +112,7 @@ static void vala_attribute_processor_real_visit_struct (ValaCodeVisitor* base, V
 static void vala_attribute_processor_real_visit_interface (ValaCodeVisitor* base, ValaInterface* iface) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (iface == NULL || VALA_IS_INTERFACE (iface));
+	g_return_if_fail (VALA_IS_INTERFACE (iface));
 	vala_interface_process_attributes (iface);
 	vala_code_node_accept_children (VALA_CODE_NODE (iface), VALA_CODE_VISITOR (self));
 }
@@ -121,15 +121,32 @@ static void vala_attribute_processor_real_visit_interface (ValaCodeVisitor* base
 static void vala_attribute_processor_real_visit_enum (ValaCodeVisitor* base, ValaEnum* en) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (en == NULL || VALA_IS_ENUM (en));
+	g_return_if_fail (VALA_IS_ENUM (en));
 	vala_enum_process_attributes (en);
+	vala_code_node_accept_children (VALA_CODE_NODE (en), VALA_CODE_VISITOR (self));
+}
+
+
+static void vala_attribute_processor_real_visit_enum_value (ValaCodeVisitor* base, ValaEnumValue* ev) {
+	ValaAttributeProcessor * self;
+	self = VALA_ATTRIBUTE_PROCESSOR (base);
+	g_return_if_fail (VALA_IS_ENUM_VALUE (ev));
+	vala_enum_value_process_attributes (ev);
+}
+
+
+static void vala_attribute_processor_real_visit_error_domain (ValaCodeVisitor* base, ValaErrorDomain* edomain) {
+	ValaAttributeProcessor * self;
+	self = VALA_ATTRIBUTE_PROCESSOR (base);
+	g_return_if_fail (VALA_IS_ERROR_DOMAIN (edomain));
+	vala_error_domain_process_attributes (edomain);
 }
 
 
 static void vala_attribute_processor_real_visit_method (ValaCodeVisitor* base, ValaMethod* m) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (m == NULL || VALA_IS_METHOD (m));
+	g_return_if_fail (VALA_IS_METHOD (m));
 	vala_method_process_attributes (m);
 	vala_code_node_accept_children (VALA_CODE_NODE (m), VALA_CODE_VISITOR (self));
 }
@@ -138,7 +155,7 @@ static void vala_attribute_processor_real_visit_method (ValaCodeVisitor* base, V
 static void vala_attribute_processor_real_visit_creation_method (ValaCodeVisitor* base, ValaCreationMethod* m) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (m == NULL || VALA_IS_CREATION_METHOD (m));
+	g_return_if_fail (VALA_IS_CREATION_METHOD (m));
 	vala_method_process_attributes (VALA_METHOD (m));
 	vala_code_node_accept_children (VALA_CODE_NODE (m), VALA_CODE_VISITOR (self));
 }
@@ -147,7 +164,7 @@ static void vala_attribute_processor_real_visit_creation_method (ValaCodeVisitor
 static void vala_attribute_processor_real_visit_formal_parameter (ValaCodeVisitor* base, ValaFormalParameter* p) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (p == NULL || VALA_IS_FORMAL_PARAMETER (p));
+	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (p));
 	vala_formal_parameter_process_attributes (p);
 }
 
@@ -155,7 +172,7 @@ static void vala_attribute_processor_real_visit_formal_parameter (ValaCodeVisito
 static void vala_attribute_processor_real_visit_property (ValaCodeVisitor* base, ValaProperty* prop) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (prop == NULL || VALA_IS_PROPERTY (prop));
+	g_return_if_fail (VALA_IS_PROPERTY (prop));
 	vala_property_process_attributes (prop);
 }
 
@@ -163,7 +180,7 @@ static void vala_attribute_processor_real_visit_property (ValaCodeVisitor* base,
 static void vala_attribute_processor_real_visit_delegate (ValaCodeVisitor* base, ValaDelegate* d) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (d == NULL || VALA_IS_DELEGATE (d));
+	g_return_if_fail (VALA_IS_DELEGATE (d));
 	vala_delegate_process_attributes (d);
 	vala_code_node_accept_children (VALA_CODE_NODE (d), VALA_CODE_VISITOR (self));
 }
@@ -172,7 +189,7 @@ static void vala_attribute_processor_real_visit_delegate (ValaCodeVisitor* base,
 static void vala_attribute_processor_real_visit_constant (ValaCodeVisitor* base, ValaConstant* c) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (c == NULL || VALA_IS_CONSTANT (c));
+	g_return_if_fail (VALA_IS_CONSTANT (c));
 	vala_constant_process_attributes (c);
 }
 
@@ -180,7 +197,7 @@ static void vala_attribute_processor_real_visit_constant (ValaCodeVisitor* base,
 static void vala_attribute_processor_real_visit_field (ValaCodeVisitor* base, ValaField* f) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (f == NULL || VALA_IS_FIELD (f));
+	g_return_if_fail (VALA_IS_FIELD (f));
 	vala_field_process_attributes (f);
 }
 
@@ -188,7 +205,7 @@ static void vala_attribute_processor_real_visit_field (ValaCodeVisitor* base, Va
 static void vala_attribute_processor_real_visit_signal (ValaCodeVisitor* base, ValaSignal* sig) {
 	ValaAttributeProcessor * self;
 	self = VALA_ATTRIBUTE_PROCESSOR (base);
-	g_return_if_fail (sig == NULL || VALA_IS_SIGNAL (sig));
+	g_return_if_fail (VALA_IS_SIGNAL (sig));
 	vala_signal_process_attributes (sig);
 	vala_code_node_accept_children (VALA_CODE_NODE (sig), VALA_CODE_VISITOR (self));
 }
@@ -212,6 +229,8 @@ static void vala_attribute_processor_class_init (ValaAttributeProcessorClass * k
 	VALA_CODE_VISITOR_CLASS (klass)->visit_struct = vala_attribute_processor_real_visit_struct;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_interface = vala_attribute_processor_real_visit_interface;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_enum = vala_attribute_processor_real_visit_enum;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_enum_value = vala_attribute_processor_real_visit_enum_value;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_error_domain = vala_attribute_processor_real_visit_error_domain;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_method = vala_attribute_processor_real_visit_method;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_creation_method = vala_attribute_processor_real_visit_creation_method;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_formal_parameter = vala_attribute_processor_real_visit_formal_parameter;
@@ -223,14 +242,14 @@ static void vala_attribute_processor_class_init (ValaAttributeProcessorClass * k
 }
 
 
-static void vala_attribute_processor_init (ValaAttributeProcessor * self) {
+static void vala_attribute_processor_instance_init (ValaAttributeProcessor * self) {
 }
 
 
 GType vala_attribute_processor_get_type (void) {
 	static GType vala_attribute_processor_type_id = 0;
 	if (G_UNLIKELY (vala_attribute_processor_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaAttributeProcessorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_attribute_processor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaAttributeProcessor), 0, (GInstanceInitFunc) vala_attribute_processor_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaAttributeProcessorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_attribute_processor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaAttributeProcessor), 0, (GInstanceInitFunc) vala_attribute_processor_instance_init };
 		vala_attribute_processor_type_id = g_type_register_static (VALA_TYPE_CODE_VISITOR, "ValaAttributeProcessor", &g_define_type_info, 0);
 	}
 	return vala_attribute_processor_type_id;
