@@ -25,7 +25,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <gee/collection.h>
+#include <gee/list.h>
 #include <vala/valasymbol.h>
 #include <vala/valastatement.h>
 #include <vala/valacodenode.h>
@@ -57,9 +57,9 @@ struct _ValaBlockClass {
 
 ValaBlock* vala_block_new (ValaSourceReference* source_reference);
 void vala_block_add_statement (ValaBlock* self, ValaStatement* stmt);
-GeeCollection* vala_block_get_statements (ValaBlock* self);
+GeeList* vala_block_get_statements (ValaBlock* self);
 void vala_block_add_local_variable (ValaBlock* self, ValaLocalVariable* local);
-GeeCollection* vala_block_get_local_variables (ValaBlock* self);
+GeeList* vala_block_get_local_variables (ValaBlock* self);
 gboolean vala_block_get_contains_jump_statement (ValaBlock* self);
 void vala_block_set_contains_jump_statement (ValaBlock* self, gboolean value);
 GType vala_block_get_type (void);
