@@ -33,6 +33,7 @@ struct _ValaCastExpressionPrivate {
 	ValaExpression* _inner;
 	ValaDataType* _data_type;
 };
+
 #define VALA_CAST_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CAST_EXPRESSION, ValaCastExpressionPrivate))
 enum  {
 	VALA_CAST_EXPRESSION_DUMMY_PROPERTY,
@@ -60,19 +61,19 @@ ValaCastExpression* vala_cast_expression_new (ValaExpression* inner, ValaDataTyp
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCastExpression * self;
-	g_return_val_if_fail (inner == NULL || VALA_IS_EXPRESSION (inner), NULL);
-	g_return_val_if_fail (type_reference == NULL || VALA_IS_DATA_TYPE (type_reference), NULL);
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (inner), NULL);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (type_reference), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
-	__params_it->name = "inner";
-	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
-	g_value_set_object (&__params_it->value, inner);
-	__params_it++;
 	__params_it->name = "is-silent-cast";
 	g_value_init (&__params_it->value, G_TYPE_BOOLEAN);
 	g_value_set_boolean (&__params_it->value, is_silent_cast);
 	__params_it++;
+	__params_it->name = "inner";
+	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
+	g_value_set_object (&__params_it->value, inner);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_CAST_EXPRESSION, __params_it - __params, __params);
 	vala_cast_expression_set_type_reference (self, type_reference);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
@@ -88,18 +89,19 @@ ValaCastExpression* vala_cast_expression_new (ValaExpression* inner, ValaDataTyp
 static void vala_cast_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaCastExpression * self;
 	self = VALA_CAST_EXPRESSION (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_cast_expression_get_inner (self)), visitor);
 	vala_code_node_accept (VALA_CODE_NODE (vala_cast_expression_get_type_reference (self)), visitor);
 	vala_code_visitor_visit_cast_expression (visitor, self);
+	vala_code_visitor_visit_expression (visitor, VALA_EXPRESSION (self));
 }
 
 
 static void vala_cast_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaCastExpression * self;
 	self = VALA_CAST_EXPRESSION (base);
-	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
 	if (vala_cast_expression_get_inner (self) == old_node) {
 		vala_cast_expression_set_inner (self, new_node);
 	}
@@ -116,8 +118,8 @@ static gboolean vala_cast_expression_real_is_pure (ValaExpression* base) {
 static void vala_cast_expression_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaCastExpression * self;
 	self = VALA_CAST_EXPRESSION (base);
-	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
 	if (vala_cast_expression_get_type_reference (self) == old_type) {
 		vala_cast_expression_set_type_reference (self, new_type);
 	}
@@ -226,7 +228,7 @@ static void vala_cast_expression_class_init (ValaCastExpressionClass * klass) {
 }
 
 
-static void vala_cast_expression_init (ValaCastExpression * self) {
+static void vala_cast_expression_instance_init (ValaCastExpression * self) {
 	self->priv = VALA_CAST_EXPRESSION_GET_PRIVATE (self);
 }
 
@@ -243,7 +245,7 @@ static void vala_cast_expression_dispose (GObject * obj) {
 GType vala_cast_expression_get_type (void) {
 	static GType vala_cast_expression_type_id = 0;
 	if (G_UNLIKELY (vala_cast_expression_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCastExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_cast_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCastExpression), 0, (GInstanceInitFunc) vala_cast_expression_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCastExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_cast_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCastExpression), 0, (GInstanceInitFunc) vala_cast_expression_instance_init };
 		vala_cast_expression_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaCastExpression", &g_define_type_info, 0);
 	}
 	return vala_cast_expression_type_id;
