@@ -127,7 +127,7 @@ void vala_catch_clause_set_error_type (ValaCatchClause* self, ValaDataType* valu
 }
 
 
-char* vala_catch_clause_get_variable_name (ValaCatchClause* self) {
+const char* vala_catch_clause_get_variable_name (ValaCatchClause* self) {
 	g_return_val_if_fail (VALA_IS_CATCH_CLAUSE (self), NULL);
 	return self->priv->_variable_name;
 }
@@ -175,7 +175,7 @@ void vala_catch_clause_set_error_variable (ValaCatchClause* self, ValaLocalVaria
 }
 
 
-char* vala_catch_clause_get_clabel_name (ValaCatchClause* self) {
+const char* vala_catch_clause_get_clabel_name (ValaCatchClause* self) {
 	g_return_val_if_fail (VALA_IS_CATCH_CLAUSE (self), NULL);
 	return self->priv->_clabel_name;
 }
@@ -260,7 +260,7 @@ static void vala_catch_clause_class_init (ValaCatchClauseClass * klass) {
 }
 
 
-static void vala_catch_clause_init (ValaCatchClause * self) {
+static void vala_catch_clause_instance_init (ValaCatchClause * self) {
 	self->priv = VALA_CATCH_CLAUSE_GET_PRIVATE (self);
 }
 
@@ -280,7 +280,7 @@ static void vala_catch_clause_dispose (GObject * obj) {
 GType vala_catch_clause_get_type (void) {
 	static GType vala_catch_clause_type_id = 0;
 	if (G_UNLIKELY (vala_catch_clause_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCatchClauseClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_catch_clause_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCatchClause), 0, (GInstanceInitFunc) vala_catch_clause_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCatchClauseClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_catch_clause_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCatchClause), 0, (GInstanceInitFunc) vala_catch_clause_instance_init };
 		vala_catch_clause_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaCatchClause", &g_define_type_info, 0);
 	}
 	return vala_catch_clause_type_id;
