@@ -21,12 +21,16 @@
  */
 
 #include <vala/valacodenode.h>
+#include <gee/readonlylist.h>
+#include <gee/arraylist.h>
+#include <gee/collection.h>
 #include <ccode/valaccodelinedirective.h>
 #include <vala/valasourcereference.h>
-#include <vala/valacodevisitor.h>
 #include <vala/valadatatype.h>
+#include <vala/valacodevisitor.h>
 #include <vala/valaexpression.h>
 #include <vala/valaattribute.h>
+#include <vala/valacodegenerator.h>
 #include <vala/valasourcefile.h>
 
 
@@ -35,32 +39,105 @@
 struct _ValaCodeNodePrivate {
 	ValaCodeNode* _parent_node;
 	ValaSourceReference* _source_reference;
-	ValaCodeBinding* _code_binding;
 	gboolean _error;
-	gboolean _tree_can_fail;
+	GeeList* _error_types;
+	ValaCodeBinding* code_binding;
 	ValaCCodeNode* _ccodenode;
 };
+
 #define VALA_CODE_NODE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CODE_NODE, ValaCodeNodePrivate))
 enum  {
 	VALA_CODE_NODE_DUMMY_PROPERTY,
 	VALA_CODE_NODE_PARENT_NODE,
 	VALA_CODE_NODE_SOURCE_REFERENCE,
 	VALA_CODE_NODE_CCODENODE,
-	VALA_CODE_NODE_CODE_BINDING,
 	VALA_CODE_NODE_ERROR,
 	VALA_CODE_NODE_TREE_CAN_FAIL
 };
+static void _g_list_free_g_object_unref (GList* self);
+static GeeList* vala_code_node__empty_type_list;
 static void vala_code_node_real_accept (ValaCodeNode* self, ValaCodeVisitor* visitor);
 static void vala_code_node_real_accept_children (ValaCodeNode* self, ValaCodeVisitor* visitor);
 static void vala_code_node_real_replace_type (ValaCodeNode* self, ValaDataType* old_type, ValaDataType* new_type);
 static void vala_code_node_real_replace_expression (ValaCodeNode* self, ValaExpression* old_node, ValaExpression* new_node);
 static char* vala_code_node_real_to_string (ValaCodeNode* self);
+static ValaCodeBinding* vala_code_node_real_create_code_binding (ValaCodeNode* self, ValaCodeGenerator* codegen);
 static gpointer vala_code_node_parent_class = NULL;
 static void vala_code_node_dispose (GObject * obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
+static void _g_list_free_g_object_unref (GList* self) {
+	g_list_foreach (self, ((GFunc) (g_object_unref)), NULL);
+	g_list_free (self);
+}
+
+
+/**
+ * Specifies the exceptions that can be thrown by this node or a child node
+ */
+GeeList* vala_code_node_get_error_types (ValaCodeNode* self) {
+	GeeList* _tmp4;
+	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
+	if (self->priv->_error_types != NULL) {
+		GeeList* _tmp0;
+		_tmp0 = NULL;
+		return (_tmp0 = self->priv->_error_types, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+	}
+	if (vala_code_node__empty_type_list == NULL) {
+		GeeList* _tmp3;
+		GeeArrayList* _tmp2;
+		_tmp3 = NULL;
+		_tmp2 = NULL;
+		vala_code_node__empty_type_list = (_tmp3 = GEE_LIST (gee_read_only_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, GEE_LIST ((_tmp2 = gee_array_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal))))), (vala_code_node__empty_type_list == NULL ? NULL : (vala_code_node__empty_type_list = (g_object_unref (vala_code_node__empty_type_list), NULL))), _tmp3);
+		(_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL)));
+	}
+	_tmp4 = NULL;
+	return (_tmp4 = vala_code_node__empty_type_list, (_tmp4 == NULL ? NULL : g_object_ref (_tmp4)));
+}
+
+
+/**
+ * Adds an error type to the exceptions that can be thrown by this node
+ * or a child node 
+ */
+void vala_code_node_add_error_type (ValaCodeNode* self, ValaDataType* error_type) {
+	g_return_if_fail (VALA_IS_CODE_NODE (self));
+	g_return_if_fail (VALA_IS_DATA_TYPE (error_type));
+	if (self->priv->_error_types == NULL) {
+		GeeList* _tmp0;
+		_tmp0 = NULL;
+		self->priv->_error_types = (_tmp0 = GEE_LIST (gee_array_list_new (VALA_TYPE_DATA_TYPE, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal)), (self->priv->_error_types == NULL ? NULL : (self->priv->_error_types = (g_object_unref (self->priv->_error_types), NULL))), _tmp0);
+	}
+	gee_collection_add (GEE_COLLECTION (self->priv->_error_types), error_type);
+	vala_code_node_set_parent_node (VALA_CODE_NODE (error_type), self);
+}
+
+
+/**
+ * Adds a collection of error types to the exceptions that can be thrown by this node
+ * or a child node 
+ */
+void vala_code_node_add_error_types (ValaCodeNode* self, GeeList* error_types) {
+	g_return_if_fail (VALA_IS_CODE_NODE (self));
+	g_return_if_fail (GEE_IS_LIST (error_types));
+	{
+		GeeList* error_type_collection;
+		int error_type_it;
+		error_type_collection = error_types;
+		for (error_type_it = 0; error_type_it < gee_collection_get_size (GEE_COLLECTION (error_type_collection)); error_type_it = error_type_it + 1) {
+			ValaDataType* error_type;
+			error_type = ((ValaDataType*) (gee_list_get (GEE_LIST (error_type_collection), error_type_it)));
+			{
+				vala_code_node_add_error_type (self, error_type);
+				(error_type == NULL ? NULL : (error_type = (g_object_unref (error_type), NULL)));
+			}
+		}
+	}
+}
+
+
 /**
  * Visits this code node with the specified CodeVisitor.
  *
@@ -68,7 +145,7 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  */
 static void vala_code_node_real_accept (ValaCodeNode* self, ValaCodeVisitor* visitor) {
 	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 }
 
 
@@ -84,7 +161,7 @@ void vala_code_node_accept (ValaCodeNode* self, ValaCodeVisitor* visitor) {
  */
 static void vala_code_node_real_accept_children (ValaCodeNode* self, ValaCodeVisitor* visitor) {
 	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 }
 
 
@@ -95,8 +172,8 @@ void vala_code_node_accept_children (ValaCodeNode* self, ValaCodeVisitor* visito
 
 static void vala_code_node_real_replace_type (ValaCodeNode* self, ValaDataType* old_type, ValaDataType* new_type) {
 	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
 }
 
 
@@ -107,8 +184,8 @@ void vala_code_node_replace_type (ValaCodeNode* self, ValaDataType* old_type, Va
 
 static void vala_code_node_real_replace_expression (ValaCodeNode* self, ValaExpression* old_node, ValaExpression* new_node) {
 	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
 }
 
 
@@ -125,6 +202,8 @@ void vala_code_node_replace_expression (ValaCodeNode* self, ValaExpression* old_
  */
 ValaAttribute* vala_code_node_get_attribute (ValaCodeNode* self, const char* name) {
 	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	/* FIXME: use hash table*/
 	{
 		GList* a_collection;
 		GList* a_it;
@@ -133,9 +212,8 @@ ValaAttribute* vala_code_node_get_attribute (ValaCodeNode* self, const char* nam
 			ValaAttribute* _tmp1;
 			ValaAttribute* a;
 			_tmp1 = NULL;
-			a = (_tmp1 = ((ValaAttribute*) a_it->data), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+			a = (_tmp1 = ((ValaAttribute*) (a_it->data)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
 			{
-				/* FIXME: use hash table*/
 				if (_vala_strcmp0 (vala_attribute_get_name (a), name) == 0) {
 					return a;
 				}
@@ -176,6 +254,40 @@ char* vala_code_node_to_string (ValaCodeNode* self) {
 }
 
 
+/**
+ * Returns the binding to the generated code.
+ *
+ * @return code binding
+ */
+ValaCodeBinding* vala_code_node_get_code_binding (ValaCodeNode* self, ValaCodeGenerator* codegen) {
+	ValaCodeBinding* _tmp1;
+	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
+	g_return_val_if_fail (VALA_IS_CODE_GENERATOR (codegen), NULL);
+	if (self->priv->code_binding == NULL) {
+		ValaCodeBinding* _tmp0;
+		_tmp0 = NULL;
+		self->priv->code_binding = (_tmp0 = vala_code_node_create_code_binding (self, codegen), (self->priv->code_binding == NULL ? NULL : (self->priv->code_binding = (g_object_unref (self->priv->code_binding), NULL))), _tmp0);
+	}
+	_tmp1 = NULL;
+	return (_tmp1 = self->priv->code_binding, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+}
+
+
+/**
+ * Creates the binding to the generated code.
+ */
+static ValaCodeBinding* vala_code_node_real_create_code_binding (ValaCodeNode* self, ValaCodeGenerator* codegen) {
+	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
+	g_return_val_if_fail (VALA_IS_CODE_GENERATOR (codegen), NULL);
+	return NULL;
+}
+
+
+ValaCodeBinding* vala_code_node_create_code_binding (ValaCodeNode* self, ValaCodeGenerator* codegen) {
+	return VALA_CODE_NODE_GET_CLASS (self)->create_code_binding (self, codegen);
+}
+
+
 ValaCodeNode* vala_code_node_get_parent_node (ValaCodeNode* self) {
 	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
 	return self->priv->_parent_node;
@@ -229,22 +341,6 @@ void vala_code_node_set_ccodenode (ValaCodeNode* self, ValaCCodeNode* value) {
 }
 
 
-ValaCodeBinding* vala_code_node_get_code_binding (ValaCodeNode* self) {
-	g_return_val_if_fail (VALA_IS_CODE_NODE (self), NULL);
-	return self->priv->_code_binding;
-}
-
-
-void vala_code_node_set_code_binding (ValaCodeNode* self, ValaCodeBinding* value) {
-	ValaCodeBinding* _tmp2;
-	ValaCodeBinding* _tmp1;
-	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_code_binding = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_code_binding == NULL ? NULL : (self->priv->_code_binding = (g_object_unref (self->priv->_code_binding), NULL))), _tmp2);
-}
-
-
 gboolean vala_code_node_get_error (ValaCodeNode* self) {
 	g_return_val_if_fail (VALA_IS_CODE_NODE (self), FALSE);
 	return self->priv->_error;
@@ -259,13 +355,7 @@ void vala_code_node_set_error (ValaCodeNode* self, gboolean value) {
 
 gboolean vala_code_node_get_tree_can_fail (ValaCodeNode* self) {
 	g_return_val_if_fail (VALA_IS_CODE_NODE (self), FALSE);
-	return self->priv->_tree_can_fail;
-}
-
-
-void vala_code_node_set_tree_can_fail (ValaCodeNode* self, gboolean value) {
-	g_return_if_fail (VALA_IS_CODE_NODE (self));
-	self->priv->_tree_can_fail = value;
+	return self->priv->_error_types != NULL && gee_collection_get_size (GEE_COLLECTION (self->priv->_error_types)) > 0;
 }
 
 
@@ -282,9 +372,6 @@ static void vala_code_node_get_property (GObject * object, guint property_id, GV
 		case VALA_CODE_NODE_CCODENODE:
 		g_value_set_object (value, vala_code_node_get_ccodenode (self));
 		break;
-		case VALA_CODE_NODE_CODE_BINDING:
-		g_value_set_object (value, vala_code_node_get_code_binding (self));
-		break;
 		case VALA_CODE_NODE_ERROR:
 		g_value_set_boolean (value, vala_code_node_get_error (self));
 		break;
@@ -311,15 +398,9 @@ static void vala_code_node_set_property (GObject * object, guint property_id, co
 		case VALA_CODE_NODE_CCODENODE:
 		vala_code_node_set_ccodenode (self, g_value_get_object (value));
 		break;
-		case VALA_CODE_NODE_CODE_BINDING:
-		vala_code_node_set_code_binding (self, g_value_get_object (value));
-		break;
 		case VALA_CODE_NODE_ERROR:
 		vala_code_node_set_error (self, g_value_get_boolean (value));
 		break;
-		case VALA_CODE_NODE_TREE_CAN_FAIL:
-		vala_code_node_set_tree_can_fail (self, g_value_get_boolean (value));
-		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -338,16 +419,16 @@ static void vala_code_node_class_init (ValaCodeNodeClass * klass) {
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_code_node_real_replace_type;
 	VALA_CODE_NODE_CLASS (klass)->replace_expression = vala_code_node_real_replace_expression;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_code_node_real_to_string;
+	VALA_CODE_NODE_CLASS (klass)->create_code_binding = vala_code_node_real_create_code_binding;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_PARENT_NODE, g_param_spec_object ("parent-node", "parent-node", "parent-node", VALA_TYPE_CODE_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_SOURCE_REFERENCE, g_param_spec_object ("source-reference", "source-reference", "source-reference", VALA_TYPE_SOURCE_REFERENCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_CCODENODE, g_param_spec_object ("ccodenode", "ccodenode", "ccodenode", VALA_TYPE_CCODE_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_CODE_BINDING, g_param_spec_object ("code-binding", "code-binding", "code-binding", VALA_TYPE_CODE_BINDING, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_ERROR, g_param_spec_boolean ("error", "error", "error", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_TREE_CAN_FAIL, g_param_spec_boolean ("tree-can-fail", "tree-can-fail", "tree-can-fail", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CODE_NODE_TREE_CAN_FAIL, g_param_spec_boolean ("tree-can-fail", "tree-can-fail", "tree-can-fail", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
 }
 
 
-static void vala_code_node_init (ValaCodeNode * self) {
+static void vala_code_node_instance_init (ValaCodeNode * self) {
 	self->priv = VALA_CODE_NODE_GET_PRIVATE (self);
 }
 
@@ -356,8 +437,9 @@ static void vala_code_node_dispose (GObject * obj) {
 	ValaCodeNode * self;
 	self = VALA_CODE_NODE (obj);
 	(self->priv->_source_reference == NULL ? NULL : (self->priv->_source_reference = (g_object_unref (self->priv->_source_reference), NULL)));
-	(self->attributes == NULL ? NULL : (self->attributes = (g_list_foreach (self->attributes, ((GFunc) g_object_unref), NULL), g_list_free (self->attributes), NULL)));
-	(self->priv->_code_binding == NULL ? NULL : (self->priv->_code_binding = (g_object_unref (self->priv->_code_binding), NULL)));
+	(self->attributes == NULL ? NULL : (self->attributes = (_g_list_free_g_object_unref (self->attributes), NULL)));
+	(self->priv->_error_types == NULL ? NULL : (self->priv->_error_types = (g_object_unref (self->priv->_error_types), NULL)));
+	(self->priv->code_binding == NULL ? NULL : (self->priv->code_binding = (g_object_unref (self->priv->code_binding), NULL)));
 	(self->priv->_ccodenode == NULL ? NULL : (self->priv->_ccodenode = (g_object_unref (self->priv->_ccodenode), NULL)));
 	G_OBJECT_CLASS (vala_code_node_parent_class)->dispose (obj);
 }
@@ -366,7 +448,7 @@ static void vala_code_node_dispose (GObject * obj) {
 GType vala_code_node_get_type (void) {
 	static GType vala_code_node_type_id = 0;
 	if (G_UNLIKELY (vala_code_node_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCodeNodeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_code_node_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCodeNode), 0, (GInstanceInitFunc) vala_code_node_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCodeNodeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_code_node_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCodeNode), 0, (GInstanceInitFunc) vala_code_node_instance_init };
 		vala_code_node_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaCodeNode", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
 	return vala_code_node_type_id;
