@@ -69,6 +69,7 @@
 #include <vala/valacatchclause.h>
 #include <vala/valalockstatement.h>
 #include <vala/valadeletestatement.h>
+#include <vala/valaexpression.h>
 #include <vala/valaarraycreationexpression.h>
 #include <vala/valabooleanliteral.h>
 #include <vala/valacharacterliteral.h>
@@ -95,7 +96,6 @@
 #include <vala/valaconditionalexpression.h>
 #include <vala/valalambdaexpression.h>
 #include <vala/valaassignment.h>
-#include <vala/valaexpression.h>
 
 
 
@@ -150,6 +150,7 @@ static void vala_code_visitor_real_visit_try_statement (ValaCodeVisitor* self, V
 static void vala_code_visitor_real_visit_catch_clause (ValaCodeVisitor* self, ValaCatchClause* clause);
 static void vala_code_visitor_real_visit_lock_statement (ValaCodeVisitor* self, ValaLockStatement* stmt);
 static void vala_code_visitor_real_visit_delete_statement (ValaCodeVisitor* self, ValaDeleteStatement* stmt);
+static void vala_code_visitor_real_visit_expression (ValaCodeVisitor* self, ValaExpression* expr);
 static void vala_code_visitor_real_visit_array_creation_expression (ValaCodeVisitor* self, ValaArrayCreationExpression* expr);
 static void vala_code_visitor_real_visit_boolean_literal (ValaCodeVisitor* self, ValaBooleanLiteral* lit);
 static void vala_code_visitor_real_visit_character_literal (ValaCodeVisitor* self, ValaCharacterLiteral* lit);
@@ -933,6 +934,22 @@ void vala_code_visitor_visit_delete_statement (ValaCodeVisitor* self, ValaDelete
 }
 
 
+/**
+ * Visit operations called for expresions.
+ *
+ * @param expr an expression
+ */
+static void vala_code_visitor_real_visit_expression (ValaCodeVisitor* self, ValaExpression* expr) {
+	g_return_if_fail (VALA_IS_CODE_VISITOR (self));
+	g_return_if_fail (VALA_IS_EXPRESSION (expr));
+}
+
+
+void vala_code_visitor_visit_expression (ValaCodeVisitor* self, ValaExpression* expr) {
+	VALA_CODE_VISITOR_GET_CLASS (self)->visit_expression (self, expr);
+}
+
+
 /**
  * Visit operations called for array creation expresions.
  *
@@ -1365,16 +1382,6 @@ void vala_code_visitor_visit_end_full_expression (ValaCodeVisitor* self, ValaExp
 }
 
 
-/**
- * Abstract code node visitor for traversing source code tree.
- */
-ValaCodeVisitor* vala_code_visitor_new (void) {
-	ValaCodeVisitor * self;
-	self = g_object_newv (VALA_TYPE_CODE_VISITOR, 0, NULL);
-	return self;
-}
-
-
 static void vala_code_visitor_class_init (ValaCodeVisitorClass * klass) {
 	vala_code_visitor_parent_class = g_type_class_peek_parent (klass);
 	VALA_CODE_VISITOR_CLASS (klass)->visit_source_file = vala_code_visitor_real_visit_source_file;
@@ -1424,6 +1431,7 @@ static void vala_code_visitor_class_init (ValaCodeVisitorClass * klass) {
 	VALA_CODE_VISITOR_CLASS (klass)->visit_catch_clause = vala_code_visitor_real_visit_catch_clause;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_lock_statement = vala_code_visitor_real_visit_lock_statement;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_delete_statement = vala_code_visitor_real_visit_delete_statement;
+	VALA_CODE_VISITOR_CLASS (klass)->visit_expression = vala_code_visitor_real_visit_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_array_creation_expression = vala_code_visitor_real_visit_array_creation_expression;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_boolean_literal = vala_code_visitor_real_visit_boolean_literal;
 	VALA_CODE_VISITOR_CLASS (klass)->visit_character_literal = vala_code_visitor_real_visit_character_literal;
@@ -1454,14 +1462,14 @@ static void vala_code_visitor_class_init (ValaCodeVisitorClass * klass) {
 }
 
 
-static void vala_code_visitor_init (ValaCodeVisitor * self) {
+static void vala_code_visitor_instance_init (ValaCodeVisitor * self) {
 }
 
 
 GType vala_code_visitor_get_type (void) {
 	static GType vala_code_visitor_type_id = 0;
 	if (G_UNLIKELY (vala_code_visitor_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCodeVisitorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_code_visitor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCodeVisitor), 0, (GInstanceInitFunc) vala_code_visitor_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCodeVisitorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_code_visitor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCodeVisitor), 0, (GInstanceInitFunc) vala_code_visitor_instance_init };
 		vala_code_visitor_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaCodeVisitor", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
 	return vala_code_visitor_type_id;
