@@ -21,8 +21,8 @@
  */
 
 #include <vala/valaconstant.h>
-#include <vala/valaexpression.h>
 #include <vala/valadatatype.h>
+#include <vala/valaexpression.h>
 #include <vala/valasourcereference.h>
 #include <vala/valasymbol.h>
 #include <vala/valacodevisitor.h>
@@ -32,10 +32,10 @@
 
 
 struct _ValaConstantPrivate {
-	ValaExpression* _initializer;
 	char* cname;
 	gboolean lock_used;
 	ValaDataType* _data_type;
+	ValaExpression* _initializer;
 };
 
 #define VALA_CONSTANT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CONSTANT, ValaConstantPrivate))
@@ -96,8 +96,8 @@ static void vala_constant_real_accept_children (ValaCodeNode* base, ValaCodeVisi
 	self = VALA_CONSTANT (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_constant_get_type_reference (self)), visitor);
-	if (self->priv->_initializer != NULL) {
-		vala_code_node_accept (VALA_CODE_NODE (self->priv->_initializer), visitor);
+	if (vala_constant_get_initializer (self) != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (vala_constant_get_initializer (self)), visitor);
 	}
 }
 
@@ -108,30 +108,40 @@ static void vala_constant_real_accept_children (ValaCodeNode* base, ValaCodeVisi
  * @return the name to be used in C code
  */
 char* vala_constant_get_cname (ValaConstant* self) {
-	const char* _tmp5;
+	const char* _tmp1;
 	g_return_val_if_fail (VALA_IS_CONSTANT (self), NULL);
 	if (self->priv->cname == NULL) {
-		if (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)) == NULL) {
-			char* _tmp1;
-			const char* _tmp0;
-			/* global constant*/
-			_tmp1 = NULL;
-			_tmp0 = NULL;
-			self->priv->cname = (_tmp1 = (_tmp0 = vala_symbol_get_name (VALA_SYMBOL (self)), (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
-		} else {
-			char* _tmp4;
-			char* _tmp3;
-			char* _tmp2;
-			_tmp4 = NULL;
-			_tmp3 = NULL;
-			_tmp2 = NULL;
-			self->priv->cname = (_tmp4 = g_strdup_printf ("%s%s", (_tmp3 = g_utf8_strup ((_tmp2 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))), -1)), vala_symbol_get_name (VALA_SYMBOL (self))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp4);
-			_tmp3 = (g_free (_tmp3), NULL);
-			_tmp2 = (g_free (_tmp2), NULL);
-		}
+		char* _tmp0;
+		_tmp0 = NULL;
+		self->priv->cname = (_tmp0 = vala_constant_get_default_cname (self), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp0);
+	}
+	_tmp1 = NULL;
+	return (_tmp1 = self->priv->cname, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
+}
+
+
+/**
+ * Returns the default name of this constant as it is used in C
+ * code.
+ *
+ * @return the name to be used in C code by default
+ */
+char* vala_constant_get_default_cname (ValaConstant* self) {
+	g_return_val_if_fail (VALA_IS_CONSTANT (self), NULL);
+	if (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)) == NULL) {
+		const char* _tmp0;
+		/* global constant*/
+		_tmp0 = NULL;
+		return (_tmp0 = vala_symbol_get_name (VALA_SYMBOL (self)), (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
+	} else {
+		char* _tmp3;
+		char* _tmp2;
+		char* _tmp4;
+		_tmp3 = NULL;
+		_tmp2 = NULL;
+		_tmp4 = NULL;
+		return (_tmp4 = g_strdup_printf ("%s%s", (_tmp3 = g_utf8_strup ((_tmp2 = vala_symbol_get_lower_case_cprefix (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))), -1)), vala_symbol_get_name (VALA_SYMBOL (self))), (_tmp3 = (g_free (_tmp3), NULL)), (_tmp2 = (g_free (_tmp2), NULL)), _tmp4);
 	}
-	_tmp5 = NULL;
-	return (_tmp5 = self->priv->cname, (_tmp5 == NULL ? NULL : g_strdup (_tmp5)));
 }
 
 
@@ -173,8 +183,8 @@ static void vala_constant_process_ccode_attribute (ValaConstant* self, ValaAttri
 		val = vala_attribute_get_string (a, "cheader_filename");
 		{
 			char** filename_collection;
-			char** filename_it;
 			int filename_collection_length1;
+			char** filename_it;
 			filename_collection = g_strsplit (val, ",", 0);
 			filename_collection_length1 = -1;
 			for (filename_it = filename_collection; *filename_it != NULL; filename_it = filename_it + 1) {
@@ -187,7 +197,7 @@ static void vala_constant_process_ccode_attribute (ValaConstant* self, ValaAttri
 					filename = (g_free (filename), NULL);
 				}
 			}
-			filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) g_free)), NULL);
+			filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) (g_free))), NULL);
 		}
 		val = (g_free (val), NULL);
 	}
@@ -207,7 +217,7 @@ void vala_constant_process_attributes (ValaConstant* self) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
 			_tmp0 = NULL;
-			a = (_tmp0 = ((ValaAttribute*) a_it->data), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_constant_process_ccode_attribute (self, a);
@@ -249,6 +259,9 @@ void vala_constant_set_initializer (ValaConstant* self, ValaExpression* value) {
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_initializer = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL))), _tmp2);
+	if (self->priv->_initializer != NULL) {
+		vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_initializer), VALA_CODE_NODE (self));
+	}
 }
 
 
@@ -307,7 +320,7 @@ static void vala_constant_vala_lockable_interface_init (ValaLockableIface * ifac
 }
 
 
-static void vala_constant_init (ValaConstant * self) {
+static void vala_constant_instance_init (ValaConstant * self) {
 	self->priv = VALA_CONSTANT_GET_PRIVATE (self);
 	self->priv->lock_used = FALSE;
 }
@@ -316,9 +329,9 @@ static void vala_constant_init (ValaConstant * self) {
 static void vala_constant_dispose (GObject * obj) {
 	ValaConstant * self;
 	self = VALA_CONSTANT (obj);
-	(self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL)));
 	self->priv->cname = (g_free (self->priv->cname), NULL);
 	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
+	(self->priv->_initializer == NULL ? NULL : (self->priv->_initializer = (g_object_unref (self->priv->_initializer), NULL)));
 	G_OBJECT_CLASS (vala_constant_parent_class)->dispose (obj);
 }
 
@@ -326,7 +339,7 @@ static void vala_constant_dispose (GObject * obj) {
 GType vala_constant_get_type (void) {
 	static GType vala_constant_type_id = 0;
 	if (G_UNLIKELY (vala_constant_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaConstantClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_constant_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaConstant), 0, (GInstanceInitFunc) vala_constant_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaConstantClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_constant_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaConstant), 0, (GInstanceInitFunc) vala_constant_instance_init };
 		static const GInterfaceInfo vala_lockable_info = { (GInterfaceInitFunc) vala_constant_vala_lockable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_constant_type_id = g_type_register_static (VALA_TYPE_MEMBER, "ValaConstant", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_constant_type_id, VALA_TYPE_LOCKABLE, &vala_lockable_info);
@@ -340,12 +353,12 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 		int i;
 		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) array)[i] != NULL)
-			destroy_func (((gpointer*) array)[i]);
+			if (((gpointer*) (array))[i] != NULL)
+			destroy_func (((gpointer*) (array))[i]);
 		}
 		else
-		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) array)[i]);
+		for (i = 0; ((gpointer*) (array))[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) (array))[i]);
 		}
 	}
 	g_free (array);
