@@ -44,7 +44,7 @@ static ValaStatementIface* vala_continue_statement_vala_statement_parent_iface =
  */
 ValaContinueStatement* vala_continue_statement_new (ValaSourceReference* source) {
 	ValaContinueStatement * self;
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
 	self = g_object_newv (VALA_TYPE_CONTINUE_STATEMENT, 0, NULL);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
 	return self;
@@ -54,7 +54,7 @@ ValaContinueStatement* vala_continue_statement_new (ValaSourceReference* source)
 static void vala_continue_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaContinueStatement * self;
 	self = VALA_CONTINUE_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_continue_statement (visitor, self);
 }
 
@@ -70,14 +70,14 @@ static void vala_continue_statement_vala_statement_interface_init (ValaStatement
 }
 
 
-static void vala_continue_statement_init (ValaContinueStatement * self) {
+static void vala_continue_statement_instance_init (ValaContinueStatement * self) {
 }
 
 
 GType vala_continue_statement_get_type (void) {
 	static GType vala_continue_statement_type_id = 0;
 	if (G_UNLIKELY (vala_continue_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaContinueStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_continue_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaContinueStatement), 0, (GInstanceInitFunc) vala_continue_statement_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaContinueStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_continue_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaContinueStatement), 0, (GInstanceInitFunc) vala_continue_statement_instance_init };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_continue_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_continue_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaContinueStatement", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_continue_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
