@@ -40,6 +40,7 @@ struct _ValaCreationMethodPrivate {
 	char* _type_name;
 	gint _n_construction_params;
 };
+
 #define VALA_CREATION_METHOD_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CREATION_METHOD, ValaCreationMethodPrivate))
 enum  {
 	VALA_CREATION_METHOD_DUMMY_PROPERTY,
@@ -90,36 +91,32 @@ static void vala_creation_method_real_accept_children (ValaCodeNode* base, ValaC
 	self = VALA_CREATION_METHOD (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
-		GeeCollection* param_collection;
-		GeeIterator* param_it;
+		GeeList* param_collection;
+		int param_it;
 		param_collection = vala_method_get_parameters (VALA_METHOD (self));
-		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
-		while (gee_iterator_next (param_it)) {
+		for (param_it = 0; param_it < gee_collection_get_size (GEE_COLLECTION (param_collection)); param_it = param_it + 1) {
 			ValaFormalParameter* param;
-			param = ((ValaFormalParameter*) gee_iterator_get (param_it));
+			param = ((ValaFormalParameter*) (gee_list_get (GEE_LIST (param_collection), param_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (param), visitor);
 				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 			}
 		}
 		(param_collection == NULL ? NULL : (param_collection = (g_object_unref (param_collection), NULL)));
-		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
 	}
 	{
-		GeeCollection* error_domain_collection;
-		GeeIterator* error_domain_it;
-		error_domain_collection = vala_method_get_error_domains (VALA_METHOD (self));
-		error_domain_it = gee_iterable_iterator (GEE_ITERABLE (error_domain_collection));
-		while (gee_iterator_next (error_domain_it)) {
-			ValaDataType* error_domain;
-			error_domain = ((ValaDataType*) gee_iterator_get (error_domain_it));
+		GeeList* error_type_collection;
+		int error_type_it;
+		error_type_collection = vala_code_node_get_error_types (VALA_CODE_NODE (self));
+		for (error_type_it = 0; error_type_it < gee_collection_get_size (GEE_COLLECTION (error_type_collection)); error_type_it = error_type_it + 1) {
+			ValaDataType* error_type;
+			error_type = ((ValaDataType*) (gee_list_get (GEE_LIST (error_type_collection), error_type_it)));
 			{
-				vala_code_node_accept (VALA_CODE_NODE (error_domain), visitor);
-				(error_domain == NULL ? NULL : (error_domain = (g_object_unref (error_domain), NULL)));
+				vala_code_node_accept (VALA_CODE_NODE (error_type), visitor);
+				(error_type == NULL ? NULL : (error_type = (g_object_unref (error_type), NULL)));
 			}
 		}
-		(error_domain_collection == NULL ? NULL : (error_domain_collection = (g_object_unref (error_domain_collection), NULL)));
-		(error_domain_it == NULL ? NULL : (error_domain_it = (g_object_unref (error_domain_it), NULL)));
+		(error_type_collection == NULL ? NULL : (error_type_collection = (g_object_unref (error_type_collection), NULL)));
 	}
 	if (vala_method_get_body (VALA_METHOD (self)) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_method_get_body (VALA_METHOD (self))), visitor);
@@ -129,14 +126,14 @@ static void vala_creation_method_real_accept_children (ValaCodeNode* base, ValaC
 
 static char* vala_creation_method_real_get_default_cname (ValaMethod* base) {
 	ValaCreationMethod * self;
-	ValaTypesymbol* _tmp1;
+	ValaTypeSymbol* _tmp1;
 	ValaSymbol* _tmp0;
-	ValaTypesymbol* parent;
+	ValaTypeSymbol* parent;
 	char* infix;
 	self = VALA_CREATION_METHOD (base);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
-	parent = (_tmp1 = (_tmp0 = vala_symbol_get_parent_symbol (VALA_SYMBOL (self)), (VALA_IS_TYPESYMBOL (_tmp0) ? ((ValaTypesymbol*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+	parent = (_tmp1 = (_tmp0 = vala_symbol_get_parent_symbol (VALA_SYMBOL (self)), (VALA_IS_TYPESYMBOL (_tmp0) ? ((ValaTypeSymbol*) (_tmp0)) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
 	infix = g_strdup ("new");
 	if (VALA_IS_STRUCT (parent)) {
 		char* _tmp2;
@@ -173,7 +170,7 @@ static ValaCodeBinding* vala_creation_method_real_create_code_binding (ValaCodeN
 }
 
 
-char* vala_creation_method_get_type_name (ValaCreationMethod* self) {
+const char* vala_creation_method_get_type_name (ValaCreationMethod* self) {
 	g_return_val_if_fail (VALA_IS_CREATION_METHOD (self), NULL);
 	return self->priv->_type_name;
 }
@@ -250,7 +247,7 @@ static void vala_creation_method_class_init (ValaCreationMethodClass * klass) {
 }
 
 
-static void vala_creation_method_init (ValaCreationMethod * self) {
+static void vala_creation_method_instance_init (ValaCreationMethod * self) {
 	self->priv = VALA_CREATION_METHOD_GET_PRIVATE (self);
 }
 
@@ -266,7 +263,7 @@ static void vala_creation_method_dispose (GObject * obj) {
 GType vala_creation_method_get_type (void) {
 	static GType vala_creation_method_type_id = 0;
 	if (G_UNLIKELY (vala_creation_method_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaCreationMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_creation_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCreationMethod), 0, (GInstanceInitFunc) vala_creation_method_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaCreationMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_creation_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCreationMethod), 0, (GInstanceInitFunc) vala_creation_method_instance_init };
 		vala_creation_method_type_id = g_type_register_static (VALA_TYPE_METHOD, "ValaCreationMethod", &g_define_type_info, 0);
 	}
 	return vala_creation_method_type_id;
