@@ -1,6 +1,6 @@
 /* valadeclarationstatement.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -41,19 +41,21 @@ G_BEGIN_DECLS
 typedef struct _ValaDeclarationStatementPrivate ValaDeclarationStatementPrivate;
 
 /**
- * Represents a local variable declaration statement in the source code.
+ * Represents a local variable or constant declaration statement in the source code.
  */
 struct _ValaDeclarationStatement {
 	ValaCodeNode parent_instance;
 	ValaDeclarationStatementPrivate * priv;
 };
+
 struct _ValaDeclarationStatementClass {
 	ValaCodeNodeClass parent_class;
 };
 
-ValaDeclarationStatement* vala_declaration_statement_new (ValaLocalVariableDeclaration* decl, ValaSourceReference* source);
-ValaLocalVariableDeclaration* vala_declaration_statement_get_declaration (ValaDeclarationStatement* self);
-void vala_declaration_statement_set_declaration (ValaDeclarationStatement* self, ValaLocalVariableDeclaration* value);
+
+ValaDeclarationStatement* vala_declaration_statement_new (ValaSymbol* declaration, ValaSourceReference* source_reference);
+ValaSymbol* vala_declaration_statement_get_declaration (ValaDeclarationStatement* self);
+void vala_declaration_statement_set_declaration (ValaDeclarationStatement* self, ValaSymbol* value);
 GType vala_declaration_statement_get_type (void);
 
 
