@@ -36,6 +36,7 @@
 #include <vala/valamember.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
+#include <vala/valareferencetype.h>
 
 
 
@@ -64,14 +65,16 @@ enum  {
 };
 static void vala_delegate_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_delegate_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
-static char* vala_delegate_real_get_cname (ValaTypesymbol* base, gboolean const_type);
+static char* vala_delegate_real_get_cname (ValaTypeSymbol* base, gboolean const_type);
 static void vala_delegate_process_ccode_attribute (ValaDelegate* self, ValaAttribute* a);
-static gboolean vala_delegate_real_is_reference_type (ValaTypesymbol* base);
-static char* vala_delegate_real_get_type_id (ValaTypesymbol* base);
-static char* vala_delegate_real_get_marshaller_type_name (ValaTypesymbol* base);
-static char* vala_delegate_real_get_get_value_function (ValaTypesymbol* base);
-static char* vala_delegate_real_get_set_value_function (ValaTypesymbol* base);
+static gboolean vala_delegate_real_is_reference_type (ValaTypeSymbol* base);
+static char* vala_delegate_real_get_type_id (ValaTypeSymbol* base);
+static char* vala_delegate_real_get_marshaller_type_name (ValaTypeSymbol* base);
+static char* vala_delegate_real_get_get_value_function (ValaTypeSymbol* base);
+static char* vala_delegate_real_get_set_value_function (ValaTypeSymbol* base);
 static void vala_delegate_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
+static char* vala_delegate_get_return_type_string (ValaDelegate* self);
+static char* vala_delegate_get_parameters_string (ValaDelegate* self);
 static GObject * vala_delegate_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_delegate_parent_class = NULL;
 static void vala_delegate_dispose (GObject * obj);
@@ -126,7 +129,7 @@ void vala_delegate_add_parameter (ValaDelegate* self, ValaFormalParameter* param
 		vala_formal_parameter_set_no_array_length (param, TRUE);
 	}
 	/* default C parameter position*/
-	vala_formal_parameter_set_cparameter_position (param, ((double) gee_collection_get_size (GEE_COLLECTION (self->priv->parameters)) + 1));
+	vala_formal_parameter_set_cparameter_position (param, ((double) (gee_collection_get_size (GEE_COLLECTION (self->priv->parameters)) + 1)));
 	vala_formal_parameter_set_carray_length_parameter_position (param, vala_formal_parameter_get_cparameter_position (param) + 0.1);
 	vala_formal_parameter_set_cdelegate_target_parameter_position (param, vala_formal_parameter_get_cparameter_position (param) + 0.1);
 	gee_collection_add (GEE_COLLECTION (self->priv->parameters), param);
@@ -141,7 +144,7 @@ void vala_delegate_add_parameter (ValaDelegate* self, ValaFormalParameter* param
  */
 GeeList* vala_delegate_get_parameters (ValaDelegate* self) {
 	g_return_val_if_fail (VALA_IS_DELEGATE (self), NULL);
-	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_FORMAL_PARAMETER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, self->priv->parameters));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_FORMAL_PARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->parameters));
 }
 
 
@@ -153,7 +156,7 @@ GeeList* vala_delegate_get_parameters (ValaDelegate* self) {
  * @return  true if the specified method is compatible to this callback
  */
 gboolean vala_delegate_matches_method (ValaDelegate* self, ValaMethod* m) {
-	GeeCollection* method_params;
+	GeeList* method_params;
 	GeeIterator* method_params_it;
 	gboolean first;
 	gboolean _tmp3;
@@ -168,12 +171,11 @@ gboolean vala_delegate_matches_method (ValaDelegate* self, ValaMethod* m) {
 	first = TRUE;
 	{
 		GeeList* param_collection;
-		GeeIterator* param_it;
+		int param_it;
 		param_collection = self->priv->parameters;
-		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
-		while (gee_iterator_next (param_it)) {
+		for (param_it = 0; param_it < gee_collection_get_size (GEE_COLLECTION (param_collection)); param_it = param_it + 1) {
 			ValaFormalParameter* param;
-			param = ((ValaFormalParameter*) gee_iterator_get (param_it));
+			param = ((ValaFormalParameter*) (gee_list_get (GEE_LIST (param_collection), param_it)));
 			{
 				ValaFormalParameter* method_param;
 				/* use first callback parameter as instance parameter if
@@ -191,16 +193,15 @@ gboolean vala_delegate_matches_method (ValaDelegate* self, ValaMethod* m) {
 					break;
 				}
 				/* method is allowed to accept arguments of looser types (weaker precondition)*/
-				method_param = ((ValaFormalParameter*) gee_iterator_get (method_params_it));
-				if (!vala_data_type_stricter (vala_formal_parameter_get_type_reference (param), vala_formal_parameter_get_type_reference (method_param))) {
+				method_param = ((ValaFormalParameter*) (gee_iterator_get (method_params_it)));
+				if (!vala_data_type_stricter (vala_formal_parameter_get_parameter_type (param), vala_formal_parameter_get_parameter_type (method_param))) {
 					gboolean _tmp1;
-					return (_tmp1 = FALSE, (param == NULL ? NULL : (param = (g_object_unref (param), NULL))), (method_param == NULL ? NULL : (method_param = (g_object_unref (method_param), NULL))), (param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL))), (method_params == NULL ? NULL : (method_params = (g_object_unref (method_params), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), _tmp1);
+					return (_tmp1 = FALSE, (param == NULL ? NULL : (param = (g_object_unref (param), NULL))), (method_param == NULL ? NULL : (method_param = (g_object_unref (method_param), NULL))), (method_params == NULL ? NULL : (method_params = (g_object_unref (method_params), NULL))), (method_params_it == NULL ? NULL : (method_params_it = (g_object_unref (method_params_it), NULL))), _tmp1);
 				}
 				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 				(method_param == NULL ? NULL : (method_param = (g_object_unref (method_param), NULL)));
 			}
 		}
-		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
 	}
 	/* method may not expect more arguments */
 	if (gee_iterator_next (method_params_it)) {
@@ -225,39 +226,35 @@ static void vala_delegate_real_accept_children (ValaCodeNode* base, ValaCodeVisi
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
 		GeeList* p_collection;
-		GeeIterator* p_it;
+		int p_it;
 		p_collection = self->priv->type_parameters;
-		p_it = gee_iterable_iterator (GEE_ITERABLE (p_collection));
-		while (gee_iterator_next (p_it)) {
+		for (p_it = 0; p_it < gee_collection_get_size (GEE_COLLECTION (p_collection)); p_it = p_it + 1) {
 			ValaTypeParameter* p;
-			p = ((ValaTypeParameter*) gee_iterator_get (p_it));
+			p = ((ValaTypeParameter*) (gee_list_get (GEE_LIST (p_collection), p_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (p), visitor);
 				(p == NULL ? NULL : (p = (g_object_unref (p), NULL)));
 			}
 		}
-		(p_it == NULL ? NULL : (p_it = (g_object_unref (p_it), NULL)));
 	}
 	vala_code_node_accept (VALA_CODE_NODE (vala_delegate_get_return_type (self)), visitor);
 	{
 		GeeList* param_collection;
-		GeeIterator* param_it;
+		int param_it;
 		param_collection = self->priv->parameters;
-		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
-		while (gee_iterator_next (param_it)) {
+		for (param_it = 0; param_it < gee_collection_get_size (GEE_COLLECTION (param_collection)); param_it = param_it + 1) {
 			ValaFormalParameter* param;
-			param = ((ValaFormalParameter*) gee_iterator_get (param_it));
+			param = ((ValaFormalParameter*) (gee_list_get (GEE_LIST (param_collection), param_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (param), visitor);
 				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 			}
 		}
-		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
 	}
 }
 
 
-static char* vala_delegate_real_get_cname (ValaTypesymbol* base, gboolean const_type) {
+static char* vala_delegate_real_get_cname (ValaTypeSymbol* base, gboolean const_type) {
 	ValaDelegate * self;
 	const char* _tmp2;
 	self = VALA_DELEGATE (base);
@@ -313,8 +310,8 @@ static void vala_delegate_process_ccode_attribute (ValaDelegate* self, ValaAttri
 		val = vala_attribute_get_string (a, "cheader_filename");
 		{
 			char** filename_collection;
-			char** filename_it;
 			int filename_collection_length1;
+			char** filename_it;
 			filename_collection = g_strsplit (val, ",", 0);
 			filename_collection_length1 = -1;
 			for (filename_it = filename_collection; *filename_it != NULL; filename_it = filename_it + 1) {
@@ -327,7 +324,7 @@ static void vala_delegate_process_ccode_attribute (ValaDelegate* self, ValaAttri
 					filename = (g_free (filename), NULL);
 				}
 			}
-			filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) g_free)), NULL);
+			filename_collection = (_vala_array_free (filename_collection, filename_collection_length1, ((GDestroyNotify) (g_free))), NULL);
 		}
 		val = (g_free (val), NULL);
 	}
@@ -347,7 +344,7 @@ void vala_delegate_process_attributes (ValaDelegate* self) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
 			_tmp0 = NULL;
-			a = (_tmp0 = ((ValaAttribute*) a_it->data), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_delegate_process_ccode_attribute (self, a);
@@ -363,35 +360,35 @@ void vala_delegate_process_attributes (ValaDelegate* self) {
 }
 
 
-static gboolean vala_delegate_real_is_reference_type (ValaTypesymbol* base) {
+static gboolean vala_delegate_real_is_reference_type (ValaTypeSymbol* base) {
 	ValaDelegate * self;
 	self = VALA_DELEGATE (base);
 	return FALSE;
 }
 
 
-static char* vala_delegate_real_get_type_id (ValaTypesymbol* base) {
+static char* vala_delegate_real_get_type_id (ValaTypeSymbol* base) {
 	ValaDelegate * self;
 	self = VALA_DELEGATE (base);
 	return g_strdup ("G_TYPE_POINTER");
 }
 
 
-static char* vala_delegate_real_get_marshaller_type_name (ValaTypesymbol* base) {
+static char* vala_delegate_real_get_marshaller_type_name (ValaTypeSymbol* base) {
 	ValaDelegate * self;
 	self = VALA_DELEGATE (base);
 	return g_strdup ("POINTER");
 }
 
 
-static char* vala_delegate_real_get_get_value_function (ValaTypesymbol* base) {
+static char* vala_delegate_real_get_get_value_function (ValaTypeSymbol* base) {
 	ValaDelegate * self;
 	self = VALA_DELEGATE (base);
 	return g_strdup ("g_value_get_pointer");
 }
 
 
-static char* vala_delegate_real_get_set_value_function (ValaTypesymbol* base) {
+static char* vala_delegate_real_get_set_value_function (ValaTypeSymbol* base) {
 	ValaDelegate * self;
 	self = VALA_DELEGATE (base);
 	return g_strdup ("g_value_set_pointer");
@@ -409,6 +406,98 @@ static void vala_delegate_real_replace_type (ValaCodeNode* base, ValaDataType* o
 }
 
 
+char* vala_delegate_get_prototype_string (ValaDelegate* self, const char* name) {
+	char* _tmp1;
+	char* _tmp0;
+	char* _tmp2;
+	g_return_val_if_fail (VALA_IS_DELEGATE (self), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	_tmp2 = NULL;
+	return (_tmp2 = g_strdup_printf ("%s %s %s", (_tmp0 = vala_delegate_get_return_type_string (self)), name, (_tmp1 = vala_delegate_get_parameters_string (self))), (_tmp1 = (g_free (_tmp1), NULL)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp2);
+}
+
+
+static char* vala_delegate_get_return_type_string (ValaDelegate* self) {
+	char* str;
+	char* _tmp2;
+	char* _tmp1;
+	g_return_val_if_fail (VALA_IS_DELEGATE (self), NULL);
+	str = g_strdup ("");
+	if (!vala_data_type_get_value_owned (vala_delegate_get_return_type (self)) && VALA_IS_REFERENCE_TYPE (vala_delegate_get_return_type (self))) {
+		char* _tmp0;
+		_tmp0 = NULL;
+		str = (_tmp0 = g_strdup ("weak "), (str = (g_free (str), NULL)), _tmp0);
+	}
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	str = (_tmp2 = g_strconcat (str, (_tmp1 = (vala_code_node_to_string (VALA_CODE_NODE (vala_delegate_get_return_type (self))))), NULL), (str = (g_free (str), NULL)), _tmp2);
+	_tmp1 = (g_free (_tmp1), NULL);
+	return str;
+}
+
+
+static char* vala_delegate_get_parameters_string (ValaDelegate* self) {
+	char* str;
+	gint i;
+	char* _tmp7;
+	g_return_val_if_fail (VALA_IS_DELEGATE (self), NULL);
+	str = g_strdup ("(");
+	i = 1;
+	{
+		GeeList* param_collection;
+		int param_it;
+		param_collection = self->priv->parameters;
+		for (param_it = 0; param_it < gee_collection_get_size (GEE_COLLECTION (param_collection)); param_it = param_it + 1) {
+			ValaFormalParameter* param;
+			param = ((ValaFormalParameter*) (gee_list_get (GEE_LIST (param_collection), param_it)));
+			{
+				char* _tmp5;
+				char* _tmp4;
+				if (i > 1) {
+					char* _tmp0;
+					_tmp0 = NULL;
+					str = (_tmp0 = g_strconcat (str, (", "), NULL), (str = (g_free (str), NULL)), _tmp0);
+				}
+				if (vala_formal_parameter_get_direction (param) != VALA_PARAMETER_DIRECTION_IN) {
+					if (vala_formal_parameter_get_direction (param) == VALA_PARAMETER_DIRECTION_REF) {
+						char* _tmp1;
+						_tmp1 = NULL;
+						str = (_tmp1 = g_strconcat (str, ("ref "), NULL), (str = (g_free (str), NULL)), _tmp1);
+					} else {
+						if (vala_formal_parameter_get_direction (param) == VALA_PARAMETER_DIRECTION_OUT) {
+							char* _tmp2;
+							_tmp2 = NULL;
+							str = (_tmp2 = g_strconcat (str, ("out "), NULL), (str = (g_free (str), NULL)), _tmp2);
+						}
+					}
+					if (!vala_data_type_get_value_owned (vala_formal_parameter_get_parameter_type (param)) && VALA_IS_REFERENCE_TYPE (vala_formal_parameter_get_parameter_type (param))) {
+						char* _tmp3;
+						_tmp3 = NULL;
+						str = (_tmp3 = g_strconcat (str, ("weak "), NULL), (str = (g_free (str), NULL)), _tmp3);
+					}
+				}
+				_tmp5 = NULL;
+				_tmp4 = NULL;
+				str = (_tmp5 = g_strconcat (str, (_tmp4 = (vala_code_node_to_string (VALA_CODE_NODE (vala_formal_parameter_get_parameter_type (param))))), NULL), (str = (g_free (str), NULL)), _tmp5);
+				_tmp4 = (g_free (_tmp4), NULL);
+				if (vala_formal_parameter_get_direction (param) == VALA_PARAMETER_DIRECTION_IN && vala_data_type_get_value_owned (vala_formal_parameter_get_parameter_type (param))) {
+					char* _tmp6;
+					_tmp6 = NULL;
+					str = (_tmp6 = g_strconcat (str, ("#"), NULL), (str = (g_free (str), NULL)), _tmp6);
+				}
+				i++;
+				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
+			}
+		}
+	}
+	_tmp7 = NULL;
+	str = (_tmp7 = g_strconcat (str, (")"), NULL), (str = (g_free (str), NULL)), _tmp7);
+	return str;
+}
+
+
 ValaDataType* vala_delegate_get_return_type (ValaDelegate* self) {
 	g_return_val_if_fail (VALA_IS_DELEGATE (self), NULL);
 	return self->priv->_return_type;
@@ -485,18 +574,16 @@ void vala_delegate_set_no_array_length (ValaDelegate* self, gboolean value) {
 	self->priv->_no_array_length = value;
 	{
 		GeeList* param_collection;
-		GeeIterator* param_it;
+		int param_it;
 		param_collection = self->priv->parameters;
-		param_it = gee_iterable_iterator (GEE_ITERABLE (param_collection));
-		while (gee_iterator_next (param_it)) {
+		for (param_it = 0; param_it < gee_collection_get_size (GEE_COLLECTION (param_collection)); param_it = param_it + 1) {
 			ValaFormalParameter* param;
-			param = ((ValaFormalParameter*) gee_iterator_get (param_it));
+			param = ((ValaFormalParameter*) (gee_list_get (GEE_LIST (param_collection), param_it)));
 			{
 				vala_formal_parameter_set_no_array_length (param, value);
 				(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 			}
 		}
-		(param_it == NULL ? NULL : (param_it = (g_object_unref (param_it), NULL)));
 	}
 }
 
@@ -511,9 +598,9 @@ static GObject * vala_delegate_constructor (GType type, guint n_construct_proper
 	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
 	self = VALA_DELEGATE (obj);
 	{
-		vala_delegate_set_cinstance_parameter_position (self, ((double) -1));
-		vala_delegate_set_carray_length_parameter_position (self, ((double) -3));
-		vala_delegate_set_cdelegate_target_parameter_position (self, ((double) -3));
+		vala_delegate_set_cinstance_parameter_position (self, ((double) (-1)));
+		vala_delegate_set_carray_length_parameter_position (self, ((double) (-3)));
+		vala_delegate_set_cdelegate_target_parameter_position (self, ((double) (-3)));
 	}
 	return obj;
 }
@@ -602,10 +689,10 @@ static void vala_delegate_class_init (ValaDelegateClass * klass) {
 }
 
 
-static void vala_delegate_init (ValaDelegate * self) {
+static void vala_delegate_instance_init (ValaDelegate * self) {
 	self->priv = VALA_DELEGATE_GET_PRIVATE (self);
-	self->priv->type_parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_TYPEPARAMETER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
-	self->priv->parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_FORMAL_PARAMETER, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->type_parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_TYPEPARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
+	self->priv->parameters = GEE_LIST (gee_array_list_new (VALA_TYPE_FORMAL_PARAMETER, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 }
 
 
@@ -623,7 +710,7 @@ static void vala_delegate_dispose (GObject * obj) {
 GType vala_delegate_get_type (void) {
 	static GType vala_delegate_type_id = 0;
 	if (G_UNLIKELY (vala_delegate_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaDelegateClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_delegate_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDelegate), 0, (GInstanceInitFunc) vala_delegate_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaDelegateClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_delegate_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDelegate), 0, (GInstanceInitFunc) vala_delegate_instance_init };
 		vala_delegate_type_id = g_type_register_static (VALA_TYPE_TYPESYMBOL, "ValaDelegate", &g_define_type_info, 0);
 	}
 	return vala_delegate_type_id;
@@ -635,12 +722,12 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 		int i;
 		if (array_length >= 0)
 		for (i = 0; i < array_length; i = i + 1) {
-			if (((gpointer*) array)[i] != NULL)
-			destroy_func (((gpointer*) array)[i]);
+			if (((gpointer*) (array))[i] != NULL)
+			destroy_func (((gpointer*) (array))[i]);
 		}
 		else
-		for (i = 0; ((gpointer*) array)[i] != NULL; i = i + 1) {
-			destroy_func (((gpointer*) array)[i]);
+		for (i = 0; ((gpointer*) (array))[i] != NULL; i = i + 1) {
+			destroy_func (((gpointer*) (array))[i]);
 		}
 	}
 	g_free (array);
