@@ -22,6 +22,7 @@
 
 #include <vala/valadelegatetype.h>
 #include <gee/arraylist.h>
+#include <gee/collection.h>
 #include <vala/valasymbol.h>
 
 
@@ -30,6 +31,7 @@
 struct _ValaDelegateTypePrivate {
 	ValaDelegate* _delegate_symbol;
 };
+
 #define VALA_DELEGATE_TYPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DELEGATE_TYPE, ValaDelegateTypePrivate))
 enum  {
 	VALA_DELEGATE_TYPE_DUMMY_PROPERTY,
@@ -37,11 +39,11 @@ enum  {
 };
 static gboolean vala_delegate_type_real_is_invokable (ValaDataType* base);
 static ValaDataType* vala_delegate_type_real_get_return_type (ValaDataType* base);
-static GeeCollection* vala_delegate_type_real_get_parameters (ValaDataType* base);
-static char* vala_delegate_type_real_to_string (ValaCodeNode* base);
+static GeeList* vala_delegate_type_real_get_parameters (ValaDataType* base);
+static char* vala_delegate_type_real_to_qualified_string (ValaDataType* base, ValaScope* scope);
 static ValaDataType* vala_delegate_type_real_copy (ValaDataType* base);
-static char* vala_delegate_type_real_get_cname (ValaDataType* base, gboolean var_type, gboolean const_type);
-static GeeCollection* vala_delegate_type_real_get_symbols (ValaDataType* base);
+static char* vala_delegate_type_real_get_cname (ValaDataType* base);
+static GeeList* vala_delegate_type_real_get_symbols (ValaDataType* base);
 static char* vala_delegate_type_real_get_type_id (ValaDataType* base);
 static gpointer vala_delegate_type_parent_class = NULL;
 static void vala_delegate_type_dispose (GObject * obj);
@@ -50,7 +52,7 @@ static void vala_delegate_type_dispose (GObject * obj);
 
 ValaDelegateType* vala_delegate_type_new (ValaDelegate* delegate_symbol) {
 	ValaDelegateType * self;
-	g_return_val_if_fail (delegate_symbol == NULL || VALA_IS_DELEGATE (delegate_symbol), NULL);
+	g_return_val_if_fail (VALA_IS_DELEGATE (delegate_symbol), NULL);
 	self = g_object_newv (VALA_TYPE_DELEGATE_TYPE, 0, NULL);
 	vala_delegate_type_set_delegate_symbol (self, delegate_symbol);
 	return self;
@@ -73,17 +75,25 @@ static ValaDataType* vala_delegate_type_real_get_return_type (ValaDataType* base
 }
 
 
-static GeeCollection* vala_delegate_type_real_get_parameters (ValaDataType* base) {
+static GeeList* vala_delegate_type_real_get_parameters (ValaDataType* base) {
 	ValaDelegateType * self;
 	self = VALA_DELEGATE_TYPE (base);
-	return GEE_COLLECTION (vala_delegate_get_parameters (self->priv->_delegate_symbol));
+	return vala_delegate_get_parameters (self->priv->_delegate_symbol);
 }
 
 
-static char* vala_delegate_type_real_to_string (ValaCodeNode* base) {
+static char* vala_delegate_type_real_to_qualified_string (ValaDataType* base, ValaScope* scope) {
 	ValaDelegateType * self;
+	char* s;
 	self = VALA_DELEGATE_TYPE (base);
-	return vala_symbol_get_full_name (VALA_SYMBOL (self->priv->_delegate_symbol));
+	g_return_val_if_fail (scope == NULL || VALA_IS_SCOPE (scope), NULL);
+	s = vala_symbol_get_full_name (VALA_SYMBOL (self->priv->_delegate_symbol));
+	if (vala_data_type_get_nullable (VALA_DATA_TYPE (self))) {
+		char* _tmp0;
+		_tmp0 = NULL;
+		s = (_tmp0 = g_strconcat (s, ("?"), NULL), (s = (g_free (s), NULL)), _tmp0);
+	}
+	return s;
 }
 
 
@@ -94,20 +104,20 @@ static ValaDataType* vala_delegate_type_real_copy (ValaDataType* base) {
 }
 
 
-static char* vala_delegate_type_real_get_cname (ValaDataType* base, gboolean var_type, gboolean const_type) {
+static char* vala_delegate_type_real_get_cname (ValaDataType* base) {
 	ValaDelegateType * self;
 	self = VALA_DELEGATE_TYPE (base);
-	return vala_typesymbol_get_cname (VALA_TYPESYMBOL (self->priv->_delegate_symbol), const_type);
+	return vala_typesymbol_get_cname (VALA_TYPESYMBOL (self->priv->_delegate_symbol), FALSE);
 }
 
 
-static GeeCollection* vala_delegate_type_real_get_symbols (ValaDataType* base) {
+static GeeList* vala_delegate_type_real_get_symbols (ValaDataType* base) {
 	ValaDelegateType * self;
 	GeeArrayList* symbols;
 	self = VALA_DELEGATE_TYPE (base);
-	symbols = gee_array_list_new (VALA_TYPE_SYMBOL, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal);
-	gee_collection_add (GEE_COLLECTION (symbols), self->priv->_delegate_symbol);
-	return GEE_COLLECTION (symbols);
+	symbols = gee_array_list_new (VALA_TYPE_SYMBOL, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal);
+	gee_collection_add (GEE_COLLECTION (symbols), VALA_SYMBOL (self->priv->_delegate_symbol));
+	return GEE_LIST (symbols);
 }
 
 
@@ -171,7 +181,7 @@ static void vala_delegate_type_class_init (ValaDelegateTypeClass * klass) {
 	VALA_DATA_TYPE_CLASS (klass)->is_invokable = vala_delegate_type_real_is_invokable;
 	VALA_DATA_TYPE_CLASS (klass)->get_return_type = vala_delegate_type_real_get_return_type;
 	VALA_DATA_TYPE_CLASS (klass)->get_parameters = vala_delegate_type_real_get_parameters;
-	VALA_CODE_NODE_CLASS (klass)->to_string = vala_delegate_type_real_to_string;
+	VALA_DATA_TYPE_CLASS (klass)->to_qualified_string = vala_delegate_type_real_to_qualified_string;
 	VALA_DATA_TYPE_CLASS (klass)->copy = vala_delegate_type_real_copy;
 	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_delegate_type_real_get_cname;
 	VALA_DATA_TYPE_CLASS (klass)->get_symbols = vala_delegate_type_real_get_symbols;
@@ -180,7 +190,7 @@ static void vala_delegate_type_class_init (ValaDelegateTypeClass * klass) {
 }
 
 
-static void vala_delegate_type_init (ValaDelegateType * self) {
+static void vala_delegate_type_instance_init (ValaDelegateType * self) {
 	self->priv = VALA_DELEGATE_TYPE_GET_PRIVATE (self);
 }
 
@@ -196,7 +206,7 @@ static void vala_delegate_type_dispose (GObject * obj) {
 GType vala_delegate_type_get_type (void) {
 	static GType vala_delegate_type_type_id = 0;
 	if (G_UNLIKELY (vala_delegate_type_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaDelegateTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_delegate_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDelegateType), 0, (GInstanceInitFunc) vala_delegate_type_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaDelegateTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_delegate_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDelegateType), 0, (GInstanceInitFunc) vala_delegate_type_instance_init };
 		vala_delegate_type_type_id = g_type_register_static (VALA_TYPE_DATA_TYPE, "ValaDelegateType", &g_define_type_info, 0);
 	}
 	return vala_delegate_type_type_id;
