@@ -33,6 +33,7 @@ struct _ValaDoStatementPrivate {
 	ValaExpression* _condition;
 	ValaBlock* _body;
 };
+
 #define VALA_DO_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DO_STATEMENT, ValaDoStatementPrivate))
 enum  {
 	VALA_DO_STATEMENT_DUMMY_PROPERTY,
@@ -60,8 +61,8 @@ ValaDoStatement* vala_do_statement_new (ValaBlock* body, ValaExpression* conditi
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaDoStatement * self;
-	g_return_val_if_fail (body == NULL || VALA_IS_BLOCK (body), NULL);
-	g_return_val_if_fail (condition == NULL || VALA_IS_EXPRESSION (condition), NULL);
+	g_return_val_if_fail (VALA_IS_BLOCK (body), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (condition), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
@@ -70,8 +71,8 @@ ValaDoStatement* vala_do_statement_new (ValaBlock* body, ValaExpression* conditi
 	g_value_set_object (&__params_it->value, condition);
 	__params_it++;
 	self = g_object_newv (VALA_TYPE_DO_STATEMENT, __params_it - __params, __params);
-	vala_do_statement_set_body (self, body);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_do_statement_set_body (self, body);
 	while (__params_it > __params) {
 		--__params_it;
 		g_value_unset (&__params_it->value);
@@ -84,7 +85,7 @@ ValaDoStatement* vala_do_statement_new (ValaBlock* body, ValaExpression* conditi
 static void vala_do_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaDoStatement * self;
 	self = VALA_DO_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_do_statement (visitor, self);
 }
 
@@ -92,7 +93,7 @@ static void vala_do_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor*
 static void vala_do_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaDoStatement * self;
 	self = VALA_DO_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_do_statement_get_body (self)), visitor);
 	vala_code_node_accept (VALA_CODE_NODE (vala_do_statement_get_condition (self)), visitor);
 	vala_code_visitor_visit_end_full_expression (visitor, vala_do_statement_get_condition (self));
@@ -102,8 +103,8 @@ static void vala_do_statement_real_accept_children (ValaCodeNode* base, ValaCode
 static void vala_do_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaDoStatement * self;
 	self = VALA_DO_STATEMENT (base);
-	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
 	if (vala_do_statement_get_condition (self) == old_node) {
 		vala_do_statement_set_condition (self, new_node);
 	}
@@ -197,7 +198,7 @@ static void vala_do_statement_vala_statement_interface_init (ValaStatementIface
 }
 
 
-static void vala_do_statement_init (ValaDoStatement * self) {
+static void vala_do_statement_instance_init (ValaDoStatement * self) {
 	self->priv = VALA_DO_STATEMENT_GET_PRIVATE (self);
 }
 
@@ -214,7 +215,7 @@ static void vala_do_statement_dispose (GObject * obj) {
 GType vala_do_statement_get_type (void) {
 	static GType vala_do_statement_type_id = 0;
 	if (G_UNLIKELY (vala_do_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaDoStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_do_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDoStatement), 0, (GInstanceInitFunc) vala_do_statement_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaDoStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_do_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDoStatement), 0, (GInstanceInitFunc) vala_do_statement_instance_init };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_do_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_do_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaDoStatement", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_do_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
