@@ -32,6 +32,7 @@ struct _ValaErrorCodePrivate {
 	ValaExpression* _value;
 	char* cname;
 };
+
 #define VALA_ERROR_CODE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_ERROR_CODE, ValaErrorCodePrivate))
 enum  {
 	VALA_ERROR_CODE_DUMMY_PROPERTY,
@@ -52,6 +53,7 @@ static void vala_error_code_dispose (GObject * obj);
  */
 ValaErrorCode* vala_error_code_new (const char* name) {
 	ValaErrorCode * self;
+	g_return_val_if_fail (name != NULL, NULL);
 	self = g_object_newv (VALA_TYPE_ERROR_CODE, 0, NULL);
 	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	return self;
@@ -67,7 +69,8 @@ ValaErrorCode* vala_error_code_new (const char* name) {
  */
 ValaErrorCode* vala_error_code_new_with_value (const char* name, ValaExpression* value) {
 	ValaErrorCode * self;
-	g_return_val_if_fail (value == NULL || VALA_IS_EXPRESSION (value), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (value), NULL);
 	self = g_object_newv (VALA_TYPE_ERROR_CODE, 0, NULL);
 	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	vala_error_code_set_value (self, value);
@@ -78,7 +81,7 @@ ValaErrorCode* vala_error_code_new_with_value (const char* name, ValaExpression*
 static void vala_error_code_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaErrorCode * self;
 	self = VALA_ERROR_CODE (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_error_code (visitor, self);
 }
 
@@ -86,7 +89,7 @@ static void vala_error_code_real_accept (ValaCodeNode* base, ValaCodeVisitor* vi
 static void vala_error_code_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaErrorCode * self;
 	self = VALA_ERROR_CODE (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (self->priv->_value != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (self->priv->_value), visitor);
 	}
@@ -175,7 +178,7 @@ static void vala_error_code_class_init (ValaErrorCodeClass * klass) {
 }
 
 
-static void vala_error_code_init (ValaErrorCode * self) {
+static void vala_error_code_instance_init (ValaErrorCode * self) {
 	self->priv = VALA_ERROR_CODE_GET_PRIVATE (self);
 }
 
@@ -192,7 +195,7 @@ static void vala_error_code_dispose (GObject * obj) {
 GType vala_error_code_get_type (void) {
 	static GType vala_error_code_type_id = 0;
 	if (G_UNLIKELY (vala_error_code_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaErrorCodeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_error_code_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaErrorCode), 0, (GInstanceInitFunc) vala_error_code_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaErrorCodeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_error_code_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaErrorCode), 0, (GInstanceInitFunc) vala_error_code_instance_init };
 		vala_error_code_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaErrorCode", &g_define_type_info, 0);
 	}
 	return vala_error_code_type_id;
