@@ -193,7 +193,7 @@ static void vala_expression_statement_vala_statement_interface_init (ValaStateme
 }
 
 
-static void vala_expression_statement_init (ValaExpressionStatement * self) {
+static void vala_expression_statement_instance_init (ValaExpressionStatement * self) {
 	self->priv = VALA_EXPRESSION_STATEMENT_GET_PRIVATE (self);
 }
 
@@ -209,7 +209,7 @@ static void vala_expression_statement_dispose (GObject * obj) {
 GType vala_expression_statement_get_type (void) {
 	static GType vala_expression_statement_type_id = 0;
 	if (G_UNLIKELY (vala_expression_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaExpressionStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_expression_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaExpressionStatement), 0, (GInstanceInitFunc) vala_expression_statement_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaExpressionStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_expression_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaExpressionStatement), 0, (GInstanceInitFunc) vala_expression_statement_instance_init };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_expression_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_expression_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaExpressionStatement", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_expression_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
