@@ -27,6 +27,8 @@
 #include <vala/valasymbol.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
+#include <vala/valanamedargument.h>
+#include <vala/valastringliteral.h>
 
 
 
@@ -252,6 +254,48 @@ static void vala_field_real_replace_type (ValaCodeNode* base, ValaDataType* old_
 }
 
 
+char* vala_field_get_ctype (ValaField* self) {
+	ValaAttribute* attr;
+	char* _tmp1;
+	g_return_val_if_fail (VALA_IS_FIELD (self), NULL);
+	attr = vala_code_node_get_attribute (VALA_CODE_NODE (self), "CCode");
+	if (attr == NULL) {
+		char* _tmp0;
+		_tmp0 = NULL;
+		return (_tmp0 = NULL, (attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL))), _tmp0);
+	}
+	_tmp1 = NULL;
+	return (_tmp1 = vala_attribute_get_string (attr, "type"), (attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL))), _tmp1);
+}
+
+
+void vala_field_set_ctype (ValaField* self, const char* ctype) {
+	ValaAttribute* attr;
+	ValaNamedArgument* _tmp4;
+	ValaStringLiteral* _tmp3;
+	char* _tmp2;
+	g_return_if_fail (VALA_IS_FIELD (self));
+	g_return_if_fail (ctype != NULL);
+	attr = vala_code_node_get_attribute (VALA_CODE_NODE (self), "CCode");
+	if (attr == NULL) {
+		ValaAttribute* _tmp0;
+		ValaAttribute* _tmp1;
+		_tmp0 = NULL;
+		attr = (_tmp0 = vala_attribute_new ("CCode", NULL), (attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL))), _tmp0);
+		_tmp1 = NULL;
+		VALA_CODE_NODE (self)->attributes = g_list_append (VALA_CODE_NODE (self)->attributes, (_tmp1 = attr, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))));
+	}
+	_tmp4 = NULL;
+	_tmp3 = NULL;
+	_tmp2 = NULL;
+	vala_attribute_add_argument (attr, (_tmp4 = vala_named_argument_new ("type", VALA_EXPRESSION ((_tmp3 = vala_string_literal_new ((_tmp2 = g_strdup_printf ("\"%s\"", ctype)), NULL))), NULL)));
+	(_tmp4 == NULL ? NULL : (_tmp4 = (g_object_unref (_tmp4), NULL)));
+	(_tmp3 == NULL ? NULL : (_tmp3 = (g_object_unref (_tmp3), NULL)));
+	_tmp2 = (g_free (_tmp2), NULL);
+	(attr == NULL ? NULL : (attr = (g_object_unref (attr), NULL)));
+}
+
+
 ValaDataType* vala_field_get_field_type (ValaField* self) {
 	g_return_val_if_fail (VALA_IS_FIELD (self), NULL);
 	return self->priv->_data_type;
