@@ -73,7 +73,7 @@ ValaForeachStatement* vala_foreach_statement_new (ValaDataType* type_reference,
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaForeachStatement * self;
-	g_return_val_if_fail (VALA_IS_DATA_TYPE (type_reference), NULL);
+	g_return_val_if_fail (type_reference == NULL || VALA_IS_DATA_TYPE (type_reference), NULL);
 	g_return_val_if_fail (variable_name != NULL, NULL);
 	g_return_val_if_fail (VALA_IS_EXPRESSION (collection), NULL);
 	g_return_val_if_fail (VALA_IS_BLOCK (body), NULL);
@@ -113,9 +113,11 @@ static void vala_foreach_statement_real_accept_children (ValaCodeNode* base, Val
 	ValaForeachStatement * self;
 	self = VALA_FOREACH_STATEMENT (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
-	vala_code_node_accept (VALA_CODE_NODE (vala_foreach_statement_get_type_reference (self)), visitor);
 	vala_code_node_accept (VALA_CODE_NODE (vala_foreach_statement_get_collection (self)), visitor);
 	vala_code_visitor_visit_end_full_expression (visitor, vala_foreach_statement_get_collection (self));
+	if (vala_foreach_statement_get_type_reference (self) != NULL) {
+		vala_code_node_accept (VALA_CODE_NODE (vala_foreach_statement_get_type_reference (self)), visitor);
+	}
 	vala_code_node_accept (VALA_CODE_NODE (vala_foreach_statement_get_body (self)), visitor);
 }
 
@@ -155,11 +157,13 @@ void vala_foreach_statement_set_type_reference (ValaForeachStatement* self, Vala
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL))), _tmp2);
-	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_data_type), VALA_CODE_NODE (self));
+	if (self->priv->_data_type != NULL) {
+		vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_data_type), VALA_CODE_NODE (self));
+	}
 }
 
 
-char* vala_foreach_statement_get_variable_name (ValaForeachStatement* self) {
+const char* vala_foreach_statement_get_variable_name (ValaForeachStatement* self) {
 	g_return_val_if_fail (VALA_IS_FOREACH_STATEMENT (self), NULL);
 	return self->priv->_variable_name;
 }
@@ -341,7 +345,7 @@ static void vala_foreach_statement_class_init (ValaForeachStatementClass * klass
 }
 
 
-static void vala_foreach_statement_init (ValaForeachStatement * self) {
+static void vala_foreach_statement_instance_init (ValaForeachStatement * self) {
 	self->priv = VALA_FOREACH_STATEMENT_GET_PRIVATE (self);
 }
 
@@ -363,7 +367,7 @@ static void vala_foreach_statement_dispose (GObject * obj) {
 GType vala_foreach_statement_get_type (void) {
 	static GType vala_foreach_statement_type_id = 0;
 	if (G_UNLIKELY (vala_foreach_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaForeachStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_foreach_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaForeachStatement), 0, (GInstanceInitFunc) vala_foreach_statement_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaForeachStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_foreach_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaForeachStatement), 0, (GInstanceInitFunc) vala_foreach_statement_instance_init };
 		vala_foreach_statement_type_id = g_type_register_static (VALA_TYPE_BLOCK, "ValaForeachStatement", &g_define_type_info, 0);
 	}
 	return vala_foreach_statement_type_id;
