@@ -59,7 +59,7 @@ struct _ValaForeachStatementClass {
 ValaForeachStatement* vala_foreach_statement_new (ValaDataType* type_reference, const char* variable_name, ValaExpression* collection, ValaBlock* body, ValaSourceReference* source_reference);
 ValaDataType* vala_foreach_statement_get_type_reference (ValaForeachStatement* self);
 void vala_foreach_statement_set_type_reference (ValaForeachStatement* self, ValaDataType* value);
-char* vala_foreach_statement_get_variable_name (ValaForeachStatement* self);
+const char* vala_foreach_statement_get_variable_name (ValaForeachStatement* self);
 void vala_foreach_statement_set_variable_name (ValaForeachStatement* self, const char* value);
 ValaExpression* vala_foreach_statement_get_collection (ValaForeachStatement* self);
 void vala_foreach_statement_set_collection (ValaForeachStatement* self, ValaExpression* value);
