@@ -42,10 +42,11 @@ struct _ValaFormalParameterPrivate {
 	double _cdelegate_target_parameter_position;
 	ValaDataType* _data_type;
 };
+
 #define VALA_FORMAL_PARAMETER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_FORMAL_PARAMETER, ValaFormalParameterPrivate))
 enum  {
 	VALA_FORMAL_PARAMETER_DUMMY_PROPERTY,
-	VALA_FORMAL_PARAMETER_TYPE_REFERENCE,
+	VALA_FORMAL_PARAMETER_PARAMETER_TYPE,
 	VALA_FORMAL_PARAMETER_DIRECTION,
 	VALA_FORMAL_PARAMETER_ELLIPSIS,
 	VALA_FORMAL_PARAMETER_DEFAULT_EXPRESSION,
@@ -74,15 +75,15 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  * @param source reference to source code
  * @return       newly created formal parameter
  */
-ValaFormalParameter* vala_formal_parameter_new (const char* _name, ValaDataType* type, ValaSourceReference* source) {
+ValaFormalParameter* vala_formal_parameter_new (const char* name, ValaDataType* parameter_type, ValaSourceReference* source_reference) {
 	ValaFormalParameter * self;
-	g_return_val_if_fail (_name != NULL, NULL);
-	g_return_val_if_fail (VALA_IS_DATA_TYPE (type), NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (parameter_type), NULL);
+	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_FORMAL_PARAMETER, 0, NULL);
-	vala_symbol_set_name (VALA_SYMBOL (self), _name);
-	vala_formal_parameter_set_type_reference (self, type);
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
+	vala_formal_parameter_set_parameter_type (self, parameter_type);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
@@ -114,7 +115,7 @@ static void vala_formal_parameter_real_accept_children (ValaCodeNode* base, Vala
 	self = VALA_FORMAL_PARAMETER (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (!self->priv->_ellipsis) {
-		vala_code_node_accept (VALA_CODE_NODE (vala_formal_parameter_get_type_reference (self)), visitor);
+		vala_code_node_accept (VALA_CODE_NODE (vala_formal_parameter_get_parameter_type (self)), visitor);
 		if (self->priv->_default_expression != NULL) {
 			vala_code_node_accept (VALA_CODE_NODE (self->priv->_default_expression), visitor);
 		}
@@ -127,8 +128,8 @@ static void vala_formal_parameter_real_replace_type (ValaCodeNode* base, ValaDat
 	self = VALA_FORMAL_PARAMETER (base);
 	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
 	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
-	if (vala_formal_parameter_get_type_reference (self) == old_type) {
-		vala_formal_parameter_set_type_reference (self, new_type);
+	if (vala_formal_parameter_get_parameter_type (self) == old_type) {
+		vala_formal_parameter_set_parameter_type (self, new_type);
 	}
 }
 
@@ -158,7 +159,7 @@ void vala_formal_parameter_process_attributes (ValaFormalParameter* self) {
 			ValaAttribute* _tmp0;
 			ValaAttribute* a;
 			_tmp0 = NULL;
-			a = (_tmp0 = ((ValaAttribute*) a_it->data), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+			a = (_tmp0 = ((ValaAttribute*) (a_it->data)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
 					vala_formal_parameter_process_ccode_attribute (self, a);
@@ -174,7 +175,7 @@ ValaFormalParameter* vala_formal_parameter_copy (ValaFormalParameter* self) {
 	g_return_val_if_fail (VALA_IS_FORMAL_PARAMETER (self), NULL);
 	if (!self->priv->_ellipsis) {
 		ValaFormalParameter* result;
-		result = vala_formal_parameter_new (vala_symbol_get_name (VALA_SYMBOL (self)), vala_formal_parameter_get_type_reference (self), vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
+		result = vala_formal_parameter_new (vala_symbol_get_name (VALA_SYMBOL (self)), vala_formal_parameter_get_parameter_type (self), vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
 		return result;
 	} else {
 		return vala_formal_parameter_new_with_ellipsis (NULL);
@@ -182,13 +183,13 @@ ValaFormalParameter* vala_formal_parameter_copy (ValaFormalParameter* self) {
 }
 
 
-ValaDataType* vala_formal_parameter_get_type_reference (ValaFormalParameter* self) {
+ValaDataType* vala_formal_parameter_get_parameter_type (ValaFormalParameter* self) {
 	g_return_val_if_fail (VALA_IS_FORMAL_PARAMETER (self), NULL);
 	return self->priv->_data_type;
 }
 
 
-void vala_formal_parameter_set_type_reference (ValaFormalParameter* self, ValaDataType* value) {
+void vala_formal_parameter_set_parameter_type (ValaFormalParameter* self, ValaDataType* value) {
 	ValaDataType* _tmp2;
 	ValaDataType* _tmp1;
 	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (self));
@@ -319,8 +320,8 @@ static void vala_formal_parameter_get_property (GObject * object, guint property
 	ValaFormalParameter * self;
 	self = VALA_FORMAL_PARAMETER (object);
 	switch (property_id) {
-		case VALA_FORMAL_PARAMETER_TYPE_REFERENCE:
-		g_value_set_object (value, vala_formal_parameter_get_type_reference (self));
+		case VALA_FORMAL_PARAMETER_PARAMETER_TYPE:
+		g_value_set_object (value, vala_formal_parameter_get_parameter_type (self));
 		break;
 		case VALA_FORMAL_PARAMETER_DIRECTION:
 		g_value_set_enum (value, vala_formal_parameter_get_direction (self));
@@ -357,8 +358,8 @@ static void vala_formal_parameter_set_property (GObject * object, guint property
 	ValaFormalParameter * self;
 	self = VALA_FORMAL_PARAMETER (object);
 	switch (property_id) {
-		case VALA_FORMAL_PARAMETER_TYPE_REFERENCE:
-		vala_formal_parameter_set_type_reference (self, g_value_get_object (value));
+		case VALA_FORMAL_PARAMETER_PARAMETER_TYPE:
+		vala_formal_parameter_set_parameter_type (self, g_value_get_object (value));
 		break;
 		case VALA_FORMAL_PARAMETER_DIRECTION:
 		vala_formal_parameter_set_direction (self, g_value_get_enum (value));
@@ -401,7 +402,7 @@ static void vala_formal_parameter_class_init (ValaFormalParameterClass * klass)
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_formal_parameter_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_formal_parameter_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_formal_parameter_real_replace_type;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_PARAMETER_TYPE, g_param_spec_object ("parameter-type", "parameter-type", "parameter-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_DIRECTION, g_param_spec_enum ("direction", "direction", "direction", VALA_TYPE_PARAMETER_DIRECTION, VALA_PARAMETER_DIRECTION_IN, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_ELLIPSIS, g_param_spec_boolean ("ellipsis", "ellipsis", "ellipsis", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FORMAL_PARAMETER_DEFAULT_EXPRESSION, g_param_spec_object ("default-expression", "default-expression", "default-expression", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -413,7 +414,7 @@ static void vala_formal_parameter_class_init (ValaFormalParameterClass * klass)
 }
 
 
-static void vala_formal_parameter_init (ValaFormalParameter * self) {
+static void vala_formal_parameter_instance_init (ValaFormalParameter * self) {
 	self->priv = VALA_FORMAL_PARAMETER_GET_PRIVATE (self);
 	self->priv->_direction = VALA_PARAMETER_DIRECTION_IN;
 }
@@ -431,7 +432,7 @@ static void vala_formal_parameter_dispose (GObject * obj) {
 GType vala_formal_parameter_get_type (void) {
 	static GType vala_formal_parameter_type_id = 0;
 	if (G_UNLIKELY (vala_formal_parameter_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaFormalParameterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_formal_parameter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaFormalParameter), 0, (GInstanceInitFunc) vala_formal_parameter_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaFormalParameterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_formal_parameter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaFormalParameter), 0, (GInstanceInitFunc) vala_formal_parameter_instance_init };
 		vala_formal_parameter_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaFormalParameter", &g_define_type_info, 0);
 	}
 	return vala_formal_parameter_type_id;
