@@ -25,7 +25,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <gee/collection.h>
+#include <gee/list.h>
 #include <vala/valacodenode.h>
 #include <vala/valastatement.h>
 
@@ -48,15 +48,17 @@ struct _ValaForStatement {
 	ValaCodeNode parent_instance;
 	ValaForStatementPrivate * priv;
 };
+
 struct _ValaForStatementClass {
 	ValaCodeNodeClass parent_class;
 };
 
+
 ValaForStatement* vala_for_statement_new (ValaExpression* condition, ValaBlock* body, ValaSourceReference* source_reference);
 void vala_for_statement_add_initializer (ValaForStatement* self, ValaExpression* init);
-GeeCollection* vala_for_statement_get_initializer (ValaForStatement* self);
+GeeList* vala_for_statement_get_initializer (ValaForStatement* self);
 void vala_for_statement_add_iterator (ValaForStatement* self, ValaExpression* iter);
-GeeCollection* vala_for_statement_get_iterator (ValaForStatement* self);
+GeeList* vala_for_statement_get_iterator (ValaForStatement* self);
 ValaExpression* vala_for_statement_get_condition (ValaForStatement* self);
 void vala_for_statement_set_condition (ValaForStatement* self, ValaExpression* value);
 ValaBlock* vala_for_statement_get_body (ValaForStatement* self);
