@@ -1,11 +1,11 @@
 /* valainitializerlist.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter, Raffaele Sandrini
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,13 +18,15 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
+ * 	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
-#ifndef __VALAINITIALIZERLIST_H__
-#define __VALAINITIALIZERLIST_H__
+#ifndef __VALA_VALAINITIALIZERLIST_H__
+#define __VALA_VALAINITIALIZERLIST_H__
 
 #include <glib.h>
 #include <glib-object.h>
+#include <gee/list.h>
 #include <vala/valaexpression.h>
 #include <vala/valacodenode.h>
 
@@ -44,17 +46,21 @@ typedef struct _ValaInitializerListPrivate ValaInitializerListPrivate;
  * Represents an array or struct initializer list in the source code.
  */
 struct _ValaInitializerList {
-	ValaExpression parent;
+	ValaExpression parent_instance;
 	ValaInitializerListPrivate * priv;
 };
+
 struct _ValaInitializerListClass {
-	ValaExpressionClass parent;
+	ValaExpressionClass parent_class;
 };
 
+
 void vala_initializer_list_append (ValaInitializerList* self, ValaExpression* expr);
-GList* vala_initializer_list_get_initializers (ValaInitializerList* self);
-ValaInitializerList* vala_initializer_list_new (ValaSourceReference* source);
-GType vala_initializer_list_get_type ();
+GeeList* vala_initializer_list_get_initializers (ValaInitializerList* self);
+ValaInitializerList* vala_initializer_list_new (ValaSourceReference* source_reference);
+gint vala_initializer_list_get_size (ValaInitializerList* self);
+GType vala_initializer_list_get_type (void);
+
 
 G_END_DECLS
 
