@@ -56,9 +56,9 @@ struct _ValaInstanceCastClass {
 };
 
 
-ValaInstanceCast* vala_instance_cast_new (ValaCCodeExpression* expr, ValaTypesymbol* type);
-ValaTypesymbol* vala_instance_cast_get_type_reference (ValaInstanceCast* self);
-void vala_instance_cast_set_type_reference (ValaInstanceCast* self, ValaTypesymbol* value);
+ValaInstanceCast* vala_instance_cast_new (ValaCCodeExpression* expr, ValaTypeSymbol* type);
+ValaTypeSymbol* vala_instance_cast_get_type_reference (ValaInstanceCast* self);
+void vala_instance_cast_set_type_reference (ValaInstanceCast* self, ValaTypeSymbol* value);
 ValaCCodeExpression* vala_instance_cast_get_inner (ValaInstanceCast* self);
 void vala_instance_cast_set_inner (ValaInstanceCast* self, ValaCCodeExpression* value);
 GType vala_instance_cast_get_type (void);
