@@ -1,6 +1,6 @@
 /* valaintegerliteral.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -23,10 +23,15 @@
 #include <vala/valaintegerliteral.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
+#include <vala/valaexpression.h>
+
+
+
 
 struct _ValaIntegerLiteralPrivate {
 	char* _value;
 };
+
 #define VALA_INTEGER_LITERAL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_INTEGER_LITERAL, ValaIntegerLiteralPrivate))
 enum  {
 	VALA_INTEGER_LITERAL_DUMMY_PROPERTY,
@@ -34,10 +39,12 @@ enum  {
 };
 static void vala_integer_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static char* vala_integer_literal_real_to_string (ValaCodeNode* base);
+static gboolean vala_integer_literal_real_is_pure (ValaExpression* base);
 static gpointer vala_integer_literal_parent_class = NULL;
 static void vala_integer_literal_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new integer literal.
  *
@@ -47,6 +54,7 @@ static void vala_integer_literal_dispose (GObject * obj);
  */
 ValaIntegerLiteral* vala_integer_literal_new (const char* i, ValaSourceReference* source) {
 	ValaIntegerLiteral * self;
+	g_return_val_if_fail (i != NULL, NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
 	self = g_object_newv (VALA_TYPE_INTEGER_LITERAL, 0, NULL);
 	vala_integer_literal_set_value (self, i);
@@ -58,8 +66,9 @@ ValaIntegerLiteral* vala_integer_literal_new (const char* i, ValaSourceReference
 static void vala_integer_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaIntegerLiteral * self;
 	self = VALA_INTEGER_LITERAL (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_integer_literal (visitor, self);
+	vala_code_visitor_visit_expression (visitor, VALA_EXPRESSION (self));
 }
 
 
@@ -68,7 +77,7 @@ static char* vala_integer_literal_real_to_string (ValaCodeNode* base) {
 	const char* _tmp0;
 	self = VALA_INTEGER_LITERAL (base);
 	_tmp0 = NULL;
-	return (_tmp0 = vala_integer_literal_get_value (self), (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
+	return (_tmp0 = self->priv->_value, (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
 }
 
 
@@ -85,20 +94,20 @@ char* vala_integer_literal_get_type_name (ValaIntegerLiteral* self) {
 	gint64 n;
 	g_return_val_if_fail (VALA_IS_INTEGER_LITERAL (self), NULL);
 	_tmp0 = NULL;
-	number = (_tmp0 = vala_integer_literal_get_value (self), (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
+	number = (_tmp0 = self->priv->_value, (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
 	l = 0;
-	while (g_str_has_suffix (number, "L")) {
+	while (g_str_has_suffix (number, "l") || g_str_has_suffix (number, "L")) {
 		char* _tmp1;
 		l++;
 		_tmp1 = NULL;
-		number = (_tmp1 = g_strndup (number, ((gulong) strlen (number) - 1)), (number = (g_free (number), NULL)), _tmp1);
+		number = (_tmp1 = g_strndup (number, ((gulong) (strlen (number) - 1))), (number = (g_free (number), NULL)), _tmp1);
 	}
 	u = FALSE;
-	if (g_str_has_suffix (number, "U")) {
+	if (g_str_has_suffix (number, "u") || g_str_has_suffix (number, "U")) {
 		char* _tmp2;
 		u = TRUE;
 		_tmp2 = NULL;
-		number = (_tmp2 = g_strndup (number, ((gulong) strlen (number) - 1)), (number = (g_free (number), NULL)), _tmp2);
+		number = (_tmp2 = g_strndup (number, ((gulong) (strlen (number) - 1))), (number = (g_free (number), NULL)), _tmp2);
 	}
 	n = g_ascii_strtoll (number, NULL, 0);
 	if (!u && n > 0x7fffffff) {
@@ -147,7 +156,14 @@ char* vala_integer_literal_get_type_name (ValaIntegerLiteral* self) {
 }
 
 
-char* vala_integer_literal_get_value (ValaIntegerLiteral* self) {
+static gboolean vala_integer_literal_real_is_pure (ValaExpression* base) {
+	ValaIntegerLiteral * self;
+	self = VALA_INTEGER_LITERAL (base);
+	return TRUE;
+}
+
+
+const char* vala_integer_literal_get_value (ValaIntegerLiteral* self) {
 	g_return_val_if_fail (VALA_IS_INTEGER_LITERAL (self), NULL);
 	return self->priv->_value;
 }
@@ -199,11 +215,12 @@ static void vala_integer_literal_class_init (ValaIntegerLiteralClass * klass) {
 	G_OBJECT_CLASS (klass)->dispose = vala_integer_literal_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_integer_literal_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->to_string = vala_integer_literal_real_to_string;
+	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_integer_literal_real_is_pure;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INTEGER_LITERAL_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_integer_literal_init (ValaIntegerLiteral * self) {
+static void vala_integer_literal_instance_init (ValaIntegerLiteral * self) {
 	self->priv = VALA_INTEGER_LITERAL_GET_PRIVATE (self);
 }
 
@@ -219,7 +236,7 @@ static void vala_integer_literal_dispose (GObject * obj) {
 GType vala_integer_literal_get_type (void) {
 	static GType vala_integer_literal_type_id = 0;
 	if (G_UNLIKELY (vala_integer_literal_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaIntegerLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_integer_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaIntegerLiteral), 0, (GInstanceInitFunc) vala_integer_literal_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaIntegerLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_integer_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaIntegerLiteral), 0, (GInstanceInitFunc) vala_integer_literal_instance_init };
 		vala_integer_literal_type_id = g_type_register_static (VALA_TYPE_LITERAL, "ValaIntegerLiteral", &g_define_type_info, 0);
 	}
 	return vala_integer_literal_type_id;
