@@ -48,7 +48,7 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
 
-ValaIntegerType* vala_integer_type_new (ValaTypesymbol* type_symbol) {
+ValaIntegerType* vala_integer_type_new (ValaTypeSymbol* type_symbol) {
 	ValaIntegerType * self;
 	g_return_val_if_fail (VALA_IS_TYPESYMBOL (type_symbol), NULL);
 	self = g_object_newv (VALA_TYPE_INTEGER_TYPE, 0, NULL);
@@ -64,6 +64,7 @@ static ValaDataType* vala_integer_type_real_copy (ValaDataType* base) {
 	self = VALA_INTEGER_TYPE (base);
 	type = vala_integer_type_new (vala_value_type_get_type_symbol (VALA_VALUE_TYPE (self)));
 	vala_integer_type_set_literal (type, self->priv->_literal);
+	vala_data_type_set_is_type_argument (VALA_DATA_TYPE (type), vala_data_type_get_is_type_argument (VALA_DATA_TYPE (self)));
 	return VALA_DATA_TYPE (type);
 }
 
@@ -170,7 +171,7 @@ static void vala_integer_type_class_init (ValaIntegerTypeClass * klass) {
 }
 
 
-static void vala_integer_type_init (ValaIntegerType * self) {
+static void vala_integer_type_instance_init (ValaIntegerType * self) {
 	self->priv = VALA_INTEGER_TYPE_GET_PRIVATE (self);
 }
 
@@ -186,7 +187,7 @@ static void vala_integer_type_dispose (GObject * obj) {
 GType vala_integer_type_get_type (void) {
 	static GType vala_integer_type_type_id = 0;
 	if (G_UNLIKELY (vala_integer_type_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaIntegerTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_integer_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaIntegerType), 0, (GInstanceInitFunc) vala_integer_type_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaIntegerTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_integer_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaIntegerType), 0, (GInstanceInitFunc) vala_integer_type_instance_init };
 		vala_integer_type_type_id = g_type_register_static (VALA_TYPE_VALUE_TYPE, "ValaIntegerType", &g_define_type_info, 0);
 	}
 	return vala_integer_type_type_id;
