@@ -57,19 +57,17 @@ static ValaDataType* vala_interface_type_real_copy (ValaDataType* base) {
 	self = VALA_INTERFACE_TYPE (base);
 	result = vala_interface_type_new (self->priv->_interface_symbol);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (result), vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
-	vala_data_type_set_transfers_ownership (VALA_DATA_TYPE (result), vala_data_type_get_transfers_ownership (VALA_DATA_TYPE (self)));
-	vala_data_type_set_takes_ownership (VALA_DATA_TYPE (result), vala_data_type_get_takes_ownership (VALA_DATA_TYPE (self)));
+	vala_data_type_set_value_owned (VALA_DATA_TYPE (result), vala_data_type_get_value_owned (VALA_DATA_TYPE (self)));
 	vala_data_type_set_nullable (VALA_DATA_TYPE (result), vala_data_type_get_nullable (VALA_DATA_TYPE (self)));
 	vala_data_type_set_is_dynamic (VALA_DATA_TYPE (result), vala_data_type_get_is_dynamic (VALA_DATA_TYPE (self)));
 	vala_data_type_set_floating_reference (VALA_DATA_TYPE (result), vala_data_type_get_floating_reference (VALA_DATA_TYPE (self)));
 	{
 		GeeList* arg_collection;
-		GeeIterator* arg_it;
+		int arg_it;
 		arg_collection = vala_data_type_get_type_arguments (VALA_DATA_TYPE (self));
-		arg_it = gee_iterable_iterator (GEE_ITERABLE (arg_collection));
-		while (gee_iterator_next (arg_it)) {
+		for (arg_it = 0; arg_it < gee_collection_get_size (GEE_COLLECTION (arg_collection)); arg_it = arg_it + 1) {
 			ValaDataType* arg;
-			arg = ((ValaDataType*) gee_iterator_get (arg_it));
+			arg = ((ValaDataType*) (gee_list_get (GEE_LIST (arg_collection), arg_it)));
 			{
 				ValaDataType* _tmp0;
 				_tmp0 = NULL;
@@ -79,7 +77,6 @@ static ValaDataType* vala_interface_type_real_copy (ValaDataType* base) {
 			}
 		}
 		(arg_collection == NULL ? NULL : (arg_collection = (g_object_unref (arg_collection), NULL)));
-		(arg_it == NULL ? NULL : (arg_it = (g_object_unref (arg_it), NULL)));
 	}
 	return VALA_DATA_TYPE (result);
 }
@@ -148,7 +145,7 @@ static void vala_interface_type_class_init (ValaInterfaceTypeClass * klass) {
 }
 
 
-static void vala_interface_type_init (ValaInterfaceType * self) {
+static void vala_interface_type_instance_init (ValaInterfaceType * self) {
 	self->priv = VALA_INTERFACE_TYPE_GET_PRIVATE (self);
 }
 
@@ -163,7 +160,7 @@ static void vala_interface_type_dispose (GObject * obj) {
 GType vala_interface_type_get_type (void) {
 	static GType vala_interface_type_type_id = 0;
 	if (G_UNLIKELY (vala_interface_type_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaInterfaceTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_interface_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInterfaceType), 0, (GInstanceInitFunc) vala_interface_type_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaInterfaceTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_interface_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaInterfaceType), 0, (GInstanceInitFunc) vala_interface_type_instance_init };
 		vala_interface_type_type_id = g_type_register_static (VALA_TYPE_REFERENCE_TYPE, "ValaInterfaceType", &g_define_type_info, 0);
 	}
 	return vala_interface_type_type_id;
