@@ -22,8 +22,8 @@
 
 #include <vala/valalambdaexpression.h>
 #include <gee/arraylist.h>
-#include <gee/list.h>
-#include <gee/readonlycollection.h>
+#include <gee/collection.h>
+#include <gee/readonlylist.h>
 #include <vala/valablock.h>
 #include <vala/valamethod.h>
 #include <vala/valasourcereference.h>
@@ -38,6 +38,7 @@ struct _ValaLambdaExpressionPrivate {
 	ValaMethod* _method;
 	GeeList* parameters;
 };
+
 #define VALA_LAMBDA_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_LAMBDA_EXPRESSION, ValaLambdaExpressionPrivate))
 enum  {
 	VALA_LAMBDA_EXPRESSION_DUMMY_PROPERTY,
@@ -106,9 +107,9 @@ void vala_lambda_expression_add_parameter (ValaLambdaExpression* self, const cha
  *
  * @return parameter list
  */
-GeeCollection* vala_lambda_expression_get_parameters (ValaLambdaExpression* self) {
+GeeList* vala_lambda_expression_get_parameters (ValaLambdaExpression* self) {
 	g_return_val_if_fail (VALA_IS_LAMBDA_EXPRESSION (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, GEE_COLLECTION (self->priv->parameters)));
+	return GEE_LIST (gee_read_only_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, self->priv->parameters));
 }
 
 
@@ -117,6 +118,7 @@ static void vala_lambda_expression_real_accept (ValaCodeNode* base, ValaCodeVisi
 	self = VALA_LAMBDA_EXPRESSION (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_lambda_expression (visitor, self);
+	vala_code_visitor_visit_expression (visitor, VALA_EXPRESSION (self));
 }
 
 
@@ -249,9 +251,9 @@ static void vala_lambda_expression_class_init (ValaLambdaExpressionClass * klass
 }
 
 
-static void vala_lambda_expression_init (ValaLambdaExpression * self) {
+static void vala_lambda_expression_instance_init (ValaLambdaExpression * self) {
 	self->priv = VALA_LAMBDA_EXPRESSION_GET_PRIVATE (self);
-	self->priv->parameters = GEE_LIST (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, g_direct_equal));
+	self->priv->parameters = GEE_LIST (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_direct_equal));
 }
 
 
@@ -269,7 +271,7 @@ static void vala_lambda_expression_dispose (GObject * obj) {
 GType vala_lambda_expression_get_type (void) {
 	static GType vala_lambda_expression_type_id = 0;
 	if (G_UNLIKELY (vala_lambda_expression_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaLambdaExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_lambda_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaLambdaExpression), 0, (GInstanceInitFunc) vala_lambda_expression_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaLambdaExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_lambda_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaLambdaExpression), 0, (GInstanceInitFunc) vala_lambda_expression_instance_init };
 		vala_lambda_expression_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaLambdaExpression", &g_define_type_info, 0);
 	}
 	return vala_lambda_expression_type_id;
