@@ -46,14 +46,14 @@ static void vala_literal_class_init (ValaLiteralClass * klass) {
 }
 
 
-static void vala_literal_init (ValaLiteral * self) {
+static void vala_literal_instance_init (ValaLiteral * self) {
 }
 
 
 GType vala_literal_get_type (void) {
 	static GType vala_literal_type_id = 0;
 	if (G_UNLIKELY (vala_literal_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaLiteral), 0, (GInstanceInitFunc) vala_literal_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaLiteral), 0, (GInstanceInitFunc) vala_literal_instance_init };
 		vala_literal_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaLiteral", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
 	return vala_literal_type_id;
