@@ -1,11 +1,11 @@
 /* valalockable.vala
  *
- * Copyright (C) 2006  Raffaele Sandrini
+ * Copyright (C) 2006-2007  Raffaele Sandrini, Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,27 +17,35 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
  *
  * Author:
- * 	Raffaele Sandrini <rasa@gmx.ch>
+ * 	Raffaele Sandrini <raffaele@sandrini.ch>
+ * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valalockable.h"
+#include <vala/valalockable.h>
 
 
 
-gboolean vala_lockable_get_lock_used (ValaLockable* self)
-{
+
+
+
+
+/**
+ * Indicates a specific lockable object beeing actually locked somewhere.
+ */
+gboolean vala_lockable_get_lock_used (ValaLockable* self) {
 	return VALA_LOCKABLE_GET_INTERFACE (self)->get_lock_used (self);
 }
 
 
-void vala_lockable_set_lock_used (ValaLockable* self, gboolean used)
-{
+/**
+ * Set this lockable object as beeing locked somewhere.
+ */
+void vala_lockable_set_lock_used (ValaLockable* self, gboolean used) {
 	VALA_LOCKABLE_GET_INTERFACE (self)->set_lock_used (self, used);
 }
 
 
-static void vala_lockable_base_init (ValaLockableIface * iface)
-{
+static void vala_lockable_base_init (ValaLockableIface * iface) {
 	static gboolean initialized = FALSE;
 	if (!initialized) {
 		initialized = TRUE;
@@ -45,8 +53,7 @@ static void vala_lockable_base_init (ValaLockableIface * iface)
 }
 
 
-GType vala_lockable_get_type (void)
-{
+GType vala_lockable_get_type (void) {
 	static GType vala_lockable_type_id = 0;
 	if (G_UNLIKELY (vala_lockable_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaLockableIface), (GBaseInitFunc) vala_lockable_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL };
