@@ -168,7 +168,7 @@ static void vala_lock_statement_vala_statement_interface_init (ValaStatementIfac
 }
 
 
-static void vala_lock_statement_init (ValaLockStatement * self) {
+static void vala_lock_statement_instance_init (ValaLockStatement * self) {
 	self->priv = VALA_LOCK_STATEMENT_GET_PRIVATE (self);
 }
 
@@ -185,7 +185,7 @@ static void vala_lock_statement_dispose (GObject * obj) {
 GType vala_lock_statement_get_type (void) {
 	static GType vala_lock_statement_type_id = 0;
 	if (G_UNLIKELY (vala_lock_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaLockStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_lock_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaLockStatement), 0, (GInstanceInitFunc) vala_lock_statement_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaLockStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_lock_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaLockStatement), 0, (GInstanceInitFunc) vala_lock_statement_instance_init };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_lock_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_lock_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaLockStatement", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_lock_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
