@@ -49,12 +49,14 @@ struct _ValaMemberInitializer {
 	ValaCodeNode parent_instance;
 	ValaMemberInitializerPrivate * priv;
 };
+
 struct _ValaMemberInitializerClass {
 	ValaCodeNodeClass parent_class;
 };
 
+
 ValaMemberInitializer* vala_member_initializer_new (const char* name, ValaExpression* initializer, ValaSourceReference* source_reference);
-char* vala_member_initializer_get_name (ValaMemberInitializer* self);
+const char* vala_member_initializer_get_name (ValaMemberInitializer* self);
 void vala_member_initializer_set_name (ValaMemberInitializer* self, const char* value);
 ValaExpression* vala_member_initializer_get_initializer (ValaMemberInitializer* self);
 void vala_member_initializer_set_initializer (ValaMemberInitializer* self, ValaExpression* value);
@@ -62,6 +64,7 @@ ValaSymbol* vala_member_initializer_get_symbol_reference (ValaMemberInitializer*
 void vala_member_initializer_set_symbol_reference (ValaMemberInitializer* self, ValaSymbol* value);
 GType vala_member_initializer_get_type (void);
 
+
 G_END_DECLS
 
 #endif
