@@ -1,6 +1,6 @@
 /* valanamedargument.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -53,25 +53,25 @@ static void vala_named_argument_dispose (GObject * obj);
  * @param source reference to source code
  * @return       newly created named argument
  */
-ValaNamedArgument* vala_named_argument_new (const char* _name, ValaExpression* arg, ValaSourceReference* source) {
+ValaNamedArgument* vala_named_argument_new (const char* name, ValaExpression* argument, ValaSourceReference* source_reference) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaNamedArgument * self;
-	g_return_val_if_fail (_name != NULL, NULL);
-	g_return_val_if_fail (VALA_IS_EXPRESSION (arg), NULL);
-	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (argument), NULL);
+	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
 	__params_it->name = "name";
 	g_value_init (&__params_it->value, G_TYPE_STRING);
-	g_value_set_string (&__params_it->value, _name);
+	g_value_set_string (&__params_it->value, name);
 	__params_it++;
 	__params_it->name = "argument";
 	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
-	g_value_set_object (&__params_it->value, arg);
+	g_value_set_object (&__params_it->value, argument);
 	__params_it++;
 	self = g_object_newv (VALA_TYPE_NAMED_ARGUMENT, __params_it - __params, __params);
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	while (__params_it > __params) {
 		--__params_it;
 		g_value_unset (&__params_it->value);
@@ -90,7 +90,7 @@ static void vala_named_argument_real_accept (ValaCodeNode* base, ValaCodeVisitor
 }
 
 
-char* vala_named_argument_get_name (ValaNamedArgument* self) {
+const char* vala_named_argument_get_name (ValaNamedArgument* self) {
 	g_return_val_if_fail (VALA_IS_NAMED_ARGUMENT (self), NULL);
 	return self->priv->_name;
 }
@@ -168,7 +168,7 @@ static void vala_named_argument_class_init (ValaNamedArgumentClass * klass) {
 }
 
 
-static void vala_named_argument_init (ValaNamedArgument * self) {
+static void vala_named_argument_instance_init (ValaNamedArgument * self) {
 	self->priv = VALA_NAMED_ARGUMENT_GET_PRIVATE (self);
 }
 
@@ -185,7 +185,7 @@ static void vala_named_argument_dispose (GObject * obj) {
 GType vala_named_argument_get_type (void) {
 	static GType vala_named_argument_type_id = 0;
 	if (G_UNLIKELY (vala_named_argument_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaNamedArgumentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_named_argument_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaNamedArgument), 0, (GInstanceInitFunc) vala_named_argument_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaNamedArgumentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_named_argument_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaNamedArgument), 0, (GInstanceInitFunc) vala_named_argument_instance_init };
 		vala_named_argument_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaNamedArgument", &g_define_type_info, 0);
 	}
 	return vala_named_argument_type_id;
