@@ -1,6 +1,6 @@
 /* valanamedargument.vala
  *
- * Copyright (C) 2006  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -55,8 +55,8 @@ struct _ValaNamedArgumentClass {
 };
 
 
-ValaNamedArgument* vala_named_argument_new (const char* _name, ValaExpression* arg, ValaSourceReference* source);
-char* vala_named_argument_get_name (ValaNamedArgument* self);
+ValaNamedArgument* vala_named_argument_new (const char* name, ValaExpression* argument, ValaSourceReference* source_reference);
+const char* vala_named_argument_get_name (ValaNamedArgument* self);
 void vala_named_argument_set_name (ValaNamedArgument* self, const char* value);
 ValaExpression* vala_named_argument_get_argument (ValaNamedArgument* self);
 void vala_named_argument_set_argument (ValaNamedArgument* self, ValaExpression* value);
