@@ -1,6 +1,6 @@
 /* valanamespacereference.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -32,6 +32,7 @@ struct _ValaNamespaceReferencePrivate {
 	char* _name;
 	ValaSymbol* _namespace_symbol;
 };
+
 #define VALA_NAMESPACE_REFERENCE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_NAMESPACE_REFERENCE, ValaNamespaceReferencePrivate))
 enum  {
 	VALA_NAMESPACE_REFERENCE_DUMMY_PROPERTY,
@@ -53,6 +54,7 @@ static void vala_namespace_reference_dispose (GObject * obj);
  */
 ValaNamespaceReference* vala_namespace_reference_new (const char* name, ValaSourceReference* source_reference) {
 	ValaNamespaceReference * self;
+	g_return_val_if_fail (name != NULL, NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_NAMESPACE_REFERENCE, 0, NULL);
 	vala_namespace_reference_set_name (self, name);
@@ -64,12 +66,12 @@ ValaNamespaceReference* vala_namespace_reference_new (const char* name, ValaSour
 static void vala_namespace_reference_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaNamespaceReference * self;
 	self = VALA_NAMESPACE_REFERENCE (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_namespace_reference (visitor, self);
 }
 
 
-char* vala_namespace_reference_get_name (ValaNamespaceReference* self) {
+const char* vala_namespace_reference_get_name (ValaNamespaceReference* self) {
 	g_return_val_if_fail (VALA_IS_NAMESPACE_REFERENCE (self), NULL);
 	return self->priv->_name;
 }
@@ -143,7 +145,7 @@ static void vala_namespace_reference_class_init (ValaNamespaceReferenceClass * k
 }
 
 
-static void vala_namespace_reference_init (ValaNamespaceReference * self) {
+static void vala_namespace_reference_instance_init (ValaNamespaceReference * self) {
 	self->priv = VALA_NAMESPACE_REFERENCE_GET_PRIVATE (self);
 }
 
@@ -159,7 +161,7 @@ static void vala_namespace_reference_dispose (GObject * obj) {
 GType vala_namespace_reference_get_type (void) {
 	static GType vala_namespace_reference_type_id = 0;
 	if (G_UNLIKELY (vala_namespace_reference_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaNamespaceReferenceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_namespace_reference_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaNamespaceReference), 0, (GInstanceInitFunc) vala_namespace_reference_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaNamespaceReferenceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_namespace_reference_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaNamespaceReference), 0, (GInstanceInitFunc) vala_namespace_reference_instance_init };
 		vala_namespace_reference_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaNamespaceReference", &g_define_type_info, 0);
 	}
 	return vala_namespace_reference_type_id;
