@@ -23,6 +23,7 @@
 #include <vala/valanullliteral.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
+#include <vala/valaexpression.h>
 
 
 
@@ -55,8 +56,9 @@ ValaNullLiteral* vala_null_literal_new (ValaSourceReference* source) {
 static void vala_null_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaNullLiteral * self;
 	self = VALA_NULL_LITERAL (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_null_literal (visitor, self);
+	vala_code_visitor_visit_expression (visitor, VALA_EXPRESSION (self));
 }
 
 
@@ -82,14 +84,14 @@ static void vala_null_literal_class_init (ValaNullLiteralClass * klass) {
 }
 
 
-static void vala_null_literal_init (ValaNullLiteral * self) {
+static void vala_null_literal_instance_init (ValaNullLiteral * self) {
 }
 
 
 GType vala_null_literal_get_type (void) {
 	static GType vala_null_literal_type_id = 0;
 	if (G_UNLIKELY (vala_null_literal_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaNullLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_null_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaNullLiteral), 0, (GInstanceInitFunc) vala_null_literal_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaNullLiteralClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_null_literal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaNullLiteral), 0, (GInstanceInitFunc) vala_null_literal_instance_init };
 		vala_null_literal_type_id = g_type_register_static (VALA_TYPE_LITERAL, "ValaNullLiteral", &g_define_type_info, 0);
 	}
 	return vala_null_literal_type_id;
