@@ -21,8 +21,8 @@
  */
 
 #include <vala/valapointertype.h>
-#include <vala/valatypesymbol.h>
 #include <vala/valacodenode.h>
+#include <vala/valatypesymbol.h>
 #include <vala/valasemanticanalyzer.h>
 
 
@@ -31,71 +31,83 @@
 struct _ValaPointerTypePrivate {
 	ValaDataType* _base_type;
 };
+
 #define VALA_POINTER_TYPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_POINTER_TYPE, ValaPointerTypePrivate))
 enum  {
 	VALA_POINTER_TYPE_DUMMY_PROPERTY,
 	VALA_POINTER_TYPE_BASE_TYPE
 };
-static char* vala_pointer_type_real_to_string (ValaCodeNode* base);
-static char* vala_pointer_type_real_get_cname (ValaDataType* base, gboolean var_type, gboolean const_type);
+static char* vala_pointer_type_real_to_qualified_string (ValaDataType* base, ValaScope* scope);
+static char* vala_pointer_type_real_get_cname (ValaDataType* base);
 static ValaDataType* vala_pointer_type_real_copy (ValaDataType* base);
-static gboolean vala_pointer_type_real_compatible (ValaDataType* base, ValaDataType* target_type, gboolean enable_non_null);
+static gboolean vala_pointer_type_real_compatible (ValaDataType* base, ValaDataType* target_type);
 static ValaSymbol* vala_pointer_type_real_get_pointer_member (ValaDataType* base, const char* member_name);
-static GeeCollection* vala_pointer_type_real_get_symbols (ValaDataType* base);
+static GeeList* vala_pointer_type_real_get_symbols (ValaDataType* base);
 static char* vala_pointer_type_real_get_type_id (ValaDataType* base);
+static void vala_pointer_type_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
+static void vala_pointer_type_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
+static gboolean vala_pointer_type_real_is_disposable (ValaDataType* base);
 static gpointer vala_pointer_type_parent_class = NULL;
 static void vala_pointer_type_dispose (GObject * obj);
 
 
 
-ValaPointerType* vala_pointer_type_new (ValaDataType* base_type) {
+ValaPointerType* vala_pointer_type_new (ValaDataType* base_type, ValaSourceReference* source_reference) {
 	ValaPointerType * self;
-	g_return_val_if_fail (base_type == NULL || VALA_IS_DATA_TYPE (base_type), NULL);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (base_type), NULL);
+	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_POINTER_TYPE, 0, NULL);
 	vala_pointer_type_set_base_type (self, base_type);
+	vala_data_type_set_nullable (VALA_DATA_TYPE (self), TRUE);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
 
-static char* vala_pointer_type_real_to_string (ValaCodeNode* base) {
+static char* vala_pointer_type_real_to_qualified_string (ValaDataType* base, ValaScope* scope) {
 	ValaPointerType * self;
 	char* _tmp0;
 	char* _tmp1;
 	self = VALA_POINTER_TYPE (base);
+	g_return_val_if_fail (scope == NULL || VALA_IS_SCOPE (scope), NULL);
 	_tmp0 = NULL;
 	_tmp1 = NULL;
-	return (_tmp1 = g_strconcat ((_tmp0 = vala_code_node_to_string (VALA_CODE_NODE (self->priv->_base_type))), "*", NULL), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+	return (_tmp1 = g_strconcat ((_tmp0 = vala_data_type_to_qualified_string (vala_pointer_type_get_base_type (self), scope)), "*", NULL), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
-static char* vala_pointer_type_real_get_cname (ValaDataType* base, gboolean var_type, gboolean const_type) {
+static char* vala_pointer_type_real_get_cname (ValaDataType* base) {
 	ValaPointerType * self;
 	self = VALA_POINTER_TYPE (base);
-	if (vala_data_type_get_data_type (self->priv->_base_type) != NULL && vala_typesymbol_is_reference_type (vala_data_type_get_data_type (self->priv->_base_type))) {
-		return vala_data_type_get_cname (self->priv->_base_type, var_type, const_type);
+	if (vala_data_type_get_data_type (vala_pointer_type_get_base_type (self)) != NULL && vala_typesymbol_is_reference_type (vala_data_type_get_data_type (vala_pointer_type_get_base_type (self)))) {
+		return vala_data_type_get_cname (vala_pointer_type_get_base_type (self));
 	} else {
 		char* _tmp1;
 		char* _tmp2;
 		_tmp1 = NULL;
 		_tmp2 = NULL;
-		return (_tmp2 = g_strconcat ((_tmp1 = vala_data_type_get_cname (self->priv->_base_type, var_type, const_type)), "*", NULL), (_tmp1 = (g_free (_tmp1), NULL)), _tmp2);
+		return (_tmp2 = g_strconcat ((_tmp1 = vala_data_type_get_cname (vala_pointer_type_get_base_type (self))), "*", NULL), (_tmp1 = (g_free (_tmp1), NULL)), _tmp2);
 	}
 }
 
 
 static ValaDataType* vala_pointer_type_real_copy (ValaDataType* base) {
 	ValaPointerType * self;
+	ValaDataType* _tmp0;
+	ValaDataType* _tmp1;
 	self = VALA_POINTER_TYPE (base);
-	return VALA_DATA_TYPE (vala_pointer_type_new (self->priv->_base_type));
+	_tmp0 = NULL;
+	_tmp1 = NULL;
+	return (_tmp1 = VALA_DATA_TYPE (vala_pointer_type_new ((_tmp0 = vala_data_type_copy (vala_pointer_type_get_base_type (self))), NULL)), (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1);
 }
 
 
-static gboolean vala_pointer_type_real_compatible (ValaDataType* base, ValaDataType* target_type, gboolean enable_non_null) {
+static gboolean vala_pointer_type_real_compatible (ValaDataType* base, ValaDataType* target_type) {
 	ValaPointerType * self;
 	ValaAttribute* _tmp0;
 	gboolean _tmp1;
 	self = VALA_POINTER_TYPE (base);
-	g_return_val_if_fail (target_type == NULL || VALA_IS_DATA_TYPE (target_type), FALSE);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (target_type), FALSE);
 	_tmp0 = NULL;
 	if ((_tmp1 = VALA_IS_POINTER_TYPE (target_type) || (vala_data_type_get_data_type (target_type) != NULL && (_tmp0 = vala_code_node_get_attribute (VALA_CODE_NODE (vala_data_type_get_data_type (target_type)), "PointerType")) != NULL), (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
 		return TRUE;
@@ -104,24 +116,26 @@ static gboolean vala_pointer_type_real_compatible (ValaDataType* base, ValaDataT
 	if (vala_data_type_get_type_parameter (target_type) != NULL) {
 		return TRUE;
 	}
-	if (vala_data_type_is_reference_type_or_type_parameter (self->priv->_base_type)) {
-		return vala_data_type_compatible (self->priv->_base_type, target_type, enable_non_null);
+	if (vala_data_type_is_reference_type_or_type_parameter (vala_pointer_type_get_base_type (self))) {
+		/* Object* is compatible with Object if Object is a reference type*/
+		return vala_data_type_compatible (vala_pointer_type_get_base_type (self), target_type);
 	}
 	return FALSE;
 }
 
 
-/* Object* is compatible with Object if Object is a reference type*/
 static ValaSymbol* vala_pointer_type_real_get_pointer_member (ValaDataType* base, const char* member_name) {
 	ValaPointerType * self;
-	ValaTypesymbol* _tmp0;
+	ValaSymbol* _tmp0;
 	ValaSymbol* base_symbol;
 	ValaSymbol* _tmp2;
 	self = VALA_POINTER_TYPE (base);
+	g_return_val_if_fail (member_name != NULL, NULL);
 	_tmp0 = NULL;
-	base_symbol = VALA_SYMBOL ((_tmp0 = vala_data_type_get_data_type (self->priv->_base_type), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))));
+	base_symbol = (_tmp0 = VALA_SYMBOL (vala_data_type_get_data_type (vala_pointer_type_get_base_type (self))), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 	if (base_symbol == NULL) {
-		gpointer _tmp1;
+		ValaSymbol* _tmp1;
+		_tmp1 = NULL;
 		return (_tmp1 = NULL, (base_symbol == NULL ? NULL : (base_symbol = (g_object_unref (base_symbol), NULL))), _tmp1);
 	}
 	_tmp2 = NULL;
@@ -129,10 +143,10 @@ static ValaSymbol* vala_pointer_type_real_get_pointer_member (ValaDataType* base
 }
 
 
-static GeeCollection* vala_pointer_type_real_get_symbols (ValaDataType* base) {
+static GeeList* vala_pointer_type_real_get_symbols (ValaDataType* base) {
 	ValaPointerType * self;
 	self = VALA_POINTER_TYPE (base);
-	return vala_data_type_get_symbols (self->priv->_base_type);
+	return vala_data_type_get_symbols (vala_pointer_type_get_base_type (self));
 }
 
 
@@ -143,6 +157,32 @@ static char* vala_pointer_type_real_get_type_id (ValaDataType* base) {
 }
 
 
+static void vala_pointer_type_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
+	ValaPointerType * self;
+	self = VALA_POINTER_TYPE (base);
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	vala_code_node_accept (VALA_CODE_NODE (vala_pointer_type_get_base_type (self)), visitor);
+}
+
+
+static void vala_pointer_type_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
+	ValaPointerType * self;
+	self = VALA_POINTER_TYPE (base);
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
+	if (vala_pointer_type_get_base_type (self) == old_type) {
+		vala_pointer_type_set_base_type (self, new_type);
+	}
+}
+
+
+static gboolean vala_pointer_type_real_is_disposable (ValaDataType* base) {
+	ValaPointerType * self;
+	self = VALA_POINTER_TYPE (base);
+	return FALSE;
+}
+
+
 ValaDataType* vala_pointer_type_get_base_type (ValaPointerType* self) {
 	g_return_val_if_fail (VALA_IS_POINTER_TYPE (self), NULL);
 	return self->priv->_base_type;
@@ -156,6 +196,7 @@ void vala_pointer_type_set_base_type (ValaPointerType* self, ValaDataType* value
 	_tmp2 = NULL;
 	_tmp1 = NULL;
 	self->priv->_base_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_base_type == NULL ? NULL : (self->priv->_base_type = (g_object_unref (self->priv->_base_type), NULL))), _tmp2);
+	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_base_type), VALA_CODE_NODE (self));
 }
 
 
@@ -193,18 +234,21 @@ static void vala_pointer_type_class_init (ValaPointerTypeClass * klass) {
 	G_OBJECT_CLASS (klass)->get_property = vala_pointer_type_get_property;
 	G_OBJECT_CLASS (klass)->set_property = vala_pointer_type_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_pointer_type_dispose;
-	VALA_CODE_NODE_CLASS (klass)->to_string = vala_pointer_type_real_to_string;
+	VALA_DATA_TYPE_CLASS (klass)->to_qualified_string = vala_pointer_type_real_to_qualified_string;
 	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_pointer_type_real_get_cname;
 	VALA_DATA_TYPE_CLASS (klass)->copy = vala_pointer_type_real_copy;
 	VALA_DATA_TYPE_CLASS (klass)->compatible = vala_pointer_type_real_compatible;
 	VALA_DATA_TYPE_CLASS (klass)->get_pointer_member = vala_pointer_type_real_get_pointer_member;
 	VALA_DATA_TYPE_CLASS (klass)->get_symbols = vala_pointer_type_real_get_symbols;
 	VALA_DATA_TYPE_CLASS (klass)->get_type_id = vala_pointer_type_real_get_type_id;
+	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_pointer_type_real_accept_children;
+	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_pointer_type_real_replace_type;
+	VALA_DATA_TYPE_CLASS (klass)->is_disposable = vala_pointer_type_real_is_disposable;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_POINTER_TYPE_BASE_TYPE, g_param_spec_object ("base-type", "base-type", "base-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_pointer_type_init (ValaPointerType * self) {
+static void vala_pointer_type_instance_init (ValaPointerType * self) {
 	self->priv = VALA_POINTER_TYPE_GET_PRIVATE (self);
 }
 
@@ -220,7 +264,7 @@ static void vala_pointer_type_dispose (GObject * obj) {
 GType vala_pointer_type_get_type (void) {
 	static GType vala_pointer_type_type_id = 0;
 	if (G_UNLIKELY (vala_pointer_type_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaPointerTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_pointer_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaPointerType), 0, (GInstanceInitFunc) vala_pointer_type_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaPointerTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_pointer_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaPointerType), 0, (GInstanceInitFunc) vala_pointer_type_instance_init };
 		vala_pointer_type_type_id = g_type_register_static (VALA_TYPE_DATA_TYPE, "ValaPointerType", &g_define_type_info, 0);
 	}
 	return vala_pointer_type_type_id;
