@@ -31,6 +31,7 @@ struct _ValaPostfixExpressionPrivate {
 	ValaExpression* _inner;
 	gboolean _increment;
 };
+
 #define VALA_POSTFIX_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_POSTFIX_EXPRESSION, ValaPostfixExpressionPrivate))
 enum  {
 	VALA_POSTFIX_EXPRESSION_DUMMY_PROPERTY,
@@ -56,8 +57,8 @@ ValaPostfixExpression* vala_postfix_expression_new (ValaExpression* _inner, gboo
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaPostfixExpression * self;
-	g_return_val_if_fail (_inner == NULL || VALA_IS_EXPRESSION (_inner), NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (_inner), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	__params_it->name = "inner";
@@ -79,9 +80,10 @@ ValaPostfixExpression* vala_postfix_expression_new (ValaExpression* _inner, gboo
 static void vala_postfix_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaPostfixExpression * self;
 	self = VALA_POSTFIX_EXPRESSION (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (self->priv->_inner), visitor);
 	vala_code_visitor_visit_postfix_expression (visitor, self);
+	vala_code_visitor_visit_expression (visitor, VALA_EXPRESSION (self));
 }
 
 
@@ -167,7 +169,7 @@ static void vala_postfix_expression_class_init (ValaPostfixExpressionClass * kla
 }
 
 
-static void vala_postfix_expression_init (ValaPostfixExpression * self) {
+static void vala_postfix_expression_instance_init (ValaPostfixExpression * self) {
 	self->priv = VALA_POSTFIX_EXPRESSION_GET_PRIVATE (self);
 }
 
@@ -183,7 +185,7 @@ static void vala_postfix_expression_dispose (GObject * obj) {
 GType vala_postfix_expression_get_type (void) {
 	static GType vala_postfix_expression_type_id = 0;
 	if (G_UNLIKELY (vala_postfix_expression_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaPostfixExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_postfix_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaPostfixExpression), 0, (GInstanceInitFunc) vala_postfix_expression_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaPostfixExpressionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_postfix_expression_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaPostfixExpression), 0, (GInstanceInitFunc) vala_postfix_expression_instance_init };
 		vala_postfix_expression_type_id = g_type_register_static (VALA_TYPE_EXPRESSION, "ValaPostfixExpression", &g_define_type_info, 0);
 	}
 	return vala_postfix_expression_type_id;
