@@ -30,6 +30,10 @@
 #include <vala/valasymbol.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
+#include <vala/valaclass.h>
+#include <vala/valainterface.h>
+#include <vala/valascope.h>
+#include <vala/valareport.h>
 
 
 
@@ -45,19 +49,21 @@ struct _ValaPropertyPrivate {
 	gboolean _is_virtual;
 	gboolean _overrides;
 	ValaField* _field;
-	ValaProperty* _base_property;
-	ValaProperty* _base_interface_property;
+	MemberBinding _binding;
 	ValaExpression* _default_expression;
 	gboolean lock_used;
 	ValaDataType* _data_type;
-	gboolean _instance;
 	char* _nick;
 	char* _blurb;
+	ValaProperty* _base_property;
+	ValaProperty* _base_interface_property;
+	gboolean base_properties_valid;
 };
+
 #define VALA_PROPERTY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_PROPERTY, ValaPropertyPrivate))
 enum  {
 	VALA_PROPERTY_DUMMY_PROPERTY,
-	VALA_PROPERTY_TYPE_REFERENCE,
+	VALA_PROPERTY_PROPERTY_TYPE,
 	VALA_PROPERTY_GET_ACCESSOR,
 	VALA_PROPERTY_SET_ACCESSOR,
 	VALA_PROPERTY_THIS_PARAMETER,
@@ -68,7 +74,7 @@ enum  {
 	VALA_PROPERTY_IS_VIRTUAL,
 	VALA_PROPERTY_OVERRIDES,
 	VALA_PROPERTY_FIELD,
-	VALA_PROPERTY_INSTANCE,
+	VALA_PROPERTY_BINDING,
 	VALA_PROPERTY_BASE_PROPERTY,
 	VALA_PROPERTY_BASE_INTERFACE_PROPERTY,
 	VALA_PROPERTY_DEFAULT_EXPRESSION,
@@ -81,6 +87,9 @@ static char* vala_property_get_canonical_name (ValaProperty* self);
 static gboolean vala_property_real_get_lock_used (ValaLockable* base);
 static void vala_property_real_set_lock_used (ValaLockable* base, gboolean used);
 static void vala_property_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type);
+static void vala_property_find_base_properties (ValaProperty* self);
+static void vala_property_find_base_class_property (ValaProperty* self, ValaClass* cl);
+static void vala_property_find_base_interface_property (ValaProperty* self, ValaClass* cl);
 static gpointer vala_property_parent_class = NULL;
 static ValaLockableIface* vala_property_vala_lockable_parent_iface = NULL;
 static void vala_property_dispose (GObject * obj);
@@ -98,18 +107,19 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  * @param source       reference to source code
  * @return             newly created property
  */
-ValaProperty* vala_property_new (const char* _name, ValaDataType* type, ValaPropertyAccessor* _get_accessor, ValaPropertyAccessor* _set_accessor, ValaSourceReference* source) {
+ValaProperty* vala_property_new (const char* name, ValaDataType* property_type, ValaPropertyAccessor* get_accessor, ValaPropertyAccessor* set_accessor, ValaSourceReference* source_reference) {
 	ValaProperty * self;
-	g_return_val_if_fail (type == NULL || VALA_IS_DATA_TYPE (type), NULL);
-	g_return_val_if_fail (_get_accessor == NULL || VALA_IS_PROPERTY_ACCESSOR (_get_accessor), NULL);
-	g_return_val_if_fail (_set_accessor == NULL || VALA_IS_PROPERTY_ACCESSOR (_set_accessor), NULL);
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (property_type), NULL);
+	g_return_val_if_fail (get_accessor == NULL || VALA_IS_PROPERTY_ACCESSOR (get_accessor), NULL);
+	g_return_val_if_fail (set_accessor == NULL || VALA_IS_PROPERTY_ACCESSOR (set_accessor), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_PROPERTY, 0, NULL);
-	vala_symbol_set_name (VALA_SYMBOL (self), _name);
-	vala_property_set_type_reference (self, type);
-	vala_property_set_get_accessor (self, _get_accessor);
-	vala_property_set_set_accessor (self, _set_accessor);
-	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
+	vala_property_set_property_type (self, property_type);
+	vala_property_set_get_accessor (self, get_accessor);
+	vala_property_set_set_accessor (self, set_accessor);
+	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
 }
 
@@ -117,7 +127,7 @@ ValaProperty* vala_property_new (const char* _name, ValaDataType* type, ValaProp
 static void vala_property_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaProperty * self;
 	self = VALA_PROPERTY (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_member (visitor, VALA_MEMBER (self));
 	vala_code_visitor_visit_property (visitor, self);
 }
@@ -126,8 +136,8 @@ static void vala_property_real_accept (ValaCodeNode* base, ValaCodeVisitor* visi
 static void vala_property_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaProperty * self;
 	self = VALA_PROPERTY (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
-	vala_code_node_accept (VALA_CODE_NODE (vala_property_get_type_reference (self)), visitor);
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
+	vala_code_node_accept (VALA_CODE_NODE (vala_property_get_property_type (self)), visitor);
 	if (self->priv->_get_accessor != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (self->priv->_get_accessor), visitor);
 	}
@@ -221,7 +231,7 @@ void vala_property_process_attributes (ValaProperty* self) {
 			ValaAttribute* _tmp2;
 			ValaAttribute* a;
 			_tmp2 = NULL;
-			a = (_tmp2 = ((ValaAttribute*) a_it->data), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)));
+			a = (_tmp2 = ((ValaAttribute*) (a_it->data)), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)));
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "Notify") == 0) {
 					vala_property_set_notify (self, TRUE);
@@ -276,8 +286,8 @@ static void vala_property_real_set_lock_used (ValaLockable* base, gboolean used)
  */
 gboolean vala_property_equals (ValaProperty* self, ValaProperty* prop2) {
 	g_return_val_if_fail (VALA_IS_PROPERTY (self), FALSE);
-	g_return_val_if_fail (prop2 == NULL || VALA_IS_PROPERTY (prop2), FALSE);
-	if (!vala_data_type_equals (vala_property_get_type_reference (prop2), vala_property_get_type_reference (self))) {
+	g_return_val_if_fail (VALA_IS_PROPERTY (prop2), FALSE);
+	if (!vala_data_type_equals (vala_property_get_property_type (prop2), vala_property_get_property_type (self))) {
 		return FALSE;
 	}
 	if ((self->priv->_get_accessor == NULL && prop2->priv->_get_accessor != NULL) || (self->priv->_get_accessor != NULL && prop2->priv->_get_accessor == NULL)) {
@@ -301,21 +311,156 @@ gboolean vala_property_equals (ValaProperty* self, ValaProperty* prop2) {
 static void vala_property_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaProperty * self;
 	self = VALA_PROPERTY (base);
-	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
-	if (vala_property_get_type_reference (self) == old_type) {
-		vala_property_set_type_reference (self, new_type);
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
+	if (vala_property_get_property_type (self) == old_type) {
+		vala_property_set_property_type (self, new_type);
 	}
 }
 
 
-ValaDataType* vala_property_get_type_reference (ValaProperty* self) {
+static void vala_property_find_base_properties (ValaProperty* self) {
+	g_return_if_fail (VALA_IS_PROPERTY (self));
+	if (self->priv->base_properties_valid) {
+		return;
+	}
+	if (VALA_IS_CLASS (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))) {
+		/* VAPI classes don't specify overridden properties */
+		if (!vala_symbol_get_external_package (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))) {
+			vala_property_find_base_interface_property (self, VALA_CLASS (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))));
+			if (self->priv->_is_virtual || self->priv->_overrides) {
+				vala_property_find_base_class_property (self, VALA_CLASS (vala_symbol_get_parent_symbol (VALA_SYMBOL (self))));
+			}
+		} else {
+			if (self->priv->_is_virtual || self->priv->_is_abstract) {
+				self->priv->_base_property = self;
+			}
+		}
+	} else {
+		if (VALA_IS_INTERFACE (vala_symbol_get_parent_symbol (VALA_SYMBOL (self)))) {
+			if (self->priv->_is_virtual || self->priv->_is_abstract) {
+				ValaProperty* _tmp1;
+				ValaProperty* _tmp0;
+				_tmp1 = NULL;
+				_tmp0 = NULL;
+				self->priv->_base_interface_property = (_tmp1 = (_tmp0 = self, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->_base_interface_property == NULL ? NULL : (self->priv->_base_interface_property = (g_object_unref (self->priv->_base_interface_property), NULL))), _tmp1);
+			}
+		}
+	}
+	self->priv->base_properties_valid = TRUE;
+}
+
+
+static void vala_property_find_base_class_property (ValaProperty* self, ValaClass* cl) {
+	ValaSymbol* sym;
+	g_return_if_fail (VALA_IS_PROPERTY (self));
+	g_return_if_fail (VALA_IS_CLASS (cl));
+	sym = vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (cl)), vala_symbol_get_name (VALA_SYMBOL (self)));
+	if (VALA_IS_PROPERTY (sym)) {
+		ValaProperty* _tmp0;
+		ValaProperty* base_property;
+		_tmp0 = NULL;
+		base_property = (_tmp0 = VALA_PROPERTY (sym), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+		if (base_property->priv->_is_abstract || base_property->priv->_is_virtual) {
+			if (!vala_property_equals (self, base_property)) {
+				char* _tmp3;
+				char* _tmp2;
+				char* _tmp1;
+				vala_code_node_set_error (VALA_CODE_NODE (self), TRUE);
+				_tmp3 = NULL;
+				_tmp2 = NULL;
+				_tmp1 = NULL;
+				vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (_tmp3 = g_strdup_printf ("Type and/or accessors of overriding property `%s' do not match overridden property `%s'.", (_tmp1 = vala_symbol_get_full_name (VALA_SYMBOL (self))), (_tmp2 = vala_symbol_get_full_name (VALA_SYMBOL (base_property))))));
+				_tmp3 = (g_free (_tmp3), NULL);
+				_tmp2 = (g_free (_tmp2), NULL);
+				_tmp1 = (g_free (_tmp1), NULL);
+				(base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL)));
+				(sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL)));
+				return;
+			}
+			self->priv->_base_property = base_property;
+			(base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL)));
+			(sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL)));
+			return;
+		}
+		(base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL)));
+	}
+	if (vala_class_get_base_class (cl) != NULL) {
+		vala_property_find_base_class_property (self, vala_class_get_base_class (cl));
+	}
+	(sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL)));
+}
+
+
+static void vala_property_find_base_interface_property (ValaProperty* self, ValaClass* cl) {
+	g_return_if_fail (VALA_IS_PROPERTY (self));
+	g_return_if_fail (VALA_IS_CLASS (cl));
+	/* FIXME report error if multiple possible base properties are found*/
+	{
+		GeeList* type_collection;
+		int type_it;
+		type_collection = vala_class_get_base_types (cl);
+		for (type_it = 0; type_it < gee_collection_get_size (GEE_COLLECTION (type_collection)); type_it = type_it + 1) {
+			ValaDataType* type;
+			type = ((ValaDataType*) (gee_list_get (GEE_LIST (type_collection), type_it)));
+			{
+				if (VALA_IS_INTERFACE (vala_data_type_get_data_type (type))) {
+					ValaSymbol* sym;
+					sym = vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (vala_data_type_get_data_type (type))), vala_symbol_get_name (VALA_SYMBOL (self)));
+					if (VALA_IS_PROPERTY (sym)) {
+						ValaProperty* _tmp0;
+						ValaProperty* base_property;
+						_tmp0 = NULL;
+						base_property = (_tmp0 = VALA_PROPERTY (sym), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+						if (base_property->priv->_is_abstract) {
+							ValaProperty* _tmp5;
+							ValaProperty* _tmp4;
+							if (!vala_property_equals (self, base_property)) {
+								char* _tmp3;
+								char* _tmp2;
+								char* _tmp1;
+								vala_code_node_set_error (VALA_CODE_NODE (self), TRUE);
+								_tmp3 = NULL;
+								_tmp2 = NULL;
+								_tmp1 = NULL;
+								vala_report_error (vala_code_node_get_source_reference (VALA_CODE_NODE (self)), (_tmp3 = g_strdup_printf ("Type and/or accessors of overriding property `%s' do not match overridden property `%s'.", (_tmp1 = vala_symbol_get_full_name (VALA_SYMBOL (self))), (_tmp2 = vala_symbol_get_full_name (VALA_SYMBOL (base_property))))));
+								_tmp3 = (g_free (_tmp3), NULL);
+								_tmp2 = (g_free (_tmp2), NULL);
+								_tmp1 = (g_free (_tmp1), NULL);
+								(base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL)));
+								(sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL)));
+								(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
+								(type_collection == NULL ? NULL : (type_collection = (g_object_unref (type_collection), NULL)));
+								return;
+							}
+							_tmp5 = NULL;
+							_tmp4 = NULL;
+							self->priv->_base_interface_property = (_tmp5 = (_tmp4 = base_property, (_tmp4 == NULL ? NULL : g_object_ref (_tmp4))), (self->priv->_base_interface_property == NULL ? NULL : (self->priv->_base_interface_property = (g_object_unref (self->priv->_base_interface_property), NULL))), _tmp5);
+							(base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL)));
+							(sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL)));
+							(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
+							(type_collection == NULL ? NULL : (type_collection = (g_object_unref (type_collection), NULL)));
+							return;
+						}
+						(base_property == NULL ? NULL : (base_property = (g_object_unref (base_property), NULL)));
+					}
+					(sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL)));
+				}
+				(type == NULL ? NULL : (type = (g_object_unref (type), NULL)));
+			}
+		}
+		(type_collection == NULL ? NULL : (type_collection = (g_object_unref (type_collection), NULL)));
+	}
+}
+
+
+ValaDataType* vala_property_get_property_type (ValaProperty* self) {
 	g_return_val_if_fail (VALA_IS_PROPERTY (self), NULL);
 	return self->priv->_data_type;
 }
 
 
-void vala_property_set_type_reference (ValaProperty* self, ValaDataType* value) {
+void vala_property_set_property_type (ValaProperty* self, ValaDataType* value) {
 	ValaDataType* _tmp2;
 	ValaDataType* _tmp1;
 	g_return_if_fail (VALA_IS_PROPERTY (self));
@@ -462,46 +607,32 @@ void vala_property_set_field (ValaProperty* self, ValaField* value) {
 }
 
 
-gboolean vala_property_get_instance (ValaProperty* self) {
-	g_return_val_if_fail (VALA_IS_PROPERTY (self), FALSE);
-	return self->priv->_instance;
+MemberBinding vala_property_get_binding (ValaProperty* self) {
+	g_return_val_if_fail (VALA_IS_PROPERTY (self), 0);
+	return self->priv->_binding;
 }
 
 
-void vala_property_set_instance (ValaProperty* self, gboolean value) {
+void vala_property_set_binding (ValaProperty* self, MemberBinding value) {
 	g_return_if_fail (VALA_IS_PROPERTY (self));
-	self->priv->_instance = value;
+	self->priv->_binding = value;
 }
 
 
 ValaProperty* vala_property_get_base_property (ValaProperty* self) {
 	g_return_val_if_fail (VALA_IS_PROPERTY (self), NULL);
+	vala_property_find_base_properties (self);
 	return self->priv->_base_property;
 }
 
 
-void vala_property_set_base_property (ValaProperty* self, ValaProperty* value) {
-	g_return_if_fail (VALA_IS_PROPERTY (self));
-	self->priv->_base_property = value;
-}
-
-
 ValaProperty* vala_property_get_base_interface_property (ValaProperty* self) {
 	g_return_val_if_fail (VALA_IS_PROPERTY (self), NULL);
+	vala_property_find_base_properties (self);
 	return self->priv->_base_interface_property;
 }
 
 
-void vala_property_set_base_interface_property (ValaProperty* self, ValaProperty* value) {
-	ValaProperty* _tmp2;
-	ValaProperty* _tmp1;
-	g_return_if_fail (VALA_IS_PROPERTY (self));
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_base_interface_property = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_base_interface_property == NULL ? NULL : (self->priv->_base_interface_property = (g_object_unref (self->priv->_base_interface_property), NULL))), _tmp2);
-}
-
-
 ValaExpression* vala_property_get_default_expression (ValaProperty* self) {
 	g_return_val_if_fail (VALA_IS_PROPERTY (self), NULL);
 	return self->priv->_default_expression;
@@ -518,7 +649,7 @@ void vala_property_set_default_expression (ValaProperty* self, ValaExpression* v
 }
 
 
-char* vala_property_get_nick (ValaProperty* self) {
+const char* vala_property_get_nick (ValaProperty* self) {
 	g_return_val_if_fail (VALA_IS_PROPERTY (self), NULL);
 	if (self->priv->_nick == NULL) {
 		char* _tmp0;
@@ -539,7 +670,7 @@ void vala_property_set_nick (ValaProperty* self, const char* value) {
 }
 
 
-char* vala_property_get_blurb (ValaProperty* self) {
+const char* vala_property_get_blurb (ValaProperty* self) {
 	g_return_val_if_fail (VALA_IS_PROPERTY (self), NULL);
 	if (self->priv->_blurb == NULL) {
 		char* _tmp0;
@@ -564,8 +695,8 @@ static void vala_property_get_property (GObject * object, guint property_id, GVa
 	ValaProperty * self;
 	self = VALA_PROPERTY (object);
 	switch (property_id) {
-		case VALA_PROPERTY_TYPE_REFERENCE:
-		g_value_set_object (value, vala_property_get_type_reference (self));
+		case VALA_PROPERTY_PROPERTY_TYPE:
+		g_value_set_object (value, vala_property_get_property_type (self));
 		break;
 		case VALA_PROPERTY_GET_ACCESSOR:
 		g_value_set_object (value, vala_property_get_get_accessor (self));
@@ -597,8 +728,8 @@ static void vala_property_get_property (GObject * object, guint property_id, GVa
 		case VALA_PROPERTY_FIELD:
 		g_value_set_object (value, vala_property_get_field (self));
 		break;
-		case VALA_PROPERTY_INSTANCE:
-		g_value_set_boolean (value, vala_property_get_instance (self));
+		case VALA_PROPERTY_BINDING:
+		g_value_set_enum (value, vala_property_get_binding (self));
 		break;
 		case VALA_PROPERTY_BASE_PROPERTY:
 		g_value_set_object (value, vala_property_get_base_property (self));
@@ -626,8 +757,8 @@ static void vala_property_set_property (GObject * object, guint property_id, con
 	ValaProperty * self;
 	self = VALA_PROPERTY (object);
 	switch (property_id) {
-		case VALA_PROPERTY_TYPE_REFERENCE:
-		vala_property_set_type_reference (self, g_value_get_object (value));
+		case VALA_PROPERTY_PROPERTY_TYPE:
+		vala_property_set_property_type (self, g_value_get_object (value));
 		break;
 		case VALA_PROPERTY_GET_ACCESSOR:
 		vala_property_set_get_accessor (self, g_value_get_object (value));
@@ -659,14 +790,8 @@ static void vala_property_set_property (GObject * object, guint property_id, con
 		case VALA_PROPERTY_FIELD:
 		vala_property_set_field (self, g_value_get_object (value));
 		break;
-		case VALA_PROPERTY_INSTANCE:
-		vala_property_set_instance (self, g_value_get_boolean (value));
-		break;
-		case VALA_PROPERTY_BASE_PROPERTY:
-		vala_property_set_base_property (self, g_value_get_object (value));
-		break;
-		case VALA_PROPERTY_BASE_INTERFACE_PROPERTY:
-		vala_property_set_base_interface_property (self, g_value_get_object (value));
+		case VALA_PROPERTY_BINDING:
+		vala_property_set_binding (self, g_value_get_enum (value));
 		break;
 		case VALA_PROPERTY_DEFAULT_EXPRESSION:
 		vala_property_set_default_expression (self, g_value_get_object (value));
@@ -693,7 +818,7 @@ static void vala_property_class_init (ValaPropertyClass * klass) {
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_property_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_property_real_accept_children;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_property_real_replace_type;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_TYPE_REFERENCE, g_param_spec_object ("type-reference", "type-reference", "type-reference", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_PROPERTY_TYPE, g_param_spec_object ("property-type", "property-type", "property-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_GET_ACCESSOR, g_param_spec_object ("get-accessor", "get-accessor", "get-accessor", VALA_TYPE_PROPERTY_ACCESSOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_SET_ACCESSOR, g_param_spec_object ("set-accessor", "set-accessor", "set-accessor", VALA_TYPE_PROPERTY_ACCESSOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_THIS_PARAMETER, g_param_spec_object ("this-parameter", "this-parameter", "this-parameter", VALA_TYPE_FORMAL_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -704,9 +829,9 @@ static void vala_property_class_init (ValaPropertyClass * klass) {
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_IS_VIRTUAL, g_param_spec_boolean ("is-virtual", "is-virtual", "is-virtual", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_OVERRIDES, g_param_spec_boolean ("overrides", "overrides", "overrides", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_FIELD, g_param_spec_object ("field", "field", "field", VALA_TYPE_FIELD, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_INSTANCE, g_param_spec_boolean ("instance", "instance", "instance", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_BASE_PROPERTY, g_param_spec_object ("base-property", "base-property", "base-property", VALA_TYPE_PROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_BASE_INTERFACE_PROPERTY, g_param_spec_object ("base-interface-property", "base-interface-property", "base-interface-property", VALA_TYPE_PROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_BINDING, g_param_spec_enum ("binding", "binding", "binding", TYPE_MEMBER_BINDING, MEMBER_BINDING_INSTANCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_BASE_PROPERTY, g_param_spec_object ("base-property", "base-property", "base-property", VALA_TYPE_PROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_BASE_INTERFACE_PROPERTY, g_param_spec_object ("base-interface-property", "base-interface-property", "base-interface-property", VALA_TYPE_PROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_DEFAULT_EXPRESSION, g_param_spec_object ("default-expression", "default-expression", "default-expression", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_NICK, g_param_spec_string ("nick", "nick", "nick", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_PROPERTY_BLURB, g_param_spec_string ("blurb", "blurb", "blurb", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
@@ -720,10 +845,10 @@ static void vala_property_vala_lockable_interface_init (ValaLockableIface * ifac
 }
 
 
-static void vala_property_init (ValaProperty * self) {
+static void vala_property_instance_init (ValaProperty * self) {
 	self->priv = VALA_PROPERTY_GET_PRIVATE (self);
+	self->priv->_binding = MEMBER_BINDING_INSTANCE;
 	self->priv->lock_used = FALSE;
-	self->priv->_instance = TRUE;
 }
 
 
@@ -734,11 +859,11 @@ static void vala_property_dispose (GObject * obj) {
 	(self->priv->_set_accessor == NULL ? NULL : (self->priv->_set_accessor = (g_object_unref (self->priv->_set_accessor), NULL)));
 	(self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL)));
 	(self->priv->_field == NULL ? NULL : (self->priv->_field = (g_object_unref (self->priv->_field), NULL)));
-	(self->priv->_base_interface_property == NULL ? NULL : (self->priv->_base_interface_property = (g_object_unref (self->priv->_base_interface_property), NULL)));
 	(self->priv->_default_expression == NULL ? NULL : (self->priv->_default_expression = (g_object_unref (self->priv->_default_expression), NULL)));
 	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
 	self->priv->_nick = (g_free (self->priv->_nick), NULL);
 	self->priv->_blurb = (g_free (self->priv->_blurb), NULL);
+	(self->priv->_base_interface_property == NULL ? NULL : (self->priv->_base_interface_property = (g_object_unref (self->priv->_base_interface_property), NULL)));
 	G_OBJECT_CLASS (vala_property_parent_class)->dispose (obj);
 }
 
@@ -746,7 +871,7 @@ static void vala_property_dispose (GObject * obj) {
 GType vala_property_get_type (void) {
 	static GType vala_property_type_id = 0;
 	if (G_UNLIKELY (vala_property_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaPropertyClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_property_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaProperty), 0, (GInstanceInitFunc) vala_property_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaPropertyClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_property_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaProperty), 0, (GInstanceInitFunc) vala_property_instance_init };
 		static const GInterfaceInfo vala_lockable_info = { (GInterfaceInitFunc) vala_property_vala_lockable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_property_type_id = g_type_register_static (VALA_TYPE_MEMBER, "ValaProperty", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_property_type_id, VALA_TYPE_LOCKABLE, &vala_lockable_info);
