@@ -51,17 +51,19 @@ struct _ValaProperty {
 	ValaMember parent_instance;
 	ValaPropertyPrivate * priv;
 };
+
 struct _ValaPropertyClass {
 	ValaMemberClass parent_class;
 };
 
-ValaProperty* vala_property_new (const char* _name, ValaDataType* type, ValaPropertyAccessor* _get_accessor, ValaPropertyAccessor* _set_accessor, ValaSourceReference* source);
+
+ValaProperty* vala_property_new (const char* name, ValaDataType* property_type, ValaPropertyAccessor* get_accessor, ValaPropertyAccessor* set_accessor, ValaSourceReference* source_reference);
 char* vala_property_get_upper_case_cname (ValaProperty* self);
 ValaCCodeConstant* vala_property_get_canonical_cconstant (ValaProperty* self);
 void vala_property_process_attributes (ValaProperty* self);
 gboolean vala_property_equals (ValaProperty* self, ValaProperty* prop2);
-ValaDataType* vala_property_get_type_reference (ValaProperty* self);
-void vala_property_set_type_reference (ValaProperty* self, ValaDataType* value);
+ValaDataType* vala_property_get_property_type (ValaProperty* self);
+void vala_property_set_property_type (ValaProperty* self, ValaDataType* value);
 ValaPropertyAccessor* vala_property_get_get_accessor (ValaProperty* self);
 void vala_property_set_get_accessor (ValaProperty* self, ValaPropertyAccessor* value);
 ValaPropertyAccessor* vala_property_get_set_accessor (ValaProperty* self);
@@ -80,20 +82,21 @@ gboolean vala_property_get_is_virtual (ValaProperty* self);
 void vala_property_set_is_virtual (ValaProperty* self, gboolean value);
 gboolean vala_property_get_overrides (ValaProperty* self);
 void vala_property_set_overrides (ValaProperty* self, gboolean value);
-gboolean vala_property_get_instance (ValaProperty* self);
-void vala_property_set_instance (ValaProperty* self, gboolean value);
+ValaField* vala_property_get_field (ValaProperty* self);
+void vala_property_set_field (ValaProperty* self, ValaField* value);
+MemberBinding vala_property_get_binding (ValaProperty* self);
+void vala_property_set_binding (ValaProperty* self, MemberBinding value);
 ValaProperty* vala_property_get_base_property (ValaProperty* self);
-void vala_property_set_base_property (ValaProperty* self, ValaProperty* value);
 ValaProperty* vala_property_get_base_interface_property (ValaProperty* self);
-void vala_property_set_base_interface_property (ValaProperty* self, ValaProperty* value);
 ValaExpression* vala_property_get_default_expression (ValaProperty* self);
 void vala_property_set_default_expression (ValaProperty* self, ValaExpression* value);
-char* vala_property_get_nick (ValaProperty* self);
+const char* vala_property_get_nick (ValaProperty* self);
 void vala_property_set_nick (ValaProperty* self, const char* value);
-char* vala_property_get_blurb (ValaProperty* self);
+const char* vala_property_get_blurb (ValaProperty* self);
 void vala_property_set_blurb (ValaProperty* self, const char* value);
 GType vala_property_get_type (void);
 
+
 G_END_DECLS
 
 #endif
