@@ -1,6 +1,6 @@
 /* valareturnstatement.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -31,6 +31,7 @@
 struct _ValaReturnStatementPrivate {
 	ValaExpression* _return_expression;
 };
+
 #define VALA_RETURN_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_RETURN_STATEMENT, ValaReturnStatementPrivate))
 enum  {
 	VALA_RETURN_STATEMENT_DUMMY_PROPERTY,
@@ -57,8 +58,8 @@ ValaReturnStatement* vala_return_statement_new (ValaExpression* return_expressio
 	g_return_val_if_fail (return_expression == NULL || VALA_IS_EXPRESSION (return_expression), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_RETURN_STATEMENT, 0, NULL);
-	vala_return_statement_set_return_expression (self, return_expression);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_return_statement_set_return_expression (self, return_expression);
 	return self;
 }
 
@@ -66,7 +67,7 @@ ValaReturnStatement* vala_return_statement_new (ValaExpression* return_expressio
 static void vala_return_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaReturnStatement * self;
 	self = VALA_RETURN_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_return_statement (visitor, self);
 }
 
@@ -74,7 +75,7 @@ static void vala_return_statement_real_accept (ValaCodeNode* base, ValaCodeVisit
 static void vala_return_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaReturnStatement * self;
 	self = VALA_RETURN_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (vala_return_statement_get_return_expression (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_return_statement_get_return_expression (self)), visitor);
 		vala_code_visitor_visit_end_full_expression (visitor, vala_return_statement_get_return_expression (self));
@@ -85,8 +86,8 @@ static void vala_return_statement_real_accept_children (ValaCodeNode* base, Vala
 static void vala_return_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaReturnStatement * self;
 	self = VALA_RETURN_STATEMENT (base);
-	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
 	if (vala_return_statement_get_return_expression (self) == old_node) {
 		vala_return_statement_set_return_expression (self, new_node);
 	}
@@ -158,7 +159,7 @@ static void vala_return_statement_vala_statement_interface_init (ValaStatementIf
 }
 
 
-static void vala_return_statement_init (ValaReturnStatement * self) {
+static void vala_return_statement_instance_init (ValaReturnStatement * self) {
 	self->priv = VALA_RETURN_STATEMENT_GET_PRIVATE (self);
 }
 
@@ -174,7 +175,7 @@ static void vala_return_statement_dispose (GObject * obj) {
 GType vala_return_statement_get_type (void) {
 	static GType vala_return_statement_type_id = 0;
 	if (G_UNLIKELY (vala_return_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaReturnStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_return_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaReturnStatement), 0, (GInstanceInitFunc) vala_return_statement_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaReturnStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_return_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaReturnStatement), 0, (GInstanceInitFunc) vala_return_statement_instance_init };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_return_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_return_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaReturnStatement", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_return_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
