@@ -36,6 +36,7 @@
 #include <vala/valainterface.h>
 #include <vala/valaenum.h>
 #include <vala/valaenumvalue.h>
+#include <vala/valaerrordomain.h>
 #include <vala/valadelegate.h>
 #include <vala/valaconstant.h>
 #include <vala/valafield.h>
@@ -49,6 +50,7 @@
 #include <vala/valadestructor.h>
 #include <vala/valanamedargument.h>
 #include <vala/valablock.h>
+#include <vala/valadeclarationstatement.h>
 #include <vala/valalocalvariable.h>
 #include <vala/valainitializerlist.h>
 #include <vala/valaexpressionstatement.h>
@@ -74,8 +76,9 @@
 #include <vala/valasymbol.h>
 #include <vala/valaparenthesizedexpression.h>
 #include <vala/valamemberaccess.h>
-#include <vala/valainvocationexpression.h>
 #include <vala/valadatatype.h>
+#include <vala/valatypesymbol.h>
+#include <vala/valainvocationexpression.h>
 #include <vala/valacodenode.h>
 #include <vala/valaelementaccess.h>
 #include <vala/valabaseaccess.h>
@@ -115,13 +118,16 @@ struct _ValaSemanticAnalyzer {
 	ValaCodeVisitor parent_instance;
 	ValaSemanticAnalyzerPrivate * priv;
 };
+
 struct _ValaSemanticAnalyzerClass {
 	ValaCodeVisitorClass parent_class;
 };
 
+
 ValaSemanticAnalyzer* vala_semantic_analyzer_new (void);
 void vala_semantic_analyzer_analyze (ValaSemanticAnalyzer* self, ValaCodeContext* context);
 ValaSymbol* vala_semantic_analyzer_symbol_lookup_inherited (ValaSymbol* sym, const char* name);
+ValaDataType* vala_semantic_analyzer_get_data_type_for_symbol (ValaTypeSymbol* sym);
 ValaDataType* vala_semantic_analyzer_get_actual_type (ValaDataType* derived_instance_type, ValaSymbol* generic_member, ValaDataType* generic_type, ValaCodeNode* node_reference);
 GType vala_semantic_analyzer_get_type (void);
 
