@@ -80,9 +80,9 @@ ValaSignal* vala_signal_new (const char* name, ValaDataType* return_type, ValaSo
 	g_return_val_if_fail (VALA_IS_DATA_TYPE (return_type), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_SIGNAL, 0, NULL);
+	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	vala_signal_set_return_type (self, return_type);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
-	vala_symbol_set_name (VALA_SYMBOL (self), name);
 	return self;
 }
 
@@ -185,7 +185,7 @@ void vala_signal_set_cname (ValaSignal* self, const char* cname) {
  *
  * @return string literal to be used in C code
  */
-ValaCCodeConstant* vala_signal_get_canonical_cconstant (ValaSignal* self) {
+ValaCCodeConstant* vala_signal_get_canonical_cconstant (ValaSignal* self, const char* detail) {
 	GString* str;
 	const char* _tmp0;
 	char* i;
@@ -208,6 +208,10 @@ ValaCCodeConstant* vala_signal_get_canonical_cconstant (ValaSignal* self) {
 		_tmp1 = NULL;
 		i = (_tmp2 = (_tmp1 = g_utf8_next_char (i), (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (i = (g_free (i), NULL)), _tmp2);
 	}
+	if (detail != NULL) {
+		g_string_append (str, "::");
+		g_string_append (str, detail);
+	}
 	g_string_append_c (str, '"');
 	_tmp3 = NULL;
 	return (_tmp3 = vala_ccode_constant_new (str->str), (str == NULL ? NULL : (str = (g_string_free (str, TRUE), NULL))), (i = (g_free (i), NULL)), _tmp3);
