@@ -115,6 +115,23 @@ ValaSourceFile* vala_source_file_new (ValaCodeContext* context, const char* file
 void vala_source_file_add_using_directive (ValaSourceFile* self, ValaNamespaceReference* ns) {
 	g_return_if_fail (VALA_IS_SOURCE_FILE (self));
 	g_return_if_fail (VALA_IS_NAMESPACE_REFERENCE (ns));
+	{
+		GeeList* using_directive_collection;
+		int using_directive_it;
+		using_directive_collection = self->priv->using_directives;
+		for (using_directive_it = 0; using_directive_it < gee_collection_get_size (GEE_COLLECTION (using_directive_collection)); using_directive_it = using_directive_it + 1) {
+			ValaNamespaceReference* using_directive;
+			using_directive = ((ValaNamespaceReference*) (gee_list_get (GEE_LIST (using_directive_collection), using_directive_it)));
+			{
+				if (_vala_strcmp0 (vala_namespace_reference_get_name (using_directive), vala_namespace_reference_get_name (ns)) == 0) {
+					/* ignore duplicates*/
+					(using_directive == NULL ? NULL : (using_directive = (g_object_unref (using_directive), NULL)));
+					return;
+				}
+				(using_directive == NULL ? NULL : (using_directive = (g_object_unref (using_directive), NULL)));
+			}
+		}
+	}
 	gee_collection_add (GEE_COLLECTION (self->priv->using_directives), ns);
 }
 
@@ -635,6 +652,7 @@ static void vala_source_file_read_source_file (ValaSourceFile* self) {
 		fe = inner_error;
 		inner_error = NULL;
 		{
+			(fe == NULL ? NULL : (fe = (g_error_free (fe), NULL)));
 			cont = (g_free (cont), NULL);
 			return;
 		}
@@ -677,10 +695,11 @@ gchar* vala_source_file_get_mapped_contents (ValaSourceFile* self) {
 			inner_error = NULL;
 			{
 				char* _tmp1;
+				gchar* _tmp2;
 				_tmp1 = NULL;
 				vala_report_error (NULL, (_tmp1 = g_strdup_printf ("Unable to map file `%s': %s", self->priv->_filename, e->message)));
 				_tmp1 = (g_free (_tmp1), NULL);
-				return NULL;
+				return (_tmp2 = NULL, (e == NULL ? NULL : (e = (g_error_free (e), NULL))), _tmp2);
 			}
 		}
 		__finally7:
