@@ -51,7 +51,7 @@ static void vala_source_file_cycle_class_init (ValaSourceFileCycleClass * klass)
 }
 
 
-static void vala_source_file_cycle_init (ValaSourceFileCycle * self) {
+static void vala_source_file_cycle_instance_init (ValaSourceFileCycle * self) {
 	self->files = GEE_LIST (gee_array_list_new (VALA_TYPE_SOURCE_FILE, NULL, NULL, g_direct_equal));
 }
 
@@ -67,7 +67,7 @@ static void vala_source_file_cycle_dispose (GObject * obj) {
 GType vala_source_file_cycle_get_type (void) {
 	static GType vala_source_file_cycle_type_id = 0;
 	if (G_UNLIKELY (vala_source_file_cycle_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaSourceFileCycleClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_source_file_cycle_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSourceFileCycle), 0, (GInstanceInitFunc) vala_source_file_cycle_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaSourceFileCycleClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_source_file_cycle_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSourceFileCycle), 0, (GInstanceInitFunc) vala_source_file_cycle_instance_init };
 		vala_source_file_cycle_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaSourceFileCycle", &g_define_type_info, 0);
 	}
 	return vala_source_file_cycle_type_id;
