@@ -104,8 +104,12 @@ ValaSourceReference* vala_source_reference_new_with_comment (ValaSourceFile* _fi
  * @return human-readable string
  */
 char* vala_source_reference_to_string (ValaSourceReference* self) {
+	char* _tmp0;
+	char* _tmp1;
 	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (self), NULL);
-	return (g_strdup_printf ("%s:%d.%d-%d.%d", vala_source_file_get_filename (self->priv->_file), self->priv->_first_line, self->priv->_first_column, self->priv->_last_line, self->priv->_last_column));
+	_tmp0 = NULL;
+	_tmp1 = NULL;
+	return (_tmp1 = (g_strdup_printf ("%s:%d.%d-%d.%d", (_tmp0 = vala_source_file_get_relative_filename (self->priv->_file)), self->priv->_first_line, self->priv->_first_column, self->priv->_last_line, self->priv->_last_column)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
 }
 
 
@@ -169,7 +173,7 @@ void vala_source_reference_set_last_column (ValaSourceReference* self, gint valu
 }
 
 
-char* vala_source_reference_get_comment (ValaSourceReference* self) {
+const char* vala_source_reference_get_comment (ValaSourceReference* self) {
 	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (self), NULL);
 	return self->priv->_comment;
 }
@@ -258,7 +262,7 @@ static void vala_source_reference_class_init (ValaSourceReferenceClass * klass)
 }
 
 
-static void vala_source_reference_init (ValaSourceReference * self) {
+static void vala_source_reference_instance_init (ValaSourceReference * self) {
 	self->priv = VALA_SOURCE_REFERENCE_GET_PRIVATE (self);
 }
 
@@ -274,7 +278,7 @@ static void vala_source_reference_dispose (GObject * obj) {
 GType vala_source_reference_get_type (void) {
 	static GType vala_source_reference_type_id = 0;
 	if (G_UNLIKELY (vala_source_reference_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaSourceReferenceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_source_reference_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSourceReference), 0, (GInstanceInitFunc) vala_source_reference_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaSourceReferenceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_source_reference_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSourceReference), 0, (GInstanceInitFunc) vala_source_reference_instance_init };
 		vala_source_reference_type_id = g_type_register_static (G_TYPE_OBJECT, "ValaSourceReference", &g_define_type_info, 0);
 	}
 	return vala_source_reference_type_id;
