@@ -1,6 +1,6 @@
 /* valasourcereference.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -48,10 +48,12 @@ struct _ValaSourceReference {
 	GObject parent_instance;
 	ValaSourceReferencePrivate * priv;
 };
+
 struct _ValaSourceReferenceClass {
 	GObjectClass parent_class;
 };
 
+
 ValaSourceReference* vala_source_reference_new (ValaSourceFile* _file, gint _first_line, gint _first_column, gint _last_line, gint _last_column);
 ValaSourceReference* vala_source_reference_new_with_comment (ValaSourceFile* _file, gint _first_line, gint _first_column, gint _last_line, gint _last_column, const char* _comment);
 char* vala_source_reference_to_string (ValaSourceReference* self);
@@ -65,7 +67,7 @@ gint vala_source_reference_get_last_line (ValaSourceReference* self);
 void vala_source_reference_set_last_line (ValaSourceReference* self, gint value);
 gint vala_source_reference_get_last_column (ValaSourceReference* self);
 void vala_source_reference_set_last_column (ValaSourceReference* self, gint value);
-char* vala_source_reference_get_comment (ValaSourceReference* self);
+const char* vala_source_reference_get_comment (ValaSourceReference* self);
 void vala_source_reference_set_comment (ValaSourceReference* self, const char* value);
 GType vala_source_reference_get_type (void);
 
