@@ -31,6 +31,7 @@
 struct _ValaSwitchLabelPrivate {
 	ValaExpression* _expression;
 };
+
 #define VALA_SWITCH_LABEL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SWITCH_LABEL, ValaSwitchLabelPrivate))
 enum  {
 	VALA_SWITCH_LABEL_DUMMY_PROPERTY,
@@ -51,7 +52,7 @@ static void vala_switch_label_dispose (GObject * obj);
  */
 ValaSwitchLabel* vala_switch_label_new (ValaExpression* expr, ValaSourceReference* source) {
 	ValaSwitchLabel * self;
-	g_return_val_if_fail (expr == NULL || VALA_IS_EXPRESSION (expr), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (expr), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
 	self = g_object_newv (VALA_TYPE_SWITCH_LABEL, 0, NULL);
 	vala_switch_label_set_expression (self, expr);
@@ -78,7 +79,7 @@ ValaSwitchLabel* vala_switch_label_new_with_default (ValaSourceReference* source
 static void vala_switch_label_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaSwitchLabel * self;
 	self = VALA_SWITCH_LABEL (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (self->priv->_expression != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (self->priv->_expression), visitor);
 		vala_code_visitor_visit_end_full_expression (visitor, self->priv->_expression);
@@ -142,7 +143,7 @@ static void vala_switch_label_class_init (ValaSwitchLabelClass * klass) {
 }
 
 
-static void vala_switch_label_init (ValaSwitchLabel * self) {
+static void vala_switch_label_instance_init (ValaSwitchLabel * self) {
 	self->priv = VALA_SWITCH_LABEL_GET_PRIVATE (self);
 }
 
@@ -158,7 +159,7 @@ static void vala_switch_label_dispose (GObject * obj) {
 GType vala_switch_label_get_type (void) {
 	static GType vala_switch_label_type_id = 0;
 	if (G_UNLIKELY (vala_switch_label_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaSwitchLabelClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_switch_label_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSwitchLabel), 0, (GInstanceInitFunc) vala_switch_label_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaSwitchLabelClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_switch_label_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSwitchLabel), 0, (GInstanceInitFunc) vala_switch_label_instance_init };
 		vala_switch_label_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaSwitchLabel", &g_define_type_info, 0);
 	}
 	return vala_switch_label_type_id;
