@@ -1,6 +1,6 @@
 /* valaswitchsection.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -22,20 +22,20 @@
 
 #include <vala/valaswitchsection.h>
 #include <gee/arraylist.h>
-#include <gee/list.h>
-#include <gee/readonlycollection.h>
+#include <gee/collection.h>
+#include <gee/readonlylist.h>
 #include <vala/valaswitchlabel.h>
-#include <vala/valastatement.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
+#include <vala/valastatement.h>
 
 
 
 
 struct _ValaSwitchSectionPrivate {
 	GeeList* labels;
-	GeeList* statement_list;
 };
+
 #define VALA_SWITCH_SECTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SWITCH_SECTION, ValaSwitchSectionPrivate))
 enum  {
 	VALA_SWITCH_SECTION_DUMMY_PROPERTY
@@ -55,7 +55,7 @@ static void vala_switch_section_dispose (GObject * obj);
  */
 ValaSwitchSection* vala_switch_section_new (ValaSourceReference* source_reference) {
 	ValaSwitchSection * self;
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_SWITCH_SECTION, 0, NULL);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	return self;
@@ -69,7 +69,7 @@ ValaSwitchSection* vala_switch_section_new (ValaSourceReference* source_referenc
  */
 void vala_switch_section_add_label (ValaSwitchSection* self, ValaSwitchLabel* label) {
 	g_return_if_fail (VALA_IS_SWITCH_SECTION (self));
-	g_return_if_fail (label == NULL || VALA_IS_SWITCH_LABEL (label));
+	g_return_if_fail (VALA_IS_SWITCH_LABEL (label));
 	gee_collection_add (GEE_COLLECTION (self->priv->labels), label);
 }
 
@@ -79,9 +79,9 @@ void vala_switch_section_add_label (ValaSwitchSection* self, ValaSwitchLabel* la
  *
  * @return switch label list
  */
-GeeCollection* vala_switch_section_get_labels (ValaSwitchSection* self) {
+GeeList* vala_switch_section_get_labels (ValaSwitchSection* self) {
 	g_return_val_if_fail (VALA_IS_SWITCH_SECTION (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_SWITCH_LABEL, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->labels)));
+	return GEE_LIST (gee_read_only_list_new (VALA_TYPE_SWITCH_LABEL, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, self->priv->labels));
 }
 
 
@@ -89,53 +89,28 @@ gboolean vala_switch_section_has_default_label (ValaSwitchSection* self) {
 	g_return_val_if_fail (VALA_IS_SWITCH_SECTION (self), FALSE);
 	{
 		GeeList* label_collection;
-		GeeIterator* label_it;
+		int label_it;
 		label_collection = self->priv->labels;
-		label_it = gee_iterable_iterator (GEE_ITERABLE (label_collection));
-		while (gee_iterator_next (label_it)) {
+		for (label_it = 0; label_it < gee_collection_get_size (GEE_COLLECTION (label_collection)); label_it = label_it + 1) {
 			ValaSwitchLabel* label;
-			label = ((ValaSwitchLabel*) gee_iterator_get (label_it));
+			label = ((ValaSwitchLabel*) (gee_list_get (GEE_LIST (label_collection), label_it)));
 			{
 				if (vala_switch_label_get_expression (label) == NULL) {
 					gboolean _tmp0;
-					return (_tmp0 = TRUE, (label == NULL ? NULL : (label = (g_object_unref (label), NULL))), (label_it == NULL ? NULL : (label_it = (g_object_unref (label_it), NULL))), _tmp0);
+					return (_tmp0 = TRUE, (label == NULL ? NULL : (label = (g_object_unref (label), NULL))), _tmp0);
 				}
 				(label == NULL ? NULL : (label = (g_object_unref (label), NULL)));
 			}
 		}
-		(label_it == NULL ? NULL : (label_it = (g_object_unref (label_it), NULL)));
 	}
 	return FALSE;
 }
 
 
-/**
- * Appends the specified statement to this switch section.
- *
- * @param stmt a statement
- */
-void vala_switch_section_add_statement (ValaSwitchSection* self, ValaStatement* stmt) {
-	g_return_if_fail (VALA_IS_SWITCH_SECTION (self));
-	g_return_if_fail (stmt == NULL || VALA_IS_STATEMENT (stmt));
-	gee_collection_add (GEE_COLLECTION (self->priv->statement_list), stmt);
-}
-
-
-/**
- * Returns a copy of the list of statements.
- *
- * @return statement list
- */
-GeeCollection* vala_switch_section_get_statements (ValaSwitchSection* self) {
-	g_return_val_if_fail (VALA_IS_SWITCH_SECTION (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_STATEMENT, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->statement_list)));
-}
-
-
 static void vala_switch_section_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaSwitchSection * self;
 	self = VALA_SWITCH_SECTION (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_switch_section (visitor, self);
 }
 
@@ -143,36 +118,33 @@ static void vala_switch_section_real_accept (ValaCodeNode* base, ValaCodeVisitor
 static void vala_switch_section_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaSwitchSection * self;
 	self = VALA_SWITCH_SECTION (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
 		GeeList* label_collection;
-		GeeIterator* label_it;
+		int label_it;
 		label_collection = self->priv->labels;
-		label_it = gee_iterable_iterator (GEE_ITERABLE (label_collection));
-		while (gee_iterator_next (label_it)) {
+		for (label_it = 0; label_it < gee_collection_get_size (GEE_COLLECTION (label_collection)); label_it = label_it + 1) {
 			ValaSwitchLabel* label;
-			label = ((ValaSwitchLabel*) gee_iterator_get (label_it));
+			label = ((ValaSwitchLabel*) (gee_list_get (GEE_LIST (label_collection), label_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (label), visitor);
 				(label == NULL ? NULL : (label = (g_object_unref (label), NULL)));
 			}
 		}
-		(label_it == NULL ? NULL : (label_it = (g_object_unref (label_it), NULL)));
 	}
 	{
 		GeeList* st_collection;
-		GeeIterator* st_it;
-		st_collection = self->priv->statement_list;
-		st_it = gee_iterable_iterator (GEE_ITERABLE (st_collection));
-		while (gee_iterator_next (st_it)) {
+		int st_it;
+		st_collection = vala_block_get_statements (VALA_BLOCK (self));
+		for (st_it = 0; st_it < gee_collection_get_size (GEE_COLLECTION (st_collection)); st_it = st_it + 1) {
 			ValaStatement* st;
-			st = ((ValaStatement*) gee_iterator_get (st_it));
+			st = ((ValaStatement*) (gee_list_get (GEE_LIST (st_collection), st_it)));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (st), visitor);
 				(st == NULL ? NULL : (st = (g_object_unref (st), NULL)));
 			}
 		}
-		(st_it == NULL ? NULL : (st_it = (g_object_unref (st_it), NULL)));
+		(st_collection == NULL ? NULL : (st_collection = (g_object_unref (st_collection), NULL)));
 	}
 }
 
@@ -186,10 +158,9 @@ static void vala_switch_section_class_init (ValaSwitchSectionClass * klass) {
 }
 
 
-static void vala_switch_section_init (ValaSwitchSection * self) {
+static void vala_switch_section_instance_init (ValaSwitchSection * self) {
 	self->priv = VALA_SWITCH_SECTION_GET_PRIVATE (self);
-	self->priv->labels = GEE_LIST (gee_array_list_new (VALA_TYPE_SWITCH_LABEL, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
-	self->priv->statement_list = GEE_LIST (gee_array_list_new (VALA_TYPE_STATEMENT, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->labels = GEE_LIST (gee_array_list_new (VALA_TYPE_SWITCH_LABEL, ((GBoxedCopyFunc) (g_object_ref)), g_object_unref, g_direct_equal));
 }
 
 
@@ -197,7 +168,6 @@ static void vala_switch_section_dispose (GObject * obj) {
 	ValaSwitchSection * self;
 	self = VALA_SWITCH_SECTION (obj);
 	(self->priv->labels == NULL ? NULL : (self->priv->labels = (g_object_unref (self->priv->labels), NULL)));
-	(self->priv->statement_list == NULL ? NULL : (self->priv->statement_list = (g_object_unref (self->priv->statement_list), NULL)));
 	G_OBJECT_CLASS (vala_switch_section_parent_class)->dispose (obj);
 }
 
@@ -205,7 +175,7 @@ static void vala_switch_section_dispose (GObject * obj) {
 GType vala_switch_section_get_type (void) {
 	static GType vala_switch_section_type_id = 0;
 	if (G_UNLIKELY (vala_switch_section_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaSwitchSectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_switch_section_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSwitchSection), 0, (GInstanceInitFunc) vala_switch_section_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaSwitchSectionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_switch_section_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSwitchSection), 0, (GInstanceInitFunc) vala_switch_section_instance_init };
 		vala_switch_section_type_id = g_type_register_static (VALA_TYPE_BLOCK, "ValaSwitchSection", &g_define_type_info, 0);
 	}
 	return vala_switch_section_type_id;
