@@ -1,6 +1,6 @@
 /* valaswitchsection.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,7 +25,7 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <gee/collection.h>
+#include <gee/list.h>
 #include <vala/valablock.h>
 #include <vala/valacodenode.h>
 
@@ -48,18 +48,19 @@ struct _ValaSwitchSection {
 	ValaBlock parent_instance;
 	ValaSwitchSectionPrivate * priv;
 };
+
 struct _ValaSwitchSectionClass {
 	ValaBlockClass parent_class;
 };
 
+
 ValaSwitchSection* vala_switch_section_new (ValaSourceReference* source_reference);
 void vala_switch_section_add_label (ValaSwitchSection* self, ValaSwitchLabel* label);
-GeeCollection* vala_switch_section_get_labels (ValaSwitchSection* self);
+GeeList* vala_switch_section_get_labels (ValaSwitchSection* self);
 gboolean vala_switch_section_has_default_label (ValaSwitchSection* self);
-void vala_switch_section_add_statement (ValaSwitchSection* self, ValaStatement* stmt);
-GeeCollection* vala_switch_section_get_statements (ValaSwitchSection* self);
 GType vala_switch_section_get_type (void);
 
+
 G_END_DECLS
 
 #endif
