@@ -1,6 +1,6 @@
 /* valasymbol.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -21,17 +21,24 @@
  */
 
 #include <vala/valasymbol.h>
-#include <gee/readonlycollection.h>
+#include <gee/arraylist.h>
 #include <vala/valascope.h>
+#include <vala/valanamespace.h>
+#include <vala/valasourcereference.h>
+#include <vala/valasourcefile.h>
+
+
+
 
 struct _ValaSymbolPrivate {
 	char* _name;
 	gboolean _active;
 	ValaSymbolAccessibility _access;
-	gboolean _is_imported;
 	ValaScope* _owner;
 	ValaScope* _scope;
+	gboolean _external;
 };
+
 #define VALA_SYMBOL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SYMBOL, ValaSymbolPrivate))
 enum  {
 	VALA_SYMBOL_DUMMY_PROPERTY,
@@ -41,17 +48,19 @@ enum  {
 	VALA_SYMBOL_ACTIVE,
 	VALA_SYMBOL_ACCESS,
 	VALA_SYMBOL_SCOPE,
-	VALA_SYMBOL_IS_IMPORTED
+	VALA_SYMBOL_EXTERNAL,
+	VALA_SYMBOL_EXTERNAL_PACKAGE
 };
 static char* vala_symbol_real_get_cprefix (ValaSymbol* self);
 static char* vala_symbol_real_get_lower_case_cname (ValaSymbol* self, const char* infix);
 static char* vala_symbol_real_get_lower_case_cprefix (ValaSymbol* self);
-static GeeCollection* vala_symbol_real_get_cheader_filenames (ValaSymbol* self);
+static GeeList* vala_symbol_real_get_cheader_filenames (ValaSymbol* self);
 static GObject * vala_symbol_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
 static gpointer vala_symbol_parent_class = NULL;
 static void vala_symbol_dispose (GObject * obj);
 
 
+
 /**
  * Check if this symbol is just internal API (and therefore doesn't need 
  * to be listed in header files for instance) by traversing parent symbols
@@ -60,20 +69,18 @@ static void vala_symbol_dispose (GObject * obj);
 gboolean vala_symbol_is_internal_symbol (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), FALSE);
 	{
+		ValaSymbol* _tmp0;
 		ValaSymbol* sym;
-		ValaSymbol* _tmp3;
 		ValaSymbol* _tmp2;
 		ValaSymbol* _tmp1;
-		ValaSymbol* _tmp0;
-		sym = NULL;
-		_tmp3 = NULL;
+		_tmp0 = NULL;
+		sym = (_tmp0 = self, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 		_tmp2 = NULL;
 		_tmp1 = NULL;
-		_tmp0 = NULL;
-		for (sym = (_tmp1 = (_tmp0 = self, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp1); NULL != sym; sym = (_tmp3 = (_tmp2 = vala_symbol_get_parent_symbol (sym), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp3)) {
-			if (VALA_SYMBOL_ACCESSIBILITY_PRIVATE == vala_symbol_get_access (sym)) {
-				gboolean _tmp4;
-				return (_tmp4 = TRUE, (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp4);
+		for (; NULL != sym; sym = (_tmp2 = (_tmp1 = vala_symbol_get_parent_symbol (sym), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp2)) {
+			if (VALA_SYMBOL_ACCESSIBILITY_PRIVATE == sym->priv->_access) {
+				gboolean _tmp3;
+				return (_tmp3 = TRUE, (sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL))), _tmp3);
 			}
 		}
 		(sym == NULL ? NULL : (sym = (g_object_unref (sym), NULL)));
@@ -97,20 +104,20 @@ char* vala_symbol_get_full_name (ValaSymbol* self) {
 	if (vala_symbol_get_parent_symbol (self) == NULL) {
 		const char* _tmp0;
 		_tmp0 = NULL;
-		return (_tmp0 = vala_symbol_get_name (self), (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
+		return (_tmp0 = self->priv->_name, (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
 	}
-	if (vala_symbol_get_name (self) == NULL) {
+	if (self->priv->_name == NULL) {
 		return vala_symbol_get_full_name (vala_symbol_get_parent_symbol (self));
 	}
 	_tmp3 = NULL;
 	if ((_tmp4 = (_tmp3 = vala_symbol_get_full_name (vala_symbol_get_parent_symbol (self))) == NULL, (_tmp3 = (g_free (_tmp3), NULL)), _tmp4)) {
 		const char* _tmp5;
 		_tmp5 = NULL;
-		return (_tmp5 = vala_symbol_get_name (self), (_tmp5 == NULL ? NULL : g_strdup (_tmp5)));
+		return (_tmp5 = self->priv->_name, (_tmp5 == NULL ? NULL : g_strdup (_tmp5)));
 	}
 	_tmp7 = NULL;
 	_tmp8 = NULL;
-	return (_tmp8 = g_strdup_printf ("%s.%s", (_tmp7 = vala_symbol_get_full_name (vala_symbol_get_parent_symbol (self))), vala_symbol_get_name (self)), (_tmp7 = (g_free (_tmp7), NULL)), _tmp8);
+	return (_tmp8 = g_strdup_printf ("%s.%s", (_tmp7 = vala_symbol_get_full_name (vala_symbol_get_parent_symbol (self))), self->priv->_name), (_tmp7 = (g_free (_tmp7), NULL)), _tmp8);
 }
 
 
@@ -122,20 +129,18 @@ char* vala_symbol_get_full_name (ValaSymbol* self) {
  */
 static char* vala_symbol_real_get_cprefix (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), NULL);
-	if (vala_symbol_get_name (self) == NULL) {
+	if (self->priv->_name == NULL) {
 		return g_strdup ("");
 	} else {
 		const char* _tmp1;
 		_tmp1 = NULL;
-		return (_tmp1 = vala_symbol_get_name (self), (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
+		return (_tmp1 = self->priv->_name, (_tmp1 == NULL ? NULL : g_strdup (_tmp1)));
 	}
 }
 
 
 char* vala_symbol_get_cprefix (ValaSymbol* self) {
-	char* result;
-	result = VALA_SYMBOL_GET_CLASS (self)->get_cprefix (self);
-	return result;
+	return VALA_SYMBOL_GET_CLASS (self)->get_cprefix (self);
 }
 
 
@@ -155,9 +160,7 @@ static char* vala_symbol_real_get_lower_case_cname (ValaSymbol* self, const char
 
 
 char* vala_symbol_get_lower_case_cname (ValaSymbol* self, const char* infix) {
-	char* result;
-	result = VALA_SYMBOL_GET_CLASS (self)->get_lower_case_cname (self, infix);
-	return result;
+	return VALA_SYMBOL_GET_CLASS (self)->get_lower_case_cname (self, infix);
 }
 
 
@@ -174,9 +177,7 @@ static char* vala_symbol_real_get_lower_case_cprefix (ValaSymbol* self) {
 
 
 char* vala_symbol_get_lower_case_cprefix (ValaSymbol* self) {
-	char* result;
-	result = VALA_SYMBOL_GET_CLASS (self)->get_lower_case_cprefix (self);
-	return result;
+	return VALA_SYMBOL_GET_CLASS (self)->get_lower_case_cprefix (self);
 }
 
 
@@ -186,16 +187,14 @@ char* vala_symbol_get_lower_case_cprefix (ValaSymbol* self) {
  *
  * @return list of C header filenames for this symbol
  */
-static GeeCollection* vala_symbol_real_get_cheader_filenames (ValaSymbol* self) {
+static GeeList* vala_symbol_real_get_cheader_filenames (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (G_TYPE_STRING, ((GBoxedCopyFunc) g_strdup), g_free, NULL));
+	return GEE_LIST (gee_array_list_new (G_TYPE_STRING, ((GBoxedCopyFunc) (g_strdup)), g_free, g_direct_equal));
 }
 
 
-GeeCollection* vala_symbol_get_cheader_filenames (ValaSymbol* self) {
-	GeeCollection* result;
-	result = VALA_SYMBOL_GET_CLASS (self)->get_cheader_filenames (self);
-	return result;
+GeeList* vala_symbol_get_cheader_filenames (ValaSymbol* self) {
+	return VALA_SYMBOL_GET_CLASS (self)->get_cheader_filenames (self);
 }
 
 
@@ -211,6 +210,7 @@ char* vala_symbol_camel_case_to_lower_case (const char* camel_case) {
 	gboolean first;
 	const char* _tmp0;
 	char* _tmp1;
+	g_return_val_if_fail (camel_case != NULL, NULL);
 	result = g_string_new ("");
 	i = camel_case;
 	first = TRUE;
@@ -228,7 +228,7 @@ char* vala_symbol_camel_case_to_lower_case (const char* camel_case) {
 			t = g_utf8_next_char (i);
 			next_upper = g_unichar_isupper (g_utf8_get_char (t));
 			if (!prev_upper || (g_utf8_strlen (i, -1) >= 2 && !next_upper)) {
-				gint len;
+				glong len;
 				/* previous character wasn't upper case or
 				 * next character isn't upper case*/
 				len = g_utf8_strlen (result->str, -1);
@@ -248,6 +248,69 @@ char* vala_symbol_camel_case_to_lower_case (const char* camel_case) {
 }
 
 
+/**
+ * Converts a string from lower_case to CamelCase.
+ *
+ * @param lower_case a string in lower case
+ * @return           the specified string converted to camel case
+ */
+char* vala_symbol_lower_case_to_camel_case (const char* lower_case) {
+	GString* result;
+	const char* i;
+	gboolean last_underscore;
+	const char* _tmp0;
+	char* _tmp1;
+	g_return_val_if_fail (lower_case != NULL, NULL);
+	result = g_string_new ("");
+	i = lower_case;
+	last_underscore = TRUE;
+	while (g_utf8_strlen (i, -1) > 0) {
+		gunichar c;
+		c = g_utf8_get_char (i);
+		if (c == '_') {
+			last_underscore = TRUE;
+		} else {
+			if (last_underscore) {
+				g_string_append_unichar (result, g_unichar_toupper (c));
+				last_underscore = FALSE;
+			} else {
+				g_string_append_unichar (result, c);
+			}
+		}
+		i = g_utf8_next_char (i);
+	}
+	_tmp0 = NULL;
+	_tmp1 = NULL;
+	return (_tmp1 = (_tmp0 = result->str, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (result == NULL ? NULL : (result = (g_string_free (result, TRUE), NULL))), _tmp1);
+}
+
+
+/* get the top scope from where this symbol is still accessible*/
+ValaScope* vala_symbol_get_top_accessible_scope (ValaSymbol* self) {
+	g_return_val_if_fail (VALA_IS_SYMBOL (self), NULL);
+	if (self->priv->_access != VALA_SYMBOL_ACCESSIBILITY_PUBLIC) {
+		ValaScope* _tmp0;
+		ValaScope* scope;
+		/* private symbols are accessible within the scope where the symbol has been declared*/
+		_tmp0 = NULL;
+		scope = (_tmp0 = vala_symbol_get_owner (self), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+		while (scope != NULL && VALA_IS_NAMESPACE (vala_scope_get_owner (scope)) && vala_scope_get_owner (scope)->priv->_name != NULL) {
+			ValaScope* _tmp2;
+			ValaScope* _tmp1;
+			_tmp2 = NULL;
+			_tmp1 = NULL;
+			scope = (_tmp2 = (_tmp1 = vala_scope_get_parent_scope (scope), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (scope == NULL ? NULL : (scope = (g_object_unref (scope), NULL))), _tmp2);
+		}
+		return scope;
+	}
+	if (vala_symbol_get_parent_symbol (self) == NULL) {
+		return NULL;
+	}
+	/* if this is a public symbol, it's equally accessible as the parent symbol*/
+	return vala_symbol_get_top_accessible_scope (vala_symbol_get_parent_symbol (self));
+}
+
+
 ValaSymbol* vala_symbol_get_parent_symbol (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), NULL);
 	if (vala_symbol_get_owner (self) == NULL) {
@@ -271,7 +334,7 @@ void vala_symbol_set_owner (ValaSymbol* self, ValaScope* value) {
 }
 
 
-char* vala_symbol_get_name (ValaSymbol* self) {
+const char* vala_symbol_get_name (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), NULL);
 	return self->priv->_name;
 }
@@ -317,15 +380,21 @@ ValaScope* vala_symbol_get_scope (ValaSymbol* self) {
 }
 
 
-gboolean vala_symbol_get_is_imported (ValaSymbol* self) {
+gboolean vala_symbol_get_external (ValaSymbol* self) {
 	g_return_val_if_fail (VALA_IS_SYMBOL (self), FALSE);
-	return self->priv->_is_imported;
+	return self->priv->_external || (vala_symbol_get_parent_symbol (self) != NULL && vala_symbol_get_external (vala_symbol_get_parent_symbol (self))) || vala_symbol_get_external_package (self);
 }
 
 
-void vala_symbol_set_is_imported (ValaSymbol* self, gboolean value) {
+void vala_symbol_set_external (ValaSymbol* self, gboolean value) {
 	g_return_if_fail (VALA_IS_SYMBOL (self));
-	self->priv->_is_imported = value;
+	self->priv->_external = value;
+}
+
+
+gboolean vala_symbol_get_external_package (ValaSymbol* self) {
+	g_return_val_if_fail (VALA_IS_SYMBOL (self), FALSE);
+	return (vala_code_node_get_source_reference (VALA_CODE_NODE (self)) != NULL && vala_source_file_get_external_package (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self)))));
 }
 
 
@@ -365,13 +434,16 @@ static void vala_symbol_get_property (GObject * object, guint property_id, GValu
 		g_value_set_boolean (value, vala_symbol_get_active (self));
 		break;
 		case VALA_SYMBOL_ACCESS:
-		g_value_set_int (value, vala_symbol_get_access (self));
+		g_value_set_enum (value, vala_symbol_get_access (self));
 		break;
 		case VALA_SYMBOL_SCOPE:
 		g_value_set_object (value, vala_symbol_get_scope (self));
 		break;
-		case VALA_SYMBOL_IS_IMPORTED:
-		g_value_set_boolean (value, vala_symbol_get_is_imported (self));
+		case VALA_SYMBOL_EXTERNAL:
+		g_value_set_boolean (value, vala_symbol_get_external (self));
+		break;
+		case VALA_SYMBOL_EXTERNAL_PACKAGE:
+		g_value_set_boolean (value, vala_symbol_get_external_package (self));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -394,10 +466,10 @@ static void vala_symbol_set_property (GObject * object, guint property_id, const
 		vala_symbol_set_active (self, g_value_get_boolean (value));
 		break;
 		case VALA_SYMBOL_ACCESS:
-		vala_symbol_set_access (self, g_value_get_int (value));
+		vala_symbol_set_access (self, g_value_get_enum (value));
 		break;
-		case VALA_SYMBOL_IS_IMPORTED:
-		vala_symbol_set_is_imported (self, g_value_get_boolean (value));
+		case VALA_SYMBOL_EXTERNAL:
+		vala_symbol_set_external (self, g_value_get_boolean (value));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -421,13 +493,14 @@ static void vala_symbol_class_init (ValaSymbolClass * klass) {
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_OWNER, g_param_spec_object ("owner", "owner", "owner", VALA_TYPE_SCOPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_ACTIVE, g_param_spec_boolean ("active", "active", "active", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_ACCESS, g_param_spec_int ("access", "access", "access", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_ACCESS, g_param_spec_enum ("access", "access", "access", VALA_TYPE_SYMBOL_ACCESSIBILITY, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_SCOPE, g_param_spec_object ("scope", "scope", "scope", VALA_TYPE_SCOPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_IS_IMPORTED, g_param_spec_boolean ("is-imported", "is-imported", "is-imported", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_EXTERNAL, g_param_spec_boolean ("external", "external", "external", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_SYMBOL_EXTERNAL_PACKAGE, g_param_spec_boolean ("external-package", "external-package", "external-package", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
 }
 
 
-static void vala_symbol_init (ValaSymbol * self) {
+static void vala_symbol_instance_init (ValaSymbol * self) {
 	self->priv = VALA_SYMBOL_GET_PRIVATE (self);
 }
 
@@ -435,7 +508,7 @@ static void vala_symbol_init (ValaSymbol * self) {
 static void vala_symbol_dispose (GObject * obj) {
 	ValaSymbol * self;
 	self = VALA_SYMBOL (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
+	self->priv->_name = (g_free (self->priv->_name), NULL);
 	(self->priv->_scope == NULL ? NULL : (self->priv->_scope = (g_object_unref (self->priv->_scope), NULL)));
 	G_OBJECT_CLASS (vala_symbol_parent_class)->dispose (obj);
 }
@@ -444,7 +517,7 @@ static void vala_symbol_dispose (GObject * obj) {
 GType vala_symbol_get_type (void) {
 	static GType vala_symbol_type_id = 0;
 	if (G_UNLIKELY (vala_symbol_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaSymbolClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_symbol_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSymbol), 0, (GInstanceInitFunc) vala_symbol_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaSymbolClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_symbol_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaSymbol), 0, (GInstanceInitFunc) vala_symbol_instance_init };
 		vala_symbol_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaSymbol", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
 	}
 	return vala_symbol_type_id;
@@ -452,4 +525,15 @@ GType vala_symbol_get_type (void) {
 
 
 
+GType vala_symbol_accessibility_get_type (void) {
+	static GType vala_symbol_accessibility_type_id = 0;
+	if (G_UNLIKELY (vala_symbol_accessibility_type_id == 0)) {
+		static const GEnumValue values[] = {{VALA_SYMBOL_ACCESSIBILITY_PRIVATE, "VALA_SYMBOL_ACCESSIBILITY_PRIVATE", "private"}, {VALA_SYMBOL_ACCESSIBILITY_INTERNAL, "VALA_SYMBOL_ACCESSIBILITY_INTERNAL", "internal"}, {VALA_SYMBOL_ACCESSIBILITY_PROTECTED, "VALA_SYMBOL_ACCESSIBILITY_PROTECTED", "protected"}, {VALA_SYMBOL_ACCESSIBILITY_PUBLIC, "VALA_SYMBOL_ACCESSIBILITY_PUBLIC", "public"}, {0, NULL, NULL}};
+		vala_symbol_accessibility_type_id = g_enum_register_static ("ValaSymbolAccessibility", values);
+	}
+	return vala_symbol_accessibility_type_id;
+}
+
+
+
 
