@@ -27,7 +27,7 @@
 #include <glib-object.h>
 #include <stdlib.h>
 #include <string.h>
-#include <gee/collection.h>
+#include <gee/list.h>
 #include <vala/valacodenode.h>
 
 G_BEGIN_DECLS
@@ -51,14 +51,15 @@ struct _ValaSymbol {
 	ValaCodeNode parent_instance;
 	ValaSymbolPrivate * priv;
 };
+
 struct _ValaSymbolClass {
 	ValaCodeNodeClass parent_class;
 	char* (*get_cprefix) (ValaSymbol* self);
 	char* (*get_lower_case_cname) (ValaSymbol* self, const char* infix);
 	char* (*get_lower_case_cprefix) (ValaSymbol* self);
-	GeeCollection* (*get_cheader_filenames) (ValaSymbol* self);
+	GeeList* (*get_cheader_filenames) (ValaSymbol* self);
 };
-/* if this is a public symbol, it's equally accessible as the parent symbol*/
+
 typedef enum  {
 	VALA_SYMBOL_ACCESSIBILITY_PRIVATE,
 	VALA_SYMBOL_ACCESSIBILITY_INTERNAL,
@@ -72,21 +73,23 @@ char* vala_symbol_get_full_name (ValaSymbol* self);
 char* vala_symbol_get_cprefix (ValaSymbol* self);
 char* vala_symbol_get_lower_case_cname (ValaSymbol* self, const char* infix);
 char* vala_symbol_get_lower_case_cprefix (ValaSymbol* self);
-GeeCollection* vala_symbol_get_cheader_filenames (ValaSymbol* self);
+GeeList* vala_symbol_get_cheader_filenames (ValaSymbol* self);
 char* vala_symbol_camel_case_to_lower_case (const char* camel_case);
+char* vala_symbol_lower_case_to_camel_case (const char* lower_case);
 ValaScope* vala_symbol_get_top_accessible_scope (ValaSymbol* self);
 ValaSymbol* vala_symbol_get_parent_symbol (ValaSymbol* self);
 ValaScope* vala_symbol_get_owner (ValaSymbol* self);
 void vala_symbol_set_owner (ValaSymbol* self, ValaScope* value);
-char* vala_symbol_get_name (ValaSymbol* self);
+const char* vala_symbol_get_name (ValaSymbol* self);
 void vala_symbol_set_name (ValaSymbol* self, const char* value);
 gboolean vala_symbol_get_active (ValaSymbol* self);
 void vala_symbol_set_active (ValaSymbol* self, gboolean value);
 ValaSymbolAccessibility vala_symbol_get_access (ValaSymbol* self);
 void vala_symbol_set_access (ValaSymbol* self, ValaSymbolAccessibility value);
 ValaScope* vala_symbol_get_scope (ValaSymbol* self);
-gboolean vala_symbol_get_is_imported (ValaSymbol* self);
-void vala_symbol_set_is_imported (ValaSymbol* self, gboolean value);
+gboolean vala_symbol_get_external (ValaSymbol* self);
+void vala_symbol_set_external (ValaSymbol* self, gboolean value);
+gboolean vala_symbol_get_external_package (ValaSymbol* self);
 GType vala_symbol_get_type (void);
 GType vala_symbol_accessibility_get_type (void);
 
