@@ -1,6 +1,6 @@
 /* valathrowstatement.vala
  *
- * Copyright (C) 2007  Jürg Billeter
+ * Copyright (C) 2007-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,13 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaThrowStatementPrivate {
 	ValaExpression* _error_expression;
 };
+
 #define VALA_THROW_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_THROW_STATEMENT, ValaThrowStatementPrivate))
 enum  {
 	VALA_THROW_STATEMENT_DUMMY_PROPERTY,
@@ -41,6 +45,7 @@ static ValaStatementIface* vala_throw_statement_vala_statement_parent_iface = NU
 static void vala_throw_statement_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new throw statement.
  *
@@ -50,11 +55,11 @@ static void vala_throw_statement_dispose (GObject * obj);
  */
 ValaThrowStatement* vala_throw_statement_new (ValaExpression* error_expression, ValaSourceReference* source_reference) {
 	ValaThrowStatement * self;
-	g_return_val_if_fail (error_expression == NULL || VALA_IS_EXPRESSION (error_expression), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (error_expression), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_THROW_STATEMENT, 0, NULL);
-	vala_throw_statement_set_error_expression (self, error_expression);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
+	vala_throw_statement_set_error_expression (self, error_expression);
 	return self;
 }
 
@@ -62,7 +67,7 @@ ValaThrowStatement* vala_throw_statement_new (ValaExpression* error_expression,
 static void vala_throw_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaThrowStatement * self;
 	self = VALA_THROW_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_throw_statement (visitor, self);
 }
 
@@ -70,9 +75,10 @@ static void vala_throw_statement_real_accept (ValaCodeNode* base, ValaCodeVisito
 static void vala_throw_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaThrowStatement * self;
 	self = VALA_THROW_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	if (vala_throw_statement_get_error_expression (self) != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (vala_throw_statement_get_error_expression (self)), visitor);
+		vala_code_visitor_visit_end_full_expression (visitor, vala_throw_statement_get_error_expression (self));
 	}
 }
 
@@ -80,8 +86,8 @@ static void vala_throw_statement_real_accept_children (ValaCodeNode* base, ValaC
 static void vala_throw_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaThrowStatement * self;
 	self = VALA_THROW_STATEMENT (base);
-	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
 	if (vala_throw_statement_get_error_expression (self) == old_node) {
 		vala_throw_statement_set_error_expression (self, new_node);
 	}
@@ -153,7 +159,7 @@ static void vala_throw_statement_vala_statement_interface_init (ValaStatementIfa
 }
 
 
-static void vala_throw_statement_init (ValaThrowStatement * self) {
+static void vala_throw_statement_instance_init (ValaThrowStatement * self) {
 	self->priv = VALA_THROW_STATEMENT_GET_PRIVATE (self);
 }
 
@@ -169,7 +175,7 @@ static void vala_throw_statement_dispose (GObject * obj) {
 GType vala_throw_statement_get_type (void) {
 	static GType vala_throw_statement_type_id = 0;
 	if (G_UNLIKELY (vala_throw_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaThrowStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_throw_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaThrowStatement), 0, (GInstanceInitFunc) vala_throw_statement_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaThrowStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_throw_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaThrowStatement), 0, (GInstanceInitFunc) vala_throw_statement_instance_init };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_throw_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_throw_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaThrowStatement", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_throw_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
