@@ -31,6 +31,7 @@
 struct _ValaTypeParameterPrivate {
 	GeeMap* array_types;
 };
+
 #define VALA_TYPEPARAMETER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_TYPEPARAMETER, ValaTypeParameterPrivate))
 enum  {
 	VALA_TYPEPARAMETER_DUMMY_PROPERTY
@@ -50,7 +51,8 @@ static void vala_typeparameter_dispose (GObject * obj);
  */
 ValaTypeParameter* vala_typeparameter_new (const char* _name, ValaSourceReference* source) {
 	ValaTypeParameter * self;
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
+	g_return_val_if_fail (_name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
 	self = g_object_newv (VALA_TYPE_TYPEPARAMETER, 0, NULL);
 	vala_symbol_set_name (VALA_SYMBOL (self), _name);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
@@ -61,7 +63,7 @@ ValaTypeParameter* vala_typeparameter_new (const char* _name, ValaSourceReferenc
 static void vala_typeparameter_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaTypeParameter * self;
 	self = VALA_TYPEPARAMETER (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_type_parameter (visitor, self);
 }
 
@@ -75,7 +77,11 @@ static void vala_typeparameter_real_accept (ValaCodeNode* base, ValaCodeVisitor*
  */
 gboolean vala_typeparameter_equals (ValaTypeParameter* self, ValaTypeParameter* param2) {
 	g_return_val_if_fail (VALA_IS_TYPEPARAMETER (self), FALSE);
-	g_return_val_if_fail (param2 == NULL || VALA_IS_TYPEPARAMETER (param2), FALSE);
+	g_return_val_if_fail (VALA_IS_TYPEPARAMETER (param2), FALSE);
+	/* FIXME check whether the corresponding data type of one of the
+	       parameters is a base type of the corresponding data
+	       type of the other parameter and check along the path
+	       whether one parameter maps to the other*/
 	return TRUE;
 }
 
@@ -88,7 +94,7 @@ static void vala_typeparameter_class_init (ValaTypeParameterClass * klass) {
 }
 
 
-static void vala_typeparameter_init (ValaTypeParameter * self) {
+static void vala_typeparameter_instance_init (ValaTypeParameter * self) {
 	self->priv = VALA_TYPEPARAMETER_GET_PRIVATE (self);
 }
 
@@ -104,7 +110,7 @@ static void vala_typeparameter_dispose (GObject * obj) {
 GType vala_typeparameter_get_type (void) {
 	static GType vala_typeparameter_type_id = 0;
 	if (G_UNLIKELY (vala_typeparameter_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaTypeParameterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_typeparameter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaTypeParameter), 0, (GInstanceInitFunc) vala_typeparameter_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaTypeParameterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_typeparameter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaTypeParameter), 0, (GInstanceInitFunc) vala_typeparameter_instance_init };
 		vala_typeparameter_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaTypeParameter", &g_define_type_info, 0);
 	}
 	return vala_typeparameter_type_id;
