@@ -1,6 +1,6 @@
 /* valatypeparameter.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -29,6 +29,7 @@
 #include <string.h>
 #include <vala/valasymbol.h>
 #include <vala/valacodenode.h>
+#include <vala/valatypesymbol.h>
 
 G_BEGIN_DECLS
 
@@ -48,17 +49,19 @@ typedef struct _ValaTypeParameterPrivate ValaTypeParameterPrivate;
 struct _ValaTypeParameter {
 	ValaSymbol parent_instance;
 	ValaTypeParameterPrivate * priv;
-	ValaTypesymbol* type;
+	ValaTypeSymbol* type;
 };
+
 struct _ValaTypeParameterClass {
 	ValaSymbolClass parent_class;
 };
 
+
 ValaTypeParameter* vala_typeparameter_new (const char* _name, ValaSourceReference* source);
-ValaArray* vala_typeparameter_get_array (ValaTypeParameter* self, gint rank);
 gboolean vala_typeparameter_equals (ValaTypeParameter* self, ValaTypeParameter* param2);
 GType vala_typeparameter_get_type (void);
 
+
 G_END_DECLS
 
 #endif
