@@ -32,6 +32,7 @@
 #include <vala/valaunresolvedsymbol.h>
 #include <vala/valasourcereference.h>
 #include <vala/valaexpression.h>
+#include <vala/valascope.h>
 
 G_BEGIN_DECLS
 
@@ -65,12 +66,6 @@ ValaUnresolvedType* vala_unresolved_type_new_from_symbol (ValaUnresolvedSymbol*
 ValaUnresolvedType* vala_unresolved_type_new_from_expression (ValaExpression* expr);
 ValaUnresolvedSymbol* vala_unresolved_type_get_unresolved_symbol (ValaUnresolvedType* self);
 void vala_unresolved_type_set_unresolved_symbol (ValaUnresolvedType* self, ValaUnresolvedSymbol* value);
-gint vala_unresolved_type_get_array_rank (ValaUnresolvedType* self);
-void vala_unresolved_type_set_array_rank (ValaUnresolvedType* self, gint value);
-gint vala_unresolved_type_get_pointer_level (ValaUnresolvedType* self);
-void vala_unresolved_type_set_pointer_level (ValaUnresolvedType* self, gint value);
-gboolean vala_unresolved_type_get_is_weak (ValaUnresolvedType* self);
-void vala_unresolved_type_set_is_weak (ValaUnresolvedType* self, gboolean value);
 GType vala_unresolved_type_get_type (void);
 
 
