@@ -57,9 +57,9 @@ struct _ValaValueTypeClass {
 };
 
 
-ValaValueType* vala_value_type_new (ValaTypesymbol* type_symbol);
-ValaTypesymbol* vala_value_type_get_type_symbol (ValaValueType* self);
-void vala_value_type_set_type_symbol (ValaValueType* self, ValaTypesymbol* value);
+ValaValueType* vala_value_type_new (ValaTypeSymbol* type_symbol);
+ValaTypeSymbol* vala_value_type_get_type_symbol (ValaValueType* self);
+void vala_value_type_set_type_symbol (ValaValueType* self, ValaTypeSymbol* value);
 GType vala_value_type_get_type (void);
 
 
