@@ -33,6 +33,7 @@ struct _ValaWhileStatementPrivate {
 	ValaExpression* _condition;
 	ValaBlock* _body;
 };
+
 #define VALA_WHILE_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_WHILE_STATEMENT, ValaWhileStatementPrivate))
 enum  {
 	VALA_WHILE_STATEMENT_DUMMY_PROPERTY,
@@ -60,8 +61,8 @@ ValaWhileStatement* vala_while_statement_new (ValaExpression* condition, ValaBlo
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaWhileStatement * self;
-	g_return_val_if_fail (condition == NULL || VALA_IS_EXPRESSION (condition), NULL);
-	g_return_val_if_fail (body == NULL || VALA_IS_BLOCK (body), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (condition), NULL);
+	g_return_val_if_fail (VALA_IS_BLOCK (body), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
@@ -84,7 +85,7 @@ ValaWhileStatement* vala_while_statement_new (ValaExpression* condition, ValaBlo
 static void vala_while_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaWhileStatement * self;
 	self = VALA_WHILE_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_while_statement (visitor, self);
 }
 
@@ -92,7 +93,7 @@ static void vala_while_statement_real_accept (ValaCodeNode* base, ValaCodeVisito
 static void vala_while_statement_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaWhileStatement * self;
 	self = VALA_WHILE_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_while_statement_get_condition (self)), visitor);
 	vala_code_visitor_visit_end_full_expression (visitor, vala_while_statement_get_condition (self));
 	vala_code_node_accept (VALA_CODE_NODE (vala_while_statement_get_body (self)), visitor);
@@ -102,8 +103,8 @@ static void vala_while_statement_real_accept_children (ValaCodeNode* base, ValaC
 static void vala_while_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaWhileStatement * self;
 	self = VALA_WHILE_STATEMENT (base);
-	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
 	if (vala_while_statement_get_condition (self) == old_node) {
 		vala_while_statement_set_condition (self, new_node);
 	}
@@ -197,7 +198,7 @@ static void vala_while_statement_vala_statement_interface_init (ValaStatementIfa
 }
 
 
-static void vala_while_statement_init (ValaWhileStatement * self) {
+static void vala_while_statement_instance_init (ValaWhileStatement * self) {
 	self->priv = VALA_WHILE_STATEMENT_GET_PRIVATE (self);
 }
 
@@ -214,7 +215,7 @@ static void vala_while_statement_dispose (GObject * obj) {
 GType vala_while_statement_get_type (void) {
 	static GType vala_while_statement_type_id = 0;
 	if (G_UNLIKELY (vala_while_statement_type_id == 0)) {
-		static const GTypeInfo g_define_type_info = { sizeof (ValaWhileStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_while_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaWhileStatement), 0, (GInstanceInitFunc) vala_while_statement_init };
+		static const GTypeInfo g_define_type_info = { sizeof (ValaWhileStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_while_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaWhileStatement), 0, (GInstanceInitFunc) vala_while_statement_instance_init };
 		static const GInterfaceInfo vala_statement_info = { (GInterfaceInitFunc) vala_while_statement_vala_statement_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
 		vala_while_statement_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaWhileStatement", &g_define_type_info, 0);
 		g_type_add_interface_static (vala_while_statement_type_id, VALA_TYPE_STATEMENT, &vala_statement_info);
