@@ -163,8 +163,10 @@ static char** vala_vapi_gen_get_packages_from_depsfile (const char* depsfile, in
 		inner_error = NULL;
 		{
 			gpointer _tmp5;
+			char** _tmp6;
 			/* deps files are optional*/
-			return (_tmp5 = NULL, (*result_length1) = 0, _tmp5);
+			_tmp6 = NULL;
+			return (_tmp6 = (_tmp5 = NULL, (*result_length1) = 0, _tmp5), (e == NULL ? NULL : (e = (g_error_free (e), NULL))), _tmp6);
 		}
 	}
 	__finally2:
@@ -380,9 +382,10 @@ static gint vala_vapi_gen_main (char** args, int args_length1) {
 		e = inner_error;
 		inner_error = NULL;
 		{
+			gint _tmp0;
 			fprintf (stdout, "%s\n", e->message);
 			fprintf (stdout, "Run '%s --help' to see a full list of available command line options.\n", args[0]);
-			return 1;
+			return (_tmp0 = 1, (e == NULL ? NULL : (e = (g_error_free (e), NULL))), _tmp0);
 		}
 	}
 	__finally3:
